@@ -45,7 +45,7 @@ enum  {
 };
 static void vala_ccode_block_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
 static gpointer vala_ccode_block_parent_class = NULL;
-static void vala_ccode_block_dispose (GObject * obj);
+static void vala_ccode_block_finalize (GObject * obj);
 
 
 
@@ -80,12 +80,11 @@ static void vala_ccode_block_real_write (ValaCCodeNode* base, ValaCCodeWriter* w
 	vala_ccode_writer_write_begin_block (writer);
 	{
 		GeeList* statement_collection;
-		GeeIterator* statement_it;
+		int statement_it;
 		statement_collection = self->priv->statements;
-		statement_it = gee_iterable_iterator (GEE_ITERABLE (statement_collection));
-		while (gee_iterator_next (statement_it)) {
+		for (statement_it = 0; statement_it < gee_collection_get_size (GEE_COLLECTION (statement_collection)); statement_it = statement_it + 1) {
 			ValaCCodeNode* statement;
-			statement = ((ValaCCodeNode*) gee_iterator_get (statement_it));
+			statement = ((ValaCCodeNode*) (gee_list_get (GEE_LIST (statement_collection), statement_it)));
 			{
 				vala_ccode_node_write_declaration (statement, writer);
 				/* determine last reachable statement*/
@@ -105,16 +104,14 @@ static void vala_ccode_block_real_write (ValaCCodeNode* base, ValaCCodeWriter* w
 				(statement == NULL ? NULL : (statement = (g_object_unref (statement), NULL)));
 			}
 		}
-		(statement_it == NULL ? NULL : (statement_it = (g_object_unref (statement_it), NULL)));
 	}
 	{
 		GeeList* statement_collection;
-		GeeIterator* statement_it;
+		int statement_it;
 		statement_collection = self->priv->statements;
-		statement_it = gee_iterable_iterator (GEE_ITERABLE (statement_collection));
-		while (gee_iterator_next (statement_it)) {
+		for (statement_it = 0; statement_it < gee_collection_get_size (GEE_COLLECTION (statement_collection)); statement_it = statement_it + 1) {
 			ValaCCodeNode* statement;
-			statement = ((ValaCCodeNode*) gee_iterator_get (statement_it));
+			statement = ((ValaCCodeNode*) (gee_list_get (GEE_LIST (statement_collection), statement_it)));
 			{
 				vala_ccode_node_write (statement, writer);
 				/* only output reachable code*/
@@ -125,7 +122,6 @@ static void vala_ccode_block_real_write (ValaCCodeNode* base, ValaCCodeWriter* w
 				(statement == NULL ? NULL : (statement = (g_object_unref (statement), NULL)));
 			}
 		}
-		(statement_it == NULL ? NULL : (statement_it = (g_object_unref (statement_it), NULL)));
 	}
 	vala_ccode_writer_write_end_block (writer);
 	if (!self->priv->_suppress_newline) {
@@ -154,6 +150,7 @@ gboolean vala_ccode_block_get_suppress_newline (ValaCCodeBlock* self) {
 void vala_ccode_block_set_suppress_newline (ValaCCodeBlock* self, gboolean value) {
 	g_return_if_fail (VALA_IS_CCODE_BLOCK (self));
 	self->priv->_suppress_newline = value;
+	g_object_notify (((GObject *) (self)), "suppress-newline");
 }
 
 
@@ -190,30 +187,30 @@ static void vala_ccode_block_class_init (ValaCCodeBlockClass * klass) {
 	g_type_class_add_private (klass, sizeof (ValaCCodeBlockPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_ccode_block_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_ccode_block_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_ccode_block_dispose;
+	G_OBJECT_CLASS (klass)->finalize = vala_ccode_block_finalize;
 	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_block_real_write;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_BLOCK_SUPPRESS_NEWLINE, g_param_spec_boolean ("suppress-newline", "suppress-newline", "suppress-newline", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
-static void vala_ccode_block_init (ValaCCodeBlock * self) {
+static void vala_ccode_block_instance_init (ValaCCodeBlock * self) {
 	self->priv = VALA_CCODE_BLOCK_GET_PRIVATE (self);
-	self->priv->statements = GEE_LIST (gee_array_list_new (VALA_TYPE_CCODE_NODE, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
+	self->priv->statements = GEE_LIST (gee_array_list_new (VALA_TYPE_CCODE_NODE, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
 }
 
 
-static void vala_ccode_block_dispose (GObject * obj) {
+static void vala_ccode_block_finalize (GObject * obj) {
 	ValaCCodeBlock * self;
 	self = VALA_CCODE_BLOCK (obj);
 	(self->priv->statements == NULL ? NULL : (self->priv->statements = (g_object_unref (self->priv->statements), NULL)));
-	G_OBJECT_CLASS (vala_ccode_block_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (vala_ccode_block_parent_class)->finalize (obj);
 }
 
 
 GType vala_ccode_block_get_type (void) {
 	static GType vala_ccode_block_type_id = 0;
-	if (G_UNLIKELY (vala_ccode_block_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeBlockClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_block_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeBlock), 0, (GInstanceInitFunc) vala_ccode_block_init };
+	if (vala_ccode_block_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeBlockClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_block_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeBlock), 0, (GInstanceInitFunc) vala_ccode_block_instance_init };
 		vala_ccode_block_type_id = g_type_register_static (VALA_TYPE_CCODE_STATEMENT, "ValaCCodeBlock", &g_define_type_info, 0);
 	}
 	return vala_ccode_block_type_id;
