@@ -39,7 +39,7 @@ enum  {
 };
 static void vala_ccode_cast_expression_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
 static gpointer vala_ccode_cast_expression_parent_class = NULL;
-static void vala_ccode_cast_expression_dispose (GObject * obj);
+static void vala_ccode_cast_expression_finalize (GObject * obj);
 
 
 
@@ -95,6 +95,7 @@ void vala_ccode_cast_expression_set_inner (ValaCCodeCastExpression* self, ValaCC
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_inner = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "inner");
 }
 
 
@@ -111,6 +112,7 @@ void vala_ccode_cast_expression_set_type_name (ValaCCodeCastExpression* self, co
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_type_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_type_name = (g_free (self->priv->_type_name), NULL)), _tmp2);
+	g_object_notify (((GObject *) (self)), "type-name");
 }
 
 
@@ -153,7 +155,7 @@ static void vala_ccode_cast_expression_class_init (ValaCCodeCastExpressionClass
 	g_type_class_add_private (klass, sizeof (ValaCCodeCastExpressionPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_ccode_cast_expression_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_ccode_cast_expression_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_ccode_cast_expression_dispose;
+	G_OBJECT_CLASS (klass)->finalize = vala_ccode_cast_expression_finalize;
 	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_cast_expression_real_write;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_CAST_EXPRESSION_INNER, g_param_spec_object ("inner", "inner", "inner", VALA_TYPE_CCODE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_CAST_EXPRESSION_TYPE_NAME, g_param_spec_string ("type-name", "type-name", "type-name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
@@ -165,18 +167,18 @@ static void vala_ccode_cast_expression_instance_init (ValaCCodeCastExpression *
 }
 
 
-static void vala_ccode_cast_expression_dispose (GObject * obj) {
+static void vala_ccode_cast_expression_finalize (GObject * obj) {
 	ValaCCodeCastExpression * self;
 	self = VALA_CCODE_CAST_EXPRESSION (obj);
 	(self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL)));
 	self->priv->_type_name = (g_free (self->priv->_type_name), NULL);
-	G_OBJECT_CLASS (vala_ccode_cast_expression_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (vala_ccode_cast_expression_parent_class)->finalize (obj);
 }
 
 
 GType vala_ccode_cast_expression_get_type (void) {
 	static GType vala_ccode_cast_expression_type_id = 0;
-	if (G_UNLIKELY (vala_ccode_cast_expression_type_id == 0)) {
+	if (vala_ccode_cast_expression_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeCastExpressionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_cast_expression_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeCastExpression), 0, (GInstanceInitFunc) vala_ccode_cast_expression_instance_init };
 		vala_ccode_cast_expression_type_id = g_type_register_static (VALA_TYPE_CCODE_EXPRESSION, "ValaCCodeCastExpression", &g_define_type_info, 0);
 	}
