@@ -36,7 +36,7 @@ enum  {
 };
 static void vala_ccode_constant_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
 static gpointer vala_ccode_constant_parent_class = NULL;
-static void vala_ccode_constant_dispose (GObject * obj);
+static void vala_ccode_constant_finalize (GObject * obj);
 
 
 
@@ -82,6 +82,7 @@ void vala_ccode_constant_set_name (ValaCCodeConstant* self, const char* value) {
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_name = (g_free (self->priv->_name), NULL)), _tmp2);
+	g_object_notify (((GObject *) (self)), "name");
 }
 
 
@@ -118,7 +119,7 @@ static void vala_ccode_constant_class_init (ValaCCodeConstantClass * klass) {
 	g_type_class_add_private (klass, sizeof (ValaCCodeConstantPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_ccode_constant_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_ccode_constant_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_ccode_constant_dispose;
+	G_OBJECT_CLASS (klass)->finalize = vala_ccode_constant_finalize;
 	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_constant_real_write;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_CONSTANT_NAME, g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
 }
@@ -129,17 +130,17 @@ static void vala_ccode_constant_instance_init (ValaCCodeConstant * self) {
 }
 
 
-static void vala_ccode_constant_dispose (GObject * obj) {
+static void vala_ccode_constant_finalize (GObject * obj) {
 	ValaCCodeConstant * self;
 	self = VALA_CCODE_CONSTANT (obj);
 	self->priv->_name = (g_free (self->priv->_name), NULL);
-	G_OBJECT_CLASS (vala_ccode_constant_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (vala_ccode_constant_parent_class)->finalize (obj);
 }
 
 
 GType vala_ccode_constant_get_type (void) {
 	static GType vala_ccode_constant_type_id = 0;
-	if (G_UNLIKELY (vala_ccode_constant_type_id == 0)) {
+	if (vala_ccode_constant_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeConstantClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_constant_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeConstant), 0, (GInstanceInitFunc) vala_ccode_constant_instance_init };
 		vala_ccode_constant_type_id = g_type_register_static (VALA_TYPE_CCODE_EXPRESSION, "ValaCCodeConstant", &g_define_type_info, 0);
 	}
