@@ -34,6 +34,7 @@ struct _ValaCCodeDoStatementPrivate {
 	ValaCCodeStatement* _body;
 	ValaCCodeExpression* _condition;
 };
+
 #define VALA_CCODE_DO_STATEMENT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_DO_STATEMENT, ValaCCodeDoStatementPrivate))
 enum  {
 	VALA_CCODE_DO_STATEMENT_DUMMY_PROPERTY,
@@ -42,7 +43,7 @@ enum  {
 };
 static void vala_ccode_do_statement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
 static gpointer vala_ccode_do_statement_parent_class = NULL;
-static void vala_ccode_do_statement_dispose (GObject * obj);
+static void vala_ccode_do_statement_finalize (GObject * obj);
 
 
 
@@ -50,8 +51,8 @@ ValaCCodeDoStatement* vala_ccode_do_statement_new (ValaCCodeStatement* stmt, Val
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaCCodeDoStatement * self;
-	g_return_val_if_fail (stmt == NULL || VALA_IS_CCODE_STATEMENT (stmt), NULL);
-	g_return_val_if_fail (cond == NULL || VALA_IS_CCODE_EXPRESSION (cond), NULL);
+	g_return_val_if_fail (VALA_IS_CCODE_STATEMENT (stmt), NULL);
+	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (cond), NULL);
 	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
 	__params_it->name = "condition";
@@ -72,7 +73,7 @@ ValaCCodeDoStatement* vala_ccode_do_statement_new (ValaCCodeStatement* stmt, Val
 static void vala_ccode_do_statement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeDoStatement * self;
 	self = VALA_CCODE_DO_STATEMENT (base);
-	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
+	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_indent (writer, vala_ccode_node_get_line (VALA_CCODE_NODE (self)));
 	vala_ccode_writer_write_string (writer, "do");
 	/* while shouldn't be on a separate line */
@@ -104,6 +105,7 @@ void vala_ccode_do_statement_set_body (ValaCCodeDoStatement* self, ValaCCodeStat
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_body = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "body");
 }
 
 
@@ -120,6 +122,7 @@ void vala_ccode_do_statement_set_condition (ValaCCodeDoStatement* self, ValaCCod
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_condition = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_condition == NULL ? NULL : (self->priv->_condition = (g_object_unref (self->priv->_condition), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "condition");
 }
 
 
@@ -162,31 +165,31 @@ static void vala_ccode_do_statement_class_init (ValaCCodeDoStatementClass * klas
 	g_type_class_add_private (klass, sizeof (ValaCCodeDoStatementPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_ccode_do_statement_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_ccode_do_statement_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_ccode_do_statement_dispose;
+	G_OBJECT_CLASS (klass)->finalize = vala_ccode_do_statement_finalize;
 	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_do_statement_real_write;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_DO_STATEMENT_BODY, g_param_spec_object ("body", "body", "body", VALA_TYPE_CCODE_STATEMENT, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_DO_STATEMENT_CONDITION, g_param_spec_object ("condition", "condition", "condition", VALA_TYPE_CCODE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
 }
 
 
-static void vala_ccode_do_statement_init (ValaCCodeDoStatement * self) {
+static void vala_ccode_do_statement_instance_init (ValaCCodeDoStatement * self) {
 	self->priv = VALA_CCODE_DO_STATEMENT_GET_PRIVATE (self);
 }
 
 
-static void vala_ccode_do_statement_dispose (GObject * obj) {
+static void vala_ccode_do_statement_finalize (GObject * obj) {
 	ValaCCodeDoStatement * self;
 	self = VALA_CCODE_DO_STATEMENT (obj);
 	(self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL)));
 	(self->priv->_condition == NULL ? NULL : (self->priv->_condition = (g_object_unref (self->priv->_condition), NULL)));
-	G_OBJECT_CLASS (vala_ccode_do_statement_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (vala_ccode_do_statement_parent_class)->finalize (obj);
 }
 
 
 GType vala_ccode_do_statement_get_type (void) {
 	static GType vala_ccode_do_statement_type_id = 0;
-	if (G_UNLIKELY (vala_ccode_do_statement_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeDoStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_do_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeDoStatement), 0, (GInstanceInitFunc) vala_ccode_do_statement_init };
+	if (vala_ccode_do_statement_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeDoStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_do_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeDoStatement), 0, (GInstanceInitFunc) vala_ccode_do_statement_instance_init };
 		vala_ccode_do_statement_type_id = g_type_register_static (VALA_TYPE_CCODE_STATEMENT, "ValaCCodeDoStatement", &g_define_type_info, 0);
 	}
 	return vala_ccode_do_statement_type_id;
