@@ -38,7 +38,7 @@ enum  {
 };
 static void vala_ccode_enum_value_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
 static gpointer vala_ccode_enum_value_parent_class = NULL;
-static void vala_ccode_enum_value_dispose (GObject * obj);
+static void vala_ccode_enum_value_finalize (GObject * obj);
 
 
 
@@ -78,6 +78,7 @@ void vala_ccode_enum_value_set_name (ValaCCodeEnumValue* self, const char* value
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_name = (g_free (self->priv->_name), NULL)), _tmp2);
+	g_object_notify (((GObject *) (self)), "name");
 }
 
 
@@ -94,6 +95,7 @@ void vala_ccode_enum_value_set_value (ValaCCodeEnumValue* self, ValaCCodeExpress
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_value = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_value == NULL ? NULL : (self->priv->_value = (g_object_unref (self->priv->_value), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "value");
 }
 
 
@@ -136,7 +138,7 @@ static void vala_ccode_enum_value_class_init (ValaCCodeEnumValueClass * klass) {
 	g_type_class_add_private (klass, sizeof (ValaCCodeEnumValuePrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_ccode_enum_value_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_ccode_enum_value_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_ccode_enum_value_dispose;
+	G_OBJECT_CLASS (klass)->finalize = vala_ccode_enum_value_finalize;
 	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_enum_value_real_write;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_ENUM_VALUE_NAME, g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_ENUM_VALUE_VALUE, g_param_spec_object ("value", "value", "value", VALA_TYPE_CCODE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
@@ -148,18 +150,18 @@ static void vala_ccode_enum_value_instance_init (ValaCCodeEnumValue * self) {
 }
 
 
-static void vala_ccode_enum_value_dispose (GObject * obj) {
+static void vala_ccode_enum_value_finalize (GObject * obj) {
 	ValaCCodeEnumValue * self;
 	self = VALA_CCODE_ENUM_VALUE (obj);
 	self->priv->_name = (g_free (self->priv->_name), NULL);
 	(self->priv->_value == NULL ? NULL : (self->priv->_value = (g_object_unref (self->priv->_value), NULL)));
-	G_OBJECT_CLASS (vala_ccode_enum_value_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (vala_ccode_enum_value_parent_class)->finalize (obj);
 }
 
 
 GType vala_ccode_enum_value_get_type (void) {
 	static GType vala_ccode_enum_value_type_id = 0;
-	if (G_UNLIKELY (vala_ccode_enum_value_type_id == 0)) {
+	if (vala_ccode_enum_value_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeEnumValueClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_enum_value_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeEnumValue), 0, (GInstanceInitFunc) vala_ccode_enum_value_instance_init };
 		vala_ccode_enum_value_type_id = g_type_register_static (VALA_TYPE_CCODE_NODE, "ValaCCodeEnumValue", &g_define_type_info, 0);
 	}
