@@ -43,7 +43,7 @@ enum  {
 static void vala_ccode_expression_statement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
 static void vala_ccode_expression_statement_write_expression (ValaCCodeExpressionStatement* self, ValaCCodeWriter* writer, ValaCCodeExpression* expr);
 static gpointer vala_ccode_expression_statement_parent_class = NULL;
-static void vala_ccode_expression_statement_dispose (GObject * obj);
+static void vala_ccode_expression_statement_finalize (GObject * obj);
 
 
 
@@ -139,6 +139,7 @@ void vala_ccode_expression_statement_set_expression (ValaCCodeExpressionStatemen
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_expression = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_expression == NULL ? NULL : (self->priv->_expression = (g_object_unref (self->priv->_expression), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "expression");
 }
 
 
@@ -175,7 +176,7 @@ static void vala_ccode_expression_statement_class_init (ValaCCodeExpressionState
 	g_type_class_add_private (klass, sizeof (ValaCCodeExpressionStatementPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_ccode_expression_statement_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_ccode_expression_statement_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_ccode_expression_statement_dispose;
+	G_OBJECT_CLASS (klass)->finalize = vala_ccode_expression_statement_finalize;
 	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_expression_statement_real_write;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_EXPRESSION_STATEMENT_EXPRESSION, g_param_spec_object ("expression", "expression", "expression", VALA_TYPE_CCODE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
 }
@@ -186,17 +187,17 @@ static void vala_ccode_expression_statement_instance_init (ValaCCodeExpressionSt
 }
 
 
-static void vala_ccode_expression_statement_dispose (GObject * obj) {
+static void vala_ccode_expression_statement_finalize (GObject * obj) {
 	ValaCCodeExpressionStatement * self;
 	self = VALA_CCODE_EXPRESSION_STATEMENT (obj);
 	(self->priv->_expression == NULL ? NULL : (self->priv->_expression = (g_object_unref (self->priv->_expression), NULL)));
-	G_OBJECT_CLASS (vala_ccode_expression_statement_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (vala_ccode_expression_statement_parent_class)->finalize (obj);
 }
 
 
 GType vala_ccode_expression_statement_get_type (void) {
 	static GType vala_ccode_expression_statement_type_id = 0;
-	if (G_UNLIKELY (vala_ccode_expression_statement_type_id == 0)) {
+	if (vala_ccode_expression_statement_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeExpressionStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_expression_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeExpressionStatement), 0, (GInstanceInitFunc) vala_ccode_expression_statement_instance_init };
 		vala_ccode_expression_statement_type_id = g_type_register_static (VALA_TYPE_CCODE_STATEMENT, "ValaCCodeExpressionStatement", &g_define_type_info, 0);
 	}
