@@ -40,7 +40,7 @@ enum  {
 };
 static void vala_ccode_formal_parameter_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
 static gpointer vala_ccode_formal_parameter_parent_class = NULL;
-static void vala_ccode_formal_parameter_dispose (GObject * obj);
+static void vala_ccode_formal_parameter_finalize (GObject * obj);
 
 
 
@@ -90,6 +90,7 @@ void vala_ccode_formal_parameter_set_name (ValaCCodeFormalParameter* self, const
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_name = (g_free (self->priv->_name), NULL)), _tmp2);
+	g_object_notify (((GObject *) (self)), "name");
 }
 
 
@@ -106,6 +107,7 @@ void vala_ccode_formal_parameter_set_type_name (ValaCCodeFormalParameter* self,
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_type_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_type_name = (g_free (self->priv->_type_name), NULL)), _tmp2);
+	g_object_notify (((GObject *) (self)), "type-name");
 }
 
 
@@ -118,6 +120,7 @@ gboolean vala_ccode_formal_parameter_get_ellipsis (ValaCCodeFormalParameter* sel
 void vala_ccode_formal_parameter_set_ellipsis (ValaCCodeFormalParameter* self, gboolean value) {
 	g_return_if_fail (VALA_IS_CCODE_FORMAL_PARAMETER (self));
 	self->priv->_ellipsis = value;
+	g_object_notify (((GObject *) (self)), "ellipsis");
 }
 
 
@@ -166,7 +169,7 @@ static void vala_ccode_formal_parameter_class_init (ValaCCodeFormalParameterClas
 	g_type_class_add_private (klass, sizeof (ValaCCodeFormalParameterPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_ccode_formal_parameter_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_ccode_formal_parameter_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_ccode_formal_parameter_dispose;
+	G_OBJECT_CLASS (klass)->finalize = vala_ccode_formal_parameter_finalize;
 	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_formal_parameter_real_write;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_FORMAL_PARAMETER_NAME, g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_FORMAL_PARAMETER_TYPE_NAME, g_param_spec_string ("type-name", "type-name", "type-name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
@@ -179,18 +182,18 @@ static void vala_ccode_formal_parameter_instance_init (ValaCCodeFormalParameter
 }
 
 
-static void vala_ccode_formal_parameter_dispose (GObject * obj) {
+static void vala_ccode_formal_parameter_finalize (GObject * obj) {
 	ValaCCodeFormalParameter * self;
 	self = VALA_CCODE_FORMAL_PARAMETER (obj);
 	self->priv->_name = (g_free (self->priv->_name), NULL);
 	self->priv->_type_name = (g_free (self->priv->_type_name), NULL);
-	G_OBJECT_CLASS (vala_ccode_formal_parameter_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (vala_ccode_formal_parameter_parent_class)->finalize (obj);
 }
 
 
 GType vala_ccode_formal_parameter_get_type (void) {
 	static GType vala_ccode_formal_parameter_type_id = 0;
-	if (G_UNLIKELY (vala_ccode_formal_parameter_type_id == 0)) {
+	if (vala_ccode_formal_parameter_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeFormalParameterClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_formal_parameter_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeFormalParameter), 0, (GInstanceInitFunc) vala_ccode_formal_parameter_instance_init };
 		vala_ccode_formal_parameter_type_id = g_type_register_static (VALA_TYPE_CCODE_NODE, "ValaCCodeFormalParameter", &g_define_type_info, 0);
 	}
