@@ -40,7 +40,7 @@ static void vala_ccode_fragment_real_write (ValaCCodeNode* base, ValaCCodeWriter
 static void vala_ccode_fragment_real_write_declaration (ValaCCodeNode* base, ValaCCodeWriter* writer);
 static void vala_ccode_fragment_real_write_combined (ValaCCodeNode* base, ValaCCodeWriter* writer);
 static gpointer vala_ccode_fragment_parent_class = NULL;
-static void vala_ccode_fragment_dispose (GObject * obj);
+static void vala_ccode_fragment_finalize (GObject * obj);
 
 
 
@@ -140,7 +140,7 @@ ValaCCodeFragment* vala_ccode_fragment_new (void) {
 static void vala_ccode_fragment_class_init (ValaCCodeFragmentClass * klass) {
 	vala_ccode_fragment_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaCCodeFragmentPrivate));
-	G_OBJECT_CLASS (klass)->dispose = vala_ccode_fragment_dispose;
+	G_OBJECT_CLASS (klass)->finalize = vala_ccode_fragment_finalize;
 	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_fragment_real_write;
 	VALA_CCODE_NODE_CLASS (klass)->write_declaration = vala_ccode_fragment_real_write_declaration;
 	VALA_CCODE_NODE_CLASS (klass)->write_combined = vala_ccode_fragment_real_write_combined;
@@ -153,17 +153,17 @@ static void vala_ccode_fragment_instance_init (ValaCCodeFragment * self) {
 }
 
 
-static void vala_ccode_fragment_dispose (GObject * obj) {
+static void vala_ccode_fragment_finalize (GObject * obj) {
 	ValaCCodeFragment * self;
 	self = VALA_CCODE_FRAGMENT (obj);
 	(self->priv->children == NULL ? NULL : (self->priv->children = (g_object_unref (self->priv->children), NULL)));
-	G_OBJECT_CLASS (vala_ccode_fragment_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (vala_ccode_fragment_parent_class)->finalize (obj);
 }
 
 
 GType vala_ccode_fragment_get_type (void) {
 	static GType vala_ccode_fragment_type_id = 0;
-	if (G_UNLIKELY (vala_ccode_fragment_type_id == 0)) {
+	if (vala_ccode_fragment_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeFragmentClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_fragment_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeFragment), 0, (GInstanceInitFunc) vala_ccode_fragment_instance_init };
 		vala_ccode_fragment_type_id = g_type_register_static (VALA_TYPE_CCODE_NODE, "ValaCCodeFragment", &g_define_type_info, 0);
 	}
