@@ -41,7 +41,7 @@ enum  {
 };
 static void vala_ccode_initializer_list_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
 static gpointer vala_ccode_initializer_list_parent_class = NULL;
-static void vala_ccode_initializer_list_dispose (GObject * obj);
+static void vala_ccode_initializer_list_finalize (GObject * obj);
 
 
 
@@ -101,7 +101,7 @@ ValaCCodeInitializerList* vala_ccode_initializer_list_new (void) {
 static void vala_ccode_initializer_list_class_init (ValaCCodeInitializerListClass * klass) {
 	vala_ccode_initializer_list_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaCCodeInitializerListPrivate));
-	G_OBJECT_CLASS (klass)->dispose = vala_ccode_initializer_list_dispose;
+	G_OBJECT_CLASS (klass)->finalize = vala_ccode_initializer_list_finalize;
 	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_initializer_list_real_write;
 }
 
@@ -112,17 +112,17 @@ static void vala_ccode_initializer_list_instance_init (ValaCCodeInitializerList
 }
 
 
-static void vala_ccode_initializer_list_dispose (GObject * obj) {
+static void vala_ccode_initializer_list_finalize (GObject * obj) {
 	ValaCCodeInitializerList * self;
 	self = VALA_CCODE_INITIALIZER_LIST (obj);
 	(self->priv->initializers == NULL ? NULL : (self->priv->initializers = (g_object_unref (self->priv->initializers), NULL)));
-	G_OBJECT_CLASS (vala_ccode_initializer_list_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (vala_ccode_initializer_list_parent_class)->finalize (obj);
 }
 
 
 GType vala_ccode_initializer_list_get_type (void) {
 	static GType vala_ccode_initializer_list_type_id = 0;
-	if (G_UNLIKELY (vala_ccode_initializer_list_type_id == 0)) {
+	if (vala_ccode_initializer_list_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeInitializerListClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_initializer_list_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeInitializerList), 0, (GInstanceInitFunc) vala_ccode_initializer_list_instance_init };
 		vala_ccode_initializer_list_type_id = g_type_register_static (VALA_TYPE_CCODE_EXPRESSION, "ValaCCodeInitializerList", &g_define_type_info, 0);
 	}
