@@ -41,7 +41,7 @@ enum  {
 };
 static void vala_ccode_macro_replacement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
 static gpointer vala_ccode_macro_replacement_parent_class = NULL;
-static void vala_ccode_macro_replacement_dispose (GObject * obj);
+static void vala_ccode_macro_replacement_finalize (GObject * obj);
 
 
 
@@ -121,6 +121,7 @@ void vala_ccode_macro_replacement_set_name (ValaCCodeMacroReplacement* self, con
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_name = (g_free (self->priv->_name), NULL)), _tmp2);
+	g_object_notify (((GObject *) (self)), "name");
 }
 
 
@@ -137,6 +138,7 @@ void vala_ccode_macro_replacement_set_replacement (ValaCCodeMacroReplacement* se
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_replacement = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_replacement = (g_free (self->priv->_replacement), NULL)), _tmp2);
+	g_object_notify (((GObject *) (self)), "replacement");
 }
 
 
@@ -153,6 +155,7 @@ void vala_ccode_macro_replacement_set_replacement_expression (ValaCCodeMacroRepl
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_replacement_expression = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_replacement_expression == NULL ? NULL : (self->priv->_replacement_expression = (g_object_unref (self->priv->_replacement_expression), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "replacement-expression");
 }
 
 
@@ -201,7 +204,7 @@ static void vala_ccode_macro_replacement_class_init (ValaCCodeMacroReplacementCl
 	g_type_class_add_private (klass, sizeof (ValaCCodeMacroReplacementPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_ccode_macro_replacement_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_ccode_macro_replacement_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_ccode_macro_replacement_dispose;
+	G_OBJECT_CLASS (klass)->finalize = vala_ccode_macro_replacement_finalize;
 	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_macro_replacement_real_write;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_MACRO_REPLACEMENT_NAME, g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_MACRO_REPLACEMENT_REPLACEMENT, g_param_spec_string ("replacement", "replacement", "replacement", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
@@ -214,19 +217,19 @@ static void vala_ccode_macro_replacement_instance_init (ValaCCodeMacroReplacemen
 }
 
 
-static void vala_ccode_macro_replacement_dispose (GObject * obj) {
+static void vala_ccode_macro_replacement_finalize (GObject * obj) {
 	ValaCCodeMacroReplacement * self;
 	self = VALA_CCODE_MACRO_REPLACEMENT (obj);
 	self->priv->_name = (g_free (self->priv->_name), NULL);
 	self->priv->_replacement = (g_free (self->priv->_replacement), NULL);
 	(self->priv->_replacement_expression == NULL ? NULL : (self->priv->_replacement_expression = (g_object_unref (self->priv->_replacement_expression), NULL)));
-	G_OBJECT_CLASS (vala_ccode_macro_replacement_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (vala_ccode_macro_replacement_parent_class)->finalize (obj);
 }
 
 
 GType vala_ccode_macro_replacement_get_type (void) {
 	static GType vala_ccode_macro_replacement_type_id = 0;
-	if (G_UNLIKELY (vala_ccode_macro_replacement_type_id == 0)) {
+	if (vala_ccode_macro_replacement_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeMacroReplacementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_macro_replacement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeMacroReplacement), 0, (GInstanceInitFunc) vala_ccode_macro_replacement_instance_init };
 		vala_ccode_macro_replacement_type_id = g_type_register_static (VALA_TYPE_CCODE_NODE, "ValaCCodeMacroReplacement", &g_define_type_info, 0);
 	}
