@@ -31,6 +31,7 @@ struct _ValaCCodeMemberAccessPrivate {
 	char* _member_name;
 	gboolean _is_pointer;
 };
+
 #define VALA_CCODE_MEMBER_ACCESS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_MEMBER_ACCESS, ValaCCodeMemberAccessPrivate))
 enum  {
 	VALA_CCODE_MEMBER_ACCESS_DUMMY_PROPERTY,
@@ -40,7 +41,7 @@ enum  {
 };
 static void vala_ccode_member_access_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
 static gpointer vala_ccode_member_access_parent_class = NULL;
-static void vala_ccode_member_access_dispose (GObject * obj);
+static void vala_ccode_member_access_finalize (GObject * obj);
 
 
 
@@ -48,7 +49,8 @@ ValaCCodeMemberAccess* vala_ccode_member_access_new (ValaCCodeExpression* contai
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaCCodeMemberAccess * self;
-	g_return_val_if_fail (container == NULL || VALA_IS_CCODE_EXPRESSION (container), NULL);
+	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (container), NULL);
+	g_return_val_if_fail (member != NULL, NULL);
 	__params = g_new0 (GParameter, 2);
 	__params_it = __params;
 	__params_it->name = "inner";
@@ -74,7 +76,8 @@ ValaCCodeMemberAccess* vala_ccode_member_access_new_pointer (ValaCCodeExpression
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaCCodeMemberAccess * self;
-	g_return_val_if_fail (container == NULL || VALA_IS_CCODE_EXPRESSION (container), NULL);
+	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (container), NULL);
+	g_return_val_if_fail (member != NULL, NULL);
 	__params = g_new0 (GParameter, 2);
 	__params_it = __params;
 	__params_it->name = "inner";
@@ -99,7 +102,7 @@ ValaCCodeMemberAccess* vala_ccode_member_access_new_pointer (ValaCCodeExpression
 static void vala_ccode_member_access_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeMemberAccess * self;
 	self = VALA_CCODE_MEMBER_ACCESS (base);
-	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
+	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_node_write (VALA_CCODE_NODE (self->priv->_inner), writer);
 	if (self->priv->_is_pointer) {
 		vala_ccode_writer_write_string (writer, "->");
@@ -123,10 +126,11 @@ void vala_ccode_member_access_set_inner (ValaCCodeMemberAccess* self, ValaCCodeE
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_inner = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "inner");
 }
 
 
-char* vala_ccode_member_access_get_member_name (ValaCCodeMemberAccess* self) {
+const char* vala_ccode_member_access_get_member_name (ValaCCodeMemberAccess* self) {
 	g_return_val_if_fail (VALA_IS_CCODE_MEMBER_ACCESS (self), NULL);
 	return self->priv->_member_name;
 }
@@ -139,6 +143,7 @@ void vala_ccode_member_access_set_member_name (ValaCCodeMemberAccess* self, cons
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_member_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_member_name = (g_free (self->priv->_member_name), NULL)), _tmp2);
+	g_object_notify (((GObject *) (self)), "member-name");
 }
 
 
@@ -151,6 +156,7 @@ gboolean vala_ccode_member_access_get_is_pointer (ValaCCodeMemberAccess* self) {
 void vala_ccode_member_access_set_is_pointer (ValaCCodeMemberAccess* self, gboolean value) {
 	g_return_if_fail (VALA_IS_CCODE_MEMBER_ACCESS (self));
 	self->priv->_is_pointer = value;
+	g_object_notify (((GObject *) (self)), "is-pointer");
 }
 
 
@@ -199,7 +205,7 @@ static void vala_ccode_member_access_class_init (ValaCCodeMemberAccessClass * kl
 	g_type_class_add_private (klass, sizeof (ValaCCodeMemberAccessPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_ccode_member_access_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_ccode_member_access_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_ccode_member_access_dispose;
+	G_OBJECT_CLASS (klass)->finalize = vala_ccode_member_access_finalize;
 	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_member_access_real_write;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_MEMBER_ACCESS_INNER, g_param_spec_object ("inner", "inner", "inner", VALA_TYPE_CCODE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_MEMBER_ACCESS_MEMBER_NAME, g_param_spec_string ("member-name", "member-name", "member-name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
@@ -207,24 +213,24 @@ static void vala_ccode_member_access_class_init (ValaCCodeMemberAccessClass * kl
 }
 
 
-static void vala_ccode_member_access_init (ValaCCodeMemberAccess * self) {
+static void vala_ccode_member_access_instance_init (ValaCCodeMemberAccess * self) {
 	self->priv = VALA_CCODE_MEMBER_ACCESS_GET_PRIVATE (self);
 }
 
 
-static void vala_ccode_member_access_dispose (GObject * obj) {
+static void vala_ccode_member_access_finalize (GObject * obj) {
 	ValaCCodeMemberAccess * self;
 	self = VALA_CCODE_MEMBER_ACCESS (obj);
 	(self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL)));
 	self->priv->_member_name = (g_free (self->priv->_member_name), NULL);
-	G_OBJECT_CLASS (vala_ccode_member_access_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (vala_ccode_member_access_parent_class)->finalize (obj);
 }
 
 
 GType vala_ccode_member_access_get_type (void) {
 	static GType vala_ccode_member_access_type_id = 0;
-	if (G_UNLIKELY (vala_ccode_member_access_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeMemberAccessClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_member_access_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeMemberAccess), 0, (GInstanceInitFunc) vala_ccode_member_access_init };
+	if (vala_ccode_member_access_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeMemberAccessClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_member_access_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeMemberAccess), 0, (GInstanceInitFunc) vala_ccode_member_access_instance_init };
 		vala_ccode_member_access_type_id = g_type_register_static (VALA_TYPE_CCODE_EXPRESSION, "ValaCCodeMemberAccess", &g_define_type_info, 0);
 	}
 	return vala_ccode_member_access_type_id;
