@@ -63,7 +63,7 @@ static void vala_ccode_newline_instance_init (ValaCCodeNewline * self) {
 
 GType vala_ccode_newline_get_type (void) {
 	static GType vala_ccode_newline_type_id = 0;
-	if (G_UNLIKELY (vala_ccode_newline_type_id == 0)) {
+	if (vala_ccode_newline_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeNewlineClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_newline_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeNewline), 0, (GInstanceInitFunc) vala_ccode_newline_instance_init };
 		vala_ccode_newline_type_id = g_type_register_static (VALA_TYPE_CCODE_NODE, "ValaCCodeNewline", &g_define_type_info, 0);
 	}
