@@ -30,6 +30,7 @@
 struct _ValaCCodeOnceSectionPrivate {
 	char* _define;
 };
+
 #define VALA_CCODE_ONCE_SECTION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_ONCE_SECTION, ValaCCodeOnceSectionPrivate))
 enum  {
 	VALA_CCODE_ONCE_SECTION_DUMMY_PROPERTY,
@@ -38,7 +39,7 @@ enum  {
 static void vala_ccode_once_section_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
 static void vala_ccode_once_section_real_write_declaration (ValaCCodeNode* base, ValaCCodeWriter* writer);
 static gpointer vala_ccode_once_section_parent_class = NULL;
-static void vala_ccode_once_section_dispose (GObject * obj);
+static void vala_ccode_once_section_finalize (GObject * obj);
 
 
 
@@ -75,20 +76,18 @@ static void vala_ccode_once_section_real_write (ValaCCodeNode* base, ValaCCodeWr
 	vala_ccode_writer_write_string (writer, self->priv->_define);
 	vala_ccode_writer_write_newline (writer);
 	{
-		GeeCollection* node_collection;
-		GeeIterator* node_it;
+		GeeList* node_collection;
+		int node_it;
 		node_collection = vala_ccode_fragment_get_children (VALA_CCODE_FRAGMENT (self));
-		node_it = gee_iterable_iterator (GEE_ITERABLE (node_collection));
-		while (gee_iterator_next (node_it)) {
+		for (node_it = 0; node_it < gee_collection_get_size (GEE_COLLECTION (node_collection)); node_it = node_it + 1) {
 			ValaCCodeNode* node;
-			node = ((ValaCCodeNode*) gee_iterator_get (node_it));
+			node = ((ValaCCodeNode*) (gee_list_get (GEE_LIST (node_collection), node_it)));
 			{
 				vala_ccode_node_write_combined (node, writer);
 				(node == NULL ? NULL : (node = (g_object_unref (node), NULL)));
 			}
 		}
 		(node_collection == NULL ? NULL : (node_collection = (g_object_unref (node_collection), NULL)));
-		(node_it == NULL ? NULL : (node_it = (g_object_unref (node_it), NULL)));
 	}
 	vala_ccode_writer_write_indent (writer, NULL);
 	vala_ccode_writer_write_string (writer, "#endif");
@@ -103,7 +102,7 @@ static void vala_ccode_once_section_real_write_declaration (ValaCCodeNode* base,
 }
 
 
-char* vala_ccode_once_section_get_define (ValaCCodeOnceSection* self) {
+const char* vala_ccode_once_section_get_define (ValaCCodeOnceSection* self) {
 	g_return_val_if_fail (VALA_IS_CCODE_ONCE_SECTION (self), NULL);
 	return self->priv->_define;
 }
@@ -116,6 +115,7 @@ void vala_ccode_once_section_set_define (ValaCCodeOnceSection* self, const char*
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_define = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_define = (g_free (self->priv->_define), NULL)), _tmp2);
+	g_object_notify (((GObject *) (self)), "define");
 }
 
 
@@ -152,30 +152,30 @@ static void vala_ccode_once_section_class_init (ValaCCodeOnceSectionClass * klas
 	g_type_class_add_private (klass, sizeof (ValaCCodeOnceSectionPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_ccode_once_section_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_ccode_once_section_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_ccode_once_section_dispose;
+	G_OBJECT_CLASS (klass)->finalize = vala_ccode_once_section_finalize;
 	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_once_section_real_write;
 	VALA_CCODE_NODE_CLASS (klass)->write_declaration = vala_ccode_once_section_real_write_declaration;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_ONCE_SECTION_DEFINE, g_param_spec_string ("define", "define", "define", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
 }
 
 
-static void vala_ccode_once_section_init (ValaCCodeOnceSection * self) {
+static void vala_ccode_once_section_instance_init (ValaCCodeOnceSection * self) {
 	self->priv = VALA_CCODE_ONCE_SECTION_GET_PRIVATE (self);
 }
 
 
-static void vala_ccode_once_section_dispose (GObject * obj) {
+static void vala_ccode_once_section_finalize (GObject * obj) {
 	ValaCCodeOnceSection * self;
 	self = VALA_CCODE_ONCE_SECTION (obj);
 	self->priv->_define = (g_free (self->priv->_define), NULL);
-	G_OBJECT_CLASS (vala_ccode_once_section_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (vala_ccode_once_section_parent_class)->finalize (obj);
 }
 
 
 GType vala_ccode_once_section_get_type (void) {
 	static GType vala_ccode_once_section_type_id = 0;
-	if (G_UNLIKELY (vala_ccode_once_section_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeOnceSectionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_once_section_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeOnceSection), 0, (GInstanceInitFunc) vala_ccode_once_section_init };
+	if (vala_ccode_once_section_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeOnceSectionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_once_section_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeOnceSection), 0, (GInstanceInitFunc) vala_ccode_once_section_instance_init };
 		vala_ccode_once_section_type_id = g_type_register_static (VALA_TYPE_CCODE_FRAGMENT, "ValaCCodeOnceSection", &g_define_type_info, 0);
 	}
 	return vala_ccode_once_section_type_id;
