@@ -40,7 +40,7 @@ enum  {
 static void vala_ccode_type_definition_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
 static void vala_ccode_type_definition_real_write_declaration (ValaCCodeNode* base, ValaCCodeWriter* writer);
 static gpointer vala_ccode_type_definition_parent_class = NULL;
-static void vala_ccode_type_definition_dispose (GObject * obj);
+static void vala_ccode_type_definition_finalize (GObject * obj);
 
 
 
@@ -89,6 +89,7 @@ void vala_ccode_type_definition_set_type_name (ValaCCodeTypeDefinition* self, co
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_type_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_type_name = (g_free (self->priv->_type_name), NULL)), _tmp2);
+	g_object_notify (((GObject *) (self)), "type-name");
 }
 
 
@@ -105,6 +106,7 @@ void vala_ccode_type_definition_set_declarator (ValaCCodeTypeDefinition* self, V
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_declarator = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_declarator == NULL ? NULL : (self->priv->_declarator = (g_object_unref (self->priv->_declarator), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "declarator");
 }
 
 
@@ -147,7 +149,7 @@ static void vala_ccode_type_definition_class_init (ValaCCodeTypeDefinitionClass
 	g_type_class_add_private (klass, sizeof (ValaCCodeTypeDefinitionPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_ccode_type_definition_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_ccode_type_definition_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_ccode_type_definition_dispose;
+	G_OBJECT_CLASS (klass)->finalize = vala_ccode_type_definition_finalize;
 	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_type_definition_real_write;
 	VALA_CCODE_NODE_CLASS (klass)->write_declaration = vala_ccode_type_definition_real_write_declaration;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_TYPE_DEFINITION_TYPE_NAME, g_param_spec_string ("type-name", "type-name", "type-name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
@@ -160,18 +162,18 @@ static void vala_ccode_type_definition_instance_init (ValaCCodeTypeDefinition *
 }
 
 
-static void vala_ccode_type_definition_dispose (GObject * obj) {
+static void vala_ccode_type_definition_finalize (GObject * obj) {
 	ValaCCodeTypeDefinition * self;
 	self = VALA_CCODE_TYPE_DEFINITION (obj);
 	self->priv->_type_name = (g_free (self->priv->_type_name), NULL);
 	(self->priv->_declarator == NULL ? NULL : (self->priv->_declarator = (g_object_unref (self->priv->_declarator), NULL)));
-	G_OBJECT_CLASS (vala_ccode_type_definition_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (vala_ccode_type_definition_parent_class)->finalize (obj);
 }
 
 
 GType vala_ccode_type_definition_get_type (void) {
 	static GType vala_ccode_type_definition_type_id = 0;
-	if (G_UNLIKELY (vala_ccode_type_definition_type_id == 0)) {
+	if (vala_ccode_type_definition_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeTypeDefinitionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_type_definition_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeTypeDefinition), 0, (GInstanceInitFunc) vala_ccode_type_definition_instance_init };
 		vala_ccode_type_definition_type_id = g_type_register_static (VALA_TYPE_CCODE_NODE, "ValaCCodeTypeDefinition", &g_define_type_info, 0);
 	}
