@@ -47,7 +47,7 @@ enum  {
 };
 static void vala_ccode_writer_set_filename (ValaCCodeWriter* self, const char* value);
 static gpointer vala_ccode_writer_parent_class = NULL;
-static void vala_ccode_writer_dispose (GObject * obj);
+static void vala_ccode_writer_finalize (GObject * obj);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
 
 
@@ -135,7 +135,7 @@ void vala_ccode_writer_close (ValaCCodeWriter* self) {
 			}
 			len = g_mapped_file_get_length (old_file);
 			if (len == g_mapped_file_get_length (new_file)) {
-				if (memcmp (g_mapped_file_get_contents (old_file), g_mapped_file_get_contents (new_file), ((gsize) len)) == 0) {
+				if (memcmp (g_mapped_file_get_contents (old_file), g_mapped_file_get_contents (new_file), ((gsize) (len))) == 0) {
 					changed = FALSE;
 				}
 			}
@@ -153,6 +153,7 @@ void vala_ccode_writer_close (ValaCCodeWriter* self) {
 			e = inner_error;
 			inner_error = NULL;
 			{
+				(e == NULL ? NULL : (e = (g_error_free (e), NULL)));
 			}
 		}
 		__finally0:
@@ -261,8 +262,10 @@ void vala_ccode_writer_write_comment (ValaCCodeWriter* self, const char* text) {
 	lines = (_tmp0 = g_strsplit (text, "\n", 0), lines_length1 = -1, _tmp0);
 	{
 		char** line_collection;
+		int line_collection_length1;
 		int line_it;
 		line_collection = lines;
+		line_collection_length1 = lines_length1;
 		for (line_it = 0; (lines_length1 != -1 && line_it < lines_length1) || (lines_length1 == -1 && line_collection[line_it] != NULL); line_it = line_it + 1) {
 			const char* _tmp1;
 			char* line;
@@ -281,11 +284,11 @@ void vala_ccode_writer_write_comment (ValaCCodeWriter* self, const char* text) {
 	}
 	fprintf (self->priv->stream, "*/");
 	vala_ccode_writer_write_newline (self);
-	lines = (_vala_array_free (lines, lines_length1, ((GDestroyNotify) g_free)), NULL);
+	lines = (_vala_array_free (lines, lines_length1, ((GDestroyNotify) (g_free))), NULL);
 }
 
 
-char* vala_ccode_writer_get_filename (ValaCCodeWriter* self) {
+const char* vala_ccode_writer_get_filename (ValaCCodeWriter* self) {
 	g_return_val_if_fail (VALA_IS_CCODE_WRITER (self), NULL);
 	return self->priv->_filename;
 }
@@ -298,6 +301,7 @@ static void vala_ccode_writer_set_filename (ValaCCodeWriter* self, const char* v
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_filename = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_filename = (g_free (self->priv->_filename), NULL)), _tmp2);
+	g_object_notify (((GObject *) (self)), "filename");
 }
 
 
@@ -310,6 +314,7 @@ gboolean vala_ccode_writer_get_line_directives (ValaCCodeWriter* self) {
 void vala_ccode_writer_set_line_directives (ValaCCodeWriter* self, gboolean value) {
 	g_return_if_fail (VALA_IS_CCODE_WRITER (self));
 	self->priv->_line_directives = value;
+	g_object_notify (((GObject *) (self)), "line-directives");
 }
 
 
@@ -361,33 +366,33 @@ static void vala_ccode_writer_class_init (ValaCCodeWriterClass * klass) {
 	g_type_class_add_private (klass, sizeof (ValaCCodeWriterPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_ccode_writer_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_ccode_writer_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_ccode_writer_dispose;
+	G_OBJECT_CLASS (klass)->finalize = vala_ccode_writer_finalize;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_WRITER_FILENAME, g_param_spec_string ("filename", "filename", "filename", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_WRITER_LINE_DIRECTIVES, g_param_spec_boolean ("line-directives", "line-directives", "line-directives", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_WRITER_BOL, g_param_spec_boolean ("bol", "bol", "bol", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
 }
 
 
-static void vala_ccode_writer_init (ValaCCodeWriter * self) {
+static void vala_ccode_writer_instance_init (ValaCCodeWriter * self) {
 	self->priv = VALA_CCODE_WRITER_GET_PRIVATE (self);
 	self->priv->_bol = TRUE;
 }
 
 
-static void vala_ccode_writer_dispose (GObject * obj) {
+static void vala_ccode_writer_finalize (GObject * obj) {
 	ValaCCodeWriter * self;
 	self = VALA_CCODE_WRITER (obj);
 	self->priv->_filename = (g_free (self->priv->_filename), NULL);
 	self->priv->temp_filename = (g_free (self->priv->temp_filename), NULL);
 	(self->priv->stream == NULL ? NULL : (self->priv->stream = (fclose (self->priv->stream), NULL)));
-	G_OBJECT_CLASS (vala_ccode_writer_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (vala_ccode_writer_parent_class)->finalize (obj);
 }
 
 
 GType vala_ccode_writer_get_type (void) {
 	static GType vala_ccode_writer_type_id = 0;
-	if (G_UNLIKELY (vala_ccode_writer_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeWriterClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_writer_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeWriter), 0, (GInstanceInitFunc) vala_ccode_writer_init };
+	if (vala_ccode_writer_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeWriterClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_writer_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeWriter), 0, (GInstanceInitFunc) vala_ccode_writer_instance_init };
 		vala_ccode_writer_type_id = g_type_register_static (G_TYPE_OBJECT, "ValaCCodeWriter", &g_define_type_info, 0);
 	}
 	return vala_ccode_writer_type_id;
@@ -399,12 +404,12 @@ static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify
 		int i;
 		if (array_length >= 0)
 		for (i = 0; i < array_length; i = i + 1) {
-			if (((gpointer*) array)[i] != NULL)
-			destroy_func (((gpointer*) array)[i]);
+			if (((gpointer*) (array))[i] != NULL)
+			destroy_func (((gpointer*) (array))[i]);
 		}
 		else
-		for (i = 0; ((gpointer*) array)[i] != NULL; i = i + 1) {
-			destroy_func (((gpointer*) array)[i]);
+		for (i = 0; ((gpointer*) (array))[i] != NULL; i = i + 1) {
+			destroy_func (((gpointer*) (array))[i]);
 		}
 	}
 	g_free (array);
