@@ -42,11 +42,13 @@ struct _GeeArrayListIterator {
 	GeeArrayListIteratorPrivate * priv;
 	gint _stamp;
 };
+
 struct _GeeArrayListIteratorClass {
 	GObjectClass parent_class;
 };
 
 
+
 struct _GeeArrayListPrivate {
 	gpointer* _items;
 	gint _items_length1;
@@ -57,6 +59,7 @@ struct _GeeArrayListPrivate {
 	GBoxedCopyFunc g_dup_func;
 	GDestroyNotify g_destroy_func;
 };
+
 #define GEE_ARRAY_LIST_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GEE_TYPE_ARRAY_LIST, GeeArrayListPrivate))
 enum  {
 	GEE_ARRAY_LIST_DUMMY_PROPERTY,
@@ -87,6 +90,7 @@ struct _GeeArrayListIteratorPrivate {
 	GBoxedCopyFunc g_dup_func;
 	GDestroyNotify g_destroy_func;
 };
+
 #define GEE_ARRAY_LIST_ITERATOR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GEE_ARRAY_LIST_TYPE_ITERATOR, GeeArrayListIteratorPrivate))
 enum  {
 	GEE_ARRAY_LIST_ITERATOR_DUMMY_PROPERTY,
@@ -101,25 +105,43 @@ static gpointer gee_array_list_iterator_real_get (GeeIterator* base);
 static void gee_array_list_iterator_set_list (GeeArrayListIterator* self, GeeArrayList* value);
 static gpointer gee_array_list_iterator_parent_class = NULL;
 static GeeIteratorIface* gee_array_list_iterator_gee_iterator_parent_iface = NULL;
-static void gee_array_list_iterator_dispose (GObject * obj);
+static void gee_array_list_iterator_finalize (GObject * obj);
 static GType gee_array_list_iterator_get_type (void);
 static gpointer gee_array_list_parent_class = NULL;
 static GeeIterableIface* gee_array_list_gee_iterable_parent_iface = NULL;
 static GeeCollectionIface* gee_array_list_gee_collection_parent_iface = NULL;
 static GeeListIface* gee_array_list_gee_list_parent_iface = NULL;
-static void gee_array_list_dispose (GObject * obj);
+static void gee_array_list_finalize (GObject * obj);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
 static void _vala_array_move (gpointer array, gsize element_size, gint src, gint dest, gint length);
 
 
 
 GeeArrayList* gee_array_list_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GEqualFunc equal_func) {
+	GParameter * __params;
+	GParameter * __params_it;
 	GeeArrayList * self;
-	self = g_object_newv (GEE_TYPE_ARRAY_LIST, 0, NULL);
+	__params = g_new0 (GParameter, 3);
+	__params_it = __params;
+	__params_it->name = "g-type";
+	g_value_init (&__params_it->value, G_TYPE_GTYPE);
+	g_value_set_gtype (&__params_it->value, g_type);
+	__params_it++;
+	__params_it->name = "g-dup-func";
+	g_value_init (&__params_it->value, G_TYPE_POINTER);
+	g_value_set_pointer (&__params_it->value, g_dup_func);
+	__params_it++;
+	__params_it->name = "g-destroy-func";
+	g_value_init (&__params_it->value, G_TYPE_POINTER);
+	g_value_set_pointer (&__params_it->value, g_destroy_func);
+	__params_it++;
+	self = g_object_newv (GEE_TYPE_ARRAY_LIST, __params_it - __params, __params);
 	gee_array_list_set_equal_func (self, equal_func);
-	self->priv->g_type = g_type;
-	self->priv->g_dup_func = g_dup_func;
-	self->priv->g_destroy_func = g_destroy_func;
+	while (__params_it > __params) {
+		--__params_it;
+		g_value_unset (&__params_it->value);
+	}
+	g_free (__params);
 	return self;
 }
 
@@ -134,7 +156,7 @@ static GType gee_array_list_real_get_element_type (GeeIterable* base) {
 static GeeIterator* gee_array_list_real_iterator (GeeIterable* base) {
 	GeeArrayList * self;
 	self = GEE_ARRAY_LIST (base);
-	return GEE_ITERATOR (gee_array_list_iterator_new (self->priv->g_type, ((GBoxedCopyFunc) self->priv->g_dup_func), self->priv->g_destroy_func, self));
+	return GEE_ITERATOR (gee_array_list_iterator_new (self->priv->g_type, ((GBoxedCopyFunc) (self->priv->g_dup_func)), self->priv->g_destroy_func, self));
 }
 
 
@@ -151,7 +173,7 @@ static gint gee_array_list_real_index_of (GeeList* base, gconstpointer item) {
 	{
 		gint index;
 		index = 0;
-		for (index = 0; index < self->priv->_size; index++) {
+		for (; index < self->priv->_size; index++) {
 			if (self->priv->_equal_func (self->priv->_items[index], item)) {
 				return index;
 			}
@@ -167,7 +189,7 @@ static gpointer gee_array_list_real_get (GeeList* base, gint index) {
 	self = GEE_ARRAY_LIST (base);
 	g_assert (index >= 0 && index < self->priv->_size);
 	_tmp0 = NULL;
-	return (_tmp0 = self->priv->_items[index], (_tmp0 == NULL || self->priv->g_dup_func == NULL ? ((gpointer) _tmp0) : self->priv->g_dup_func (((gpointer) _tmp0))));
+	return (_tmp0 = self->priv->_items[index], (_tmp0 == NULL || self->priv->g_dup_func == NULL ? ((gpointer) (_tmp0)) : self->priv->g_dup_func (((gpointer) (_tmp0)))));
 }
 
 
@@ -179,7 +201,7 @@ static void gee_array_list_real_set (GeeList* base, gint index, gconstpointer it
 	g_assert (index >= 0 && index < self->priv->_size);
 	_tmp1 = NULL;
 	_tmp0 = NULL;
-	self->priv->_items[index] = (_tmp1 = (_tmp0 = item, (_tmp0 == NULL || self->priv->g_dup_func == NULL ? ((gpointer) _tmp0) : self->priv->g_dup_func (((gpointer) _tmp0)))), (self->priv->_items[index] == NULL || self->priv->g_destroy_func == NULL ? NULL : (self->priv->_items[index] = (self->priv->g_destroy_func (self->priv->_items[index]), NULL))), _tmp1);
+	self->priv->_items[index] = (_tmp1 = (_tmp0 = item, (_tmp0 == NULL || self->priv->g_dup_func == NULL ? ((gpointer) (_tmp0)) : self->priv->g_dup_func (((gpointer) (_tmp0))))), (self->priv->_items[index] == NULL || self->priv->g_destroy_func == NULL ? NULL : (self->priv->_items[index] = (self->priv->g_destroy_func (self->priv->_items[index]), NULL))), _tmp1);
 }
 
 
@@ -195,7 +217,7 @@ static gboolean gee_array_list_real_add (GeeCollection* base, gconstpointer item
 	_tmp1 = NULL;
 	_tmp0 = NULL;
 	_tmp2 = self->priv->_size++;
-	self->priv->_items[_tmp2] = (_tmp1 = (_tmp0 = item, (_tmp0 == NULL || self->priv->g_dup_func == NULL ? ((gpointer) _tmp0) : self->priv->g_dup_func (((gpointer) _tmp0)))), (self->priv->_items[_tmp2] == NULL || self->priv->g_destroy_func == NULL ? NULL : (self->priv->_items[_tmp2] = (self->priv->g_destroy_func (self->priv->_items[_tmp2]), NULL))), _tmp1);
+	self->priv->_items[_tmp2] = (_tmp1 = (_tmp0 = item, (_tmp0 == NULL || self->priv->g_dup_func == NULL ? ((gpointer) (_tmp0)) : self->priv->g_dup_func (((gpointer) (_tmp0))))), (self->priv->_items[_tmp2] == NULL || self->priv->g_destroy_func == NULL ? NULL : (self->priv->_items[_tmp2] = (self->priv->g_destroy_func (self->priv->_items[_tmp2]), NULL))), _tmp1);
 	self->priv->_stamp++;
 	return TRUE;
 }
@@ -213,7 +235,7 @@ static void gee_array_list_real_insert (GeeList* base, gint index, gconstpointer
 	gee_array_list_shift (self, index, 1);
 	_tmp1 = NULL;
 	_tmp0 = NULL;
-	self->priv->_items[index] = (_tmp1 = (_tmp0 = item, (_tmp0 == NULL || self->priv->g_dup_func == NULL ? ((gpointer) _tmp0) : self->priv->g_dup_func (((gpointer) _tmp0)))), (self->priv->_items[index] == NULL || self->priv->g_destroy_func == NULL ? NULL : (self->priv->_items[index] = (self->priv->g_destroy_func (self->priv->_items[index]), NULL))), _tmp1);
+	self->priv->_items[index] = (_tmp1 = (_tmp0 = item, (_tmp0 == NULL || self->priv->g_dup_func == NULL ? ((gpointer) (_tmp0)) : self->priv->g_dup_func (((gpointer) (_tmp0))))), (self->priv->_items[index] == NULL || self->priv->g_destroy_func == NULL ? NULL : (self->priv->_items[index] = (self->priv->g_destroy_func (self->priv->_items[index]), NULL))), _tmp1);
 	self->priv->_stamp++;
 }
 
@@ -224,7 +246,7 @@ static gboolean gee_array_list_real_remove (GeeCollection* base, gconstpointer i
 	{
 		gint index;
 		index = 0;
-		for (index = 0; index < self->priv->_size; index++) {
+		for (; index < self->priv->_size; index++) {
 			if (self->priv->_equal_func (self->priv->_items[index], item)) {
 				gee_list_remove_at (GEE_LIST (self), index);
 				return TRUE;
@@ -253,7 +275,7 @@ static void gee_array_list_real_clear (GeeCollection* base) {
 	{
 		gint index;
 		index = 0;
-		for (index = 0; index < self->priv->_size; index++) {
+		for (; index < self->priv->_size; index++) {
 			gpointer _tmp0;
 			_tmp0 = NULL;
 			self->priv->_items[index] = (_tmp0 = NULL, (self->priv->_items[index] == NULL || self->priv->g_destroy_func == NULL ? NULL : (self->priv->_items[index] = (self->priv->g_destroy_func (self->priv->_items[index]), NULL))), _tmp0);
@@ -295,8 +317,9 @@ static void gee_array_list_set_capacity (GeeArrayList* self, gint value) {
 }
 
 
-static gint gee_array_list_real_get_size (GeeArrayList* self) {
-	g_return_val_if_fail (GEE_IS_ARRAY_LIST (self), 0);
+static gint gee_array_list_real_get_size (GeeCollection* base) {
+	GeeArrayList* self;
+	self = GEE_ARRAY_LIST (base);
 	return self->priv->_size;
 }
 
@@ -304,17 +327,36 @@ static gint gee_array_list_real_get_size (GeeArrayList* self) {
 void gee_array_list_set_equal_func (GeeArrayList* self, GEqualFunc value) {
 	g_return_if_fail (GEE_IS_ARRAY_LIST (self));
 	self->priv->_equal_func = value;
+	g_object_notify (((GObject *) (self)), "equal-func");
 }
 
 
 static GeeArrayListIterator* gee_array_list_iterator_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GeeArrayList* list) {
+	GParameter * __params;
+	GParameter * __params_it;
 	GeeArrayListIterator * self;
-	g_return_val_if_fail (list == NULL || GEE_IS_ARRAY_LIST (list), NULL);
-	self = g_object_newv (GEE_ARRAY_LIST_TYPE_ITERATOR, 0, NULL);
+	g_return_val_if_fail (GEE_IS_ARRAY_LIST (list), NULL);
+	__params = g_new0 (GParameter, 3);
+	__params_it = __params;
+	__params_it->name = "g-type";
+	g_value_init (&__params_it->value, G_TYPE_GTYPE);
+	g_value_set_gtype (&__params_it->value, g_type);
+	__params_it++;
+	__params_it->name = "g-dup-func";
+	g_value_init (&__params_it->value, G_TYPE_POINTER);
+	g_value_set_pointer (&__params_it->value, g_dup_func);
+	__params_it++;
+	__params_it->name = "g-destroy-func";
+	g_value_init (&__params_it->value, G_TYPE_POINTER);
+	g_value_set_pointer (&__params_it->value, g_destroy_func);
+	__params_it++;
+	self = g_object_newv (GEE_ARRAY_LIST_TYPE_ITERATOR, __params_it - __params, __params);
 	gee_array_list_iterator_set_list (self, list);
-	self->priv->g_type = g_type;
-	self->priv->g_dup_func = g_dup_func;
-	self->priv->g_destroy_func = g_destroy_func;
+	while (__params_it > __params) {
+		--__params_it;
+		g_value_unset (&__params_it->value);
+	}
+	g_free (__params);
 	return self;
 }
 
@@ -349,6 +391,7 @@ static void gee_array_list_iterator_set_list (GeeArrayListIterator* self, GeeArr
 	_tmp0 = NULL;
 	self->priv->_list = (_tmp1 = (_tmp0 = value, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0))), (self->priv->_list == NULL ? NULL : (self->priv->_list = (g_object_unref (self->priv->_list), NULL))), _tmp1);
 	self->_stamp = self->priv->_list->priv->_stamp;
+	g_object_notify (((GObject *) (self)), "list");
 }
 
 
@@ -391,10 +434,10 @@ static void gee_array_list_iterator_class_init (GeeArrayListIteratorClass * klas
 	g_type_class_add_private (klass, sizeof (GeeArrayListIteratorPrivate));
 	G_OBJECT_CLASS (klass)->get_property = gee_array_list_iterator_get_property;
 	G_OBJECT_CLASS (klass)->set_property = gee_array_list_iterator_set_property;
-	G_OBJECT_CLASS (klass)->dispose = gee_array_list_iterator_dispose;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_ARRAY_LIST_ITERATOR_G_TYPE, g_param_spec_gtype ("g-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_ARRAY_LIST_ITERATOR_G_DUP_FUNC, g_param_spec_pointer ("g-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_ARRAY_LIST_ITERATOR_G_DESTROY_FUNC, g_param_spec_pointer ("g-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
+	G_OBJECT_CLASS (klass)->finalize = gee_array_list_iterator_finalize;
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_ARRAY_LIST_ITERATOR_G_TYPE, g_param_spec_gtype ("g-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_ARRAY_LIST_ITERATOR_G_DUP_FUNC, g_param_spec_pointer ("g-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_ARRAY_LIST_ITERATOR_G_DESTROY_FUNC, g_param_spec_pointer ("g-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_ARRAY_LIST_ITERATOR_LIST, g_param_spec_object ("list", "list", "list", GEE_TYPE_ARRAY_LIST, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
 }
 
@@ -406,25 +449,25 @@ static void gee_array_list_iterator_gee_iterator_interface_init (GeeIteratorIfac
 }
 
 
-static void gee_array_list_iterator_init (GeeArrayListIterator * self) {
+static void gee_array_list_iterator_instance_init (GeeArrayListIterator * self) {
 	self->priv = GEE_ARRAY_LIST_ITERATOR_GET_PRIVATE (self);
 	self->priv->_index = -1;
 	self->_stamp = 0;
 }
 
 
-static void gee_array_list_iterator_dispose (GObject * obj) {
+static void gee_array_list_iterator_finalize (GObject * obj) {
 	GeeArrayListIterator * self;
 	self = GEE_ARRAY_LIST_ITERATOR (obj);
 	(self->priv->_list == NULL ? NULL : (self->priv->_list = (g_object_unref (self->priv->_list), NULL)));
-	G_OBJECT_CLASS (gee_array_list_iterator_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (gee_array_list_iterator_parent_class)->finalize (obj);
 }
 
 
 static GType gee_array_list_iterator_get_type (void) {
 	static GType gee_array_list_iterator_type_id = 0;
-	if (G_UNLIKELY (gee_array_list_iterator_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (GeeArrayListIteratorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gee_array_list_iterator_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GeeArrayListIterator), 0, (GInstanceInitFunc) gee_array_list_iterator_init };
+	if (gee_array_list_iterator_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (GeeArrayListIteratorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gee_array_list_iterator_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GeeArrayListIterator), 0, (GInstanceInitFunc) gee_array_list_iterator_instance_init };
 		static const GInterfaceInfo gee_iterator_info = { (GInterfaceInitFunc) gee_array_list_iterator_gee_iterator_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		gee_array_list_iterator_type_id = g_type_register_static (G_TYPE_OBJECT, "GeeArrayListIterator", &g_define_type_info, 0);
 		g_type_add_interface_static (gee_array_list_iterator_type_id, GEE_TYPE_ITERATOR, &gee_iterator_info);
@@ -438,7 +481,7 @@ static void gee_array_list_get_property (GObject * object, guint property_id, GV
 	self = GEE_ARRAY_LIST (object);
 	switch (property_id) {
 		case GEE_ARRAY_LIST_SIZE:
-		g_value_set_int (value, gee_array_list_real_get_size (self));
+		g_value_set_int (value, gee_collection_get_size (GEE_COLLECTION (self)));
 		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -475,10 +518,10 @@ static void gee_array_list_class_init (GeeArrayListClass * klass) {
 	g_type_class_add_private (klass, sizeof (GeeArrayListPrivate));
 	G_OBJECT_CLASS (klass)->get_property = gee_array_list_get_property;
 	G_OBJECT_CLASS (klass)->set_property = gee_array_list_set_property;
-	G_OBJECT_CLASS (klass)->dispose = gee_array_list_dispose;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_ARRAY_LIST_G_TYPE, g_param_spec_gtype ("g-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_ARRAY_LIST_G_DUP_FUNC, g_param_spec_pointer ("g-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_ARRAY_LIST_G_DESTROY_FUNC, g_param_spec_pointer ("g-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
+	G_OBJECT_CLASS (klass)->finalize = gee_array_list_finalize;
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_ARRAY_LIST_G_TYPE, g_param_spec_gtype ("g-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_ARRAY_LIST_G_DUP_FUNC, g_param_spec_pointer ("g-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_ARRAY_LIST_G_DESTROY_FUNC, g_param_spec_pointer ("g-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
 	g_object_class_override_property (G_OBJECT_CLASS (klass), GEE_ARRAY_LIST_SIZE, "size");
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_ARRAY_LIST_EQUAL_FUNC, g_param_spec_pointer ("equal-func", "equal-func", "equal-func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
 }
@@ -497,6 +540,7 @@ static void gee_array_list_gee_collection_interface_init (GeeCollectionIface * i
 	iface->add = gee_array_list_real_add;
 	iface->remove = gee_array_list_real_remove;
 	iface->clear = gee_array_list_real_clear;
+	iface->get_size = gee_array_list_real_get_size;
 }
 
 
@@ -510,7 +554,7 @@ static void gee_array_list_gee_list_interface_init (GeeListIface * iface) {
 }
 
 
-static void gee_array_list_init (GeeArrayList * self) {
+static void gee_array_list_instance_init (GeeArrayList * self) {
 	self->priv = GEE_ARRAY_LIST_GET_PRIVATE (self);
 	self->priv->_items = g_new0 (gpointer, 4);
 	self->priv->_items_length1 = 4;
@@ -518,18 +562,18 @@ static void gee_array_list_init (GeeArrayList * self) {
 }
 
 
-static void gee_array_list_dispose (GObject * obj) {
+static void gee_array_list_finalize (GObject * obj) {
 	GeeArrayList * self;
 	self = GEE_ARRAY_LIST (obj);
-	self->priv->_items = (_vala_array_free (self->priv->_items, self->priv->_items_length1, ((GDestroyNotify) self->priv->g_destroy_func)), NULL);
-	G_OBJECT_CLASS (gee_array_list_parent_class)->dispose (obj);
+	self->priv->_items = (_vala_array_free (self->priv->_items, self->priv->_items_length1, ((GDestroyNotify) (self->priv->g_destroy_func))), NULL);
+	G_OBJECT_CLASS (gee_array_list_parent_class)->finalize (obj);
 }
 
 
 GType gee_array_list_get_type (void) {
 	static GType gee_array_list_type_id = 0;
-	if (G_UNLIKELY (gee_array_list_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (GeeArrayListClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gee_array_list_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GeeArrayList), 0, (GInstanceInitFunc) gee_array_list_init };
+	if (gee_array_list_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (GeeArrayListClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gee_array_list_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GeeArrayList), 0, (GInstanceInitFunc) gee_array_list_instance_init };
 		static const GInterfaceInfo gee_iterable_info = { (GInterfaceInitFunc) gee_array_list_gee_iterable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		static const GInterfaceInfo gee_collection_info = { (GInterfaceInitFunc) gee_array_list_gee_collection_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		static const GInterfaceInfo gee_list_info = { (GInterfaceInitFunc) gee_array_list_gee_list_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
@@ -547,12 +591,12 @@ static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify
 		int i;
 		if (array_length >= 0)
 		for (i = 0; i < array_length; i = i + 1) {
-			if (((gpointer*) array)[i] != NULL)
-			destroy_func (((gpointer*) array)[i]);
+			if (((gpointer*) (array))[i] != NULL)
+			destroy_func (((gpointer*) (array))[i]);
 		}
 		else
-		for (i = 0; ((gpointer*) array)[i] != NULL; i = i + 1) {
-			destroy_func (((gpointer*) array)[i]);
+		for (i = 0; ((gpointer*) (array))[i] != NULL; i = i + 1) {
+			destroy_func (((gpointer*) (array))[i]);
 		}
 	}
 	g_free (array);
@@ -560,11 +604,11 @@ static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify
 
 
 static void _vala_array_move (gpointer array, gsize element_size, gint src, gint dest, gint length) {
-	g_memmove (array + dest * element_size, array + src * element_size, length * element_size);
+	g_memmove (((char*) (array)) + dest * element_size, ((char*) (array)) + src * element_size, length * element_size);
 	if (src < dest) {
-		memset (((char *) array + src * element_size), 0, (dest - src) * element_size);
+		memset (((char*) (array)) + src * element_size, 0, (dest - src) * element_size);
 	} else {
-		memset (((char *) array + (dest + length) * element_size), 0, (src - dest) * element_size);
+		memset (((char*) (array)) + (dest + length) * element_size, 0, (src - dest) * element_size);
 	}
 }
 
