@@ -24,6 +24,10 @@
 
 
 
+
+
+
+
 /**
  * Determines whether this collection contains the specified item.
  *
@@ -32,9 +36,7 @@
  * @return     true if item is found, false otherwise
  */
 gboolean gee_collection_contains (GeeCollection* self, gconstpointer item) {
-	gboolean result;
-	result = GEE_COLLECTION_GET_INTERFACE (self)->contains (self, item);
-	return result;
+	return GEE_COLLECTION_GET_INTERFACE (self)->contains (self, item);
 }
 
 
@@ -47,9 +49,7 @@ gboolean gee_collection_contains (GeeCollection* self, gconstpointer item) {
  * @return     true if the collection has been changed, false otherwise
  */
 gboolean gee_collection_add (GeeCollection* self, gconstpointer item) {
-	gboolean result;
-	result = GEE_COLLECTION_GET_INTERFACE (self)->add (self, item);
-	return result;
+	return GEE_COLLECTION_GET_INTERFACE (self)->add (self, item);
 }
 
 
@@ -62,9 +62,7 @@ gboolean gee_collection_add (GeeCollection* self, gconstpointer item) {
  * @return     true if the collection has been changed, false otherwise
  */
 gboolean gee_collection_remove (GeeCollection* self, gconstpointer item) {
-	gboolean result;
-	result = GEE_COLLECTION_GET_INTERFACE (self)->remove (self, item);
-	return result;
+	return GEE_COLLECTION_GET_INTERFACE (self)->remove (self, item);
 }
 
 
@@ -78,9 +76,7 @@ void gee_collection_clear (GeeCollection* self) {
 
 
 gint gee_collection_get_size (GeeCollection* self) {
-	gint value;
-	g_object_get (G_OBJECT (self), "size", &value, NULL);
-	return value;
+	return GEE_COLLECTION_GET_INTERFACE (self)->get_size (self);
 }
 
 
@@ -95,7 +91,7 @@ static void gee_collection_base_init (GeeCollectionIface * iface) {
 
 GType gee_collection_get_type (void) {
 	static GType gee_collection_type_id = 0;
-	if (G_UNLIKELY (gee_collection_type_id == 0)) {
+	if (gee_collection_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (GeeCollectionIface), (GBaseInitFunc) gee_collection_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL };
 		gee_collection_type_id = g_type_register_static (G_TYPE_INTERFACE, "GeeCollection", &g_define_type_info, 0);
 		g_type_interface_add_prerequisite (gee_collection_type_id, GEE_TYPE_ITERABLE);
