@@ -87,6 +87,7 @@ static void gee_hash_set_real_clear (GeeCollection* base);
 static void gee_hash_set_resize (GeeHashSet* self);
 static GObject * gee_hash_set_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
 static GeeHashSetNode* gee_hash_set_node_new (gpointer k, guint hash);
+static void gee_hash_set_node_instance_init (GeeHashSetNode * self);
 static void gee_hash_set_node_free (GeeHashSetNode* self);
 struct _GeeHashSetIteratorPrivate {
 	GeeHashSet* _set;
@@ -112,13 +113,13 @@ static gpointer gee_hash_set_iterator_real_get (GeeIterator* base);
 static void gee_hash_set_iterator_set_set (GeeHashSetIterator* self, GeeHashSet* value);
 static gpointer gee_hash_set_iterator_parent_class = NULL;
 static GeeIteratorIface* gee_hash_set_iterator_gee_iterator_parent_iface = NULL;
-static void gee_hash_set_iterator_dispose (GObject * obj);
+static void gee_hash_set_iterator_finalize (GObject * obj);
 static GType gee_hash_set_iterator_get_type (void);
 static gpointer gee_hash_set_parent_class = NULL;
 static GeeIterableIface* gee_hash_set_gee_iterable_parent_iface = NULL;
 static GeeCollectionIface* gee_hash_set_gee_collection_parent_iface = NULL;
 static GeeSetIface* gee_hash_set_gee_set_parent_iface = NULL;
-static void gee_hash_set_dispose (GObject * obj);
+static void gee_hash_set_finalize (GObject * obj);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
 
 static const gint GEE_HASH_SET_MIN_SIZE = 11;
@@ -326,8 +327,9 @@ static void gee_hash_set_resize (GeeHashSet* self) {
 }
 
 
-static gint gee_hash_set_real_get_size (GeeHashSet* self) {
-	g_return_val_if_fail (GEE_IS_HASH_SET (self), 0);
+static gint gee_hash_set_real_get_size (GeeCollection* base) {
+	GeeHashSet* self;
+	self = GEE_HASH_SET (base);
 	return self->priv->_nnodes;
 }
 
@@ -335,12 +337,14 @@ static gint gee_hash_set_real_get_size (GeeHashSet* self) {
 void gee_hash_set_set_hash_func (GeeHashSet* self, GHashFunc value) {
 	g_return_if_fail (GEE_IS_HASH_SET (self));
 	self->priv->_hash_func = value;
+	g_object_notify (((GObject *) (self)), "hash-func");
 }
 
 
 void gee_hash_set_set_equal_func (GeeHashSet* self, GEqualFunc value) {
 	g_return_if_fail (GEE_IS_HASH_SET (self));
 	self->priv->_equal_func = value;
+	g_object_notify (((GObject *) (self)), "equal-func");
 }
 
 
@@ -367,6 +371,7 @@ static GeeHashSetNode* gee_hash_set_node_new (gpointer k, guint hash) {
 	GeeHashSetNode* self;
 	gpointer _tmp0;
 	self = g_slice_new0 (GeeHashSetNode);
+	gee_hash_set_node_instance_init (self);
 	_tmp0 = NULL;
 	self->key = (_tmp0 = k, k = NULL, _tmp0);
 	self->key_hash = hash;
@@ -374,6 +379,10 @@ static GeeHashSetNode* gee_hash_set_node_new (gpointer k, guint hash) {
 }
 
 
+static void gee_hash_set_node_instance_init (GeeHashSetNode * self) {
+}
+
+
 static void gee_hash_set_node_free (GeeHashSetNode* self) {
 	(self->next == NULL ? NULL : (self->next = (gee_hash_set_node_free (self->next), NULL)));
 	g_slice_free (GeeHashSetNode, self);
@@ -443,6 +452,7 @@ static void gee_hash_set_iterator_set_set (GeeHashSetIterator* self, GeeHashSet*
 	_tmp0 = NULL;
 	self->priv->_set = (_tmp1 = (_tmp0 = value, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0))), (self->priv->_set == NULL ? NULL : (self->priv->_set = (g_object_unref (self->priv->_set), NULL))), _tmp1);
 	self->priv->_stamp = self->priv->_set->priv->_stamp;
+	g_object_notify (((GObject *) (self)), "set");
 }
 
 
@@ -485,7 +495,7 @@ static void gee_hash_set_iterator_class_init (GeeHashSetIteratorClass * klass) {
 	g_type_class_add_private (klass, sizeof (GeeHashSetIteratorPrivate));
 	G_OBJECT_CLASS (klass)->get_property = gee_hash_set_iterator_get_property;
 	G_OBJECT_CLASS (klass)->set_property = gee_hash_set_iterator_set_property;
-	G_OBJECT_CLASS (klass)->dispose = gee_hash_set_iterator_dispose;
+	G_OBJECT_CLASS (klass)->finalize = gee_hash_set_iterator_finalize;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_SET_ITERATOR_G_TYPE, g_param_spec_gtype ("g-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_SET_ITERATOR_G_DUP_FUNC, g_param_spec_pointer ("g-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_SET_ITERATOR_G_DESTROY_FUNC, g_param_spec_pointer ("g-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
@@ -507,17 +517,17 @@ static void gee_hash_set_iterator_instance_init (GeeHashSetIterator * self) {
 }
 
 
-static void gee_hash_set_iterator_dispose (GObject * obj) {
+static void gee_hash_set_iterator_finalize (GObject * obj) {
 	GeeHashSetIterator * self;
 	self = GEE_HASH_SET_ITERATOR (obj);
 	(self->priv->_set == NULL ? NULL : (self->priv->_set = (g_object_unref (self->priv->_set), NULL)));
-	G_OBJECT_CLASS (gee_hash_set_iterator_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (gee_hash_set_iterator_parent_class)->finalize (obj);
 }
 
 
 static GType gee_hash_set_iterator_get_type (void) {
 	static GType gee_hash_set_iterator_type_id = 0;
-	if (G_UNLIKELY (gee_hash_set_iterator_type_id == 0)) {
+	if (gee_hash_set_iterator_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (GeeHashSetIteratorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gee_hash_set_iterator_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GeeHashSetIterator), 0, (GInstanceInitFunc) gee_hash_set_iterator_instance_init };
 		static const GInterfaceInfo gee_iterator_info = { (GInterfaceInitFunc) gee_hash_set_iterator_gee_iterator_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		gee_hash_set_iterator_type_id = g_type_register_static (G_TYPE_OBJECT, "GeeHashSetIterator", &g_define_type_info, 0);
@@ -532,7 +542,7 @@ static void gee_hash_set_get_property (GObject * object, guint property_id, GVal
 	self = GEE_HASH_SET (object);
 	switch (property_id) {
 		case GEE_HASH_SET_SIZE:
-		g_value_set_int (value, gee_hash_set_real_get_size (self));
+		g_value_set_int (value, gee_collection_get_size (GEE_COLLECTION (self)));
 		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -573,7 +583,7 @@ static void gee_hash_set_class_init (GeeHashSetClass * klass) {
 	G_OBJECT_CLASS (klass)->get_property = gee_hash_set_get_property;
 	G_OBJECT_CLASS (klass)->set_property = gee_hash_set_set_property;
 	G_OBJECT_CLASS (klass)->constructor = gee_hash_set_constructor;
-	G_OBJECT_CLASS (klass)->dispose = gee_hash_set_dispose;
+	G_OBJECT_CLASS (klass)->finalize = gee_hash_set_finalize;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_SET_G_TYPE, g_param_spec_gtype ("g-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_SET_G_DUP_FUNC, g_param_spec_pointer ("g-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_SET_G_DESTROY_FUNC, g_param_spec_pointer ("g-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
@@ -596,6 +606,7 @@ static void gee_hash_set_gee_collection_interface_init (GeeCollectionIface * ifa
 	iface->add = gee_hash_set_real_add;
 	iface->remove = gee_hash_set_real_remove;
 	iface->clear = gee_hash_set_real_clear;
+	iface->get_size = gee_hash_set_real_get_size;
 }
 
 
@@ -610,20 +621,20 @@ static void gee_hash_set_instance_init (GeeHashSet * self) {
 }
 
 
-static void gee_hash_set_dispose (GObject * obj) {
+static void gee_hash_set_finalize (GObject * obj) {
 	GeeHashSet * self;
 	self = GEE_HASH_SET (obj);
 	{
 		gee_collection_clear (GEE_COLLECTION (self));
 	}
 	self->priv->_nodes = (_vala_array_free (self->priv->_nodes, self->priv->_nodes_length1, ((GDestroyNotify) (gee_hash_set_node_free))), NULL);
-	G_OBJECT_CLASS (gee_hash_set_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (gee_hash_set_parent_class)->finalize (obj);
 }
 
 
 GType gee_hash_set_get_type (void) {
 	static GType gee_hash_set_type_id = 0;
-	if (G_UNLIKELY (gee_hash_set_type_id == 0)) {
+	if (gee_hash_set_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (GeeHashSetClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gee_hash_set_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GeeHashSet), 0, (GInstanceInitFunc) gee_hash_set_instance_init };
 		static const GInterfaceInfo gee_iterable_info = { (GInterfaceInitFunc) gee_hash_set_gee_iterable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		static const GInterfaceInfo gee_collection_info = { (GInterfaceInitFunc) gee_hash_set_gee_collection_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
