@@ -24,6 +24,10 @@
 
 
 
+
+
+
+
 /**
  * Returns the item at the specified index in this list.
  *
@@ -32,9 +36,7 @@
  * @return      the item at the specified index in the list
  */
 gpointer gee_list_get (GeeList* self, gint index) {
-	gpointer result;
-	result = GEE_LIST_GET_INTERFACE (self)->get (self, index);
-	return result;
+	return GEE_LIST_GET_INTERFACE (self)->get (self, index);
 }
 
 
@@ -56,9 +58,7 @@ void gee_list_set (GeeList* self, gint index, gconstpointer item) {
  *         -1 if the item could not be found
  */
 gint gee_list_index_of (GeeList* self, gconstpointer item) {
-	gint result;
-	result = GEE_LIST_GET_INTERFACE (self)->index_of (self, item);
-	return result;
+	return GEE_LIST_GET_INTERFACE (self)->index_of (self, item);
 }
 
 
@@ -93,7 +93,7 @@ static void gee_list_base_init (GeeListIface * iface) {
 
 GType gee_list_get_type (void) {
 	static GType gee_list_type_id = 0;
-	if (G_UNLIKELY (gee_list_type_id == 0)) {
+	if (gee_list_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (GeeListIface), (GBaseInitFunc) gee_list_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL };
 		gee_list_type_id = g_type_register_static (G_TYPE_INTERFACE, "GeeList", &g_define_type_info, 0);
 		g_type_interface_add_prerequisite (gee_list_type_id, GEE_TYPE_COLLECTION);
