@@ -89,7 +89,7 @@ static GType gee_read_only_collection_iterator_get_type (void);
 static gpointer gee_read_only_collection_parent_class = NULL;
 static GeeIterableIface* gee_read_only_collection_gee_iterable_parent_iface = NULL;
 static GeeCollectionIface* gee_read_only_collection_gee_collection_parent_iface = NULL;
-static void gee_read_only_collection_dispose (GObject * obj);
+static void gee_read_only_collection_finalize (GObject * obj);
 
 
 
@@ -171,8 +171,9 @@ static void gee_read_only_collection_real_clear (GeeCollection* base) {
 }
 
 
-static gint gee_read_only_collection_real_get_size (GeeReadOnlyCollection* self) {
-	g_return_val_if_fail (GEE_IS_READ_ONLY_COLLECTION (self), 0);
+static gint gee_read_only_collection_real_get_size (GeeCollection* base) {
+	GeeReadOnlyCollection* self;
+	self = GEE_READ_ONLY_COLLECTION (base);
 	return gee_collection_get_size (self->priv->_collection);
 }
 
@@ -184,6 +185,7 @@ void gee_read_only_collection_set_collection (GeeReadOnlyCollection* self, GeeCo
 	_tmp1 = NULL;
 	_tmp0 = NULL;
 	self->priv->_collection = (_tmp1 = (_tmp0 = value, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0))), (self->priv->_collection == NULL ? NULL : (self->priv->_collection = (g_object_unref (self->priv->_collection), NULL))), _tmp1);
+	g_object_notify (((GObject *) (self)), "collection");
 }
 
 
@@ -285,7 +287,7 @@ static void gee_read_only_collection_iterator_instance_init (GeeReadOnlyCollecti
 
 static GType gee_read_only_collection_iterator_get_type (void) {
 	static GType gee_read_only_collection_iterator_type_id = 0;
-	if (G_UNLIKELY (gee_read_only_collection_iterator_type_id == 0)) {
+	if (gee_read_only_collection_iterator_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (GeeReadOnlyCollectionIteratorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gee_read_only_collection_iterator_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GeeReadOnlyCollectionIterator), 0, (GInstanceInitFunc) gee_read_only_collection_iterator_instance_init };
 		static const GInterfaceInfo gee_iterator_info = { (GInterfaceInitFunc) gee_read_only_collection_iterator_gee_iterator_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		gee_read_only_collection_iterator_type_id = g_type_register_static (G_TYPE_OBJECT, "GeeReadOnlyCollectionIterator", &g_define_type_info, 0);
@@ -300,7 +302,7 @@ static void gee_read_only_collection_get_property (GObject * object, guint prope
 	self = GEE_READ_ONLY_COLLECTION (object);
 	switch (property_id) {
 		case GEE_READ_ONLY_COLLECTION_SIZE:
-		g_value_set_int (value, gee_read_only_collection_real_get_size (self));
+		g_value_set_int (value, gee_collection_get_size (GEE_COLLECTION (self)));
 		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -337,7 +339,7 @@ static void gee_read_only_collection_class_init (GeeReadOnlyCollectionClass * kl
 	g_type_class_add_private (klass, sizeof (GeeReadOnlyCollectionPrivate));
 	G_OBJECT_CLASS (klass)->get_property = gee_read_only_collection_get_property;
 	G_OBJECT_CLASS (klass)->set_property = gee_read_only_collection_set_property;
-	G_OBJECT_CLASS (klass)->dispose = gee_read_only_collection_dispose;
+	G_OBJECT_CLASS (klass)->finalize = gee_read_only_collection_finalize;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_COLLECTION_G_TYPE, g_param_spec_gtype ("g-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_COLLECTION_G_DUP_FUNC, g_param_spec_pointer ("g-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_COLLECTION_G_DESTROY_FUNC, g_param_spec_pointer ("g-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
@@ -359,6 +361,7 @@ static void gee_read_only_collection_gee_collection_interface_init (GeeCollectio
 	iface->add = gee_read_only_collection_real_add;
 	iface->remove = gee_read_only_collection_real_remove;
 	iface->clear = gee_read_only_collection_real_clear;
+	iface->get_size = gee_read_only_collection_real_get_size;
 }
 
 
@@ -367,17 +370,17 @@ static void gee_read_only_collection_instance_init (GeeReadOnlyCollection * self
 }
 
 
-static void gee_read_only_collection_dispose (GObject * obj) {
+static void gee_read_only_collection_finalize (GObject * obj) {
 	GeeReadOnlyCollection * self;
 	self = GEE_READ_ONLY_COLLECTION (obj);
 	(self->priv->_collection == NULL ? NULL : (self->priv->_collection = (g_object_unref (self->priv->_collection), NULL)));
-	G_OBJECT_CLASS (gee_read_only_collection_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (gee_read_only_collection_parent_class)->finalize (obj);
 }
 
 
 GType gee_read_only_collection_get_type (void) {
 	static GType gee_read_only_collection_type_id = 0;
-	if (G_UNLIKELY (gee_read_only_collection_type_id == 0)) {
+	if (gee_read_only_collection_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (GeeReadOnlyCollectionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gee_read_only_collection_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GeeReadOnlyCollection), 0, (GInstanceInitFunc) gee_read_only_collection_instance_init };
 		static const GInterfaceInfo gee_iterable_info = { (GInterfaceInitFunc) gee_read_only_collection_gee_iterable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		static const GInterfaceInfo gee_collection_info = { (GInterfaceInitFunc) gee_read_only_collection_gee_collection_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
