@@ -95,7 +95,7 @@ static gpointer gee_read_only_list_parent_class = NULL;
 static GeeIterableIface* gee_read_only_list_gee_iterable_parent_iface = NULL;
 static GeeCollectionIface* gee_read_only_list_gee_collection_parent_iface = NULL;
 static GeeListIface* gee_read_only_list_gee_list_parent_iface = NULL;
-static void gee_read_only_list_dispose (GObject * obj);
+static void gee_read_only_list_finalize (GObject * obj);
 
 
 
@@ -218,8 +218,9 @@ static void gee_read_only_list_real_clear (GeeCollection* base) {
 }
 
 
-static gint gee_read_only_list_real_get_size (GeeReadOnlyList* self) {
-	g_return_val_if_fail (GEE_IS_READ_ONLY_LIST (self), 0);
+static gint gee_read_only_list_real_get_size (GeeCollection* base) {
+	GeeReadOnlyList* self;
+	self = GEE_READ_ONLY_LIST (base);
 	return gee_collection_get_size (GEE_COLLECTION (self->priv->_list));
 }
 
@@ -231,6 +232,7 @@ void gee_read_only_list_set_list (GeeReadOnlyList* self, GeeList* value) {
 	_tmp1 = NULL;
 	_tmp0 = NULL;
 	self->priv->_list = (_tmp1 = (_tmp0 = value, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0))), (self->priv->_list == NULL ? NULL : (self->priv->_list = (g_object_unref (self->priv->_list), NULL))), _tmp1);
+	g_object_notify (((GObject *) (self)), "list");
 }
 
 
@@ -332,7 +334,7 @@ static void gee_read_only_list_iterator_instance_init (GeeReadOnlyListIterator *
 
 static GType gee_read_only_list_iterator_get_type (void) {
 	static GType gee_read_only_list_iterator_type_id = 0;
-	if (G_UNLIKELY (gee_read_only_list_iterator_type_id == 0)) {
+	if (gee_read_only_list_iterator_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (GeeReadOnlyListIteratorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gee_read_only_list_iterator_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GeeReadOnlyListIterator), 0, (GInstanceInitFunc) gee_read_only_list_iterator_instance_init };
 		static const GInterfaceInfo gee_iterator_info = { (GInterfaceInitFunc) gee_read_only_list_iterator_gee_iterator_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		gee_read_only_list_iterator_type_id = g_type_register_static (G_TYPE_OBJECT, "GeeReadOnlyListIterator", &g_define_type_info, 0);
@@ -347,7 +349,7 @@ static void gee_read_only_list_get_property (GObject * object, guint property_id
 	self = GEE_READ_ONLY_LIST (object);
 	switch (property_id) {
 		case GEE_READ_ONLY_LIST_SIZE:
-		g_value_set_int (value, gee_read_only_list_real_get_size (self));
+		g_value_set_int (value, gee_collection_get_size (GEE_COLLECTION (self)));
 		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -384,7 +386,7 @@ static void gee_read_only_list_class_init (GeeReadOnlyListClass * klass) {
 	g_type_class_add_private (klass, sizeof (GeeReadOnlyListPrivate));
 	G_OBJECT_CLASS (klass)->get_property = gee_read_only_list_get_property;
 	G_OBJECT_CLASS (klass)->set_property = gee_read_only_list_set_property;
-	G_OBJECT_CLASS (klass)->dispose = gee_read_only_list_dispose;
+	G_OBJECT_CLASS (klass)->finalize = gee_read_only_list_finalize;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_LIST_G_TYPE, g_param_spec_gtype ("g-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_LIST_G_DUP_FUNC, g_param_spec_pointer ("g-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_LIST_G_DESTROY_FUNC, g_param_spec_pointer ("g-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
@@ -406,6 +408,7 @@ static void gee_read_only_list_gee_collection_interface_init (GeeCollectionIface
 	iface->add = gee_read_only_list_real_add;
 	iface->remove = gee_read_only_list_real_remove;
 	iface->clear = gee_read_only_list_real_clear;
+	iface->get_size = gee_read_only_list_real_get_size;
 }
 
 
@@ -424,17 +427,17 @@ static void gee_read_only_list_instance_init (GeeReadOnlyList * self) {
 }
 
 
-static void gee_read_only_list_dispose (GObject * obj) {
+static void gee_read_only_list_finalize (GObject * obj) {
 	GeeReadOnlyList * self;
 	self = GEE_READ_ONLY_LIST (obj);
 	(self->priv->_list == NULL ? NULL : (self->priv->_list = (g_object_unref (self->priv->_list), NULL)));
-	G_OBJECT_CLASS (gee_read_only_list_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (gee_read_only_list_parent_class)->finalize (obj);
 }
 
 
 GType gee_read_only_list_get_type (void) {
 	static GType gee_read_only_list_type_id = 0;
-	if (G_UNLIKELY (gee_read_only_list_type_id == 0)) {
+	if (gee_read_only_list_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (GeeReadOnlyListClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gee_read_only_list_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GeeReadOnlyList), 0, (GInstanceInitFunc) gee_read_only_list_instance_init };
 		static const GInterfaceInfo gee_iterable_info = { (GInterfaceInitFunc) gee_read_only_list_gee_iterable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		static const GInterfaceInfo gee_collection_info = { (GInterfaceInitFunc) gee_read_only_list_gee_collection_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
