@@ -90,7 +90,7 @@ static gpointer gee_read_only_set_parent_class = NULL;
 static GeeIterableIface* gee_read_only_set_gee_iterable_parent_iface = NULL;
 static GeeCollectionIface* gee_read_only_set_gee_collection_parent_iface = NULL;
 static GeeSetIface* gee_read_only_set_gee_set_parent_iface = NULL;
-static void gee_read_only_set_dispose (GObject * obj);
+static void gee_read_only_set_finalize (GObject * obj);
 
 
 
@@ -172,8 +172,9 @@ static void gee_read_only_set_real_clear (GeeCollection* base) {
 }
 
 
-static gint gee_read_only_set_real_get_size (GeeReadOnlySet* self) {
-	g_return_val_if_fail (GEE_IS_READ_ONLY_SET (self), 0);
+static gint gee_read_only_set_real_get_size (GeeCollection* base) {
+	GeeReadOnlySet* self;
+	self = GEE_READ_ONLY_SET (base);
 	return gee_collection_get_size (GEE_COLLECTION (self->priv->_set));
 }
 
@@ -185,6 +186,7 @@ void gee_read_only_set_set_set (GeeReadOnlySet* self, GeeSet* value) {
 	_tmp1 = NULL;
 	_tmp0 = NULL;
 	self->priv->_set = (_tmp1 = (_tmp0 = value, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0))), (self->priv->_set == NULL ? NULL : (self->priv->_set = (g_object_unref (self->priv->_set), NULL))), _tmp1);
+	g_object_notify (((GObject *) (self)), "set");
 }
 
 
@@ -286,7 +288,7 @@ static void gee_read_only_set_iterator_instance_init (GeeReadOnlySetIterator * s
 
 static GType gee_read_only_set_iterator_get_type (void) {
 	static GType gee_read_only_set_iterator_type_id = 0;
-	if (G_UNLIKELY (gee_read_only_set_iterator_type_id == 0)) {
+	if (gee_read_only_set_iterator_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (GeeReadOnlySetIteratorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gee_read_only_set_iterator_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GeeReadOnlySetIterator), 0, (GInstanceInitFunc) gee_read_only_set_iterator_instance_init };
 		static const GInterfaceInfo gee_iterator_info = { (GInterfaceInitFunc) gee_read_only_set_iterator_gee_iterator_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		gee_read_only_set_iterator_type_id = g_type_register_static (G_TYPE_OBJECT, "GeeReadOnlySetIterator", &g_define_type_info, 0);
@@ -301,7 +303,7 @@ static void gee_read_only_set_get_property (GObject * object, guint property_id,
 	self = GEE_READ_ONLY_SET (object);
 	switch (property_id) {
 		case GEE_READ_ONLY_SET_SIZE:
-		g_value_set_int (value, gee_read_only_set_real_get_size (self));
+		g_value_set_int (value, gee_collection_get_size (GEE_COLLECTION (self)));
 		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -338,7 +340,7 @@ static void gee_read_only_set_class_init (GeeReadOnlySetClass * klass) {
 	g_type_class_add_private (klass, sizeof (GeeReadOnlySetPrivate));
 	G_OBJECT_CLASS (klass)->get_property = gee_read_only_set_get_property;
 	G_OBJECT_CLASS (klass)->set_property = gee_read_only_set_set_property;
-	G_OBJECT_CLASS (klass)->dispose = gee_read_only_set_dispose;
+	G_OBJECT_CLASS (klass)->finalize = gee_read_only_set_finalize;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_SET_G_TYPE, g_param_spec_gtype ("g-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_SET_G_DUP_FUNC, g_param_spec_pointer ("g-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_SET_G_DESTROY_FUNC, g_param_spec_pointer ("g-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
@@ -360,6 +362,7 @@ static void gee_read_only_set_gee_collection_interface_init (GeeCollectionIface
 	iface->add = gee_read_only_set_real_add;
 	iface->remove = gee_read_only_set_real_remove;
 	iface->clear = gee_read_only_set_real_clear;
+	iface->get_size = gee_read_only_set_real_get_size;
 }
 
 
@@ -373,17 +376,17 @@ static void gee_read_only_set_instance_init (GeeReadOnlySet * self) {
 }
 
 
-static void gee_read_only_set_dispose (GObject * obj) {
+static void gee_read_only_set_finalize (GObject * obj) {
 	GeeReadOnlySet * self;
 	self = GEE_READ_ONLY_SET (obj);
 	(self->priv->_set == NULL ? NULL : (self->priv->_set = (g_object_unref (self->priv->_set), NULL)));
-	G_OBJECT_CLASS (gee_read_only_set_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (gee_read_only_set_parent_class)->finalize (obj);
 }
 
 
 GType gee_read_only_set_get_type (void) {
 	static GType gee_read_only_set_type_id = 0;
-	if (G_UNLIKELY (gee_read_only_set_type_id == 0)) {
+	if (gee_read_only_set_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (GeeReadOnlySetClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gee_read_only_set_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GeeReadOnlySet), 0, (GInstanceInitFunc) gee_read_only_set_instance_init };
 		static const GInterfaceInfo gee_iterable_info = { (GInterfaceInitFunc) gee_read_only_set_gee_iterable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		static const GInterfaceInfo gee_collection_info = { (GInterfaceInitFunc) gee_read_only_set_gee_collection_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
