@@ -24,6 +24,10 @@
 
 
 
+
+
+
+
 static void gee_set_base_init (GeeSetIface * iface) {
 	static gboolean initialized = FALSE;
 	if (!initialized) {
@@ -34,7 +38,7 @@ static void gee_set_base_init (GeeSetIface * iface) {
 
 GType gee_set_get_type (void) {
 	static GType gee_set_type_id = 0;
-	if (G_UNLIKELY (gee_set_type_id == 0)) {
+	if (gee_set_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (GeeSetIface), (GBaseInitFunc) gee_set_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL };
 		gee_set_type_id = g_type_register_static (G_TYPE_INTERFACE, "GeeSet", &g_define_type_info, 0);
 		g_type_interface_add_prerequisite (gee_set_type_id, GEE_TYPE_COLLECTION);
