@@ -106,7 +106,7 @@ static char* vala_project_generator_get_automake_path (ValaProjectGenerator* sel
 static void vala_project_generator_main (char** args, int args_length1);
 static GObject * vala_project_generator_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
 static gpointer vala_project_generator_parent_class = NULL;
-static void vala_project_generator_dispose (GObject * obj);
+static void vala_project_generator_finalize (GObject * obj);
 static GType vala_project_generator_get_type (void);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
 
@@ -151,14 +151,14 @@ static GtkHBox* vala_project_generator_create_hbox (ValaProjectGenerator* self,
 	g_return_val_if_fail (VALA_IS_PROJECT_GENERATOR (self), NULL);
 	g_return_val_if_fail (title != NULL, NULL);
 	g_return_val_if_fail (GTK_IS_SIZE_GROUP (size_group), NULL);
-	hbox = g_object_ref_sink (gtk_hbox_new (FALSE, 6));
+	hbox = g_object_ref_sink (((GtkHBox*) (gtk_hbox_new (FALSE, 6))));
 	gtk_box_pack_start (GTK_BOX ((GTK_VBOX (GTK_DIALOG (self)->vbox))), GTK_WIDGET (hbox), FALSE, FALSE, ((guint) (0)));
 	gtk_widget_show (GTK_WIDGET (hbox));
-	label = g_object_ref_sink (gtk_label_new ("    "));
+	label = g_object_ref_sink (((GtkLabel*) (gtk_label_new ("    "))));
 	gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (label), FALSE, FALSE, ((guint) (0)));
 	gtk_widget_show (GTK_WIDGET (label));
 	_tmp0 = NULL;
-	label = (_tmp0 = g_object_ref_sink (gtk_label_new (title)), (label == NULL ? NULL : (label = (g_object_unref (label), NULL))), _tmp0);
+	label = (_tmp0 = g_object_ref_sink (((GtkLabel*) (gtk_label_new (title)))), (label == NULL ? NULL : (label = (g_object_unref (label), NULL))), _tmp0);
 	gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (label), FALSE, FALSE, ((guint) (0)));
 	g_object_set (GTK_MISC (label), "xalign", ((float) (0)), NULL);
 	gtk_widget_show (GTK_WIDGET (label));
@@ -1112,7 +1112,7 @@ static GObject * vala_project_generator_constructor (GType type, guint n_constru
 		hbox = NULL;
 		gtk_box_set_spacing (GTK_BOX (vbox), 6);
 		_tmp1 = NULL;
-		label = (_tmp1 = g_object_ref_sink (gtk_label_new ("<b>Project</b>")), (label == NULL ? NULL : (label = (g_object_unref (label), NULL))), _tmp1);
+		label = (_tmp1 = g_object_ref_sink (((GtkLabel*) (gtk_label_new ("<b>Project</b>")))), (label == NULL ? NULL : (label = (g_object_unref (label), NULL))), _tmp1);
 		gtk_box_pack_start (GTK_BOX (vbox), GTK_WIDGET (label), FALSE, FALSE, ((guint) (0)));
 		gtk_label_set_use_markup (label, TRUE);
 		g_object_set (GTK_MISC (label), "xalign", ((float) (0)), NULL);
@@ -1120,13 +1120,13 @@ static GObject * vala_project_generator_constructor (GType type, guint n_constru
 		_tmp3 = NULL;
 		hbox = (_tmp3 = vala_project_generator_create_hbox (self, "Project folder:", size_group), (hbox == NULL ? NULL : (hbox = (g_object_unref (hbox), NULL))), _tmp3);
 		_tmp4 = NULL;
-		self->priv->project_folder_button = (_tmp4 = g_object_ref_sink (gtk_file_chooser_button_new ("Select a project folder", GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER)), (self->priv->project_folder_button == NULL ? NULL : (self->priv->project_folder_button = (g_object_unref (self->priv->project_folder_button), NULL))), _tmp4);
+		self->priv->project_folder_button = (_tmp4 = g_object_ref_sink (((GtkFileChooserButton*) (gtk_file_chooser_button_new ("Select a project folder", GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER)))), (self->priv->project_folder_button == NULL ? NULL : (self->priv->project_folder_button = (g_object_unref (self->priv->project_folder_button), NULL))), _tmp4);
 		gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (self->priv->project_folder_button), TRUE, TRUE, ((guint) (0)));
 		gtk_widget_show (GTK_WIDGET (self->priv->project_folder_button));
 		_tmp5 = NULL;
 		hbox = (_tmp5 = vala_project_generator_create_hbox (self, "Project type:", size_group), (hbox == NULL ? NULL : (hbox = (g_object_unref (hbox), NULL))), _tmp5);
 		_tmp6 = NULL;
-		self->priv->project_type_combobox = (_tmp6 = g_object_ref_sink (gtk_combo_box_new_text ()), (self->priv->project_type_combobox == NULL ? NULL : (self->priv->project_type_combobox = (g_object_unref (self->priv->project_type_combobox), NULL))), _tmp6);
+		self->priv->project_type_combobox = (_tmp6 = g_object_ref_sink (((GtkComboBox*) (gtk_combo_box_new_text ()))), (self->priv->project_type_combobox == NULL ? NULL : (self->priv->project_type_combobox = (g_object_unref (self->priv->project_type_combobox), NULL))), _tmp6);
 		gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (self->priv->project_type_combobox), TRUE, TRUE, ((guint) (0)));
 		gtk_combo_box_append_text (self->priv->project_type_combobox, "Console Application");
 		gtk_combo_box_append_text (self->priv->project_type_combobox, "GTK+ Application");
@@ -1135,7 +1135,7 @@ static GObject * vala_project_generator_constructor (GType type, guint n_constru
 		_tmp7 = NULL;
 		hbox = (_tmp7 = vala_project_generator_create_hbox (self, "License:", size_group), (hbox == NULL ? NULL : (hbox = (g_object_unref (hbox), NULL))), _tmp7);
 		_tmp8 = NULL;
-		self->priv->license_combobox = (_tmp8 = g_object_ref_sink (gtk_combo_box_new_text ()), (self->priv->license_combobox == NULL ? NULL : (self->priv->license_combobox = (g_object_unref (self->priv->license_combobox), NULL))), _tmp8);
+		self->priv->license_combobox = (_tmp8 = g_object_ref_sink (((GtkComboBox*) (gtk_combo_box_new_text ()))), (self->priv->license_combobox == NULL ? NULL : (self->priv->license_combobox = (g_object_unref (self->priv->license_combobox), NULL))), _tmp8);
 		gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (self->priv->license_combobox), TRUE, TRUE, ((guint) (0)));
 		gtk_combo_box_append_text (self->priv->license_combobox, "GNU General Public License, version 2 or later");
 		gtk_combo_box_append_text (self->priv->license_combobox, "GNU General Public License, version 3 or later");
@@ -1144,7 +1144,7 @@ static GObject * vala_project_generator_constructor (GType type, guint n_constru
 		gtk_combo_box_set_active (self->priv->license_combobox, ((gint) (VALA_PROJECT_LICENSE_LGPL2)));
 		gtk_widget_show (GTK_WIDGET (self->priv->license_combobox));
 		_tmp9 = NULL;
-		label = (_tmp9 = g_object_ref_sink (gtk_label_new ("<b>Author</b>")), (label == NULL ? NULL : (label = (g_object_unref (label), NULL))), _tmp9);
+		label = (_tmp9 = g_object_ref_sink (((GtkLabel*) (gtk_label_new ("<b>Author</b>")))), (label == NULL ? NULL : (label = (g_object_unref (label), NULL))), _tmp9);
 		gtk_box_pack_start (GTK_BOX (vbox), GTK_WIDGET (label), FALSE, FALSE, ((guint) (0)));
 		gtk_label_set_use_markup (label, TRUE);
 		g_object_set (GTK_MISC (label), "xalign", ((float) (0)), NULL);
@@ -1152,7 +1152,7 @@ static GObject * vala_project_generator_constructor (GType type, guint n_constru
 		_tmp11 = NULL;
 		hbox = (_tmp11 = vala_project_generator_create_hbox (self, "Name:", size_group), (hbox == NULL ? NULL : (hbox = (g_object_unref (hbox), NULL))), _tmp11);
 		_tmp12 = NULL;
-		self->priv->name_entry = (_tmp12 = g_object_ref_sink (gtk_entry_new ()), (self->priv->name_entry == NULL ? NULL : (self->priv->name_entry = (g_object_unref (self->priv->name_entry), NULL))), _tmp12);
+		self->priv->name_entry = (_tmp12 = g_object_ref_sink (((GtkEntry*) (gtk_entry_new ()))), (self->priv->name_entry == NULL ? NULL : (self->priv->name_entry = (g_object_unref (self->priv->name_entry), NULL))), _tmp12);
 		gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (self->priv->name_entry), TRUE, TRUE, ((guint) (0)));
 		_tmp14 = NULL;
 		_tmp13 = NULL;
@@ -1164,7 +1164,7 @@ static GObject * vala_project_generator_constructor (GType type, guint n_constru
 		_tmp15 = NULL;
 		hbox = (_tmp15 = vala_project_generator_create_hbox (self, "E-mail address:", size_group), (hbox == NULL ? NULL : (hbox = (g_object_unref (hbox), NULL))), _tmp15);
 		_tmp16 = NULL;
-		self->priv->email_entry = (_tmp16 = g_object_ref_sink (gtk_entry_new ()), (self->priv->email_entry == NULL ? NULL : (self->priv->email_entry = (g_object_unref (self->priv->email_entry), NULL))), _tmp16);
+		self->priv->email_entry = (_tmp16 = g_object_ref_sink (((GtkEntry*) (gtk_entry_new ()))), (self->priv->email_entry == NULL ? NULL : (self->priv->email_entry = (g_object_unref (self->priv->email_entry), NULL))), _tmp16);
 		gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (self->priv->email_entry), TRUE, TRUE, ((guint) (0)));
 		_tmp18 = NULL;
 		_tmp17 = NULL;
@@ -1191,7 +1191,7 @@ static void vala_project_generator_class_init (ValaProjectGeneratorClass * klass
 	vala_project_generator_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaProjectGeneratorPrivate));
 	G_OBJECT_CLASS (klass)->constructor = vala_project_generator_constructor;
-	G_OBJECT_CLASS (klass)->dispose = vala_project_generator_dispose;
+	G_OBJECT_CLASS (klass)->finalize = vala_project_generator_finalize;
 }
 
 
@@ -1200,7 +1200,7 @@ static void vala_project_generator_instance_init (ValaProjectGenerator * self) {
 }
 
 
-static void vala_project_generator_dispose (GObject * obj) {
+static void vala_project_generator_finalize (GObject * obj) {
 	ValaProjectGenerator * self;
 	self = VALA_PROJECT_GENERATOR (obj);
 	(self->priv->project_folder_button == NULL ? NULL : (self->priv->project_folder_button = (g_object_unref (self->priv->project_folder_button), NULL)));
@@ -1215,13 +1215,13 @@ static void vala_project_generator_dispose (GObject * obj) {
 	self->priv->upper_case_make_name = (g_free (self->priv->upper_case_make_name), NULL);
 	self->priv->real_name = (g_free (self->priv->real_name), NULL);
 	self->priv->email_address = (g_free (self->priv->email_address), NULL);
-	G_OBJECT_CLASS (vala_project_generator_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (vala_project_generator_parent_class)->finalize (obj);
 }
 
 
 static GType vala_project_generator_get_type (void) {
 	static GType vala_project_generator_type_id = 0;
-	if (G_UNLIKELY (vala_project_generator_type_id == 0)) {
+	if (vala_project_generator_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaProjectGeneratorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_project_generator_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaProjectGenerator), 0, (GInstanceInitFunc) vala_project_generator_instance_init };
 		vala_project_generator_type_id = g_type_register_static (GTK_TYPE_DIALOG, "ValaProjectGenerator", &g_define_type_info, 0);
 	}
