@@ -1184,17 +1184,21 @@ g_igenerator_process_symbols (GIGenerator * igenerator)
 void
 g_igenerator_add_symbol (GIGenerator * igenerator, CSymbol * symbol)
 {
+  GList *l;
+
   /* only add symbols of main file */
   gboolean found_filename = FALSE;
 
-  GList *l;
-  for (l = igenerator->filenames; l != NULL; l = l->next)
+  if (igenerator->current_filename)
     {
-      if (strcmp (l->data, igenerator->current_filename) == 0)
-	{
-	  found_filename = TRUE;
-	  break;
-	}
+      for (l = igenerator->filenames; l != NULL; l = l->next)
+        {
+          if (strcmp (l->data, igenerator->current_filename) == 0)
+            {
+	      found_filename = TRUE;
+              break;
+            }
+        }
     }
 
   symbol->directives = g_slist_reverse (igenerator->directives);
@@ -1203,7 +1207,9 @@ g_igenerator_add_symbol (GIGenerator * igenerator, CSymbol * symbol)
   /* that's not very optimized ! */
   for (l = igenerator->symbol_list; l != NULL; l = l->next)
     {
-      if (g_str_equal (((CSymbol*)l->data)->ident, symbol->ident))
+      CSymbol *other_symbol = (CSymbol *)l->data;
+      if (g_str_equal (other_symbol->ident, symbol->ident)
+          && other_symbol->type == symbol->type)
         {
           g_printerr ("Dropping %s duplicate\n", symbol->ident);
           return;
