@@ -87,7 +87,7 @@ static void vala_ccode_assignment_binding_emit_non_array_element_access (ValaCCo
 static void vala_ccode_assignment_binding_emit_simple_assignment (ValaCCodeAssignmentBinding* self);
 static void vala_ccode_assignment_binding_real_emit (ValaCCodeBinding* base);
 static gpointer vala_ccode_assignment_binding_parent_class = NULL;
-static void vala_ccode_assignment_binding_dispose (GObject * obj);
+static void vala_ccode_assignment_binding_finalize (GObject * obj);
 
 
 
@@ -823,6 +823,7 @@ void vala_ccode_assignment_binding_set_assignment (ValaCCodeAssignmentBinding* s
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_assignment = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_assignment == NULL ? NULL : (self->priv->_assignment = (g_object_unref (self->priv->_assignment), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "assignment");
 }
 
 
@@ -859,7 +860,7 @@ static void vala_ccode_assignment_binding_class_init (ValaCCodeAssignmentBinding
 	g_type_class_add_private (klass, sizeof (ValaCCodeAssignmentBindingPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_ccode_assignment_binding_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_ccode_assignment_binding_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_ccode_assignment_binding_dispose;
+	G_OBJECT_CLASS (klass)->finalize = vala_ccode_assignment_binding_finalize;
 	VALA_CCODE_BINDING_CLASS (klass)->emit = vala_ccode_assignment_binding_real_emit;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_ASSIGNMENT_BINDING_ASSIGNMENT, g_param_spec_object ("assignment", "assignment", "assignment", VALA_TYPE_ASSIGNMENT, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
@@ -870,17 +871,17 @@ static void vala_ccode_assignment_binding_instance_init (ValaCCodeAssignmentBind
 }
 
 
-static void vala_ccode_assignment_binding_dispose (GObject * obj) {
+static void vala_ccode_assignment_binding_finalize (GObject * obj) {
 	ValaCCodeAssignmentBinding * self;
 	self = VALA_CCODE_ASSIGNMENT_BINDING (obj);
 	(self->priv->_assignment == NULL ? NULL : (self->priv->_assignment = (g_object_unref (self->priv->_assignment), NULL)));
-	G_OBJECT_CLASS (vala_ccode_assignment_binding_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (vala_ccode_assignment_binding_parent_class)->finalize (obj);
 }
 
 
 GType vala_ccode_assignment_binding_get_type (void) {
 	static GType vala_ccode_assignment_binding_type_id = 0;
-	if (G_UNLIKELY (vala_ccode_assignment_binding_type_id == 0)) {
+	if (vala_ccode_assignment_binding_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeAssignmentBindingClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_assignment_binding_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeAssignmentBinding), 0, (GInstanceInitFunc) vala_ccode_assignment_binding_instance_init };
 		vala_ccode_assignment_binding_type_id = g_type_register_static (VALA_TYPE_CCODE_EXPRESSION_BINDING, "ValaCCodeAssignmentBinding", &g_define_type_info, 0);
 	}
