@@ -50,7 +50,7 @@ enum  {
 };
 static void vala_ccode_binding_real_emit (ValaCCodeBinding* self);
 static gpointer vala_ccode_binding_parent_class = NULL;
-static void vala_ccode_binding_dispose (GObject * obj);
+static void vala_ccode_binding_finalize (GObject * obj);
 
 
 
@@ -189,6 +189,7 @@ void vala_ccode_binding_set_codegen (ValaCCodeBinding* self, ValaCCodeGenerator*
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_codegen = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_codegen == NULL ? NULL : (self->priv->_codegen = (g_object_unref (self->priv->_codegen), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "codegen");
 }
 
 
@@ -225,7 +226,7 @@ static void vala_ccode_binding_class_init (ValaCCodeBindingClass * klass) {
 	g_type_class_add_private (klass, sizeof (ValaCCodeBindingPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_ccode_binding_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_ccode_binding_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_ccode_binding_dispose;
+	G_OBJECT_CLASS (klass)->finalize = vala_ccode_binding_finalize;
 	VALA_CCODE_BINDING_CLASS (klass)->emit = vala_ccode_binding_real_emit;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_BINDING_CODEGEN, g_param_spec_object ("codegen", "codegen", "codegen", VALA_TYPE_CCODE_GENERATOR, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
@@ -236,17 +237,17 @@ static void vala_ccode_binding_instance_init (ValaCCodeBinding * self) {
 }
 
 
-static void vala_ccode_binding_dispose (GObject * obj) {
+static void vala_ccode_binding_finalize (GObject * obj) {
 	ValaCCodeBinding * self;
 	self = VALA_CCODE_BINDING (obj);
 	(self->priv->_codegen == NULL ? NULL : (self->priv->_codegen = (g_object_unref (self->priv->_codegen), NULL)));
-	G_OBJECT_CLASS (vala_ccode_binding_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (vala_ccode_binding_parent_class)->finalize (obj);
 }
 
 
 GType vala_ccode_binding_get_type (void) {
 	static GType vala_ccode_binding_type_id = 0;
-	if (G_UNLIKELY (vala_ccode_binding_type_id == 0)) {
+	if (vala_ccode_binding_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeBindingClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_binding_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeBinding), 0, (GInstanceInitFunc) vala_ccode_binding_instance_init };
 		vala_ccode_binding_type_id = g_type_register_static (VALA_TYPE_CODE_BINDING, "ValaCCodeBinding", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
 	}
