@@ -67,7 +67,7 @@ static void vala_ccode_dynamic_property_binding_create_dbus_property_proxy (Vala
 static void vala_ccode_dynamic_property_binding_generate_dbus_property_getter_wrapper (ValaCCodeDynamicPropertyBinding* self, ValaCCodeBlock* block);
 static void vala_ccode_dynamic_property_binding_generate_dbus_property_setter_wrapper (ValaCCodeDynamicPropertyBinding* self, ValaCCodeBlock* block);
 static gpointer vala_ccode_dynamic_property_binding_parent_class = NULL;
-static void vala_ccode_dynamic_property_binding_dispose (GObject * obj);
+static void vala_ccode_dynamic_property_binding_finalize (GObject * obj);
 
 
 
@@ -642,6 +642,7 @@ void vala_ccode_dynamic_property_binding_set_node (ValaCCodeDynamicPropertyBindi
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_node = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_node == NULL ? NULL : (self->priv->_node = (g_object_unref (self->priv->_node), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "node");
 }
 
 
@@ -678,7 +679,7 @@ static void vala_ccode_dynamic_property_binding_class_init (ValaCCodeDynamicProp
 	g_type_class_add_private (klass, sizeof (ValaCCodeDynamicPropertyBindingPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_ccode_dynamic_property_binding_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_ccode_dynamic_property_binding_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_ccode_dynamic_property_binding_dispose;
+	G_OBJECT_CLASS (klass)->finalize = vala_ccode_dynamic_property_binding_finalize;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_DYNAMIC_PROPERTY_BINDING_NODE, g_param_spec_object ("node", "node", "node", VALA_TYPE_PROPERTY, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
@@ -688,19 +689,19 @@ static void vala_ccode_dynamic_property_binding_instance_init (ValaCCodeDynamicP
 }
 
 
-static void vala_ccode_dynamic_property_binding_dispose (GObject * obj) {
+static void vala_ccode_dynamic_property_binding_finalize (GObject * obj) {
 	ValaCCodeDynamicPropertyBinding * self;
 	self = VALA_CCODE_DYNAMIC_PROPERTY_BINDING (obj);
 	(self->priv->_node == NULL ? NULL : (self->priv->_node = (g_object_unref (self->priv->_node), NULL)));
 	self->priv->getter_cname = (g_free (self->priv->getter_cname), NULL);
 	self->priv->setter_cname = (g_free (self->priv->setter_cname), NULL);
-	G_OBJECT_CLASS (vala_ccode_dynamic_property_binding_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (vala_ccode_dynamic_property_binding_parent_class)->finalize (obj);
 }
 
 
 GType vala_ccode_dynamic_property_binding_get_type (void) {
 	static GType vala_ccode_dynamic_property_binding_type_id = 0;
-	if (G_UNLIKELY (vala_ccode_dynamic_property_binding_type_id == 0)) {
+	if (vala_ccode_dynamic_property_binding_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeDynamicPropertyBindingClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_dynamic_property_binding_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeDynamicPropertyBinding), 0, (GInstanceInitFunc) vala_ccode_dynamic_property_binding_instance_init };
 		vala_ccode_dynamic_property_binding_type_id = g_type_register_static (VALA_TYPE_CCODE_BINDING, "ValaCCodeDynamicPropertyBinding", &g_define_type_info, 0);
 	}
