@@ -35,7 +35,7 @@ enum  {
 	VALA_CCODE_EXPRESSION_BINDING_CODENODE
 };
 static gpointer vala_ccode_expression_binding_parent_class = NULL;
-static void vala_ccode_expression_binding_dispose (GObject * obj);
+static void vala_ccode_expression_binding_finalize (GObject * obj);
 
 
 
@@ -52,6 +52,7 @@ void vala_ccode_expression_binding_set_codenode (ValaCCodeExpressionBinding* sel
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_codenode = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_codenode == NULL ? NULL : (self->priv->_codenode = (g_object_unref (self->priv->_codenode), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "codenode");
 }
 
 
@@ -88,7 +89,7 @@ static void vala_ccode_expression_binding_class_init (ValaCCodeExpressionBinding
 	g_type_class_add_private (klass, sizeof (ValaCCodeExpressionBindingPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_ccode_expression_binding_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_ccode_expression_binding_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_ccode_expression_binding_dispose;
+	G_OBJECT_CLASS (klass)->finalize = vala_ccode_expression_binding_finalize;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_EXPRESSION_BINDING_CODENODE, g_param_spec_object ("codenode", "codenode", "codenode", VALA_TYPE_CCODE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
@@ -98,17 +99,17 @@ static void vala_ccode_expression_binding_instance_init (ValaCCodeExpressionBind
 }
 
 
-static void vala_ccode_expression_binding_dispose (GObject * obj) {
+static void vala_ccode_expression_binding_finalize (GObject * obj) {
 	ValaCCodeExpressionBinding * self;
 	self = VALA_CCODE_EXPRESSION_BINDING (obj);
 	(self->priv->_codenode == NULL ? NULL : (self->priv->_codenode = (g_object_unref (self->priv->_codenode), NULL)));
-	G_OBJECT_CLASS (vala_ccode_expression_binding_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (vala_ccode_expression_binding_parent_class)->finalize (obj);
 }
 
 
 GType vala_ccode_expression_binding_get_type (void) {
 	static GType vala_ccode_expression_binding_type_id = 0;
-	if (G_UNLIKELY (vala_ccode_expression_binding_type_id == 0)) {
+	if (vala_ccode_expression_binding_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeExpressionBindingClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_expression_binding_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeExpressionBinding), 0, (GInstanceInitFunc) vala_ccode_expression_binding_instance_init };
 		vala_ccode_expression_binding_type_id = g_type_register_static (VALA_TYPE_CCODE_BINDING, "ValaCCodeExpressionBinding", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
 	}
