@@ -81,7 +81,7 @@ enum  {
 static void vala_ccode_interface_binding_real_emit (ValaCCodeBinding* base);
 static void vala_ccode_interface_binding_add_interface_base_init_function (ValaCCodeInterfaceBinding* self, ValaInterface* iface);
 static gpointer vala_ccode_interface_binding_parent_class = NULL;
-static void vala_ccode_interface_binding_dispose (GObject * obj);
+static void vala_ccode_interface_binding_finalize (GObject * obj);
 
 
 
@@ -216,7 +216,7 @@ static void vala_ccode_interface_binding_real_emit (ValaCCodeBinding* base) {
 		_tmp34 = NULL;
 		_tmp33 = NULL;
 		_tmp32 = NULL;
-		vala_ccode_fragment_append (decl_frag, VALA_CCODE_NODE ((_tmp34 = vala_ccode_macro_replacement_new ((_tmp33 = g_strdup_printf ("%s(obj)", (_tmp32 = vala_typesymbol_get_upper_case_cname (VALA_TYPESYMBOL (self->priv->_iface), "IS_")))), macro))));
+		vala_ccode_fragment_append (decl_frag, VALA_CCODE_NODE ((_tmp34 = vala_ccode_macro_replacement_new ((_tmp33 = g_strdup_printf ("%s(obj)", (_tmp32 = vala_ccode_generator_get_type_check_function (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self)), VALA_TYPESYMBOL (self->priv->_iface))))), macro))));
 		(_tmp34 == NULL ? NULL : (_tmp34 = (g_object_unref (_tmp34), NULL)));
 		_tmp33 = (g_free (_tmp33), NULL);
 		_tmp32 = (g_free (_tmp32), NULL);
@@ -282,7 +282,7 @@ static void vala_ccode_interface_binding_real_emit (ValaCCodeBinding* base) {
 		ValaInterfaceRegisterFunction* type_fun;
 		ValaCCodeFragment* _tmp54;
 		vala_ccode_interface_binding_add_interface_base_init_function (self, self->priv->_iface);
-		type_fun = vala_interface_register_function_new (self->priv->_iface);
+		type_fun = vala_interface_register_function_new (self->priv->_iface, vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self)));
 		vala_typeregister_function_init_from_type (VALA_TYPEREGISTER_FUNCTION (type_fun), FALSE);
 		if (vala_symbol_get_access (VALA_SYMBOL (self->priv->_iface)) != VALA_SYMBOL_ACCESSIBILITY_PRIVATE) {
 			ValaCCodeFragment* _tmp52;
@@ -491,6 +491,7 @@ void vala_ccode_interface_binding_set_iface (ValaCCodeInterfaceBinding* self, Va
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_iface = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_iface == NULL ? NULL : (self->priv->_iface = (g_object_unref (self->priv->_iface), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "iface");
 }
 
 
@@ -527,7 +528,7 @@ static void vala_ccode_interface_binding_class_init (ValaCCodeInterfaceBindingCl
 	g_type_class_add_private (klass, sizeof (ValaCCodeInterfaceBindingPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_ccode_interface_binding_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_ccode_interface_binding_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_ccode_interface_binding_dispose;
+	G_OBJECT_CLASS (klass)->finalize = vala_ccode_interface_binding_finalize;
 	VALA_CCODE_BINDING_CLASS (klass)->emit = vala_ccode_interface_binding_real_emit;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_INTERFACE_BINDING_IFACE, g_param_spec_object ("iface", "iface", "iface", VALA_TYPE_INTERFACE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
@@ -538,17 +539,17 @@ static void vala_ccode_interface_binding_instance_init (ValaCCodeInterfaceBindin
 }
 
 
-static void vala_ccode_interface_binding_dispose (GObject * obj) {
+static void vala_ccode_interface_binding_finalize (GObject * obj) {
 	ValaCCodeInterfaceBinding * self;
 	self = VALA_CCODE_INTERFACE_BINDING (obj);
 	(self->priv->_iface == NULL ? NULL : (self->priv->_iface = (g_object_unref (self->priv->_iface), NULL)));
-	G_OBJECT_CLASS (vala_ccode_interface_binding_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (vala_ccode_interface_binding_parent_class)->finalize (obj);
 }
 
 
 GType vala_ccode_interface_binding_get_type (void) {
 	static GType vala_ccode_interface_binding_type_id = 0;
-	if (G_UNLIKELY (vala_ccode_interface_binding_type_id == 0)) {
+	if (vala_ccode_interface_binding_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeInterfaceBindingClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_interface_binding_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeInterfaceBinding), 0, (GInstanceInitFunc) vala_ccode_interface_binding_instance_init };
 		vala_ccode_interface_binding_type_id = g_type_register_static (VALA_TYPE_CCODE_OBJECT_TYPE_SYMBOL_BINDING, "ValaCCodeInterfaceBinding", &g_define_type_info, 0);
 	}
