@@ -75,7 +75,7 @@ enum  {
 static void vala_ccode_member_access_binding_process_cmember (ValaCCodeMemberAccessBinding* self, ValaMemberAccess* expr, ValaCCodeExpression* pub_inst, ValaDataType* base_type);
 static void vala_ccode_member_access_binding_real_emit (ValaCCodeBinding* base);
 static gpointer vala_ccode_member_access_binding_parent_class = NULL;
-static void vala_ccode_member_access_binding_dispose (GObject * obj);
+static void vala_ccode_member_access_binding_finalize (GObject * obj);
 static int _vala_strcmp0 (const char * str1, const char * str2);
 
 
@@ -265,7 +265,7 @@ static void vala_ccode_member_access_binding_process_cmember (ValaCCodeMemberAcc
 					_tmp34 = NULL;
 					_tmp33 = NULL;
 					cl = (_tmp34 = (_tmp33 = vala_data_type_get_data_type (instance_target_type), (VALA_IS_CLASS (_tmp33) ? ((ValaClass*) (_tmp33)) : NULL)), (_tmp34 == NULL ? NULL : g_object_ref (_tmp34)));
-					is_gtypeinstance = (cl == NULL || !vala_class_get_is_compact (cl));
+					is_gtypeinstance = ((vala_data_type_get_data_type (instance_target_type) == VALA_TYPESYMBOL (cl)) && (cl == NULL || !vala_class_get_is_compact (cl)));
 					inst = NULL;
 					if (is_gtypeinstance && vala_symbol_get_access (VALA_SYMBOL (f)) == VALA_SYMBOL_ACCESSIBILITY_PRIVATE) {
 						ValaCCodeExpression* _tmp35;
@@ -406,68 +406,140 @@ static void vala_ccode_member_access_binding_process_cmember (ValaCCodeMemberAcc
 						ValaProperty* prop;
 						_tmp65 = NULL;
 						prop = (_tmp65 = VALA_PROPERTY (vala_expression_get_symbol_reference (VALA_EXPRESSION (expr))), (_tmp65 == NULL ? NULL : g_object_ref (_tmp65)));
-						if (vala_property_get_get_accessor (prop) != NULL && vala_property_accessor_get_automatic_body (vala_property_get_get_accessor (prop)) && VALA_SYMBOL (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->current_type_symbol) == vala_symbol_get_parent_symbol (VALA_SYMBOL (prop)) && vala_property_get_base_property (prop) == NULL && vala_property_get_base_interface_property (prop) == NULL) {
+						if (vala_property_get_get_accessor (prop) == NULL) {
+							(prop == NULL ? NULL : (prop = (g_object_unref (prop), NULL)));
+							return;
+						}
+						if (VALA_IS_BASE_ACCESS (vala_member_access_get_inner (expr))) {
+							if (vala_property_get_base_property (prop) != NULL) {
+								ValaClass* _tmp66;
+								ValaClass* base_class;
+								ValaCCodeIdentifier* _tmp69;
+								char* _tmp68;
+								char* _tmp67;
+								ValaCCodeFunctionCall* _tmp70;
+								ValaCCodeFunctionCall* vcast;
+								ValaCCodeIdentifier* _tmp73;
+								char* _tmp72;
+								char* _tmp71;
+								ValaCCodeMemberAccess* _tmp75;
+								char* _tmp74;
+								ValaCCodeFunctionCall* _tmp76;
+								ValaCCodeFunctionCall* ccall;
+								_tmp66 = NULL;
+								base_class = (_tmp66 = VALA_CLASS (vala_symbol_get_parent_symbol (VALA_SYMBOL (vala_property_get_base_property (prop)))), (_tmp66 == NULL ? NULL : g_object_ref (_tmp66)));
+								_tmp69 = NULL;
+								_tmp68 = NULL;
+								_tmp67 = NULL;
+								_tmp70 = NULL;
+								vcast = (_tmp70 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp69 = vala_ccode_identifier_new ((_tmp68 = g_strdup_printf ("%s_CLASS", (_tmp67 = vala_typesymbol_get_upper_case_cname (VALA_TYPESYMBOL (base_class), NULL)))))))), (_tmp69 == NULL ? NULL : (_tmp69 = (g_object_unref (_tmp69), NULL))), (_tmp68 = (g_free (_tmp68), NULL)), (_tmp67 = (g_free (_tmp67), NULL)), _tmp70);
+								_tmp73 = NULL;
+								_tmp72 = NULL;
+								_tmp71 = NULL;
+								vala_ccode_function_call_add_argument (vcast, VALA_CCODE_EXPRESSION ((_tmp73 = vala_ccode_identifier_new ((_tmp72 = g_strdup_printf ("%s_parent_class", (_tmp71 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->current_class), NULL))))))));
+								(_tmp73 == NULL ? NULL : (_tmp73 = (g_object_unref (_tmp73), NULL)));
+								_tmp72 = (g_free (_tmp72), NULL);
+								_tmp71 = (g_free (_tmp71), NULL);
+								_tmp75 = NULL;
+								_tmp74 = NULL;
+								_tmp76 = NULL;
+								ccall = (_tmp76 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp75 = vala_ccode_member_access_new_pointer (VALA_CCODE_EXPRESSION (vcast), (_tmp74 = g_strdup_printf ("get_%s", vala_symbol_get_name (VALA_SYMBOL (prop)))))))), (_tmp75 == NULL ? NULL : (_tmp75 = (g_object_unref (_tmp75), NULL))), (_tmp74 = (g_free (_tmp74), NULL)), _tmp76);
+								vala_ccode_function_call_add_argument (ccall, VALA_CCODE_EXPRESSION (vala_code_node_get_ccodenode (VALA_CODE_NODE (vala_member_access_get_inner (expr)))));
+								vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE (ccall));
+								(base_class == NULL ? NULL : (base_class = (g_object_unref (base_class), NULL)));
+								(vcast == NULL ? NULL : (vcast = (g_object_unref (vcast), NULL)));
+								(ccall == NULL ? NULL : (ccall = (g_object_unref (ccall), NULL)));
+								(prop == NULL ? NULL : (prop = (g_object_unref (prop), NULL)));
+								return;
+							} else {
+								if (vala_property_get_base_interface_property (prop) != NULL) {
+									ValaInterface* _tmp77;
+									ValaInterface* base_iface;
+									char* _tmp79;
+									char* _tmp78;
+									char* _tmp80;
+									char* parent_iface_var;
+									ValaCCodeMemberAccess* _tmp83;
+									char* _tmp82;
+									ValaCCodeIdentifier* _tmp81;
+									ValaCCodeFunctionCall* _tmp84;
+									ValaCCodeFunctionCall* ccall;
+									_tmp77 = NULL;
+									base_iface = (_tmp77 = VALA_INTERFACE (vala_symbol_get_parent_symbol (VALA_SYMBOL (vala_property_get_base_interface_property (prop)))), (_tmp77 == NULL ? NULL : g_object_ref (_tmp77)));
+									_tmp79 = NULL;
+									_tmp78 = NULL;
+									_tmp80 = NULL;
+									parent_iface_var = (_tmp80 = g_strdup_printf ("%s_%s_parent_iface", (_tmp78 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->current_class), NULL)), (_tmp79 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (base_iface), NULL))), (_tmp79 = (g_free (_tmp79), NULL)), (_tmp78 = (g_free (_tmp78), NULL)), _tmp80);
+									_tmp83 = NULL;
+									_tmp82 = NULL;
+									_tmp81 = NULL;
+									_tmp84 = NULL;
+									ccall = (_tmp84 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp83 = vala_ccode_member_access_new_pointer (VALA_CCODE_EXPRESSION ((_tmp81 = vala_ccode_identifier_new (parent_iface_var))), (_tmp82 = g_strdup_printf ("get_%s", vala_symbol_get_name (VALA_SYMBOL (prop)))))))), (_tmp83 == NULL ? NULL : (_tmp83 = (g_object_unref (_tmp83), NULL))), (_tmp82 = (g_free (_tmp82), NULL)), (_tmp81 == NULL ? NULL : (_tmp81 = (g_object_unref (_tmp81), NULL))), _tmp84);
+									vala_ccode_function_call_add_argument (ccall, VALA_CCODE_EXPRESSION (vala_code_node_get_ccodenode (VALA_CODE_NODE (vala_member_access_get_inner (expr)))));
+									vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE (ccall));
+									(base_iface == NULL ? NULL : (base_iface = (g_object_unref (base_iface), NULL)));
+									parent_iface_var = (g_free (parent_iface_var), NULL);
+									(ccall == NULL ? NULL : (ccall = (g_object_unref (ccall), NULL)));
+									(prop == NULL ? NULL : (prop = (g_object_unref (prop), NULL)));
+									return;
+								}
+							}
+						}
+						if (vala_property_accessor_get_automatic_body (vala_property_get_get_accessor (prop)) && VALA_SYMBOL (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->current_type_symbol) == vala_symbol_get_parent_symbol (VALA_SYMBOL (prop)) && vala_property_get_base_property (prop) == NULL && vala_property_get_base_interface_property (prop) == NULL) {
 							ValaCCodeExpression* inst;
-							ValaCCodeExpression* _tmp66;
-							ValaCCodeMemberAccess* _tmp68;
-							char* _tmp67;
+							ValaCCodeExpression* _tmp85;
+							ValaCCodeMemberAccess* _tmp87;
+							char* _tmp86;
 							inst = NULL;
-							_tmp66 = NULL;
-							inst = (_tmp66 = VALA_CCODE_EXPRESSION (vala_ccode_member_access_new_pointer (pub_inst, "priv")), (inst == NULL ? NULL : (inst = (g_object_unref (inst), NULL))), _tmp66);
-							_tmp68 = NULL;
-							_tmp67 = NULL;
-							vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE ((_tmp68 = vala_ccode_member_access_new_pointer (inst, (_tmp67 = vala_field_get_cname (vala_property_get_field (prop)))))));
-							(_tmp68 == NULL ? NULL : (_tmp68 = (g_object_unref (_tmp68), NULL)));
-							_tmp67 = (g_free (_tmp67), NULL);
+							_tmp85 = NULL;
+							inst = (_tmp85 = VALA_CCODE_EXPRESSION (vala_ccode_member_access_new_pointer (pub_inst, "priv")), (inst == NULL ? NULL : (inst = (g_object_unref (inst), NULL))), _tmp85);
+							_tmp87 = NULL;
+							_tmp86 = NULL;
+							vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE ((_tmp87 = vala_ccode_member_access_new_pointer (inst, (_tmp86 = vala_field_get_cname (vala_property_get_field (prop)))))));
+							(_tmp87 == NULL ? NULL : (_tmp87 = (g_object_unref (_tmp87), NULL)));
+							_tmp86 = (g_free (_tmp86), NULL);
 							(inst == NULL ? NULL : (inst = (g_object_unref (inst), NULL)));
 						} else {
 							if (!vala_property_get_no_accessor_method (prop)) {
-								ValaProperty* _tmp69;
+								ValaProperty* _tmp88;
 								ValaProperty* base_property;
-								ValaTypeSymbol* _tmp74;
-								ValaTypeSymbol* base_property_type;
 								char* getter_cname;
-								ValaCCodeIdentifier* _tmp79;
-								ValaCCodeFunctionCall* _tmp80;
+								ValaCCodeIdentifier* _tmp96;
+								ValaCCodeFunctionCall* _tmp97;
 								ValaCCodeFunctionCall* ccall;
-								_tmp69 = NULL;
-								base_property = (_tmp69 = prop, (_tmp69 == NULL ? NULL : g_object_ref (_tmp69)));
+								_tmp88 = NULL;
+								base_property = (_tmp88 = prop, (_tmp88 == NULL ? NULL : g_object_ref (_tmp88)));
 								if (vala_property_get_base_property (prop) != NULL) {
-									ValaProperty* _tmp71;
-									ValaProperty* _tmp70;
-									_tmp71 = NULL;
-									_tmp70 = NULL;
-									base_property = (_tmp71 = (_tmp70 = vala_property_get_base_property (prop), (_tmp70 == NULL ? NULL : g_object_ref (_tmp70))), (base_property == NULL ? NULL : (base_property = (g_object_unref (base_property), NULL))), _tmp71);
+									ValaProperty* _tmp90;
+									ValaProperty* _tmp89;
+									_tmp90 = NULL;
+									_tmp89 = NULL;
+									base_property = (_tmp90 = (_tmp89 = vala_property_get_base_property (prop), (_tmp89 == NULL ? NULL : g_object_ref (_tmp89))), (base_property == NULL ? NULL : (base_property = (g_object_unref (base_property), NULL))), _tmp90);
 								} else {
 									if (vala_property_get_base_interface_property (prop) != NULL) {
-										ValaProperty* _tmp73;
-										ValaProperty* _tmp72;
-										_tmp73 = NULL;
-										_tmp72 = NULL;
-										base_property = (_tmp73 = (_tmp72 = vala_property_get_base_interface_property (prop), (_tmp72 == NULL ? NULL : g_object_ref (_tmp72))), (base_property == NULL ? NULL : (base_property = (g_object_unref (base_property), NULL))), _tmp73);
+										ValaProperty* _tmp92;
+										ValaProperty* _tmp91;
+										_tmp92 = NULL;
+										_tmp91 = NULL;
+										base_property = (_tmp92 = (_tmp91 = vala_property_get_base_interface_property (prop), (_tmp91 == NULL ? NULL : g_object_ref (_tmp91))), (base_property == NULL ? NULL : (base_property = (g_object_unref (base_property), NULL))), _tmp92);
 									}
 								}
-								_tmp74 = NULL;
-								base_property_type = (_tmp74 = VALA_TYPESYMBOL (vala_symbol_get_parent_symbol (VALA_SYMBOL (base_property))), (_tmp74 == NULL ? NULL : g_object_ref (_tmp74)));
 								getter_cname = NULL;
 								if (VALA_IS_DYNAMIC_PROPERTY (prop)) {
-									char* _tmp76;
-									ValaCCodeDynamicPropertyBinding* _tmp75;
-									_tmp76 = NULL;
-									_tmp75 = NULL;
-									getter_cname = (_tmp76 = vala_ccode_dynamic_property_binding_get_getter_cname ((_tmp75 = vala_ccode_generator_dynamic_property_binding (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self)), VALA_DYNAMIC_PROPERTY (prop)))), (getter_cname = (g_free (getter_cname), NULL)), _tmp76);
-									(_tmp75 == NULL ? NULL : (_tmp75 = (g_object_unref (_tmp75), NULL)));
+									char* _tmp94;
+									ValaCCodeDynamicPropertyBinding* _tmp93;
+									_tmp94 = NULL;
+									_tmp93 = NULL;
+									getter_cname = (_tmp94 = vala_ccode_dynamic_property_binding_get_getter_cname ((_tmp93 = vala_ccode_generator_dynamic_property_binding (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self)), VALA_DYNAMIC_PROPERTY (prop)))), (getter_cname = (g_free (getter_cname), NULL)), _tmp94);
+									(_tmp93 == NULL ? NULL : (_tmp93 = (g_object_unref (_tmp93), NULL)));
 								} else {
-									char* _tmp78;
-									char* _tmp77;
-									_tmp78 = NULL;
-									_tmp77 = NULL;
-									getter_cname = (_tmp78 = g_strdup_printf ("%s_get_%s", (_tmp77 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (base_property_type), NULL)), vala_symbol_get_name (VALA_SYMBOL (base_property))), (getter_cname = (g_free (getter_cname), NULL)), _tmp78);
-									_tmp77 = (g_free (_tmp77), NULL);
+									char* _tmp95;
+									_tmp95 = NULL;
+									getter_cname = (_tmp95 = vala_property_accessor_get_cname (vala_property_get_get_accessor (base_property)), (getter_cname = (g_free (getter_cname), NULL)), _tmp95);
 								}
-								_tmp79 = NULL;
-								_tmp80 = NULL;
-								ccall = (_tmp80 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp79 = vala_ccode_identifier_new (getter_cname)))), (_tmp79 == NULL ? NULL : (_tmp79 = (g_object_unref (_tmp79), NULL))), _tmp80);
+								_tmp96 = NULL;
+								_tmp97 = NULL;
+								ccall = (_tmp97 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp96 = vala_ccode_identifier_new (getter_cname)))), (_tmp96 == NULL ? NULL : (_tmp96 = (g_object_unref (_tmp96), NULL))), _tmp97);
 								vala_ccode_function_call_add_argument (ccall, pub_inst);
 								/* Property acesses to real struct types are handeled different to other properties.
 								 They are returned as out parameter.*/
@@ -475,14 +547,14 @@ static void vala_ccode_member_access_binding_process_cmember (ValaCCodeMemberAcc
 									ValaCCodeCommaExpression* ccomma;
 									ValaLocalVariable* temp_var;
 									ValaCCodeIdentifier* ctemp;
-									ValaCCodeUnaryExpression* _tmp81;
+									ValaCCodeUnaryExpression* _tmp98;
 									ccomma = vala_ccode_comma_expression_new ();
 									temp_var = vala_ccode_generator_get_temp_variable (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self)), vala_property_get_property_type (base_property), TRUE, NULL);
 									ctemp = vala_ccode_identifier_new (vala_symbol_get_name (VALA_SYMBOL (temp_var)));
 									gee_collection_add (GEE_COLLECTION (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->temp_vars), temp_var);
-									_tmp81 = NULL;
-									vala_ccode_function_call_add_argument (ccall, VALA_CCODE_EXPRESSION ((_tmp81 = vala_ccode_unary_expression_new (VALA_CCODE_UNARY_OPERATOR_ADDRESS_OF, VALA_CCODE_EXPRESSION (ctemp)))));
-									(_tmp81 == NULL ? NULL : (_tmp81 = (g_object_unref (_tmp81), NULL)));
+									_tmp98 = NULL;
+									vala_ccode_function_call_add_argument (ccall, VALA_CCODE_EXPRESSION ((_tmp98 = vala_ccode_unary_expression_new (VALA_CCODE_UNARY_OPERATOR_ADDRESS_OF, VALA_CCODE_EXPRESSION (ctemp)))));
+									(_tmp98 == NULL ? NULL : (_tmp98 = (g_object_unref (_tmp98), NULL)));
 									vala_ccode_comma_expression_append_expression (ccomma, VALA_CCODE_EXPRESSION (ccall));
 									vala_ccode_comma_expression_append_expression (ccomma, VALA_CCODE_EXPRESSION (ctemp));
 									vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE (ccomma));
@@ -493,44 +565,43 @@ static void vala_ccode_member_access_binding_process_cmember (ValaCCodeMemberAcc
 									vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE (ccall));
 								}
 								(base_property == NULL ? NULL : (base_property = (g_object_unref (base_property), NULL)));
-								(base_property_type == NULL ? NULL : (base_property_type = (g_object_unref (base_property_type), NULL)));
 								getter_cname = (g_free (getter_cname), NULL);
 								(ccall == NULL ? NULL : (ccall = (g_object_unref (ccall), NULL)));
 							} else {
-								ValaCCodeIdentifier* _tmp82;
-								ValaCCodeFunctionCall* _tmp83;
+								ValaCCodeIdentifier* _tmp99;
+								ValaCCodeFunctionCall* _tmp100;
 								ValaCCodeFunctionCall* ccall;
-								ValaCCodeIdentifier* _tmp84;
-								ValaCCodeFunctionCall* _tmp85;
+								ValaCCodeIdentifier* _tmp101;
+								ValaCCodeFunctionCall* _tmp102;
 								ValaCCodeFunctionCall* ccast;
-								ValaCCodeConstant* _tmp86;
+								ValaCCodeConstant* _tmp103;
 								ValaLocalVariable* temp_var;
 								ValaCCodeIdentifier* ctemp;
-								ValaCCodeUnaryExpression* _tmp87;
-								ValaCCodeConstant* _tmp88;
+								ValaCCodeUnaryExpression* _tmp104;
+								ValaCCodeConstant* _tmp105;
 								ValaCCodeCommaExpression* ccomma;
-								_tmp82 = NULL;
-								_tmp83 = NULL;
-								ccall = (_tmp83 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp82 = vala_ccode_identifier_new ("g_object_get")))), (_tmp82 == NULL ? NULL : (_tmp82 = (g_object_unref (_tmp82), NULL))), _tmp83);
-								_tmp84 = NULL;
-								_tmp85 = NULL;
-								ccast = (_tmp85 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp84 = vala_ccode_identifier_new ("G_OBJECT")))), (_tmp84 == NULL ? NULL : (_tmp84 = (g_object_unref (_tmp84), NULL))), _tmp85);
+								_tmp99 = NULL;
+								_tmp100 = NULL;
+								ccall = (_tmp100 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp99 = vala_ccode_identifier_new ("g_object_get")))), (_tmp99 == NULL ? NULL : (_tmp99 = (g_object_unref (_tmp99), NULL))), _tmp100);
+								_tmp101 = NULL;
+								_tmp102 = NULL;
+								ccast = (_tmp102 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp101 = vala_ccode_identifier_new ("G_OBJECT")))), (_tmp101 == NULL ? NULL : (_tmp101 = (g_object_unref (_tmp101), NULL))), _tmp102);
 								vala_ccode_function_call_add_argument (ccast, pub_inst);
 								vala_ccode_function_call_add_argument (ccall, VALA_CCODE_EXPRESSION (ccast));
 								/* property name is second argument of g_object_get*/
-								_tmp86 = NULL;
-								vala_ccode_function_call_add_argument (ccall, VALA_CCODE_EXPRESSION ((_tmp86 = vala_property_get_canonical_cconstant (prop))));
-								(_tmp86 == NULL ? NULL : (_tmp86 = (g_object_unref (_tmp86), NULL)));
+								_tmp103 = NULL;
+								vala_ccode_function_call_add_argument (ccall, VALA_CCODE_EXPRESSION ((_tmp103 = vala_property_get_canonical_cconstant (prop))));
+								(_tmp103 == NULL ? NULL : (_tmp103 = (g_object_unref (_tmp103), NULL)));
 								/* we need a temporary variable to save the property value*/
 								temp_var = vala_ccode_generator_get_temp_variable (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self)), vala_expression_get_value_type (VALA_EXPRESSION (expr)), TRUE, NULL);
 								gee_list_insert (GEE_LIST (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->temp_vars), 0, temp_var);
 								ctemp = vala_ccode_identifier_new (vala_symbol_get_name (VALA_SYMBOL (temp_var)));
-								_tmp87 = NULL;
-								vala_ccode_function_call_add_argument (ccall, VALA_CCODE_EXPRESSION ((_tmp87 = vala_ccode_unary_expression_new (VALA_CCODE_UNARY_OPERATOR_ADDRESS_OF, VALA_CCODE_EXPRESSION (ctemp)))));
-								(_tmp87 == NULL ? NULL : (_tmp87 = (g_object_unref (_tmp87), NULL)));
-								_tmp88 = NULL;
-								vala_ccode_function_call_add_argument (ccall, VALA_CCODE_EXPRESSION ((_tmp88 = vala_ccode_constant_new ("NULL"))));
-								(_tmp88 == NULL ? NULL : (_tmp88 = (g_object_unref (_tmp88), NULL)));
+								_tmp104 = NULL;
+								vala_ccode_function_call_add_argument (ccall, VALA_CCODE_EXPRESSION ((_tmp104 = vala_ccode_unary_expression_new (VALA_CCODE_UNARY_OPERATOR_ADDRESS_OF, VALA_CCODE_EXPRESSION (ctemp)))));
+								(_tmp104 == NULL ? NULL : (_tmp104 = (g_object_unref (_tmp104), NULL)));
+								_tmp105 = NULL;
+								vala_ccode_function_call_add_argument (ccall, VALA_CCODE_EXPRESSION ((_tmp105 = vala_ccode_constant_new ("NULL"))));
+								(_tmp105 == NULL ? NULL : (_tmp105 = (g_object_unref (_tmp105), NULL)));
 								ccomma = vala_ccode_comma_expression_new ();
 								vala_ccode_comma_expression_append_expression (ccomma, VALA_CCODE_EXPRESSION (ccall));
 								vala_ccode_comma_expression_append_expression (ccomma, VALA_CCODE_EXPRESSION (ctemp));
@@ -545,86 +616,86 @@ static void vala_ccode_member_access_binding_process_cmember (ValaCCodeMemberAcc
 						(prop == NULL ? NULL : (prop = (g_object_unref (prop), NULL)));
 					} else {
 						if (VALA_IS_ENUM_VALUE (vala_expression_get_symbol_reference (VALA_EXPRESSION (expr)))) {
-							ValaEnumValue* _tmp89;
+							ValaEnumValue* _tmp106;
 							ValaEnumValue* ev;
-							ValaCCodeConstant* _tmp91;
-							char* _tmp90;
-							_tmp89 = NULL;
-							ev = (_tmp89 = VALA_ENUM_VALUE (vala_expression_get_symbol_reference (VALA_EXPRESSION (expr))), (_tmp89 == NULL ? NULL : g_object_ref (_tmp89)));
-							_tmp91 = NULL;
-							_tmp90 = NULL;
-							vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE ((_tmp91 = vala_ccode_constant_new ((_tmp90 = vala_enum_value_get_cname (ev))))));
-							(_tmp91 == NULL ? NULL : (_tmp91 = (g_object_unref (_tmp91), NULL)));
-							_tmp90 = (g_free (_tmp90), NULL);
+							ValaCCodeConstant* _tmp108;
+							char* _tmp107;
+							_tmp106 = NULL;
+							ev = (_tmp106 = VALA_ENUM_VALUE (vala_expression_get_symbol_reference (VALA_EXPRESSION (expr))), (_tmp106 == NULL ? NULL : g_object_ref (_tmp106)));
+							_tmp108 = NULL;
+							_tmp107 = NULL;
+							vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE ((_tmp108 = vala_ccode_constant_new ((_tmp107 = vala_enum_value_get_cname (ev))))));
+							(_tmp108 == NULL ? NULL : (_tmp108 = (g_object_unref (_tmp108), NULL)));
+							_tmp107 = (g_free (_tmp107), NULL);
 							(ev == NULL ? NULL : (ev = (g_object_unref (ev), NULL)));
 						} else {
 							if (VALA_IS_LOCAL_VARIABLE (vala_expression_get_symbol_reference (VALA_EXPRESSION (expr)))) {
-								ValaLocalVariable* _tmp92;
+								ValaLocalVariable* _tmp109;
 								ValaLocalVariable* local;
-								ValaCCodeIdentifier* _tmp94;
-								char* _tmp93;
-								_tmp92 = NULL;
-								local = (_tmp92 = VALA_LOCAL_VARIABLE (vala_expression_get_symbol_reference (VALA_EXPRESSION (expr))), (_tmp92 == NULL ? NULL : g_object_ref (_tmp92)));
-								_tmp94 = NULL;
-								_tmp93 = NULL;
-								vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE ((_tmp94 = vala_ccode_identifier_new ((_tmp93 = vala_ccode_generator_get_variable_cname (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self)), vala_symbol_get_name (VALA_SYMBOL (local))))))));
-								(_tmp94 == NULL ? NULL : (_tmp94 = (g_object_unref (_tmp94), NULL)));
-								_tmp93 = (g_free (_tmp93), NULL);
+								ValaCCodeIdentifier* _tmp111;
+								char* _tmp110;
+								_tmp109 = NULL;
+								local = (_tmp109 = VALA_LOCAL_VARIABLE (vala_expression_get_symbol_reference (VALA_EXPRESSION (expr))), (_tmp109 == NULL ? NULL : g_object_ref (_tmp109)));
+								_tmp111 = NULL;
+								_tmp110 = NULL;
+								vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE ((_tmp111 = vala_ccode_identifier_new ((_tmp110 = vala_ccode_generator_get_variable_cname (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self)), vala_symbol_get_name (VALA_SYMBOL (local))))))));
+								(_tmp111 == NULL ? NULL : (_tmp111 = (g_object_unref (_tmp111), NULL)));
+								_tmp110 = (g_free (_tmp110), NULL);
 								(local == NULL ? NULL : (local = (g_object_unref (local), NULL)));
 							} else {
 								if (VALA_IS_FORMAL_PARAMETER (vala_expression_get_symbol_reference (VALA_EXPRESSION (expr)))) {
-									ValaFormalParameter* _tmp95;
+									ValaFormalParameter* _tmp112;
 									ValaFormalParameter* p;
-									_tmp95 = NULL;
-									p = (_tmp95 = VALA_FORMAL_PARAMETER (vala_expression_get_symbol_reference (VALA_EXPRESSION (expr))), (_tmp95 == NULL ? NULL : g_object_ref (_tmp95)));
+									_tmp112 = NULL;
+									p = (_tmp112 = VALA_FORMAL_PARAMETER (vala_expression_get_symbol_reference (VALA_EXPRESSION (expr))), (_tmp112 == NULL ? NULL : g_object_ref (_tmp112)));
 									if (_vala_strcmp0 (vala_symbol_get_name (VALA_SYMBOL (p)), "this") == 0) {
-										ValaStruct* _tmp97;
-										ValaTypeSymbol* _tmp96;
+										ValaStruct* _tmp114;
+										ValaTypeSymbol* _tmp113;
 										ValaStruct* st;
-										_tmp97 = NULL;
-										_tmp96 = NULL;
-										st = (_tmp97 = (_tmp96 = vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->current_type_symbol, (VALA_IS_STRUCT (_tmp96) ? ((ValaStruct*) (_tmp96)) : NULL)), (_tmp97 == NULL ? NULL : g_object_ref (_tmp97)));
+										_tmp114 = NULL;
+										_tmp113 = NULL;
+										st = (_tmp114 = (_tmp113 = vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->current_type_symbol, (VALA_IS_STRUCT (_tmp113) ? ((ValaStruct*) (_tmp113)) : NULL)), (_tmp114 == NULL ? NULL : g_object_ref (_tmp114)));
 										if (st != NULL && !vala_struct_is_simple_type (st)) {
-											ValaCCodeIdentifier* _tmp98;
-											_tmp98 = NULL;
-											vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE ((_tmp98 = vala_ccode_identifier_new ("(*self)"))));
-											(_tmp98 == NULL ? NULL : (_tmp98 = (g_object_unref (_tmp98), NULL)));
+											ValaCCodeIdentifier* _tmp115;
+											_tmp115 = NULL;
+											vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE ((_tmp115 = vala_ccode_identifier_new ("(*self)"))));
+											(_tmp115 == NULL ? NULL : (_tmp115 = (g_object_unref (_tmp115), NULL)));
 										} else {
-											ValaCCodeIdentifier* _tmp99;
-											_tmp99 = NULL;
-											vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE ((_tmp99 = vala_ccode_identifier_new ("self"))));
-											(_tmp99 == NULL ? NULL : (_tmp99 = (g_object_unref (_tmp99), NULL)));
+											ValaCCodeIdentifier* _tmp116;
+											_tmp116 = NULL;
+											vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE ((_tmp116 = vala_ccode_identifier_new ("self"))));
+											(_tmp116 == NULL ? NULL : (_tmp116 = (g_object_unref (_tmp116), NULL)));
 										}
 										(st == NULL ? NULL : (st = (g_object_unref (st), NULL)));
 									} else {
-										ValaStruct* _tmp101;
-										ValaTypeSymbol* _tmp100;
+										ValaStruct* _tmp118;
+										ValaTypeSymbol* _tmp117;
 										ValaStruct* type_as_struct;
-										_tmp101 = NULL;
-										_tmp100 = NULL;
-										type_as_struct = (_tmp101 = (_tmp100 = vala_data_type_get_data_type (vala_formal_parameter_get_parameter_type (p)), (VALA_IS_STRUCT (_tmp100) ? ((ValaStruct*) (_tmp100)) : NULL)), (_tmp101 == NULL ? NULL : g_object_ref (_tmp101)));
+										_tmp118 = NULL;
+										_tmp117 = NULL;
+										type_as_struct = (_tmp118 = (_tmp117 = vala_data_type_get_data_type (vala_formal_parameter_get_parameter_type (p)), (VALA_IS_STRUCT (_tmp117) ? ((ValaStruct*) (_tmp117)) : NULL)), (_tmp118 == NULL ? NULL : g_object_ref (_tmp118)));
 										if (vala_formal_parameter_get_direction (p) != VALA_PARAMETER_DIRECTION_IN || (type_as_struct != NULL && !vala_struct_is_simple_type (type_as_struct) && !vala_data_type_get_nullable (vala_formal_parameter_get_parameter_type (p)))) {
-											ValaCCodeIdentifier* _tmp103;
-											char* _tmp102;
-											_tmp103 = NULL;
-											_tmp102 = NULL;
-											vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE ((_tmp103 = vala_ccode_identifier_new ((_tmp102 = g_strdup_printf ("(*%s)", vala_symbol_get_name (VALA_SYMBOL (p))))))));
-											(_tmp103 == NULL ? NULL : (_tmp103 = (g_object_unref (_tmp103), NULL)));
-											_tmp102 = (g_free (_tmp102), NULL);
+											ValaCCodeIdentifier* _tmp120;
+											char* _tmp119;
+											_tmp120 = NULL;
+											_tmp119 = NULL;
+											vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE ((_tmp120 = vala_ccode_identifier_new ((_tmp119 = g_strdup_printf ("(*%s)", vala_symbol_get_name (VALA_SYMBOL (p))))))));
+											(_tmp120 == NULL ? NULL : (_tmp120 = (g_object_unref (_tmp120), NULL)));
+											_tmp119 = (g_free (_tmp119), NULL);
 										} else {
 											/* Property setters of non simple structs shall replace all occurences
 											 of the "value" formal parameter with a dereferencing version of that
 											 parameter.*/
 											if (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->current_property_accessor != NULL && vala_property_accessor_get_writable (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->current_property_accessor) && vala_property_accessor_get_value_parameter (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->current_property_accessor) == p && vala_data_type_is_real_struct_type (vala_property_get_property_type (vala_property_accessor_get_prop (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->current_property_accessor)))) {
-												ValaCCodeIdentifier* _tmp104;
-												_tmp104 = NULL;
-												vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE ((_tmp104 = vala_ccode_identifier_new ("(*value)"))));
-												(_tmp104 == NULL ? NULL : (_tmp104 = (g_object_unref (_tmp104), NULL)));
+												ValaCCodeIdentifier* _tmp121;
+												_tmp121 = NULL;
+												vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE ((_tmp121 = vala_ccode_identifier_new ("(*value)"))));
+												(_tmp121 == NULL ? NULL : (_tmp121 = (g_object_unref (_tmp121), NULL)));
 											} else {
-												ValaCCodeIdentifier* _tmp105;
-												_tmp105 = NULL;
-												vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE ((_tmp105 = vala_ccode_identifier_new (vala_symbol_get_name (VALA_SYMBOL (p))))));
-												(_tmp105 == NULL ? NULL : (_tmp105 = (g_object_unref (_tmp105), NULL)));
+												ValaCCodeIdentifier* _tmp122;
+												_tmp122 = NULL;
+												vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE ((_tmp122 = vala_ccode_identifier_new (vala_symbol_get_name (VALA_SYMBOL (p))))));
+												(_tmp122 == NULL ? NULL : (_tmp122 = (g_object_unref (_tmp122), NULL)));
 											}
 										}
 										(type_as_struct == NULL ? NULL : (type_as_struct = (g_object_unref (type_as_struct), NULL)));
@@ -632,48 +703,48 @@ static void vala_ccode_member_access_binding_process_cmember (ValaCCodeMemberAcc
 									(p == NULL ? NULL : (p = (g_object_unref (p), NULL)));
 								} else {
 									if (VALA_IS_SIGNAL (vala_expression_get_symbol_reference (VALA_EXPRESSION (expr)))) {
-										ValaSignal* _tmp106;
+										ValaSignal* _tmp123;
 										ValaSignal* sig;
-										ValaTypeSymbol* _tmp107;
+										ValaTypeSymbol* _tmp124;
 										ValaTypeSymbol* cl;
-										_tmp106 = NULL;
-										sig = (_tmp106 = VALA_SIGNAL (vala_expression_get_symbol_reference (VALA_EXPRESSION (expr))), (_tmp106 == NULL ? NULL : g_object_ref (_tmp106)));
-										_tmp107 = NULL;
-										cl = (_tmp107 = VALA_TYPESYMBOL (vala_symbol_get_parent_symbol (VALA_SYMBOL (sig))), (_tmp107 == NULL ? NULL : g_object_ref (_tmp107)));
+										_tmp123 = NULL;
+										sig = (_tmp123 = VALA_SIGNAL (vala_expression_get_symbol_reference (VALA_EXPRESSION (expr))), (_tmp123 == NULL ? NULL : g_object_ref (_tmp123)));
+										_tmp124 = NULL;
+										cl = (_tmp124 = VALA_TYPESYMBOL (vala_symbol_get_parent_symbol (VALA_SYMBOL (sig))), (_tmp124 == NULL ? NULL : g_object_ref (_tmp124)));
 										if (vala_signal_get_has_emitter (sig)) {
-											ValaCCodeIdentifier* _tmp110;
-											char* _tmp109;
-											char* _tmp108;
-											ValaCCodeFunctionCall* _tmp111;
+											ValaCCodeIdentifier* _tmp127;
+											char* _tmp126;
+											char* _tmp125;
+											ValaCCodeFunctionCall* _tmp128;
 											ValaCCodeFunctionCall* ccall;
-											_tmp110 = NULL;
-											_tmp109 = NULL;
-											_tmp108 = NULL;
-											_tmp111 = NULL;
-											ccall = (_tmp111 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp110 = vala_ccode_identifier_new ((_tmp109 = g_strdup_printf ("%s_%s", (_tmp108 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (cl), NULL)), vala_symbol_get_name (VALA_SYMBOL (sig)))))))), (_tmp110 == NULL ? NULL : (_tmp110 = (g_object_unref (_tmp110), NULL))), (_tmp109 = (g_free (_tmp109), NULL)), (_tmp108 = (g_free (_tmp108), NULL)), _tmp111);
+											_tmp127 = NULL;
+											_tmp126 = NULL;
+											_tmp125 = NULL;
+											_tmp128 = NULL;
+											ccall = (_tmp128 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp127 = vala_ccode_identifier_new ((_tmp126 = g_strdup_printf ("%s_%s", (_tmp125 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (cl), NULL)), vala_symbol_get_name (VALA_SYMBOL (sig)))))))), (_tmp127 == NULL ? NULL : (_tmp127 = (g_object_unref (_tmp127), NULL))), (_tmp126 = (g_free (_tmp126), NULL)), (_tmp125 = (g_free (_tmp125), NULL)), _tmp128);
 											vala_ccode_function_call_add_argument (ccall, pub_inst);
 											vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE (ccall));
 											(ccall == NULL ? NULL : (ccall = (g_object_unref (ccall), NULL)));
 										} else {
-											ValaCCodeIdentifier* _tmp112;
-											ValaCCodeFunctionCall* _tmp113;
+											ValaCCodeIdentifier* _tmp129;
+											ValaCCodeFunctionCall* _tmp130;
 											ValaCCodeFunctionCall* ccall;
-											ValaCCodeIdentifier* _tmp114;
-											ValaCCodeFunctionCall* _tmp115;
+											ValaCCodeIdentifier* _tmp131;
+											ValaCCodeFunctionCall* _tmp132;
 											ValaCCodeFunctionCall* ccast;
-											ValaCCodeConstant* _tmp116;
-											_tmp112 = NULL;
-											_tmp113 = NULL;
-											ccall = (_tmp113 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp112 = vala_ccode_identifier_new ("g_signal_emit_by_name")))), (_tmp112 == NULL ? NULL : (_tmp112 = (g_object_unref (_tmp112), NULL))), _tmp113);
+											ValaCCodeConstant* _tmp133;
+											_tmp129 = NULL;
+											_tmp130 = NULL;
+											ccall = (_tmp130 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp129 = vala_ccode_identifier_new ("g_signal_emit_by_name")))), (_tmp129 == NULL ? NULL : (_tmp129 = (g_object_unref (_tmp129), NULL))), _tmp130);
 											/* FIXME: use C cast if debugging disabled*/
-											_tmp114 = NULL;
-											_tmp115 = NULL;
-											ccast = (_tmp115 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp114 = vala_ccode_identifier_new ("G_OBJECT")))), (_tmp114 == NULL ? NULL : (_tmp114 = (g_object_unref (_tmp114), NULL))), _tmp115);
+											_tmp131 = NULL;
+											_tmp132 = NULL;
+											ccast = (_tmp132 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp131 = vala_ccode_identifier_new ("G_OBJECT")))), (_tmp131 == NULL ? NULL : (_tmp131 = (g_object_unref (_tmp131), NULL))), _tmp132);
 											vala_ccode_function_call_add_argument (ccast, pub_inst);
 											vala_ccode_function_call_add_argument (ccall, VALA_CCODE_EXPRESSION (ccast));
-											_tmp116 = NULL;
-											vala_ccode_function_call_add_argument (ccall, VALA_CCODE_EXPRESSION ((_tmp116 = vala_signal_get_canonical_cconstant (sig, NULL))));
-											(_tmp116 == NULL ? NULL : (_tmp116 = (g_object_unref (_tmp116), NULL)));
+											_tmp133 = NULL;
+											vala_ccode_function_call_add_argument (ccall, VALA_CCODE_EXPRESSION ((_tmp133 = vala_signal_get_canonical_cconstant (sig, NULL))));
+											(_tmp133 == NULL ? NULL : (_tmp133 = (g_object_unref (_tmp133), NULL)));
 											vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE (ccall));
 											(ccall == NULL ? NULL : (ccall = (g_object_unref (ccall), NULL)));
 											(ccast == NULL ? NULL : (ccast = (g_object_unref (ccast), NULL)));
@@ -737,6 +808,7 @@ void vala_ccode_member_access_binding_set_member_access (ValaCCodeMemberAccessBi
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_member_access = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_member_access == NULL ? NULL : (self->priv->_member_access = (g_object_unref (self->priv->_member_access), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "member-access");
 }
 
 
@@ -773,7 +845,7 @@ static void vala_ccode_member_access_binding_class_init (ValaCCodeMemberAccessBi
 	g_type_class_add_private (klass, sizeof (ValaCCodeMemberAccessBindingPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_ccode_member_access_binding_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_ccode_member_access_binding_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_ccode_member_access_binding_dispose;
+	G_OBJECT_CLASS (klass)->finalize = vala_ccode_member_access_binding_finalize;
 	VALA_CCODE_BINDING_CLASS (klass)->emit = vala_ccode_member_access_binding_real_emit;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_MEMBER_ACCESS_BINDING_MEMBER_ACCESS, g_param_spec_object ("member-access", "member-access", "member-access", VALA_TYPE_MEMBER_ACCESS, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
@@ -784,17 +856,17 @@ static void vala_ccode_member_access_binding_instance_init (ValaCCodeMemberAcces
 }
 
 
-static void vala_ccode_member_access_binding_dispose (GObject * obj) {
+static void vala_ccode_member_access_binding_finalize (GObject * obj) {
 	ValaCCodeMemberAccessBinding * self;
 	self = VALA_CCODE_MEMBER_ACCESS_BINDING (obj);
 	(self->priv->_member_access == NULL ? NULL : (self->priv->_member_access = (g_object_unref (self->priv->_member_access), NULL)));
-	G_OBJECT_CLASS (vala_ccode_member_access_binding_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (vala_ccode_member_access_binding_parent_class)->finalize (obj);
 }
 
 
 GType vala_ccode_member_access_binding_get_type (void) {
 	static GType vala_ccode_member_access_binding_type_id = 0;
-	if (G_UNLIKELY (vala_ccode_member_access_binding_type_id == 0)) {
+	if (vala_ccode_member_access_binding_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeMemberAccessBindingClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_member_access_binding_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeMemberAccessBinding), 0, (GInstanceInitFunc) vala_ccode_member_access_binding_instance_init };
 		vala_ccode_member_access_binding_type_id = g_type_register_static (VALA_TYPE_CCODE_EXPRESSION_BINDING, "ValaCCodeMemberAccessBinding", &g_define_type_info, 0);
 	}
