@@ -36,10 +36,10 @@
 #include <vala/valapropertyaccessor.h>
 #include <vala/valasymbol.h>
 #include <gee/list.h>
-#include <gee/collection.h>
 #include <vala/valapointertype.h>
 #include <vala/valaerrortype.h>
 #include <vala/valaformalparameter.h>
+#include <vala/valaarraytype.h>
 #include <gobject/valaccodegenerator.h>
 
 
@@ -61,8 +61,8 @@ ValaCCodeFunctionCall* vala_ccode_type_symbol_binding_get_param_spec (ValaCCodeT
 	ValaCCodeConstant* _tmp4;
 	char* _tmp3;
 	char* pflags;
-	ValaCCodeConstant* _tmp81;
-	ValaCCodeFunctionCall* _tmp82;
+	ValaCCodeConstant* _tmp99;
+	ValaCCodeFunctionCall* _tmp100;
 	g_return_val_if_fail (VALA_IS_CCODE_TYPE_SYMBOL_BINDING (self), NULL);
 	g_return_val_if_fail (VALA_IS_PROPERTY (prop), NULL);
 	cspec = vala_ccode_function_call_new (NULL);
@@ -88,7 +88,7 @@ ValaCCodeFunctionCall* vala_ccode_type_symbol_binding_get_param_spec (ValaCCodeT
 		(_tmp5 == NULL ? NULL : (_tmp5 = (g_object_unref (_tmp5), NULL)));
 		_tmp7 = NULL;
 		_tmp6 = NULL;
-		vala_ccode_function_call_add_argument (cspec, VALA_CCODE_EXPRESSION ((_tmp7 = vala_ccode_identifier_new ((_tmp6 = vala_typesymbol_get_upper_case_cname (vala_data_type_get_data_type (vala_property_get_property_type (prop)), "TYPE_"))))));
+		vala_ccode_function_call_add_argument (cspec, VALA_CCODE_EXPRESSION ((_tmp7 = vala_ccode_identifier_new ((_tmp6 = vala_typesymbol_get_type_id (vala_data_type_get_data_type (vala_property_get_property_type (prop))))))));
 		(_tmp7 == NULL ? NULL : (_tmp7 = (g_object_unref (_tmp7), NULL)));
 		_tmp6 = (g_free (_tmp6), NULL);
 	} else {
@@ -228,166 +228,244 @@ ValaCCodeFunctionCall* vala_ccode_type_symbol_binding_get_param_spec (ValaCCodeT
 							char* _tmp37;
 							gboolean _tmp38;
 							_tmp37 = NULL;
-							if ((_tmp38 = _vala_strcmp0 ((_tmp37 = vala_typesymbol_get_type_id (VALA_TYPESYMBOL (st))), "G_TYPE_LONG") == 0, (_tmp37 = (g_free (_tmp37), NULL)), _tmp38)) {
+							if ((_tmp38 = _vala_strcmp0 ((_tmp37 = vala_typesymbol_get_type_id (VALA_TYPESYMBOL (st))), "G_TYPE_INT64") == 0, (_tmp37 = (g_free (_tmp37), NULL)), _tmp38)) {
 								ValaCCodeIdentifier* _tmp39;
 								ValaCCodeConstant* _tmp40;
 								ValaCCodeConstant* _tmp41;
 								_tmp39 = NULL;
-								vala_ccode_function_call_set_call (cspec, VALA_CCODE_EXPRESSION ((_tmp39 = vala_ccode_identifier_new ("g_param_spec_long"))));
+								vala_ccode_function_call_set_call (cspec, VALA_CCODE_EXPRESSION ((_tmp39 = vala_ccode_identifier_new ("g_param_spec_int64"))));
 								(_tmp39 == NULL ? NULL : (_tmp39 = (g_object_unref (_tmp39), NULL)));
 								_tmp40 = NULL;
-								vala_ccode_function_call_add_argument (cspec, VALA_CCODE_EXPRESSION ((_tmp40 = vala_ccode_constant_new ("G_MINLONG"))));
+								vala_ccode_function_call_add_argument (cspec, VALA_CCODE_EXPRESSION ((_tmp40 = vala_ccode_constant_new ("G_MININT64"))));
 								(_tmp40 == NULL ? NULL : (_tmp40 = (g_object_unref (_tmp40), NULL)));
 								_tmp41 = NULL;
-								vala_ccode_function_call_add_argument (cspec, VALA_CCODE_EXPRESSION ((_tmp41 = vala_ccode_constant_new ("G_MAXLONG"))));
+								vala_ccode_function_call_add_argument (cspec, VALA_CCODE_EXPRESSION ((_tmp41 = vala_ccode_constant_new ("G_MAXINT64"))));
 								(_tmp41 == NULL ? NULL : (_tmp41 = (g_object_unref (_tmp41), NULL)));
 								if (vala_property_get_default_expression (prop) != NULL) {
 									vala_ccode_function_call_add_argument (cspec, VALA_CCODE_EXPRESSION (vala_code_node_get_ccodenode (VALA_CODE_NODE (vala_property_get_default_expression (prop)))));
 								} else {
 									ValaCCodeConstant* _tmp42;
 									_tmp42 = NULL;
-									vala_ccode_function_call_add_argument (cspec, VALA_CCODE_EXPRESSION ((_tmp42 = vala_ccode_constant_new ("0L"))));
+									vala_ccode_function_call_add_argument (cspec, VALA_CCODE_EXPRESSION ((_tmp42 = vala_ccode_constant_new ("0"))));
 									(_tmp42 == NULL ? NULL : (_tmp42 = (g_object_unref (_tmp42), NULL)));
 								}
 							} else {
 								char* _tmp43;
 								gboolean _tmp44;
 								_tmp43 = NULL;
-								if ((_tmp44 = _vala_strcmp0 ((_tmp43 = vala_typesymbol_get_type_id (VALA_TYPESYMBOL (st))), "G_TYPE_ULONG") == 0, (_tmp43 = (g_free (_tmp43), NULL)), _tmp44)) {
+								if ((_tmp44 = _vala_strcmp0 ((_tmp43 = vala_typesymbol_get_type_id (VALA_TYPESYMBOL (st))), "G_TYPE_UINT64") == 0, (_tmp43 = (g_free (_tmp43), NULL)), _tmp44)) {
 									ValaCCodeIdentifier* _tmp45;
 									ValaCCodeConstant* _tmp46;
 									ValaCCodeConstant* _tmp47;
 									_tmp45 = NULL;
-									vala_ccode_function_call_set_call (cspec, VALA_CCODE_EXPRESSION ((_tmp45 = vala_ccode_identifier_new ("g_param_spec_ulong"))));
+									vala_ccode_function_call_set_call (cspec, VALA_CCODE_EXPRESSION ((_tmp45 = vala_ccode_identifier_new ("g_param_spec_uint64"))));
 									(_tmp45 == NULL ? NULL : (_tmp45 = (g_object_unref (_tmp45), NULL)));
 									_tmp46 = NULL;
 									vala_ccode_function_call_add_argument (cspec, VALA_CCODE_EXPRESSION ((_tmp46 = vala_ccode_constant_new ("0"))));
 									(_tmp46 == NULL ? NULL : (_tmp46 = (g_object_unref (_tmp46), NULL)));
 									_tmp47 = NULL;
-									vala_ccode_function_call_add_argument (cspec, VALA_CCODE_EXPRESSION ((_tmp47 = vala_ccode_constant_new ("G_MAXULONG"))));
+									vala_ccode_function_call_add_argument (cspec, VALA_CCODE_EXPRESSION ((_tmp47 = vala_ccode_constant_new ("G_MAXUINT64"))));
 									(_tmp47 == NULL ? NULL : (_tmp47 = (g_object_unref (_tmp47), NULL)));
 									if (vala_property_get_default_expression (prop) != NULL) {
 										vala_ccode_function_call_add_argument (cspec, VALA_CCODE_EXPRESSION (vala_code_node_get_ccodenode (VALA_CODE_NODE (vala_property_get_default_expression (prop)))));
 									} else {
 										ValaCCodeConstant* _tmp48;
 										_tmp48 = NULL;
-										vala_ccode_function_call_add_argument (cspec, VALA_CCODE_EXPRESSION ((_tmp48 = vala_ccode_constant_new ("0UL"))));
+										vala_ccode_function_call_add_argument (cspec, VALA_CCODE_EXPRESSION ((_tmp48 = vala_ccode_constant_new ("0U"))));
 										(_tmp48 == NULL ? NULL : (_tmp48 = (g_object_unref (_tmp48), NULL)));
 									}
 								} else {
 									char* _tmp49;
 									gboolean _tmp50;
 									_tmp49 = NULL;
-									if ((_tmp50 = _vala_strcmp0 ((_tmp49 = vala_typesymbol_get_type_id (VALA_TYPESYMBOL (st))), "G_TYPE_BOOLEAN") == 0, (_tmp49 = (g_free (_tmp49), NULL)), _tmp50)) {
+									if ((_tmp50 = _vala_strcmp0 ((_tmp49 = vala_typesymbol_get_type_id (VALA_TYPESYMBOL (st))), "G_TYPE_LONG") == 0, (_tmp49 = (g_free (_tmp49), NULL)), _tmp50)) {
 										ValaCCodeIdentifier* _tmp51;
+										ValaCCodeConstant* _tmp52;
+										ValaCCodeConstant* _tmp53;
 										_tmp51 = NULL;
-										vala_ccode_function_call_set_call (cspec, VALA_CCODE_EXPRESSION ((_tmp51 = vala_ccode_identifier_new ("g_param_spec_boolean"))));
+										vala_ccode_function_call_set_call (cspec, VALA_CCODE_EXPRESSION ((_tmp51 = vala_ccode_identifier_new ("g_param_spec_long"))));
 										(_tmp51 == NULL ? NULL : (_tmp51 = (g_object_unref (_tmp51), NULL)));
+										_tmp52 = NULL;
+										vala_ccode_function_call_add_argument (cspec, VALA_CCODE_EXPRESSION ((_tmp52 = vala_ccode_constant_new ("G_MINLONG"))));
+										(_tmp52 == NULL ? NULL : (_tmp52 = (g_object_unref (_tmp52), NULL)));
+										_tmp53 = NULL;
+										vala_ccode_function_call_add_argument (cspec, VALA_CCODE_EXPRESSION ((_tmp53 = vala_ccode_constant_new ("G_MAXLONG"))));
+										(_tmp53 == NULL ? NULL : (_tmp53 = (g_object_unref (_tmp53), NULL)));
 										if (vala_property_get_default_expression (prop) != NULL) {
 											vala_ccode_function_call_add_argument (cspec, VALA_CCODE_EXPRESSION (vala_code_node_get_ccodenode (VALA_CODE_NODE (vala_property_get_default_expression (prop)))));
 										} else {
-											ValaCCodeConstant* _tmp52;
-											_tmp52 = NULL;
-											vala_ccode_function_call_add_argument (cspec, VALA_CCODE_EXPRESSION ((_tmp52 = vala_ccode_constant_new ("FALSE"))));
-											(_tmp52 == NULL ? NULL : (_tmp52 = (g_object_unref (_tmp52), NULL)));
+											ValaCCodeConstant* _tmp54;
+											_tmp54 = NULL;
+											vala_ccode_function_call_add_argument (cspec, VALA_CCODE_EXPRESSION ((_tmp54 = vala_ccode_constant_new ("0L"))));
+											(_tmp54 == NULL ? NULL : (_tmp54 = (g_object_unref (_tmp54), NULL)));
 										}
 									} else {
-										char* _tmp53;
-										gboolean _tmp54;
-										_tmp53 = NULL;
-										if ((_tmp54 = _vala_strcmp0 ((_tmp53 = vala_typesymbol_get_type_id (VALA_TYPESYMBOL (st))), "G_TYPE_CHAR") == 0, (_tmp53 = (g_free (_tmp53), NULL)), _tmp54)) {
-											ValaCCodeIdentifier* _tmp55;
-											ValaCCodeConstant* _tmp56;
-											ValaCCodeConstant* _tmp57;
-											_tmp55 = NULL;
-											vala_ccode_function_call_set_call (cspec, VALA_CCODE_EXPRESSION ((_tmp55 = vala_ccode_identifier_new ("g_param_spec_char"))));
-											(_tmp55 == NULL ? NULL : (_tmp55 = (g_object_unref (_tmp55), NULL)));
-											_tmp56 = NULL;
-											vala_ccode_function_call_add_argument (cspec, VALA_CCODE_EXPRESSION ((_tmp56 = vala_ccode_constant_new ("G_MININT8"))));
-											(_tmp56 == NULL ? NULL : (_tmp56 = (g_object_unref (_tmp56), NULL)));
+										char* _tmp55;
+										gboolean _tmp56;
+										_tmp55 = NULL;
+										if ((_tmp56 = _vala_strcmp0 ((_tmp55 = vala_typesymbol_get_type_id (VALA_TYPESYMBOL (st))), "G_TYPE_ULONG") == 0, (_tmp55 = (g_free (_tmp55), NULL)), _tmp56)) {
+											ValaCCodeIdentifier* _tmp57;
+											ValaCCodeConstant* _tmp58;
+											ValaCCodeConstant* _tmp59;
 											_tmp57 = NULL;
-											vala_ccode_function_call_add_argument (cspec, VALA_CCODE_EXPRESSION ((_tmp57 = vala_ccode_constant_new ("G_MAXINT8"))));
+											vala_ccode_function_call_set_call (cspec, VALA_CCODE_EXPRESSION ((_tmp57 = vala_ccode_identifier_new ("g_param_spec_ulong"))));
 											(_tmp57 == NULL ? NULL : (_tmp57 = (g_object_unref (_tmp57), NULL)));
+											_tmp58 = NULL;
+											vala_ccode_function_call_add_argument (cspec, VALA_CCODE_EXPRESSION ((_tmp58 = vala_ccode_constant_new ("0"))));
+											(_tmp58 == NULL ? NULL : (_tmp58 = (g_object_unref (_tmp58), NULL)));
+											_tmp59 = NULL;
+											vala_ccode_function_call_add_argument (cspec, VALA_CCODE_EXPRESSION ((_tmp59 = vala_ccode_constant_new ("G_MAXULONG"))));
+											(_tmp59 == NULL ? NULL : (_tmp59 = (g_object_unref (_tmp59), NULL)));
 											if (vala_property_get_default_expression (prop) != NULL) {
 												vala_ccode_function_call_add_argument (cspec, VALA_CCODE_EXPRESSION (vala_code_node_get_ccodenode (VALA_CODE_NODE (vala_property_get_default_expression (prop)))));
 											} else {
-												ValaCCodeConstant* _tmp58;
-												_tmp58 = NULL;
-												vala_ccode_function_call_add_argument (cspec, VALA_CCODE_EXPRESSION ((_tmp58 = vala_ccode_constant_new ("0"))));
-												(_tmp58 == NULL ? NULL : (_tmp58 = (g_object_unref (_tmp58), NULL)));
+												ValaCCodeConstant* _tmp60;
+												_tmp60 = NULL;
+												vala_ccode_function_call_add_argument (cspec, VALA_CCODE_EXPRESSION ((_tmp60 = vala_ccode_constant_new ("0UL"))));
+												(_tmp60 == NULL ? NULL : (_tmp60 = (g_object_unref (_tmp60), NULL)));
 											}
 										} else {
-											char* _tmp59;
-											gboolean _tmp60;
-											_tmp59 = NULL;
-											if ((_tmp60 = _vala_strcmp0 ((_tmp59 = vala_typesymbol_get_type_id (VALA_TYPESYMBOL (st))), "G_TYPE_FLOAT") == 0, (_tmp59 = (g_free (_tmp59), NULL)), _tmp60)) {
-												ValaCCodeIdentifier* _tmp61;
-												ValaCCodeConstant* _tmp62;
-												ValaCCodeConstant* _tmp63;
-												_tmp61 = NULL;
-												vala_ccode_function_call_set_call (cspec, VALA_CCODE_EXPRESSION ((_tmp61 = vala_ccode_identifier_new ("g_param_spec_float"))));
-												(_tmp61 == NULL ? NULL : (_tmp61 = (g_object_unref (_tmp61), NULL)));
-												_tmp62 = NULL;
-												vala_ccode_function_call_add_argument (cspec, VALA_CCODE_EXPRESSION ((_tmp62 = vala_ccode_constant_new ("-G_MAXFLOAT"))));
-												(_tmp62 == NULL ? NULL : (_tmp62 = (g_object_unref (_tmp62), NULL)));
+											char* _tmp61;
+											gboolean _tmp62;
+											_tmp61 = NULL;
+											if ((_tmp62 = _vala_strcmp0 ((_tmp61 = vala_typesymbol_get_type_id (VALA_TYPESYMBOL (st))), "G_TYPE_BOOLEAN") == 0, (_tmp61 = (g_free (_tmp61), NULL)), _tmp62)) {
+												ValaCCodeIdentifier* _tmp63;
 												_tmp63 = NULL;
-												vala_ccode_function_call_add_argument (cspec, VALA_CCODE_EXPRESSION ((_tmp63 = vala_ccode_constant_new ("G_MAXFLOAT"))));
+												vala_ccode_function_call_set_call (cspec, VALA_CCODE_EXPRESSION ((_tmp63 = vala_ccode_identifier_new ("g_param_spec_boolean"))));
 												(_tmp63 == NULL ? NULL : (_tmp63 = (g_object_unref (_tmp63), NULL)));
 												if (vala_property_get_default_expression (prop) != NULL) {
 													vala_ccode_function_call_add_argument (cspec, VALA_CCODE_EXPRESSION (vala_code_node_get_ccodenode (VALA_CODE_NODE (vala_property_get_default_expression (prop)))));
 												} else {
 													ValaCCodeConstant* _tmp64;
 													_tmp64 = NULL;
-													vala_ccode_function_call_add_argument (cspec, VALA_CCODE_EXPRESSION ((_tmp64 = vala_ccode_constant_new ("0.0F"))));
+													vala_ccode_function_call_add_argument (cspec, VALA_CCODE_EXPRESSION ((_tmp64 = vala_ccode_constant_new ("FALSE"))));
 													(_tmp64 == NULL ? NULL : (_tmp64 = (g_object_unref (_tmp64), NULL)));
 												}
 											} else {
 												char* _tmp65;
 												gboolean _tmp66;
 												_tmp65 = NULL;
-												if ((_tmp66 = _vala_strcmp0 ((_tmp65 = vala_typesymbol_get_type_id (VALA_TYPESYMBOL (st))), "G_TYPE_DOUBLE") == 0, (_tmp65 = (g_free (_tmp65), NULL)), _tmp66)) {
+												if ((_tmp66 = _vala_strcmp0 ((_tmp65 = vala_typesymbol_get_type_id (VALA_TYPESYMBOL (st))), "G_TYPE_CHAR") == 0, (_tmp65 = (g_free (_tmp65), NULL)), _tmp66)) {
 													ValaCCodeIdentifier* _tmp67;
 													ValaCCodeConstant* _tmp68;
 													ValaCCodeConstant* _tmp69;
 													_tmp67 = NULL;
-													vala_ccode_function_call_set_call (cspec, VALA_CCODE_EXPRESSION ((_tmp67 = vala_ccode_identifier_new ("g_param_spec_double"))));
+													vala_ccode_function_call_set_call (cspec, VALA_CCODE_EXPRESSION ((_tmp67 = vala_ccode_identifier_new ("g_param_spec_char"))));
 													(_tmp67 == NULL ? NULL : (_tmp67 = (g_object_unref (_tmp67), NULL)));
 													_tmp68 = NULL;
-													vala_ccode_function_call_add_argument (cspec, VALA_CCODE_EXPRESSION ((_tmp68 = vala_ccode_constant_new ("-G_MAXDOUBLE"))));
+													vala_ccode_function_call_add_argument (cspec, VALA_CCODE_EXPRESSION ((_tmp68 = vala_ccode_constant_new ("G_MININT8"))));
 													(_tmp68 == NULL ? NULL : (_tmp68 = (g_object_unref (_tmp68), NULL)));
 													_tmp69 = NULL;
-													vala_ccode_function_call_add_argument (cspec, VALA_CCODE_EXPRESSION ((_tmp69 = vala_ccode_constant_new ("G_MAXDOUBLE"))));
+													vala_ccode_function_call_add_argument (cspec, VALA_CCODE_EXPRESSION ((_tmp69 = vala_ccode_constant_new ("G_MAXINT8"))));
 													(_tmp69 == NULL ? NULL : (_tmp69 = (g_object_unref (_tmp69), NULL)));
 													if (vala_property_get_default_expression (prop) != NULL) {
 														vala_ccode_function_call_add_argument (cspec, VALA_CCODE_EXPRESSION (vala_code_node_get_ccodenode (VALA_CODE_NODE (vala_property_get_default_expression (prop)))));
 													} else {
 														ValaCCodeConstant* _tmp70;
 														_tmp70 = NULL;
-														vala_ccode_function_call_add_argument (cspec, VALA_CCODE_EXPRESSION ((_tmp70 = vala_ccode_constant_new ("0.0"))));
+														vala_ccode_function_call_add_argument (cspec, VALA_CCODE_EXPRESSION ((_tmp70 = vala_ccode_constant_new ("0"))));
 														(_tmp70 == NULL ? NULL : (_tmp70 = (g_object_unref (_tmp70), NULL)));
 													}
 												} else {
 													char* _tmp71;
 													gboolean _tmp72;
 													_tmp71 = NULL;
-													if ((_tmp72 = _vala_strcmp0 ((_tmp71 = vala_typesymbol_get_type_id (VALA_TYPESYMBOL (st))), "G_TYPE_GTYPE") == 0, (_tmp71 = (g_free (_tmp71), NULL)), _tmp72)) {
+													if ((_tmp72 = _vala_strcmp0 ((_tmp71 = vala_typesymbol_get_type_id (VALA_TYPESYMBOL (st))), "G_TYPE_UCHAR") == 0, (_tmp71 = (g_free (_tmp71), NULL)), _tmp72)) {
 														ValaCCodeIdentifier* _tmp73;
+														ValaCCodeConstant* _tmp74;
+														ValaCCodeConstant* _tmp75;
 														_tmp73 = NULL;
-														vala_ccode_function_call_set_call (cspec, VALA_CCODE_EXPRESSION ((_tmp73 = vala_ccode_identifier_new ("g_param_spec_gtype"))));
+														vala_ccode_function_call_set_call (cspec, VALA_CCODE_EXPRESSION ((_tmp73 = vala_ccode_identifier_new ("g_param_spec_uchar"))));
 														(_tmp73 == NULL ? NULL : (_tmp73 = (g_object_unref (_tmp73), NULL)));
+														_tmp74 = NULL;
+														vala_ccode_function_call_add_argument (cspec, VALA_CCODE_EXPRESSION ((_tmp74 = vala_ccode_constant_new ("0"))));
+														(_tmp74 == NULL ? NULL : (_tmp74 = (g_object_unref (_tmp74), NULL)));
+														_tmp75 = NULL;
+														vala_ccode_function_call_add_argument (cspec, VALA_CCODE_EXPRESSION ((_tmp75 = vala_ccode_constant_new ("G_MAXUINT8"))));
+														(_tmp75 == NULL ? NULL : (_tmp75 = (g_object_unref (_tmp75), NULL)));
 														if (vala_property_get_default_expression (prop) != NULL) {
 															vala_ccode_function_call_add_argument (cspec, VALA_CCODE_EXPRESSION (vala_code_node_get_ccodenode (VALA_CODE_NODE (vala_property_get_default_expression (prop)))));
 														} else {
-															ValaCCodeConstant* _tmp74;
-															_tmp74 = NULL;
-															vala_ccode_function_call_add_argument (cspec, VALA_CCODE_EXPRESSION ((_tmp74 = vala_ccode_constant_new ("G_TYPE_NONE"))));
-															(_tmp74 == NULL ? NULL : (_tmp74 = (g_object_unref (_tmp74), NULL)));
+															ValaCCodeConstant* _tmp76;
+															_tmp76 = NULL;
+															vala_ccode_function_call_add_argument (cspec, VALA_CCODE_EXPRESSION ((_tmp76 = vala_ccode_constant_new ("0"))));
+															(_tmp76 == NULL ? NULL : (_tmp76 = (g_object_unref (_tmp76), NULL)));
 														}
 													} else {
-														ValaCCodeIdentifier* _tmp75;
-														_tmp75 = NULL;
-														vala_ccode_function_call_set_call (cspec, VALA_CCODE_EXPRESSION ((_tmp75 = vala_ccode_identifier_new ("g_param_spec_pointer"))));
-														(_tmp75 == NULL ? NULL : (_tmp75 = (g_object_unref (_tmp75), NULL)));
+														char* _tmp77;
+														gboolean _tmp78;
+														_tmp77 = NULL;
+														if ((_tmp78 = _vala_strcmp0 ((_tmp77 = vala_typesymbol_get_type_id (VALA_TYPESYMBOL (st))), "G_TYPE_FLOAT") == 0, (_tmp77 = (g_free (_tmp77), NULL)), _tmp78)) {
+															ValaCCodeIdentifier* _tmp79;
+															ValaCCodeConstant* _tmp80;
+															ValaCCodeConstant* _tmp81;
+															_tmp79 = NULL;
+															vala_ccode_function_call_set_call (cspec, VALA_CCODE_EXPRESSION ((_tmp79 = vala_ccode_identifier_new ("g_param_spec_float"))));
+															(_tmp79 == NULL ? NULL : (_tmp79 = (g_object_unref (_tmp79), NULL)));
+															_tmp80 = NULL;
+															vala_ccode_function_call_add_argument (cspec, VALA_CCODE_EXPRESSION ((_tmp80 = vala_ccode_constant_new ("-G_MAXFLOAT"))));
+															(_tmp80 == NULL ? NULL : (_tmp80 = (g_object_unref (_tmp80), NULL)));
+															_tmp81 = NULL;
+															vala_ccode_function_call_add_argument (cspec, VALA_CCODE_EXPRESSION ((_tmp81 = vala_ccode_constant_new ("G_MAXFLOAT"))));
+															(_tmp81 == NULL ? NULL : (_tmp81 = (g_object_unref (_tmp81), NULL)));
+															if (vala_property_get_default_expression (prop) != NULL) {
+																vala_ccode_function_call_add_argument (cspec, VALA_CCODE_EXPRESSION (vala_code_node_get_ccodenode (VALA_CODE_NODE (vala_property_get_default_expression (prop)))));
+															} else {
+																ValaCCodeConstant* _tmp82;
+																_tmp82 = NULL;
+																vala_ccode_function_call_add_argument (cspec, VALA_CCODE_EXPRESSION ((_tmp82 = vala_ccode_constant_new ("0.0F"))));
+																(_tmp82 == NULL ? NULL : (_tmp82 = (g_object_unref (_tmp82), NULL)));
+															}
+														} else {
+															char* _tmp83;
+															gboolean _tmp84;
+															_tmp83 = NULL;
+															if ((_tmp84 = _vala_strcmp0 ((_tmp83 = vala_typesymbol_get_type_id (VALA_TYPESYMBOL (st))), "G_TYPE_DOUBLE") == 0, (_tmp83 = (g_free (_tmp83), NULL)), _tmp84)) {
+																ValaCCodeIdentifier* _tmp85;
+																ValaCCodeConstant* _tmp86;
+																ValaCCodeConstant* _tmp87;
+																_tmp85 = NULL;
+																vala_ccode_function_call_set_call (cspec, VALA_CCODE_EXPRESSION ((_tmp85 = vala_ccode_identifier_new ("g_param_spec_double"))));
+																(_tmp85 == NULL ? NULL : (_tmp85 = (g_object_unref (_tmp85), NULL)));
+																_tmp86 = NULL;
+																vala_ccode_function_call_add_argument (cspec, VALA_CCODE_EXPRESSION ((_tmp86 = vala_ccode_constant_new ("-G_MAXDOUBLE"))));
+																(_tmp86 == NULL ? NULL : (_tmp86 = (g_object_unref (_tmp86), NULL)));
+																_tmp87 = NULL;
+																vala_ccode_function_call_add_argument (cspec, VALA_CCODE_EXPRESSION ((_tmp87 = vala_ccode_constant_new ("G_MAXDOUBLE"))));
+																(_tmp87 == NULL ? NULL : (_tmp87 = (g_object_unref (_tmp87), NULL)));
+																if (vala_property_get_default_expression (prop) != NULL) {
+																	vala_ccode_function_call_add_argument (cspec, VALA_CCODE_EXPRESSION (vala_code_node_get_ccodenode (VALA_CODE_NODE (vala_property_get_default_expression (prop)))));
+																} else {
+																	ValaCCodeConstant* _tmp88;
+																	_tmp88 = NULL;
+																	vala_ccode_function_call_add_argument (cspec, VALA_CCODE_EXPRESSION ((_tmp88 = vala_ccode_constant_new ("0.0"))));
+																	(_tmp88 == NULL ? NULL : (_tmp88 = (g_object_unref (_tmp88), NULL)));
+																}
+															} else {
+																char* _tmp89;
+																gboolean _tmp90;
+																_tmp89 = NULL;
+																if ((_tmp90 = _vala_strcmp0 ((_tmp89 = vala_typesymbol_get_type_id (VALA_TYPESYMBOL (st))), "G_TYPE_GTYPE") == 0, (_tmp89 = (g_free (_tmp89), NULL)), _tmp90)) {
+																	ValaCCodeIdentifier* _tmp91;
+																	_tmp91 = NULL;
+																	vala_ccode_function_call_set_call (cspec, VALA_CCODE_EXPRESSION ((_tmp91 = vala_ccode_identifier_new ("g_param_spec_gtype"))));
+																	(_tmp91 == NULL ? NULL : (_tmp91 = (g_object_unref (_tmp91), NULL)));
+																	if (vala_property_get_default_expression (prop) != NULL) {
+																		vala_ccode_function_call_add_argument (cspec, VALA_CCODE_EXPRESSION (vala_code_node_get_ccodenode (VALA_CODE_NODE (vala_property_get_default_expression (prop)))));
+																	} else {
+																		ValaCCodeConstant* _tmp92;
+																		_tmp92 = NULL;
+																		vala_ccode_function_call_add_argument (cspec, VALA_CCODE_EXPRESSION ((_tmp92 = vala_ccode_constant_new ("G_TYPE_NONE"))));
+																		(_tmp92 == NULL ? NULL : (_tmp92 = (g_object_unref (_tmp92), NULL)));
+																	}
+																} else {
+																	ValaCCodeIdentifier* _tmp93;
+																	_tmp93 = NULL;
+																	vala_ccode_function_call_set_call (cspec, VALA_CCODE_EXPRESSION ((_tmp93 = vala_ccode_identifier_new ("g_param_spec_pointer"))));
+																	(_tmp93 == NULL ? NULL : (_tmp93 = (g_object_unref (_tmp93), NULL)));
+																}
+															}
+														}
 													}
 												}
 											}
@@ -399,41 +477,41 @@ ValaCCodeFunctionCall* vala_ccode_type_symbol_binding_get_param_spec (ValaCCodeT
 					}
 					(st == NULL ? NULL : (st = (g_object_unref (st), NULL)));
 				} else {
-					ValaCCodeIdentifier* _tmp76;
-					_tmp76 = NULL;
-					vala_ccode_function_call_set_call (cspec, VALA_CCODE_EXPRESSION ((_tmp76 = vala_ccode_identifier_new ("g_param_spec_pointer"))));
-					(_tmp76 == NULL ? NULL : (_tmp76 = (g_object_unref (_tmp76), NULL)));
+					ValaCCodeIdentifier* _tmp94;
+					_tmp94 = NULL;
+					vala_ccode_function_call_set_call (cspec, VALA_CCODE_EXPRESSION ((_tmp94 = vala_ccode_identifier_new ("g_param_spec_pointer"))));
+					(_tmp94 == NULL ? NULL : (_tmp94 = (g_object_unref (_tmp94), NULL)));
 				}
 			}
 		}
 	}
 	pflags = g_strdup ("G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB");
 	if (vala_property_get_get_accessor (prop) != NULL) {
-		char* _tmp77;
-		_tmp77 = NULL;
-		pflags = (_tmp77 = g_strdup_printf ("%s%s", pflags, " | G_PARAM_READABLE"), (pflags = (g_free (pflags), NULL)), _tmp77);
+		char* _tmp95;
+		_tmp95 = NULL;
+		pflags = (_tmp95 = g_strdup_printf ("%s%s", pflags, " | G_PARAM_READABLE"), (pflags = (g_free (pflags), NULL)), _tmp95);
 	}
 	if (vala_property_get_set_accessor (prop) != NULL) {
-		char* _tmp78;
-		_tmp78 = NULL;
-		pflags = (_tmp78 = g_strdup_printf ("%s%s", pflags, " | G_PARAM_WRITABLE"), (pflags = (g_free (pflags), NULL)), _tmp78);
+		char* _tmp96;
+		_tmp96 = NULL;
+		pflags = (_tmp96 = g_strdup_printf ("%s%s", pflags, " | G_PARAM_WRITABLE"), (pflags = (g_free (pflags), NULL)), _tmp96);
 		if (vala_property_accessor_get_construction (vala_property_get_set_accessor (prop))) {
 			if (vala_property_accessor_get_writable (vala_property_get_set_accessor (prop))) {
-				char* _tmp79;
-				_tmp79 = NULL;
-				pflags = (_tmp79 = g_strdup_printf ("%s%s", pflags, " | G_PARAM_CONSTRUCT"), (pflags = (g_free (pflags), NULL)), _tmp79);
+				char* _tmp97;
+				_tmp97 = NULL;
+				pflags = (_tmp97 = g_strdup_printf ("%s%s", pflags, " | G_PARAM_CONSTRUCT"), (pflags = (g_free (pflags), NULL)), _tmp97);
 			} else {
-				char* _tmp80;
-				_tmp80 = NULL;
-				pflags = (_tmp80 = g_strdup_printf ("%s%s", pflags, " | G_PARAM_CONSTRUCT_ONLY"), (pflags = (g_free (pflags), NULL)), _tmp80);
+				char* _tmp98;
+				_tmp98 = NULL;
+				pflags = (_tmp98 = g_strdup_printf ("%s%s", pflags, " | G_PARAM_CONSTRUCT_ONLY"), (pflags = (g_free (pflags), NULL)), _tmp98);
 			}
 		}
 	}
-	_tmp81 = NULL;
-	vala_ccode_function_call_add_argument (cspec, VALA_CCODE_EXPRESSION ((_tmp81 = vala_ccode_constant_new (pflags))));
-	(_tmp81 == NULL ? NULL : (_tmp81 = (g_object_unref (_tmp81), NULL)));
-	_tmp82 = NULL;
-	return (_tmp82 = cspec, (pflags = (g_free (pflags), NULL)), _tmp82);
+	_tmp99 = NULL;
+	vala_ccode_function_call_add_argument (cspec, VALA_CCODE_EXPRESSION ((_tmp99 = vala_ccode_constant_new (pflags))));
+	(_tmp99 == NULL ? NULL : (_tmp99 = (g_object_unref (_tmp99), NULL)));
+	_tmp100 = NULL;
+	return (_tmp100 = cspec, (pflags = (g_free (pflags), NULL)), _tmp100);
 }
 
 
@@ -457,7 +535,7 @@ ValaCCodeFunctionCall* vala_ccode_type_symbol_binding_get_signal_creation (ValaC
 	gint params_len;
 	ValaCCodeConstant* _tmp18;
 	char* _tmp17;
-	ValaCCodeFunctionCall* _tmp23;
+	ValaCCodeFunctionCall* _tmp26;
 	g_return_val_if_fail (VALA_IS_CCODE_TYPE_SYMBOL_BINDING (self), NULL);
 	g_return_val_if_fail (VALA_IS_SIGNAL (sig), NULL);
 	g_return_val_if_fail (VALA_IS_TYPESYMBOL (type), NULL);
@@ -471,7 +549,7 @@ ValaCCodeFunctionCall* vala_ccode_type_symbol_binding_get_signal_creation (ValaC
 	_tmp2 = (g_free (_tmp2), NULL);
 	_tmp5 = NULL;
 	_tmp4 = NULL;
-	vala_ccode_function_call_add_argument (csignew, VALA_CCODE_EXPRESSION ((_tmp5 = vala_ccode_identifier_new ((_tmp4 = vala_typesymbol_get_upper_case_cname (type, "TYPE_"))))));
+	vala_ccode_function_call_add_argument (csignew, VALA_CCODE_EXPRESSION ((_tmp5 = vala_ccode_identifier_new ((_tmp4 = vala_typesymbol_get_type_id (type))))));
 	(_tmp5 == NULL ? NULL : (_tmp5 = (g_object_unref (_tmp5), NULL)));
 	_tmp4 = (g_free (_tmp4), NULL);
 	_tmp6 = NULL;
@@ -492,7 +570,6 @@ ValaCCodeFunctionCall* vala_ccode_type_symbol_binding_get_signal_creation (ValaC
 	marshal_arg = vala_ccode_identifier_new (marshaller);
 	vala_ccode_function_call_add_argument (csignew, VALA_CCODE_EXPRESSION (marshal_arg));
 	params = vala_signal_get_parameters (sig);
-	params_len = gee_collection_get_size (GEE_COLLECTION (params));
 	if (VALA_IS_POINTER_TYPE (vala_signal_get_return_type (sig)) || vala_data_type_get_type_parameter (vala_signal_get_return_type (sig)) != NULL) {
 		ValaCCodeConstant* _tmp12;
 		_tmp12 = NULL;
@@ -521,6 +598,23 @@ ValaCCodeFunctionCall* vala_ccode_type_symbol_binding_get_signal_creation (ValaC
 			}
 		}
 	}
+	params_len = 0;
+	{
+		GeeList* param_collection;
+		int param_it;
+		param_collection = params;
+		for (param_it = 0; param_it < gee_collection_get_size (GEE_COLLECTION (param_collection)); param_it = param_it + 1) {
+			ValaFormalParameter* param;
+			param = ((ValaFormalParameter*) (gee_list_get (GEE_LIST (param_collection), param_it)));
+			{
+				params_len++;
+				if (vala_data_type_is_array (vala_formal_parameter_get_parameter_type (param))) {
+					params_len++;
+				}
+				(param == NULL ? NULL : (param = (g_object_unref (param), NULL)));
+			}
+		}
+	}
 	_tmp18 = NULL;
 	_tmp17 = NULL;
 	vala_ccode_function_call_add_argument (csignew, VALA_CCODE_EXPRESSION ((_tmp18 = vala_ccode_constant_new ((_tmp17 = g_strdup_printf ("%d", params_len))))));
@@ -534,25 +628,43 @@ ValaCCodeFunctionCall* vala_ccode_type_symbol_binding_get_signal_creation (ValaC
 			ValaFormalParameter* param;
 			param = ((ValaFormalParameter*) (gee_list_get (GEE_LIST (param_collection), param_it)));
 			{
-				if (VALA_IS_POINTER_TYPE (vala_formal_parameter_get_parameter_type (param)) || vala_data_type_get_type_parameter (vala_formal_parameter_get_parameter_type (param)) != NULL || vala_formal_parameter_get_direction (param) != VALA_PARAMETER_DIRECTION_IN) {
-					ValaCCodeConstant* _tmp19;
-					_tmp19 = NULL;
-					vala_ccode_function_call_add_argument (csignew, VALA_CCODE_EXPRESSION ((_tmp19 = vala_ccode_constant_new ("G_TYPE_POINTER"))));
-					(_tmp19 == NULL ? NULL : (_tmp19 = (g_object_unref (_tmp19), NULL)));
-				} else {
-					if (VALA_IS_ERROR_TYPE (vala_formal_parameter_get_parameter_type (param))) {
+				if (vala_data_type_is_array (vala_formal_parameter_get_parameter_type (param))) {
+					ValaCCodeConstant* _tmp21;
+					if (vala_data_type_get_data_type (vala_array_type_get_element_type ((VALA_ARRAY_TYPE (vala_formal_parameter_get_parameter_type (param))))) == vala_data_type_get_data_type (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->string_type)) {
+						ValaCCodeConstant* _tmp19;
+						_tmp19 = NULL;
+						vala_ccode_function_call_add_argument (csignew, VALA_CCODE_EXPRESSION ((_tmp19 = vala_ccode_constant_new ("G_TYPE_STRV"))));
+						(_tmp19 == NULL ? NULL : (_tmp19 = (g_object_unref (_tmp19), NULL)));
+					} else {
 						ValaCCodeConstant* _tmp20;
 						_tmp20 = NULL;
 						vala_ccode_function_call_add_argument (csignew, VALA_CCODE_EXPRESSION ((_tmp20 = vala_ccode_constant_new ("G_TYPE_POINTER"))));
 						(_tmp20 == NULL ? NULL : (_tmp20 = (g_object_unref (_tmp20), NULL)));
-					} else {
+					}
+					_tmp21 = NULL;
+					vala_ccode_function_call_add_argument (csignew, VALA_CCODE_EXPRESSION ((_tmp21 = vala_ccode_constant_new ("G_TYPE_INT"))));
+					(_tmp21 == NULL ? NULL : (_tmp21 = (g_object_unref (_tmp21), NULL)));
+				} else {
+					if (VALA_IS_POINTER_TYPE (vala_formal_parameter_get_parameter_type (param)) || vala_data_type_get_type_parameter (vala_formal_parameter_get_parameter_type (param)) != NULL || vala_formal_parameter_get_direction (param) != VALA_PARAMETER_DIRECTION_IN) {
 						ValaCCodeConstant* _tmp22;
-						char* _tmp21;
 						_tmp22 = NULL;
-						_tmp21 = NULL;
-						vala_ccode_function_call_add_argument (csignew, VALA_CCODE_EXPRESSION ((_tmp22 = vala_ccode_constant_new ((_tmp21 = vala_typesymbol_get_type_id (vala_data_type_get_data_type (vala_formal_parameter_get_parameter_type (param))))))));
+						vala_ccode_function_call_add_argument (csignew, VALA_CCODE_EXPRESSION ((_tmp22 = vala_ccode_constant_new ("G_TYPE_POINTER"))));
 						(_tmp22 == NULL ? NULL : (_tmp22 = (g_object_unref (_tmp22), NULL)));
-						_tmp21 = (g_free (_tmp21), NULL);
+					} else {
+						if (VALA_IS_ERROR_TYPE (vala_formal_parameter_get_parameter_type (param))) {
+							ValaCCodeConstant* _tmp23;
+							_tmp23 = NULL;
+							vala_ccode_function_call_add_argument (csignew, VALA_CCODE_EXPRESSION ((_tmp23 = vala_ccode_constant_new ("G_TYPE_POINTER"))));
+							(_tmp23 == NULL ? NULL : (_tmp23 = (g_object_unref (_tmp23), NULL)));
+						} else {
+							ValaCCodeConstant* _tmp25;
+							char* _tmp24;
+							_tmp25 = NULL;
+							_tmp24 = NULL;
+							vala_ccode_function_call_add_argument (csignew, VALA_CCODE_EXPRESSION ((_tmp25 = vala_ccode_constant_new ((_tmp24 = vala_typesymbol_get_type_id (vala_data_type_get_data_type (vala_formal_parameter_get_parameter_type (param))))))));
+							(_tmp25 == NULL ? NULL : (_tmp25 = (g_object_unref (_tmp25), NULL)));
+							_tmp24 = (g_free (_tmp24), NULL);
+						}
 					}
 				}
 				(param == NULL ? NULL : (param = (g_object_unref (param), NULL)));
@@ -560,8 +672,8 @@ ValaCCodeFunctionCall* vala_ccode_type_symbol_binding_get_signal_creation (ValaC
 		}
 	}
 	vala_ccode_identifier_set_name (marshal_arg, marshaller);
-	_tmp23 = NULL;
-	return (_tmp23 = csignew, (marshaller = (g_free (marshaller), NULL)), (marshal_arg == NULL ? NULL : (marshal_arg = (g_object_unref (marshal_arg), NULL))), (params == NULL ? NULL : (params = (g_object_unref (params), NULL))), _tmp23);
+	_tmp26 = NULL;
+	return (_tmp26 = csignew, (marshaller = (g_free (marshaller), NULL)), (marshal_arg == NULL ? NULL : (marshal_arg = (g_object_unref (marshal_arg), NULL))), (params == NULL ? NULL : (params = (g_object_unref (params), NULL))), _tmp26);
 }
 
 
@@ -576,7 +688,7 @@ static void vala_ccode_type_symbol_binding_instance_init (ValaCCodeTypeSymbolBin
 
 GType vala_ccode_type_symbol_binding_get_type (void) {
 	static GType vala_ccode_type_symbol_binding_type_id = 0;
-	if (G_UNLIKELY (vala_ccode_type_symbol_binding_type_id == 0)) {
+	if (vala_ccode_type_symbol_binding_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeTypeSymbolBindingClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_type_symbol_binding_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeTypeSymbolBinding), 0, (GInstanceInitFunc) vala_ccode_type_symbol_binding_instance_init };
 		vala_ccode_type_symbol_binding_type_id = g_type_register_static (VALA_TYPE_CCODE_BINDING, "ValaCCodeTypeSymbolBinding", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
 	}
