@@ -70,7 +70,7 @@ static void vala_gidl_writer_write_indent (ValaGIdlWriter* self);
 static void vala_gidl_writer_write_return_type (ValaGIdlWriter* self, ValaDataType* type);
 static gboolean vala_gidl_writer_check_accessibility (ValaGIdlWriter* self, ValaSymbol* sym);
 static gpointer vala_gidl_writer_parent_class = NULL;
-static void vala_gidl_writer_dispose (GObject * obj);
+static void vala_gidl_writer_finalize (GObject * obj);
 
 
 
@@ -741,7 +741,7 @@ ValaGIdlWriter* vala_gidl_writer_new (void) {
 static void vala_gidl_writer_class_init (ValaGIdlWriterClass * klass) {
 	vala_gidl_writer_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaGIdlWriterPrivate));
-	G_OBJECT_CLASS (klass)->dispose = vala_gidl_writer_dispose;
+	G_OBJECT_CLASS (klass)->finalize = vala_gidl_writer_finalize;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_namespace = vala_gidl_writer_real_visit_namespace;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_class = vala_gidl_writer_real_visit_class;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_struct = vala_gidl_writer_real_visit_struct;
@@ -765,19 +765,19 @@ static void vala_gidl_writer_instance_init (ValaGIdlWriter * self) {
 }
 
 
-static void vala_gidl_writer_dispose (GObject * obj) {
+static void vala_gidl_writer_finalize (GObject * obj) {
 	ValaGIdlWriter * self;
 	self = VALA_GIDL_WRITER (obj);
 	(self->priv->context == NULL ? NULL : (self->priv->context = (g_object_unref (self->priv->context), NULL)));
 	(self->priv->stream == NULL ? NULL : (self->priv->stream = (fclose (self->priv->stream), NULL)));
 	(self->priv->gobject_type == NULL ? NULL : (self->priv->gobject_type = (g_object_unref (self->priv->gobject_type), NULL)));
-	G_OBJECT_CLASS (vala_gidl_writer_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (vala_gidl_writer_parent_class)->finalize (obj);
 }
 
 
 GType vala_gidl_writer_get_type (void) {
 	static GType vala_gidl_writer_type_id = 0;
-	if (G_UNLIKELY (vala_gidl_writer_type_id == 0)) {
+	if (vala_gidl_writer_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaGIdlWriterClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_gidl_writer_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaGIdlWriter), 0, (GInstanceInitFunc) vala_gidl_writer_instance_init };
 		vala_gidl_writer_type_id = g_type_register_static (VALA_TYPE_CODE_VISITOR, "ValaGIdlWriter", &g_define_type_info, 0);
 	}
