@@ -1,7 +1,7 @@
 #!/bin/bash
 # testrunner.sh
 #
-# Copyright (C) 2006-2007  Jürg Billeter
+# Copyright (C) 2006-2008  Jürg Billeter
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -27,6 +27,9 @@ topsrcdir=$srcdir/..
 vapidir=$topsrcdir/vapi
 exe=$EXEEXT
 
+# make sure we detect failed test cases
+set -o pipefail
+
 export G_DEBUG=fatal_warnings
 
 VALAC=$topbuilddir/compiler/valac
@@ -40,13 +43,17 @@ for testcasesource in "$@"
 do
 	testsrc=${testcasesource/.vala/}
 	testbuild=`basename "$testsrc"`
-	if ! $VALAC --vapidir "$vapidir" --pkg gee-1.0 --basedir $topsrcdir -d $topbuilddir $testsrc.vala > $testbuild.err 2>&1
+	if ! $VALAC -C --vapidir "$vapidir" --pkg gee-1.0 --basedir $topsrcdir -d $topbuilddir $testsrc.vala > $testbuild.err 2>&1
 	then
+		echo "ERROR: Compiling" $testcasesource 
+		cat $testbuild.err
 		CODE=1
 		continue
 	fi
 	if ! $CC $CFLAGS $testbuild.c $(pkg-config --cflags --libs gobject-2.0) -o $testbuild $LDLIBS > $testbuild.err 2>&1
 	then
+		echo "ERROR: Compiling" $testbuild.c
+		cat $testbuild.err
 		CODE=1
 		continue
 	fi
@@ -54,6 +61,8 @@ do
 	then
 		rm $testbuild.c $testbuild.h $testbuild$exe $testbuild.err
 	else
+		echo "ERROR: test failed. This is the difference between" $testbuild.exp "and" $testbuild.err
+		diff -u $testbuild.exp $testbuild.err
 		CODE=1
 	fi
 done
