@@ -29,7 +29,6 @@
 #include <vala/valacodecontext.h>
 #include <vala/valanamespace.h>
 #include <vala/valavaluetype.h>
-#include <vala/valascope.h>
 #include <vala/valatypesymbol.h>
 #include <vala/valafield.h>
 #include <vala/valamethod.h>
@@ -41,8 +40,8 @@
 
 
 struct _ValaArrayTypePrivate {
-	ValaDataType* _element_type;
 	gint _rank;
+	ValaDataType* _element_type;
 	ValaArrayLengthField* length_field;
 	ValaArrayResizeMethod* resize_method;
 	ValaArrayMoveMethod* move_method;
@@ -61,39 +60,27 @@ static ValaArrayMoveMethod* vala_array_type_get_move_method (ValaArrayType* self
 static ValaDataType* vala_array_type_real_copy (ValaDataType* base);
 static char* vala_array_type_real_get_cname (ValaDataType* base);
 static gboolean vala_array_type_real_is_array (ValaDataType* base);
-static char* vala_array_type_real_to_string (ValaCodeNode* base);
+static char* vala_array_type_real_to_qualified_string (ValaDataType* base, ValaScope* scope);
 static gboolean vala_array_type_real_compatible (ValaDataType* base, ValaDataType* target_type);
 static gboolean vala_array_type_real_is_reference_type_or_type_parameter (ValaDataType* base);
 static char* vala_array_type_real_get_type_signature (ValaDataType* base);
+static void vala_array_type_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
+static void vala_array_type_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type);
+static GeeList* vala_array_type_real_get_symbols (ValaDataType* base);
 static gpointer vala_array_type_parent_class = NULL;
-static void vala_array_type_dispose (GObject * obj);
+static void vala_array_type_finalize (GObject * obj);
 static int _vala_strcmp0 (const char * str1, const char * str2);
 
 
 
 ValaArrayType* vala_array_type_new (ValaDataType* element_type, gint rank, ValaSourceReference* source_reference) {
-	GParameter * __params;
-	GParameter * __params_it;
 	ValaArrayType * self;
 	g_return_val_if_fail (VALA_IS_DATA_TYPE (element_type), NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
-	__params = g_new0 (GParameter, 2);
-	__params_it = __params;
-	__params_it->name = "element-type";
-	g_value_init (&__params_it->value, VALA_TYPE_DATA_TYPE);
-	g_value_set_object (&__params_it->value, element_type);
-	__params_it++;
-	__params_it->name = "rank";
-	g_value_init (&__params_it->value, G_TYPE_INT);
-	g_value_set_int (&__params_it->value, rank);
-	__params_it++;
-	self = g_object_newv (VALA_TYPE_ARRAY_TYPE, __params_it - __params, __params);
+	self = g_object_newv (VALA_TYPE_ARRAY_TYPE, 0, NULL);
+	vala_array_type_set_element_type (self, element_type);
+	vala_array_type_set_rank (self, rank);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
-	while (__params_it > __params) {
-		--__params_it;
-		g_value_unset (&__params_it->value);
-	}
-	g_free (__params);
 	return self;
 }
 
@@ -130,7 +117,7 @@ static ValaArrayLengthField* vala_array_type_get_length_field (ValaArrayType* se
 		_tmp1 = NULL;
 		root_symbol = (_tmp1 = vala_code_context_get_root (vala_source_file_get_context (vala_source_reference_get_file (vala_code_node_get_source_reference (VALA_CODE_NODE (self))))), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
 		if (self->priv->_rank > 1) {
-			ValaTypesymbol* _tmp2;
+			ValaTypeSymbol* _tmp2;
 			ValaValueType* _tmp3;
 			ValaValueType* integer;
 			ValaArrayType* _tmp4;
@@ -139,16 +126,15 @@ static ValaArrayLengthField* vala_array_type_get_length_field (ValaArrayType* se
 			_tmp3 = NULL;
 			integer = (_tmp3 = vala_value_type_new ((_tmp2 = VALA_TYPESYMBOL (vala_scope_lookup (vala_symbol_get_scope (VALA_SYMBOL (root_symbol)), "int")))), (_tmp2 == NULL ? NULL : (_tmp2 = (g_object_unref (_tmp2), NULL))), _tmp3);
 			_tmp4 = NULL;
-			vala_field_set_type_reference (VALA_FIELD (self->priv->length_field), VALA_DATA_TYPE ((_tmp4 = vala_array_type_new (VALA_DATA_TYPE (integer), 1, vala_code_node_get_source_reference (VALA_CODE_NODE (self))))));
+			vala_field_set_field_type (VALA_FIELD (self->priv->length_field), VALA_DATA_TYPE ((_tmp4 = vala_array_type_new (VALA_DATA_TYPE (integer), 1, vala_code_node_get_source_reference (VALA_CODE_NODE (self))))));
 			(_tmp4 == NULL ? NULL : (_tmp4 = (g_object_unref (_tmp4), NULL)));
-			vala_data_type_add_type_argument (vala_field_get_type_reference (VALA_FIELD (self->priv->length_field)), VALA_DATA_TYPE (integer));
 			(integer == NULL ? NULL : (integer = (g_object_unref (integer), NULL)));
 		} else {
 			ValaValueType* _tmp6;
-			ValaTypesymbol* _tmp5;
+			ValaTypeSymbol* _tmp5;
 			_tmp6 = NULL;
 			_tmp5 = NULL;
-			vala_field_set_type_reference (VALA_FIELD (self->priv->length_field), VALA_DATA_TYPE ((_tmp6 = vala_value_type_new ((_tmp5 = VALA_TYPESYMBOL (vala_scope_lookup (vala_symbol_get_scope (VALA_SYMBOL (root_symbol)), "int")))))));
+			vala_field_set_field_type (VALA_FIELD (self->priv->length_field), VALA_DATA_TYPE ((_tmp6 = vala_value_type_new ((_tmp5 = VALA_TYPESYMBOL (vala_scope_lookup (vala_symbol_get_scope (VALA_SYMBOL (root_symbol)), "int")))))));
 			(_tmp6 == NULL ? NULL : (_tmp6 = (g_object_unref (_tmp6), NULL)));
 			(_tmp5 == NULL ? NULL : (_tmp5 = (g_object_unref (_tmp5), NULL)));
 		}
@@ -167,7 +153,7 @@ static ValaArrayResizeMethod* vala_array_type_get_resize_method (ValaArrayType*
 		ValaVoidType* _tmp1;
 		ValaNamespace* _tmp2;
 		ValaNamespace* root_symbol;
-		ValaTypesymbol* _tmp3;
+		ValaTypeSymbol* _tmp3;
 		ValaValueType* _tmp4;
 		ValaValueType* int_type;
 		ValaFormalParameter* _tmp5;
@@ -203,7 +189,7 @@ static ValaArrayMoveMethod* vala_array_type_get_move_method (ValaArrayType* self
 		ValaVoidType* _tmp1;
 		ValaNamespace* _tmp2;
 		ValaNamespace* root_symbol;
-		ValaTypesymbol* _tmp3;
+		ValaTypeSymbol* _tmp3;
 		ValaValueType* _tmp4;
 		ValaValueType* int_type;
 		ValaFormalParameter* _tmp5;
@@ -240,32 +226,16 @@ static ValaArrayMoveMethod* vala_array_type_get_move_method (ValaArrayType* self
 
 static ValaDataType* vala_array_type_real_copy (ValaDataType* base) {
 	ValaArrayType * self;
+	ValaDataType* _tmp0;
+	ValaArrayType* _tmp1;
 	ValaArrayType* result;
 	self = VALA_ARRAY_TYPE (base);
-	result = vala_array_type_new (self->priv->_element_type, self->priv->_rank, vala_code_node_get_source_reference (VALA_CODE_NODE (self)));
-	vala_data_type_set_transfers_ownership (VALA_DATA_TYPE (result), vala_data_type_get_transfers_ownership (VALA_DATA_TYPE (self)));
-	vala_data_type_set_takes_ownership (VALA_DATA_TYPE (result), vala_data_type_get_takes_ownership (VALA_DATA_TYPE (self)));
+	_tmp0 = NULL;
+	_tmp1 = NULL;
+	result = (_tmp1 = vala_array_type_new ((_tmp0 = vala_data_type_copy (vala_array_type_get_element_type (self))), self->priv->_rank, vala_code_node_get_source_reference (VALA_CODE_NODE (self))), (_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL))), _tmp1);
+	vala_data_type_set_value_owned (VALA_DATA_TYPE (result), vala_data_type_get_value_owned (VALA_DATA_TYPE (self)));
 	vala_data_type_set_nullable (VALA_DATA_TYPE (result), vala_data_type_get_nullable (VALA_DATA_TYPE (self)));
 	vala_data_type_set_floating_reference (VALA_DATA_TYPE (result), vala_data_type_get_floating_reference (VALA_DATA_TYPE (self)));
-	{
-		GeeList* arg_collection;
-		GeeIterator* arg_it;
-		arg_collection = vala_data_type_get_type_arguments (VALA_DATA_TYPE (self));
-		arg_it = gee_iterable_iterator (GEE_ITERABLE (arg_collection));
-		while (gee_iterator_next (arg_it)) {
-			ValaDataType* arg;
-			arg = ((ValaDataType*) gee_iterator_get (arg_it));
-			{
-				ValaDataType* _tmp0;
-				_tmp0 = NULL;
-				vala_data_type_add_type_argument (VALA_DATA_TYPE (result), (_tmp0 = vala_data_type_copy (arg)));
-				(_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL)));
-				(arg == NULL ? NULL : (arg = (g_object_unref (arg), NULL)));
-			}
-		}
-		(arg_collection == NULL ? NULL : (arg_collection = (g_object_unref (arg_collection), NULL)));
-		(arg_it == NULL ? NULL : (arg_it = (g_object_unref (arg_it), NULL)));
-	}
 	return VALA_DATA_TYPE (result);
 }
 
@@ -278,7 +248,7 @@ static char* vala_array_type_real_get_cname (ValaDataType* base) {
 	/* FIXME add support for [Immutable] or [Const] attribute to support arrays to const data*/
 	_tmp0 = NULL;
 	_tmp1 = NULL;
-	return (_tmp1 = g_strconcat ((_tmp0 = vala_data_type_get_cname (self->priv->_element_type)), "*", NULL), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
+	return (_tmp1 = g_strconcat ((_tmp0 = vala_data_type_get_cname (vala_array_type_get_element_type (self))), "*", NULL), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
 }
 
 
@@ -289,14 +259,17 @@ static gboolean vala_array_type_real_is_array (ValaDataType* base) {
 }
 
 
-static char* vala_array_type_real_to_string (ValaCodeNode* base) {
+static char* vala_array_type_real_to_qualified_string (ValaDataType* base, ValaScope* scope) {
 	ValaArrayType * self;
-	char* _tmp0;
 	char* _tmp1;
+	char* _tmp0;
+	char* _tmp2;
 	self = VALA_ARRAY_TYPE (base);
-	_tmp0 = NULL;
+	g_return_val_if_fail (scope == NULL || VALA_IS_SCOPE (scope), NULL);
 	_tmp1 = NULL;
-	return (_tmp1 = g_strconcat ((_tmp0 = vala_code_node_to_string (VALA_CODE_NODE (self->priv->_element_type))), "[]", NULL), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
+	_tmp0 = NULL;
+	_tmp2 = NULL;
+	return (_tmp2 = g_strdup_printf ("%s[%s]", (_tmp0 = vala_data_type_to_qualified_string (vala_array_type_get_element_type (self), scope)), (_tmp1 = g_strnfill (((gulong) (self->priv->_rank - 1)), ','))), (_tmp1 = (g_free (_tmp1), NULL)), (_tmp0 = (g_free (_tmp0), NULL)), _tmp2);
 }
 
 
@@ -321,12 +294,12 @@ static gboolean vala_array_type_real_compatible (ValaDataType* base, ValaDataTyp
 	}
 	_tmp5 = NULL;
 	_tmp4 = NULL;
-	target_array_type = (_tmp5 = (_tmp4 = target_type, (VALA_IS_ARRAY_TYPE (_tmp4) ? ((ValaArrayType*) _tmp4) : NULL)), (_tmp5 == NULL ? NULL : g_object_ref (_tmp5)));
+	target_array_type = (_tmp5 = (_tmp4 = target_type, (VALA_IS_ARRAY_TYPE (_tmp4) ? ((ValaArrayType*) (_tmp4)) : NULL)), (_tmp5 == NULL ? NULL : g_object_ref (_tmp5)));
 	if (target_array_type == NULL) {
 		gboolean _tmp6;
 		return (_tmp6 = FALSE, (target_array_type == NULL ? NULL : (target_array_type = (g_object_unref (target_array_type), NULL))), _tmp6);
 	}
-	if (vala_data_type_compatible (self->priv->_element_type, target_array_type->priv->_element_type) && vala_data_type_compatible (target_array_type->priv->_element_type, self->priv->_element_type)) {
+	if (vala_data_type_compatible (vala_array_type_get_element_type (self), vala_array_type_get_element_type (target_array_type)) && vala_data_type_compatible (vala_array_type_get_element_type (target_array_type), vala_array_type_get_element_type (self))) {
 		gboolean _tmp7;
 		return (_tmp7 = TRUE, (target_array_type == NULL ? NULL : (target_array_type = (g_object_unref (target_array_type), NULL))), _tmp7);
 	}
@@ -346,9 +319,10 @@ static char* vala_array_type_real_get_type_signature (ValaDataType* base) {
 	char* element_type_signature;
 	char* _tmp1;
 	self = VALA_ARRAY_TYPE (base);
-	element_type_signature = vala_data_type_get_type_signature (self->priv->_element_type);
+	element_type_signature = vala_data_type_get_type_signature (vala_array_type_get_element_type (self));
 	if (element_type_signature == NULL) {
-		gpointer _tmp0;
+		char* _tmp0;
+		_tmp0 = NULL;
 		return (_tmp0 = NULL, (element_type_signature = (g_free (element_type_signature), NULL)), _tmp0);
 	}
 	_tmp1 = NULL;
@@ -356,6 +330,32 @@ static char* vala_array_type_real_get_type_signature (ValaDataType* base) {
 }
 
 
+static void vala_array_type_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
+	ValaArrayType * self;
+	self = VALA_ARRAY_TYPE (base);
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	vala_code_node_accept (VALA_CODE_NODE (vala_array_type_get_element_type (self)), visitor);
+}
+
+
+static void vala_array_type_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type) {
+	ValaArrayType * self;
+	self = VALA_ARRAY_TYPE (base);
+	g_return_if_fail (VALA_IS_DATA_TYPE (old_type));
+	g_return_if_fail (VALA_IS_DATA_TYPE (new_type));
+	if (vala_array_type_get_element_type (self) == old_type) {
+		vala_array_type_set_element_type (self, new_type);
+	}
+}
+
+
+static GeeList* vala_array_type_real_get_symbols (ValaDataType* base) {
+	ValaArrayType * self;
+	self = VALA_ARRAY_TYPE (base);
+	return vala_data_type_get_symbols (vala_array_type_get_element_type (self));
+}
+
+
 ValaDataType* vala_array_type_get_element_type (ValaArrayType* self) {
 	g_return_val_if_fail (VALA_IS_ARRAY_TYPE (self), NULL);
 	return self->priv->_element_type;
@@ -363,8 +363,14 @@ ValaDataType* vala_array_type_get_element_type (ValaArrayType* self) {
 
 
 void vala_array_type_set_element_type (ValaArrayType* self, ValaDataType* value) {
+	ValaDataType* _tmp2;
+	ValaDataType* _tmp1;
 	g_return_if_fail (VALA_IS_ARRAY_TYPE (self));
-	self->priv->_element_type = value;
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_element_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_element_type == NULL ? NULL : (self->priv->_element_type = (g_object_unref (self->priv->_element_type), NULL))), _tmp2);
+	vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_element_type), VALA_CODE_NODE (self));
+	g_object_notify (((GObject *) (self)), "element-type");
 }
 
 
@@ -377,6 +383,7 @@ gint vala_array_type_get_rank (ValaArrayType* self) {
 void vala_array_type_set_rank (ValaArrayType* self, gint value) {
 	g_return_if_fail (VALA_IS_ARRAY_TYPE (self));
 	self->priv->_rank = value;
+	g_object_notify (((GObject *) (self)), "rank");
 }
 
 
@@ -419,39 +426,43 @@ static void vala_array_type_class_init (ValaArrayTypeClass * klass) {
 	g_type_class_add_private (klass, sizeof (ValaArrayTypePrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_array_type_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_array_type_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_array_type_dispose;
+	G_OBJECT_CLASS (klass)->finalize = vala_array_type_finalize;
 	VALA_DATA_TYPE_CLASS (klass)->get_member = vala_array_type_real_get_member;
 	VALA_DATA_TYPE_CLASS (klass)->copy = vala_array_type_real_copy;
 	VALA_DATA_TYPE_CLASS (klass)->get_cname = vala_array_type_real_get_cname;
 	VALA_DATA_TYPE_CLASS (klass)->is_array = vala_array_type_real_is_array;
-	VALA_CODE_NODE_CLASS (klass)->to_string = vala_array_type_real_to_string;
+	VALA_DATA_TYPE_CLASS (klass)->to_qualified_string = vala_array_type_real_to_qualified_string;
 	VALA_DATA_TYPE_CLASS (klass)->compatible = vala_array_type_real_compatible;
 	VALA_DATA_TYPE_CLASS (klass)->is_reference_type_or_type_parameter = vala_array_type_real_is_reference_type_or_type_parameter;
 	VALA_DATA_TYPE_CLASS (klass)->get_type_signature = vala_array_type_real_get_type_signature;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_ARRAY_TYPE_ELEMENT_TYPE, g_param_spec_object ("element-type", "element-type", "element-type", VALA_TYPE_DATA_TYPE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_ARRAY_TYPE_RANK, g_param_spec_int ("rank", "rank", "rank", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
+	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_array_type_real_accept_children;
+	VALA_CODE_NODE_CLASS (klass)->replace_type = vala_array_type_real_replace_type;
+	VALA_DATA_TYPE_CLASS (klass)->get_symbols = vala_array_type_real_get_symbols;
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_ARRAY_TYPE_ELEMENT_TYPE, g_param_spec_object ("element-type", "element-type", "element-type", VALA_TYPE_DATA_TYPE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_ARRAY_TYPE_RANK, g_param_spec_int ("rank", "rank", "rank", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
-static void vala_array_type_init (ValaArrayType * self) {
+static void vala_array_type_instance_init (ValaArrayType * self) {
 	self->priv = VALA_ARRAY_TYPE_GET_PRIVATE (self);
 }
 
 
-static void vala_array_type_dispose (GObject * obj) {
+static void vala_array_type_finalize (GObject * obj) {
 	ValaArrayType * self;
 	self = VALA_ARRAY_TYPE (obj);
+	(self->priv->_element_type == NULL ? NULL : (self->priv->_element_type = (g_object_unref (self->priv->_element_type), NULL)));
 	(self->priv->length_field == NULL ? NULL : (self->priv->length_field = (g_object_unref (self->priv->length_field), NULL)));
 	(self->priv->resize_method == NULL ? NULL : (self->priv->resize_method = (g_object_unref (self->priv->resize_method), NULL)));
 	(self->priv->move_method == NULL ? NULL : (self->priv->move_method = (g_object_unref (self->priv->move_method), NULL)));
-	G_OBJECT_CLASS (vala_array_type_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (vala_array_type_parent_class)->finalize (obj);
 }
 
 
 GType vala_array_type_get_type (void) {
 	static GType vala_array_type_type_id = 0;
-	if (G_UNLIKELY (vala_array_type_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaArrayTypeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_array_type_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaArrayType), 0, (GInstanceInitFunc) vala_array_type_init };
+	if (vala_array_type_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (ValaArrayTypeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_array_type_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaArrayType), 0, (GInstanceInitFunc) vala_array_type_instance_init };
 		vala_array_type_type_id = g_type_register_static (VALA_TYPE_REFERENCE_TYPE, "ValaArrayType", &g_define_type_info, 0);
 	}
 	return vala_array_type_type_id;
