@@ -25,8 +25,15 @@
 
 #include <glib.h>
 #include <glib-object.h>
+#include <stdlib.h>
+#include <string.h>
+#include <gee/list.h>
 #include <vala/valareferencetype.h>
 #include <vala/valadatatype.h>
+#include <vala/valasourcereference.h>
+#include <vala/valasymbol.h>
+#include <vala/valascope.h>
+#include <vala/valacodevisitor.h>
 
 G_BEGIN_DECLS
 
@@ -49,17 +56,20 @@ struct _ValaArrayType {
 	ValaReferenceType parent_instance;
 	ValaArrayTypePrivate * priv;
 };
+
 struct _ValaArrayTypeClass {
 	ValaReferenceTypeClass parent_class;
 };
 
-ValaArrayType* vala_array_type_new (ValaDataType* element_type, gint rank);
+
+ValaArrayType* vala_array_type_new (ValaDataType* element_type, gint rank, ValaSourceReference* source_reference);
 ValaDataType* vala_array_type_get_element_type (ValaArrayType* self);
 void vala_array_type_set_element_type (ValaArrayType* self, ValaDataType* value);
 gint vala_array_type_get_rank (ValaArrayType* self);
 void vala_array_type_set_rank (ValaArrayType* self, gint value);
 GType vala_array_type_get_type (void);
 
+
 G_END_DECLS
 
 #endif
