@@ -89,7 +89,7 @@ static void vala_base_access_instance_init (ValaBaseAccess * self) {
 
 GType vala_base_access_get_type (void) {
 	static GType vala_base_access_type_id = 0;
-	if (G_UNLIKELY (vala_base_access_type_id == 0)) {
+	if (vala_base_access_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaBaseAccessClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_base_access_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaBaseAccess), 0, (GInstanceInitFunc) vala_base_access_instance_init };
 		vala_base_access_type_id = g_type_register_static (VALA_TYPE_EXPRESSION, "ValaBaseAccess", &g_define_type_info, 0);
 	}
