@@ -22,8 +22,8 @@
 
 #include <vala/valablock.h>
 #include <gee/arraylist.h>
-#include <gee/list.h>
-#include <gee/readonlycollection.h>
+#include <gee/collection.h>
+#include <gee/readonlylist.h>
 #include <vala/valalocalvariable.h>
 #include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
@@ -46,7 +46,7 @@ static void vala_block_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor
 static void vala_block_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static gpointer vala_block_parent_class = NULL;
 static ValaStatementIface* vala_block_vala_statement_parent_iface = NULL;
-static void vala_block_dispose (GObject * obj);
+static void vala_block_finalize (GObject * obj);
 
 
 
@@ -57,7 +57,7 @@ static void vala_block_dispose (GObject * obj);
  */
 ValaBlock* vala_block_new (ValaSourceReference* source_reference) {
 	ValaBlock * self;
-	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
+	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	self = g_object_newv (VALA_TYPE_BLOCK, 0, NULL);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
 	return self;
@@ -81,9 +81,9 @@ void vala_block_add_statement (ValaBlock* self, ValaStatement* stmt) {
  *
  * @return statement list
  */
-GeeCollection* vala_block_get_statements (ValaBlock* self) {
+GeeList* vala_block_get_statements (ValaBlock* self) {
 	g_return_val_if_fail (VALA_IS_BLOCK (self), NULL);
-	return GEE_COLLECTION (gee_read_only_collection_new (VALA_TYPE_STATEMENT, ((GBoxedCopyFunc) g_object_ref), g_object_unref, GEE_COLLECTION (self->priv->statement_list)));
+	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_STATEMENT, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, self->priv->statement_list));
 }
 
 
@@ -104,9 +104,9 @@ void vala_block_add_local_variable (ValaBlock* self, ValaLocalVariable* local) {
  *
  * @return variable declarator list
  */
-GeeCollection* vala_block_get_local_variables (ValaBlock* self) {
+GeeList* vala_block_get_local_variables (ValaBlock* self) {
 	g_return_val_if_fail (VALA_IS_BLOCK (self), NULL);
-	return GEE_COLLECTION (gee_read_only_collection_new (VALA_TYPE_LOCAL_VARIABLE, ((GBoxedCopyFunc) g_object_ref), g_object_unref, GEE_COLLECTION (self->priv->local_variables)));
+	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_LOCAL_VARIABLE, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, self->priv->local_variables));
 }
 
 
@@ -124,18 +124,16 @@ static void vala_block_real_accept_children (ValaCodeNode* base, ValaCodeVisitor
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	{
 		GeeList* stmt_collection;
-		GeeIterator* stmt_it;
+		int stmt_it;
 		stmt_collection = self->priv->statement_list;
-		stmt_it = gee_iterable_iterator (GEE_ITERABLE (stmt_collection));
-		while (gee_iterator_next (stmt_it)) {
+		for (stmt_it = 0; stmt_it < gee_collection_get_size (GEE_COLLECTION (stmt_collection)); stmt_it = stmt_it + 1) {
 			ValaStatement* stmt;
-			stmt = ((ValaStatement*) gee_iterator_get (stmt_it));
+			stmt = ((ValaStatement*) (gee_list_get (GEE_LIST (stmt_collection), stmt_it)));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (stmt), visitor);
 				(stmt == NULL ? NULL : (stmt = (g_object_unref (stmt), NULL)));
 			}
 		}
-		(stmt_it == NULL ? NULL : (stmt_it = (g_object_unref (stmt_it), NULL)));
 	}
 }
 
@@ -149,6 +147,7 @@ gboolean vala_block_get_contains_jump_statement (ValaBlock* self) {
 void vala_block_set_contains_jump_statement (ValaBlock* self, gboolean value) {
 	g_return_if_fail (VALA_IS_BLOCK (self));
 	self->priv->_contains_jump_statement = value;
+	g_object_notify (((GObject *) (self)), "contains-jump-statement");
 }
 
 
@@ -185,7 +184,7 @@ static void vala_block_class_init (ValaBlockClass * klass) {
 	g_type_class_add_private (klass, sizeof (ValaBlockPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_block_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_block_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_block_dispose;
+	G_OBJECT_CLASS (klass)->finalize = vala_block_finalize;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_block_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_block_real_accept_children;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_BLOCK_CONTAINS_JUMP_STATEMENT, g_param_spec_boolean ("contains-jump-statement", "contains-jump-statement", "contains-jump-statement", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
@@ -197,26 +196,26 @@ static void vala_block_vala_statement_interface_init (ValaStatementIface * iface
 }
 
 
-static void vala_block_init (ValaBlock * self) {
+static void vala_block_instance_init (ValaBlock * self) {
 	self->priv = VALA_BLOCK_GET_PRIVATE (self);
-	self->priv->statement_list = GEE_LIST (gee_array_list_new (VALA_TYPE_STATEMENT, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
-	self->priv->local_variables = GEE_LIST (gee_array_list_new (VALA_TYPE_LOCAL_VARIABLE, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
+	self->priv->statement_list = GEE_LIST (gee_array_list_new (VALA_TYPE_STATEMENT, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
+	self->priv->local_variables = GEE_LIST (gee_array_list_new (VALA_TYPE_LOCAL_VARIABLE, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
 }
 
 
-static void vala_block_dispose (GObject * obj) {
+static void vala_block_finalize (GObject * obj) {
 	ValaBlock * self;
 	self = VALA_BLOCK (obj);
 	(self->priv->statement_list == NULL ? NULL : (self->priv->statement_list = (g_object_unref (self->priv->statement_list), NULL)));
 	(self->priv->local_variables == NULL ? NULL : (self->priv->local_variables = (g_object_unref (self->priv->local_variables), NULL)));
-	G_OBJECT_CLASS (vala_block_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (vala_block_parent_class)->finalize (obj);
 }
 
 
 GType vala_block_get_type (void) {
 	static GType vala_block_type_id = 0;
-	if (G_UNLIKELY (vala_block_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaBlockClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_block_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaBlock), 0, (GInstanceInitFunc) vala_block_init };
+	if (vala_block_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (ValaBlockClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_block_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaBlock), 0, (GInstanceInitFunc) vala_block_instance_init };
 		static const GInterfaceInfo vala_statement_info = { (GInterfaceInitFunc) vala_block_vala_statement_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		vala_block_type_id = g_type_register_static (VALA_TYPE_SYMBOL, "ValaBlock", &g_define_type_info, 0);
 		g_type_add_interface_static (vala_block_type_id, VALA_TYPE_STATEMENT, &vala_statement_info);
