@@ -41,7 +41,7 @@ static void vala_boolean_literal_real_accept (ValaCodeNode* base, ValaCodeVisito
 static char* vala_boolean_literal_real_to_string (ValaCodeNode* base);
 static gboolean vala_boolean_literal_real_is_pure (ValaExpression* base);
 static gpointer vala_boolean_literal_parent_class = NULL;
-static void vala_boolean_literal_dispose (GObject * obj);
+static void vala_boolean_literal_finalize (GObject * obj);
 
 
 
@@ -98,6 +98,7 @@ gboolean vala_boolean_literal_get_value (ValaBooleanLiteral* self) {
 void vala_boolean_literal_set_value (ValaBooleanLiteral* self, gboolean value) {
 	g_return_if_fail (VALA_IS_BOOLEAN_LITERAL (self));
 	self->priv->_value = value;
+	g_object_notify (((GObject *) (self)), "value");
 }
 
 
@@ -134,7 +135,7 @@ static void vala_boolean_literal_class_init (ValaBooleanLiteralClass * klass) {
 	g_type_class_add_private (klass, sizeof (ValaBooleanLiteralPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_boolean_literal_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_boolean_literal_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_boolean_literal_dispose;
+	G_OBJECT_CLASS (klass)->finalize = vala_boolean_literal_finalize;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_boolean_literal_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->to_string = vala_boolean_literal_real_to_string;
 	VALA_EXPRESSION_CLASS (klass)->is_pure = vala_boolean_literal_real_is_pure;
@@ -147,16 +148,16 @@ static void vala_boolean_literal_instance_init (ValaBooleanLiteral * self) {
 }
 
 
-static void vala_boolean_literal_dispose (GObject * obj) {
+static void vala_boolean_literal_finalize (GObject * obj) {
 	ValaBooleanLiteral * self;
 	self = VALA_BOOLEAN_LITERAL (obj);
-	G_OBJECT_CLASS (vala_boolean_literal_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (vala_boolean_literal_parent_class)->finalize (obj);
 }
 
 
 GType vala_boolean_literal_get_type (void) {
 	static GType vala_boolean_literal_type_id = 0;
-	if (G_UNLIKELY (vala_boolean_literal_type_id == 0)) {
+	if (vala_boolean_literal_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaBooleanLiteralClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_boolean_literal_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaBooleanLiteral), 0, (GInstanceInitFunc) vala_boolean_literal_instance_init };
 		vala_boolean_literal_type_id = g_type_register_static (VALA_TYPE_LITERAL, "ValaBooleanLiteral", &g_define_type_info, 0);
 	}
