@@ -46,7 +46,7 @@ static void vala_cast_expression_real_replace_expression (ValaCodeNode* base, Va
 static gboolean vala_cast_expression_real_is_pure (ValaExpression* base);
 static void vala_cast_expression_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type);
 static gpointer vala_cast_expression_parent_class = NULL;
-static void vala_cast_expression_dispose (GObject * obj);
+static void vala_cast_expression_finalize (GObject * obj);
 
 
 
@@ -140,6 +140,7 @@ void vala_cast_expression_set_inner (ValaCastExpression* self, ValaExpression* v
 	_tmp1 = NULL;
 	self->priv->_inner = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL))), _tmp2);
 	vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_inner), VALA_CODE_NODE (self));
+	g_object_notify (((GObject *) (self)), "inner");
 }
 
 
@@ -157,6 +158,7 @@ void vala_cast_expression_set_type_reference (ValaCastExpression* self, ValaData
 	_tmp1 = NULL;
 	self->priv->_data_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_data_type == NULL ? NULL : (self->priv->_data_type = (g_object_unref (self->priv->_data_type), NULL))), _tmp2);
 	vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_data_type), VALA_CODE_NODE (self));
+	g_object_notify (((GObject *) (self)), "type-reference");
 }
 
 
@@ -169,6 +171,7 @@ gboolean vala_cast_expression_get_is_silent_cast (ValaCastExpression* self) {
 void vala_cast_expression_set_is_silent_cast (ValaCastExpression* self, gboolean value) {
 	g_return_if_fail (VALA_IS_CAST_EXPRESSION (self));
 	self->priv->_is_silent_cast = value;
+	g_object_notify (((GObject *) (self)), "is-silent-cast");
 }
 
 
@@ -217,7 +220,7 @@ static void vala_cast_expression_class_init (ValaCastExpressionClass * klass) {
 	g_type_class_add_private (klass, sizeof (ValaCastExpressionPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_cast_expression_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_cast_expression_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_cast_expression_dispose;
+	G_OBJECT_CLASS (klass)->finalize = vala_cast_expression_finalize;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_cast_expression_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->replace_expression = vala_cast_expression_real_replace_expression;
 	VALA_EXPRESSION_CLASS (klass)->is_pure = vala_cast_expression_real_is_pure;
@@ -233,18 +236,18 @@ static void vala_cast_expression_instance_init (ValaCastExpression * self) {
 }
 
 
-static void vala_cast_expression_dispose (GObject * obj) {
+static void vala_cast_expression_finalize (GObject * obj) {
 	ValaCastExpression * self;
 	self = VALA_CAST_EXPRESSION (obj);
 	(self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL)));
 	(self->priv->_data_type == NULL ? NULL : (self->priv->_data_type = (g_object_unref (self->priv->_data_type), NULL)));
-	G_OBJECT_CLASS (vala_cast_expression_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (vala_cast_expression_parent_class)->finalize (obj);
 }
 
 
 GType vala_cast_expression_get_type (void) {
 	static GType vala_cast_expression_type_id = 0;
-	if (G_UNLIKELY (vala_cast_expression_type_id == 0)) {
+	if (vala_cast_expression_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaCastExpressionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_cast_expression_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCastExpression), 0, (GInstanceInitFunc) vala_cast_expression_instance_init };
 		vala_cast_expression_type_id = g_type_register_static (VALA_TYPE_EXPRESSION, "ValaCastExpression", &g_define_type_info, 0);
 	}
