@@ -155,10 +155,10 @@ static void vala_cfg_builder_jump_target_set_last_block (ValaCFGBuilderJumpTarge
 static ValaCatchClause* vala_cfg_builder_jump_target_get_catch_clause (ValaCFGBuilderJumpTarget* self);
 static void vala_cfg_builder_jump_target_set_catch_clause (ValaCFGBuilderJumpTarget* self, ValaCatchClause* value);
 static gpointer vala_cfg_builder_jump_target_parent_class = NULL;
-static void vala_cfg_builder_jump_target_dispose (GObject * obj);
+static void vala_cfg_builder_jump_target_finalize (GObject * obj);
 static GType vala_cfg_builder_jump_target_get_type (void);
 static gpointer vala_cfg_builder_parent_class = NULL;
-static void vala_cfg_builder_dispose (GObject * obj);
+static void vala_cfg_builder_finalize (GObject * obj);
 
 
 
@@ -1326,6 +1326,7 @@ static gboolean vala_cfg_builder_jump_target_get_break_target (ValaCFGBuilderJum
 static void vala_cfg_builder_jump_target_set_break_target (ValaCFGBuilderJumpTarget* self, gboolean value) {
 	g_return_if_fail (VALA_CFG_BUILDER_IS_JUMP_TARGET (self));
 	self->priv->_break_target = value;
+	g_object_notify (((GObject *) (self)), "break-target");
 }
 
 
@@ -1338,6 +1339,7 @@ static gboolean vala_cfg_builder_jump_target_get_continue_target (ValaCFGBuilder
 static void vala_cfg_builder_jump_target_set_continue_target (ValaCFGBuilderJumpTarget* self, gboolean value) {
 	g_return_if_fail (VALA_CFG_BUILDER_IS_JUMP_TARGET (self));
 	self->priv->_continue_target = value;
+	g_object_notify (((GObject *) (self)), "continue-target");
 }
 
 
@@ -1350,6 +1352,7 @@ static gboolean vala_cfg_builder_jump_target_get_return_target (ValaCFGBuilderJu
 static void vala_cfg_builder_jump_target_set_return_target (ValaCFGBuilderJumpTarget* self, gboolean value) {
 	g_return_if_fail (VALA_CFG_BUILDER_IS_JUMP_TARGET (self));
 	self->priv->_return_target = value;
+	g_object_notify (((GObject *) (self)), "return-target");
 }
 
 
@@ -1362,6 +1365,7 @@ static gboolean vala_cfg_builder_jump_target_get_error_target (ValaCFGBuilderJum
 static void vala_cfg_builder_jump_target_set_error_target (ValaCFGBuilderJumpTarget* self, gboolean value) {
 	g_return_if_fail (VALA_CFG_BUILDER_IS_JUMP_TARGET (self));
 	self->priv->_error_target = value;
+	g_object_notify (((GObject *) (self)), "error-target");
 }
 
 
@@ -1378,6 +1382,7 @@ static void vala_cfg_builder_jump_target_set_error_domain (ValaCFGBuilderJumpTar
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_error_domain = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_error_domain == NULL ? NULL : (self->priv->_error_domain = (g_object_unref (self->priv->_error_domain), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "error-domain");
 }
 
 
@@ -1394,6 +1399,7 @@ static void vala_cfg_builder_jump_target_set_error_code (ValaCFGBuilderJumpTarge
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_error_code = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_error_code == NULL ? NULL : (self->priv->_error_code = (g_object_unref (self->priv->_error_code), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "error-code");
 }
 
 
@@ -1406,6 +1412,7 @@ static gboolean vala_cfg_builder_jump_target_get_finally_clause (ValaCFGBuilderJ
 static void vala_cfg_builder_jump_target_set_finally_clause (ValaCFGBuilderJumpTarget* self, gboolean value) {
 	g_return_if_fail (VALA_CFG_BUILDER_IS_JUMP_TARGET (self));
 	self->priv->_finally_clause = value;
+	g_object_notify (((GObject *) (self)), "finally-clause");
 }
 
 
@@ -1422,6 +1429,7 @@ static void vala_cfg_builder_jump_target_set_basic_block (ValaCFGBuilderJumpTarg
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_basic_block = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_basic_block == NULL ? NULL : (self->priv->_basic_block = (g_object_unref (self->priv->_basic_block), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "basic-block");
 }
 
 
@@ -1438,6 +1446,7 @@ static void vala_cfg_builder_jump_target_set_last_block (ValaCFGBuilderJumpTarge
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_last_block = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_last_block == NULL ? NULL : (self->priv->_last_block = (g_object_unref (self->priv->_last_block), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "last-block");
 }
 
 
@@ -1454,6 +1463,7 @@ static void vala_cfg_builder_jump_target_set_catch_clause (ValaCFGBuilderJumpTar
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_catch_clause = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_catch_clause == NULL ? NULL : (self->priv->_catch_clause = (g_object_unref (self->priv->_catch_clause), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "catch-clause");
 }
 
 
@@ -1544,7 +1554,7 @@ static void vala_cfg_builder_jump_target_class_init (ValaCFGBuilderJumpTargetCla
 	g_type_class_add_private (klass, sizeof (ValaCFGBuilderJumpTargetPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_cfg_builder_jump_target_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_cfg_builder_jump_target_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_cfg_builder_jump_target_dispose;
+	G_OBJECT_CLASS (klass)->finalize = vala_cfg_builder_jump_target_finalize;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CFG_BUILDER_JUMP_TARGET_BREAK_TARGET, g_param_spec_boolean ("break-target", "break-target", "break-target", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CFG_BUILDER_JUMP_TARGET_CONTINUE_TARGET, g_param_spec_boolean ("continue-target", "continue-target", "continue-target", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CFG_BUILDER_JUMP_TARGET_RETURN_TARGET, g_param_spec_boolean ("return-target", "return-target", "return-target", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
@@ -1563,7 +1573,7 @@ static void vala_cfg_builder_jump_target_instance_init (ValaCFGBuilderJumpTarget
 }
 
 
-static void vala_cfg_builder_jump_target_dispose (GObject * obj) {
+static void vala_cfg_builder_jump_target_finalize (GObject * obj) {
 	ValaCFGBuilderJumpTarget * self;
 	self = VALA_CFG_BUILDER_JUMP_TARGET (obj);
 	(self->priv->_error_domain == NULL ? NULL : (self->priv->_error_domain = (g_object_unref (self->priv->_error_domain), NULL)));
@@ -1571,13 +1581,13 @@ static void vala_cfg_builder_jump_target_dispose (GObject * obj) {
 	(self->priv->_basic_block == NULL ? NULL : (self->priv->_basic_block = (g_object_unref (self->priv->_basic_block), NULL)));
 	(self->priv->_last_block == NULL ? NULL : (self->priv->_last_block = (g_object_unref (self->priv->_last_block), NULL)));
 	(self->priv->_catch_clause == NULL ? NULL : (self->priv->_catch_clause = (g_object_unref (self->priv->_catch_clause), NULL)));
-	G_OBJECT_CLASS (vala_cfg_builder_jump_target_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (vala_cfg_builder_jump_target_parent_class)->finalize (obj);
 }
 
 
 static GType vala_cfg_builder_jump_target_get_type (void) {
 	static GType vala_cfg_builder_jump_target_type_id = 0;
-	if (G_UNLIKELY (vala_cfg_builder_jump_target_type_id == 0)) {
+	if (vala_cfg_builder_jump_target_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaCFGBuilderJumpTargetClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_cfg_builder_jump_target_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCFGBuilderJumpTarget), 0, (GInstanceInitFunc) vala_cfg_builder_jump_target_instance_init };
 		vala_cfg_builder_jump_target_type_id = g_type_register_static (G_TYPE_OBJECT, "ValaCFGBuilderJumpTarget", &g_define_type_info, 0);
 	}
@@ -1588,7 +1598,7 @@ static GType vala_cfg_builder_jump_target_get_type (void) {
 static void vala_cfg_builder_class_init (ValaCFGBuilderClass * klass) {
 	vala_cfg_builder_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaCFGBuilderPrivate));
-	G_OBJECT_CLASS (klass)->dispose = vala_cfg_builder_dispose;
+	G_OBJECT_CLASS (klass)->finalize = vala_cfg_builder_finalize;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_source_file = vala_cfg_builder_real_visit_source_file;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_class = vala_cfg_builder_real_visit_class;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_struct = vala_cfg_builder_real_visit_struct;
@@ -1622,19 +1632,19 @@ static void vala_cfg_builder_instance_init (ValaCFGBuilder * self) {
 }
 
 
-static void vala_cfg_builder_dispose (GObject * obj) {
+static void vala_cfg_builder_finalize (GObject * obj) {
 	ValaCFGBuilder * self;
 	self = VALA_CFG_BUILDER (obj);
 	(self->priv->context == NULL ? NULL : (self->priv->context = (g_object_unref (self->priv->context), NULL)));
 	(self->priv->current_block == NULL ? NULL : (self->priv->current_block = (g_object_unref (self->priv->current_block), NULL)));
 	(self->priv->jump_stack == NULL ? NULL : (self->priv->jump_stack = (g_object_unref (self->priv->jump_stack), NULL)));
-	G_OBJECT_CLASS (vala_cfg_builder_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (vala_cfg_builder_parent_class)->finalize (obj);
 }
 
 
 GType vala_cfg_builder_get_type (void) {
 	static GType vala_cfg_builder_type_id = 0;
-	if (G_UNLIKELY (vala_cfg_builder_type_id == 0)) {
+	if (vala_cfg_builder_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaCFGBuilderClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_cfg_builder_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCFGBuilder), 0, (GInstanceInitFunc) vala_cfg_builder_instance_init };
 		vala_cfg_builder_type_id = g_type_register_static (VALA_TYPE_CODE_VISITOR, "ValaCFGBuilder", &g_define_type_info, 0);
 	}
