@@ -58,6 +58,7 @@ struct _ValaClassPrivate {
 	ValaClass* _base_class;
 	gboolean _is_abstract;
 	gboolean _is_static;
+	char* _type_check_function;
 	gboolean _has_private_fields;
 	char* cname;
 	char* const_cname;
@@ -101,6 +102,7 @@ enum  {
 	VALA_CLASS_IS_STATIC,
 	VALA_CLASS_IS_COMPACT,
 	VALA_CLASS_IS_IMMUTABLE,
+	VALA_CLASS_TYPE_CHECK_FUNCTION,
 	VALA_CLASS_HAS_PRIVATE_FIELDS,
 	VALA_CLASS_DEFAULT_CONSTRUCTION_METHOD,
 	VALA_CLASS_CONSTRUCTOR,
@@ -139,7 +141,7 @@ static void vala_class_real_replace_type (ValaCodeNode* base, ValaDataType* old_
 static ValaCodeBinding* vala_class_real_create_code_binding (ValaCodeNode* base, ValaCodeGenerator* codegen);
 static void vala_class_set_has_private_fields (ValaClass* self, gboolean value);
 static gpointer vala_class_parent_class = NULL;
-static void vala_class_dispose (GObject * obj);
+static void vala_class_finalize (GObject * obj);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
 static int _vala_strcmp0 (const char * str1, const char * str2);
 
@@ -878,6 +880,12 @@ static void vala_class_process_ccode_attribute (ValaClass* self, ValaAttribute*
 		_tmp13 = NULL;
 		self->priv->type_signature = (_tmp13 = vala_attribute_get_string (a, "type_signature"), (self->priv->type_signature = (g_free (self->priv->type_signature), NULL)), _tmp13);
 	}
+	if (vala_attribute_has_argument (a, "type_check_function")) {
+		char* _tmp14;
+		_tmp14 = NULL;
+		vala_class_set_type_check_function (self, (_tmp14 = vala_attribute_get_string (a, "type_check_function")));
+		_tmp14 = (g_free (_tmp14), NULL);
+	}
 }
 
 
@@ -1240,6 +1248,7 @@ void vala_class_set_base_class (ValaClass* self, ValaClass* value) {
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_base_class = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_base_class == NULL ? NULL : (self->priv->_base_class = (g_object_unref (self->priv->_base_class), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "base-class");
 }
 
 
@@ -1252,6 +1261,7 @@ gboolean vala_class_get_is_abstract (ValaClass* self) {
 void vala_class_set_is_abstract (ValaClass* self, gboolean value) {
 	g_return_if_fail (VALA_IS_CLASS (self));
 	self->priv->_is_abstract = value;
+	g_object_notify (((GObject *) (self)), "is-abstract");
 }
 
 
@@ -1264,6 +1274,7 @@ gboolean vala_class_get_is_static (ValaClass* self) {
 void vala_class_set_is_static (ValaClass* self, gboolean value) {
 	g_return_if_fail (VALA_IS_CLASS (self));
 	self->priv->_is_static = value;
+	g_object_notify (((GObject *) (self)), "is-static");
 }
 
 
@@ -1279,6 +1290,7 @@ gboolean vala_class_get_is_compact (ValaClass* self) {
 void vala_class_set_is_compact (ValaClass* self, gboolean value) {
 	g_return_if_fail (VALA_IS_CLASS (self));
 	self->priv->_is_compact = value;
+	g_object_notify (((GObject *) (self)), "is-compact");
 }
 
 
@@ -1294,6 +1306,24 @@ gboolean vala_class_get_is_immutable (ValaClass* self) {
 void vala_class_set_is_immutable (ValaClass* self, gboolean value) {
 	g_return_if_fail (VALA_IS_CLASS (self));
 	self->priv->_is_immutable = value;
+	g_object_notify (((GObject *) (self)), "is-immutable");
+}
+
+
+const char* vala_class_get_type_check_function (ValaClass* self) {
+	g_return_val_if_fail (VALA_IS_CLASS (self), NULL);
+	return self->priv->_type_check_function;
+}
+
+
+void vala_class_set_type_check_function (ValaClass* self, const char* value) {
+	char* _tmp2;
+	const char* _tmp1;
+	g_return_if_fail (VALA_IS_CLASS (self));
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_type_check_function = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_type_check_function = (g_free (self->priv->_type_check_function), NULL)), _tmp2);
+	g_object_notify (((GObject *) (self)), "type-check-function");
 }
 
 
@@ -1306,6 +1336,7 @@ gboolean vala_class_get_has_private_fields (ValaClass* self) {
 static void vala_class_set_has_private_fields (ValaClass* self, gboolean value) {
 	g_return_if_fail (VALA_IS_CLASS (self));
 	self->priv->_has_private_fields = value;
+	g_object_notify (((GObject *) (self)), "has-private-fields");
 }
 
 
@@ -1322,6 +1353,7 @@ void vala_class_set_default_construction_method (ValaClass* self, ValaMethod* va
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_default_construction_method = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_default_construction_method == NULL ? NULL : (self->priv->_default_construction_method = (g_object_unref (self->priv->_default_construction_method), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "default-construction-method");
 }
 
 
@@ -1338,6 +1370,7 @@ void vala_class_set_constructor (ValaClass* self, ValaConstructor* value) {
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_constructor = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_constructor == NULL ? NULL : (self->priv->_constructor = (g_object_unref (self->priv->_constructor), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "constructor");
 }
 
 
@@ -1354,6 +1387,7 @@ void vala_class_set_class_constructor (ValaClass* self, ValaConstructor* value)
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_class_constructor = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_class_constructor == NULL ? NULL : (self->priv->_class_constructor = (g_object_unref (self->priv->_class_constructor), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "class-constructor");
 }
 
 
@@ -1370,6 +1404,7 @@ void vala_class_set_static_constructor (ValaClass* self, ValaConstructor* value)
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_static_constructor = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_static_constructor == NULL ? NULL : (self->priv->_static_constructor = (g_object_unref (self->priv->_static_constructor), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "static-constructor");
 }
 
 
@@ -1399,6 +1434,7 @@ void vala_class_set_destructor (ValaClass* self, ValaDestructor* value) {
 		(_tmp3 == NULL ? NULL : (_tmp3 = (g_object_unref (_tmp3), NULL)));
 		vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (self->priv->_destructor)), vala_symbol_get_name (VALA_SYMBOL (vala_destructor_get_this_parameter (self->priv->_destructor))), VALA_SYMBOL (vala_destructor_get_this_parameter (self->priv->_destructor)));
 	}
+	g_object_notify (((GObject *) (self)), "destructor");
 }
 
 
@@ -1411,6 +1447,7 @@ gboolean vala_class_get_is_error_base (ValaClass* self) {
 void vala_class_set_is_error_base (ValaClass* self, gboolean value) {
 	g_return_if_fail (VALA_IS_CLASS (self));
 	self->priv->_is_error_base = value;
+	g_object_notify (((GObject *) (self)), "is-error-base");
 }
 
 
@@ -1433,6 +1470,9 @@ static void vala_class_get_property (GObject * object, guint property_id, GValue
 		case VALA_CLASS_IS_IMMUTABLE:
 		g_value_set_boolean (value, vala_class_get_is_immutable (self));
 		break;
+		case VALA_CLASS_TYPE_CHECK_FUNCTION:
+		g_value_set_string (value, vala_class_get_type_check_function (self));
+		break;
 		case VALA_CLASS_HAS_PRIVATE_FIELDS:
 		g_value_set_boolean (value, vala_class_get_has_private_fields (self));
 		break;
@@ -1480,6 +1520,9 @@ static void vala_class_set_property (GObject * object, guint property_id, const
 		case VALA_CLASS_IS_IMMUTABLE:
 		vala_class_set_is_immutable (self, g_value_get_boolean (value));
 		break;
+		case VALA_CLASS_TYPE_CHECK_FUNCTION:
+		vala_class_set_type_check_function (self, g_value_get_string (value));
+		break;
 		case VALA_CLASS_HAS_PRIVATE_FIELDS:
 		vala_class_set_has_private_fields (self, g_value_get_boolean (value));
 		break;
@@ -1513,7 +1556,7 @@ static void vala_class_class_init (ValaClassClass * klass) {
 	g_type_class_add_private (klass, sizeof (ValaClassPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_class_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_class_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_class_dispose;
+	G_OBJECT_CLASS (klass)->finalize = vala_class_finalize;
 	VALA_OBJECT_TYPE_SYMBOL_CLASS (klass)->get_methods = vala_class_real_get_methods;
 	VALA_OBJECT_TYPE_SYMBOL_CLASS (klass)->get_properties = vala_class_real_get_properties;
 	VALA_OBJECT_TYPE_SYMBOL_CLASS (klass)->get_signals = vala_class_real_get_signals;
@@ -1544,6 +1587,7 @@ static void vala_class_class_init (ValaClassClass * klass) {
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CLASS_IS_STATIC, g_param_spec_boolean ("is-static", "is-static", "is-static", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CLASS_IS_COMPACT, g_param_spec_boolean ("is-compact", "is-compact", "is-compact", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CLASS_IS_IMMUTABLE, g_param_spec_boolean ("is-immutable", "is-immutable", "is-immutable", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CLASS_TYPE_CHECK_FUNCTION, g_param_spec_string ("type-check-function", "type-check-function", "type-check-function", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CLASS_HAS_PRIVATE_FIELDS, g_param_spec_boolean ("has-private-fields", "has-private-fields", "has-private-fields", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CLASS_DEFAULT_CONSTRUCTION_METHOD, g_param_spec_object ("default-construction-method", "default-construction-method", "default-construction-method", VALA_TYPE_METHOD, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CLASS_CONSTRUCTOR, g_param_spec_object ("constructor", "constructor", "constructor", VALA_TYPE_CONSTRUCTOR, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
@@ -1570,10 +1614,11 @@ static void vala_class_instance_init (ValaClass * self) {
 }
 
 
-static void vala_class_dispose (GObject * obj) {
+static void vala_class_finalize (GObject * obj) {
 	ValaClass * self;
 	self = VALA_CLASS (obj);
 	(self->priv->_base_class == NULL ? NULL : (self->priv->_base_class = (g_object_unref (self->priv->_base_class), NULL)));
+	self->priv->_type_check_function = (g_free (self->priv->_type_check_function), NULL);
 	self->priv->cname = (g_free (self->priv->cname), NULL);
 	self->priv->const_cname = (g_free (self->priv->const_cname), NULL);
 	self->priv->lower_case_cprefix = (g_free (self->priv->lower_case_cprefix), NULL);
@@ -1603,13 +1648,13 @@ static void vala_class_dispose (GObject * obj) {
 	(self->priv->_class_constructor == NULL ? NULL : (self->priv->_class_constructor = (g_object_unref (self->priv->_class_constructor), NULL)));
 	(self->priv->_static_constructor == NULL ? NULL : (self->priv->_static_constructor = (g_object_unref (self->priv->_static_constructor), NULL)));
 	(self->priv->_destructor == NULL ? NULL : (self->priv->_destructor = (g_object_unref (self->priv->_destructor), NULL)));
-	G_OBJECT_CLASS (vala_class_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (vala_class_parent_class)->finalize (obj);
 }
 
 
 GType vala_class_get_type (void) {
 	static GType vala_class_type_id = 0;
-	if (G_UNLIKELY (vala_class_type_id == 0)) {
+	if (vala_class_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaClassClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_class_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaClass), 0, (GInstanceInitFunc) vala_class_instance_init };
 		vala_class_type_id = g_type_register_static (VALA_TYPE_OBJECT_TYPE_SYMBOL, "ValaClass", &g_define_type_info, 0);
 	}
