@@ -55,6 +55,8 @@ struct _ValaCodeContextPrivate {
 	gboolean _thread;
 	ValaMethod* _module_init_method;
 	gboolean _save_temps;
+	gint _target_glib_major;
+	gint _target_glib_minor;
 	GeeList* source_files;
 	GeeList* c_source_files;
 	ValaNamespace* _root;
@@ -83,6 +85,8 @@ enum  {
 	VALA_CODE_CONTEXT_THREAD,
 	VALA_CODE_CONTEXT_MODULE_INIT_METHOD,
 	VALA_CODE_CONTEXT_SAVE_TEMPS,
+	VALA_CODE_CONTEXT_TARGET_GLIB_MAJOR,
+	VALA_CODE_CONTEXT_TARGET_GLIB_MINOR,
 	VALA_CODE_CONTEXT_SAVE_CSOURCES,
 	VALA_CODE_CONTEXT_SAVE_CHEADERS,
 	VALA_CODE_CONTEXT_ROOT,
@@ -92,10 +96,20 @@ static ValaSourceFile* vala_code_context_find_cycle_head (ValaCodeContext* self,
 static void vala_code_context_visit (ValaCodeContext* self, ValaSourceFile* file, GeeList* chain);
 static GObject * vala_code_context_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
 static gpointer vala_code_context_parent_class = NULL;
-static void vala_code_context_dispose (GObject * obj);
+static void vala_code_context_finalize (GObject * obj);
 
 
 
+/**
+ * Returns true if the target version of glib is greater than or 
+ * equal to the specified version.
+ */
+gboolean vala_code_context_require_glib_version (ValaCodeContext* self, gint major, gint minor) {
+	g_return_val_if_fail (VALA_IS_CODE_CONTEXT (self), FALSE);
+	return (self->priv->_target_glib_major > major) || (self->priv->_target_glib_major == major && self->priv->_target_glib_minor >= minor);
+}
+
+
 ValaCodeContext* vala_code_context_new (void) {
 	ValaCodeContext * self;
 	self = g_object_newv (VALA_TYPE_CODE_CONTEXT, 0, NULL);
@@ -595,6 +609,7 @@ void vala_code_context_set_library (ValaCodeContext* self, const char* value) {
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_library = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_library = (g_free (self->priv->_library), NULL)), _tmp2);
+	g_object_notify (((GObject *) (self)), "library");
 }
 
 
@@ -607,6 +622,7 @@ gboolean vala_code_context_get_memory_management (ValaCodeContext* self) {
 void vala_code_context_set_memory_management (ValaCodeContext* self, gboolean value) {
 	g_return_if_fail (VALA_IS_CODE_CONTEXT (self));
 	self->priv->_memory_management = value;
+	g_object_notify (((GObject *) (self)), "memory-management");
 }
 
 
@@ -619,6 +635,7 @@ gboolean vala_code_context_get_assert (ValaCodeContext* self) {
 void vala_code_context_set_assert (ValaCodeContext* self, gboolean value) {
 	g_return_if_fail (VALA_IS_CODE_CONTEXT (self));
 	self->priv->_assert = value;
+	g_object_notify (((GObject *) (self)), "assert");
 }
 
 
@@ -631,6 +648,7 @@ gboolean vala_code_context_get_checking (ValaCodeContext* self) {
 void vala_code_context_set_checking (ValaCodeContext* self, gboolean value) {
 	g_return_if_fail (VALA_IS_CODE_CONTEXT (self));
 	self->priv->_checking = value;
+	g_object_notify (((GObject *) (self)), "checking");
 }
 
 
@@ -643,6 +661,7 @@ gboolean vala_code_context_get_non_null (ValaCodeContext* self) {
 void vala_code_context_set_non_null (ValaCodeContext* self, gboolean value) {
 	g_return_if_fail (VALA_IS_CODE_CONTEXT (self));
 	self->priv->_non_null = value;
+	g_object_notify (((GObject *) (self)), "non-null");
 }
 
 
@@ -655,6 +674,7 @@ gboolean vala_code_context_get_non_null_experimental (ValaCodeContext* self) {
 void vala_code_context_set_non_null_experimental (ValaCodeContext* self, gboolean value) {
 	g_return_if_fail (VALA_IS_CODE_CONTEXT (self));
 	self->priv->_non_null_experimental = value;
+	g_object_notify (((GObject *) (self)), "non-null-experimental");
 }
 
 
@@ -667,6 +687,7 @@ gboolean vala_code_context_get_ccode_only (ValaCodeContext* self) {
 void vala_code_context_set_ccode_only (ValaCodeContext* self, gboolean value) {
 	g_return_if_fail (VALA_IS_CODE_CONTEXT (self));
 	self->priv->_ccode_only = value;
+	g_object_notify (((GObject *) (self)), "ccode-only");
 }
 
 
@@ -679,6 +700,7 @@ gboolean vala_code_context_get_compile_only (ValaCodeContext* self) {
 void vala_code_context_set_compile_only (ValaCodeContext* self, gboolean value) {
 	g_return_if_fail (VALA_IS_CODE_CONTEXT (self));
 	self->priv->_compile_only = value;
+	g_object_notify (((GObject *) (self)), "compile-only");
 }
 
 
@@ -695,6 +717,7 @@ void vala_code_context_set_output (ValaCodeContext* self, const char* value) {
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_output = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_output = (g_free (self->priv->_output), NULL)), _tmp2);
+	g_object_notify (((GObject *) (self)), "output");
 }
 
 
@@ -711,6 +734,7 @@ void vala_code_context_set_basedir (ValaCodeContext* self, const char* value) {
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_basedir = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_basedir = (g_free (self->priv->_basedir), NULL)), _tmp2);
+	g_object_notify (((GObject *) (self)), "basedir");
 }
 
 
@@ -727,6 +751,7 @@ void vala_code_context_set_directory (ValaCodeContext* self, const char* value)
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_directory = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_directory = (g_free (self->priv->_directory), NULL)), _tmp2);
+	g_object_notify (((GObject *) (self)), "directory");
 }
 
 
@@ -739,6 +764,7 @@ gboolean vala_code_context_get_debug (ValaCodeContext* self) {
 void vala_code_context_set_debug (ValaCodeContext* self, gboolean value) {
 	g_return_if_fail (VALA_IS_CODE_CONTEXT (self));
 	self->priv->_debug = value;
+	g_object_notify (((GObject *) (self)), "debug");
 }
 
 
@@ -751,6 +777,7 @@ gint vala_code_context_get_optlevel (ValaCodeContext* self) {
 void vala_code_context_set_optlevel (ValaCodeContext* self, gint value) {
 	g_return_if_fail (VALA_IS_CODE_CONTEXT (self));
 	self->priv->_optlevel = value;
+	g_object_notify (((GObject *) (self)), "optlevel");
 }
 
 
@@ -763,6 +790,7 @@ gboolean vala_code_context_get_thread (ValaCodeContext* self) {
 void vala_code_context_set_thread (ValaCodeContext* self, gboolean value) {
 	g_return_if_fail (VALA_IS_CODE_CONTEXT (self));
 	self->priv->_thread = value;
+	g_object_notify (((GObject *) (self)), "thread");
 }
 
 
@@ -779,6 +807,7 @@ void vala_code_context_set_module_init_method (ValaCodeContext* self, ValaMethod
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_module_init_method = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_module_init_method == NULL ? NULL : (self->priv->_module_init_method = (g_object_unref (self->priv->_module_init_method), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "module-init-method");
 }
 
 
@@ -791,6 +820,33 @@ gboolean vala_code_context_get_save_temps (ValaCodeContext* self) {
 void vala_code_context_set_save_temps (ValaCodeContext* self, gboolean value) {
 	g_return_if_fail (VALA_IS_CODE_CONTEXT (self));
 	self->priv->_save_temps = value;
+	g_object_notify (((GObject *) (self)), "save-temps");
+}
+
+
+gint vala_code_context_get_target_glib_major (ValaCodeContext* self) {
+	g_return_val_if_fail (VALA_IS_CODE_CONTEXT (self), 0);
+	return self->priv->_target_glib_major;
+}
+
+
+void vala_code_context_set_target_glib_major (ValaCodeContext* self, gint value) {
+	g_return_if_fail (VALA_IS_CODE_CONTEXT (self));
+	self->priv->_target_glib_major = value;
+	g_object_notify (((GObject *) (self)), "target-glib-major");
+}
+
+
+gint vala_code_context_get_target_glib_minor (ValaCodeContext* self) {
+	g_return_val_if_fail (VALA_IS_CODE_CONTEXT (self), 0);
+	return self->priv->_target_glib_minor;
+}
+
+
+void vala_code_context_set_target_glib_minor (ValaCodeContext* self, gint value) {
+	g_return_if_fail (VALA_IS_CODE_CONTEXT (self));
+	self->priv->_target_glib_minor = value;
+	g_object_notify (((GObject *) (self)), "target-glib-minor");
 }
 
 
@@ -825,6 +881,7 @@ void vala_code_context_set_codegen (ValaCodeContext* self, ValaCodeGenerator* va
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_codegen = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_codegen == NULL ? NULL : (self->priv->_codegen = (g_object_unref (self->priv->_codegen), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "codegen");
 }
 
 
@@ -899,6 +956,12 @@ static void vala_code_context_get_property (GObject * object, guint property_id,
 		case VALA_CODE_CONTEXT_SAVE_TEMPS:
 		g_value_set_boolean (value, vala_code_context_get_save_temps (self));
 		break;
+		case VALA_CODE_CONTEXT_TARGET_GLIB_MAJOR:
+		g_value_set_int (value, vala_code_context_get_target_glib_major (self));
+		break;
+		case VALA_CODE_CONTEXT_TARGET_GLIB_MINOR:
+		g_value_set_int (value, vala_code_context_get_target_glib_minor (self));
+		break;
 		case VALA_CODE_CONTEXT_SAVE_CSOURCES:
 		g_value_set_boolean (value, vala_code_context_get_save_csources (self));
 		break;
@@ -970,6 +1033,12 @@ static void vala_code_context_set_property (GObject * object, guint property_id,
 		case VALA_CODE_CONTEXT_SAVE_TEMPS:
 		vala_code_context_set_save_temps (self, g_value_get_boolean (value));
 		break;
+		case VALA_CODE_CONTEXT_TARGET_GLIB_MAJOR:
+		vala_code_context_set_target_glib_major (self, g_value_get_int (value));
+		break;
+		case VALA_CODE_CONTEXT_TARGET_GLIB_MINOR:
+		vala_code_context_set_target_glib_minor (self, g_value_get_int (value));
+		break;
 		case VALA_CODE_CONTEXT_CODEGEN:
 		vala_code_context_set_codegen (self, g_value_get_object (value));
 		break;
@@ -986,7 +1055,7 @@ static void vala_code_context_class_init (ValaCodeContextClass * klass) {
 	G_OBJECT_CLASS (klass)->get_property = vala_code_context_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_code_context_set_property;
 	G_OBJECT_CLASS (klass)->constructor = vala_code_context_constructor;
-	G_OBJECT_CLASS (klass)->dispose = vala_code_context_dispose;
+	G_OBJECT_CLASS (klass)->finalize = vala_code_context_finalize;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CODE_CONTEXT_LIBRARY, g_param_spec_string ("library", "library", "library", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CODE_CONTEXT_MEMORY_MANAGEMENT, g_param_spec_boolean ("memory-management", "memory-management", "memory-management", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CODE_CONTEXT_ASSERT, g_param_spec_boolean ("assert", "assert", "assert", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
@@ -1003,6 +1072,8 @@ static void vala_code_context_class_init (ValaCodeContextClass * klass) {
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CODE_CONTEXT_THREAD, g_param_spec_boolean ("thread", "thread", "thread", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CODE_CONTEXT_MODULE_INIT_METHOD, g_param_spec_object ("module-init-method", "module-init-method", "module-init-method", VALA_TYPE_METHOD, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CODE_CONTEXT_SAVE_TEMPS, g_param_spec_boolean ("save-temps", "save-temps", "save-temps", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CODE_CONTEXT_TARGET_GLIB_MAJOR, g_param_spec_int ("target-glib-major", "target-glib-major", "target-glib-major", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CODE_CONTEXT_TARGET_GLIB_MINOR, g_param_spec_int ("target-glib-minor", "target-glib-minor", "target-glib-minor", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CODE_CONTEXT_SAVE_CSOURCES, g_param_spec_boolean ("save-csources", "save-csources", "save-csources", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CODE_CONTEXT_SAVE_CHEADERS, g_param_spec_boolean ("save-cheaders", "save-cheaders", "save-cheaders", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CODE_CONTEXT_ROOT, g_param_spec_object ("root", "root", "root", VALA_TYPE_NAMESPACE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
@@ -1021,7 +1092,7 @@ static void vala_code_context_instance_init (ValaCodeContext * self) {
 }
 
 
-static void vala_code_context_dispose (GObject * obj) {
+static void vala_code_context_finalize (GObject * obj) {
 	ValaCodeContext * self;
 	self = VALA_CODE_CONTEXT (obj);
 	self->priv->_library = (g_free (self->priv->_library), NULL);
@@ -1036,13 +1107,13 @@ static void vala_code_context_dispose (GObject * obj) {
 	(self->priv->packages == NULL ? NULL : (self->priv->packages = (g_object_unref (self->priv->packages), NULL)));
 	(self->priv->defines == NULL ? NULL : (self->priv->defines = (g_object_unref (self->priv->defines), NULL)));
 	(self->priv->_codegen == NULL ? NULL : (self->priv->_codegen = (g_object_unref (self->priv->_codegen), NULL)));
-	G_OBJECT_CLASS (vala_code_context_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (vala_code_context_parent_class)->finalize (obj);
 }
 
 
 GType vala_code_context_get_type (void) {
 	static GType vala_code_context_type_id = 0;
-	if (G_UNLIKELY (vala_code_context_type_id == 0)) {
+	if (vala_code_context_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaCodeContextClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_code_context_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCodeContext), 0, (GInstanceInitFunc) vala_code_context_instance_init };
 		vala_code_context_type_id = g_type_register_static (G_TYPE_OBJECT, "ValaCodeContext", &g_define_type_info, 0);
 	}
