@@ -1137,7 +1137,7 @@ static void vala_code_generator_instance_init (ValaCodeGenerator * self) {
 
 GType vala_code_generator_get_type (void) {
 	static GType vala_code_generator_type_id = 0;
-	if (G_UNLIKELY (vala_code_generator_type_id == 0)) {
+	if (vala_code_generator_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaCodeGeneratorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_code_generator_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCodeGenerator), 0, (GInstanceInitFunc) vala_code_generator_instance_init };
 		vala_code_generator_type_id = g_type_register_static (VALA_TYPE_CODE_VISITOR, "ValaCodeGenerator", &g_define_type_info, 0);
 	}
