@@ -76,7 +76,7 @@ static void vala_continue_statement_instance_init (ValaContinueStatement * self)
 
 GType vala_continue_statement_get_type (void) {
 	static GType vala_continue_statement_type_id = 0;
-	if (G_UNLIKELY (vala_continue_statement_type_id == 0)) {
+	if (vala_continue_statement_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaContinueStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_continue_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaContinueStatement), 0, (GInstanceInitFunc) vala_continue_statement_instance_init };
 		static const GInterfaceInfo vala_statement_info = { (GInterfaceInitFunc) vala_continue_statement_vala_statement_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		vala_continue_statement_type_id = g_type_register_static (VALA_TYPE_CODE_NODE, "ValaContinueStatement", &g_define_type_info, 0);
