@@ -39,20 +39,22 @@
 struct _ValaCreationMethodPrivate {
 	char* _type_name;
 	gint _n_construction_params;
+	char* _custom_return_type_cname;
 };
 
 #define VALA_CREATION_METHOD_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CREATION_METHOD, ValaCreationMethodPrivate))
 enum  {
 	VALA_CREATION_METHOD_DUMMY_PROPERTY,
 	VALA_CREATION_METHOD_TYPE_NAME,
-	VALA_CREATION_METHOD_N_CONSTRUCTION_PARAMS
+	VALA_CREATION_METHOD_N_CONSTRUCTION_PARAMS,
+	VALA_CREATION_METHOD_CUSTOM_RETURN_TYPE_CNAME
 };
 static void vala_creation_method_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_creation_method_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static char* vala_creation_method_real_get_default_cname (ValaMethod* base);
 static ValaCodeBinding* vala_creation_method_real_create_code_binding (ValaCodeNode* base, ValaCodeGenerator* codegen);
 static gpointer vala_creation_method_parent_class = NULL;
-static void vala_creation_method_dispose (GObject * obj);
+static void vala_creation_method_finalize (GObject * obj);
 
 
 
@@ -183,6 +185,7 @@ void vala_creation_method_set_type_name (ValaCreationMethod* self, const char* v
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_type_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_type_name = (g_free (self->priv->_type_name), NULL)), _tmp2);
+	g_object_notify (((GObject *) (self)), "type-name");
 }
 
 
@@ -195,6 +198,24 @@ gint vala_creation_method_get_n_construction_params (ValaCreationMethod* self) {
 void vala_creation_method_set_n_construction_params (ValaCreationMethod* self, gint value) {
 	g_return_if_fail (VALA_IS_CREATION_METHOD (self));
 	self->priv->_n_construction_params = value;
+	g_object_notify (((GObject *) (self)), "n-construction-params");
+}
+
+
+const char* vala_creation_method_get_custom_return_type_cname (ValaCreationMethod* self) {
+	g_return_val_if_fail (VALA_IS_CREATION_METHOD (self), NULL);
+	return self->priv->_custom_return_type_cname;
+}
+
+
+void vala_creation_method_set_custom_return_type_cname (ValaCreationMethod* self, const char* value) {
+	char* _tmp2;
+	const char* _tmp1;
+	g_return_if_fail (VALA_IS_CREATION_METHOD (self));
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_custom_return_type_cname = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_custom_return_type_cname = (g_free (self->priv->_custom_return_type_cname), NULL)), _tmp2);
+	g_object_notify (((GObject *) (self)), "custom-return-type-cname");
 }
 
 
@@ -208,6 +229,9 @@ static void vala_creation_method_get_property (GObject * object, guint property_
 		case VALA_CREATION_METHOD_N_CONSTRUCTION_PARAMS:
 		g_value_set_int (value, vala_creation_method_get_n_construction_params (self));
 		break;
+		case VALA_CREATION_METHOD_CUSTOM_RETURN_TYPE_CNAME:
+		g_value_set_string (value, vala_creation_method_get_custom_return_type_cname (self));
+		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
 		break;
@@ -225,6 +249,9 @@ static void vala_creation_method_set_property (GObject * object, guint property_
 		case VALA_CREATION_METHOD_N_CONSTRUCTION_PARAMS:
 		vala_creation_method_set_n_construction_params (self, g_value_get_int (value));
 		break;
+		case VALA_CREATION_METHOD_CUSTOM_RETURN_TYPE_CNAME:
+		vala_creation_method_set_custom_return_type_cname (self, g_value_get_string (value));
+		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
 		break;
@@ -237,13 +264,14 @@ static void vala_creation_method_class_init (ValaCreationMethodClass * klass) {
 	g_type_class_add_private (klass, sizeof (ValaCreationMethodPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_creation_method_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_creation_method_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_creation_method_dispose;
+	G_OBJECT_CLASS (klass)->finalize = vala_creation_method_finalize;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_creation_method_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_creation_method_real_accept_children;
 	VALA_METHOD_CLASS (klass)->get_default_cname = vala_creation_method_real_get_default_cname;
 	VALA_CODE_NODE_CLASS (klass)->create_code_binding = vala_creation_method_real_create_code_binding;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CREATION_METHOD_TYPE_NAME, g_param_spec_string ("type-name", "type-name", "type-name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CREATION_METHOD_N_CONSTRUCTION_PARAMS, g_param_spec_int ("n-construction-params", "n-construction-params", "n-construction-params", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CREATION_METHOD_CUSTOM_RETURN_TYPE_CNAME, g_param_spec_string ("custom-return-type-cname", "custom-return-type-cname", "custom-return-type-cname", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
@@ -252,17 +280,18 @@ static void vala_creation_method_instance_init (ValaCreationMethod * self) {
 }
 
 
-static void vala_creation_method_dispose (GObject * obj) {
+static void vala_creation_method_finalize (GObject * obj) {
 	ValaCreationMethod * self;
 	self = VALA_CREATION_METHOD (obj);
 	self->priv->_type_name = (g_free (self->priv->_type_name), NULL);
-	G_OBJECT_CLASS (vala_creation_method_parent_class)->dispose (obj);
+	self->priv->_custom_return_type_cname = (g_free (self->priv->_custom_return_type_cname), NULL);
+	G_OBJECT_CLASS (vala_creation_method_parent_class)->finalize (obj);
 }
 
 
 GType vala_creation_method_get_type (void) {
 	static GType vala_creation_method_type_id = 0;
-	if (G_UNLIKELY (vala_creation_method_type_id == 0)) {
+	if (vala_creation_method_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaCreationMethodClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_creation_method_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCreationMethod), 0, (GInstanceInitFunc) vala_creation_method_instance_init };
 		vala_creation_method_type_id = g_type_register_static (VALA_TYPE_METHOD, "ValaCreationMethod", &g_define_type_info, 0);
 	}
