@@ -62,6 +62,8 @@ const char* vala_creation_method_get_type_name (ValaCreationMethod* self);
 void vala_creation_method_set_type_name (ValaCreationMethod* self, const char* value);
 gint vala_creation_method_get_n_construction_params (ValaCreationMethod* self);
 void vala_creation_method_set_n_construction_params (ValaCreationMethod* self, gint value);
+const char* vala_creation_method_get_custom_return_type_cname (ValaCreationMethod* self);
+void vala_creation_method_set_custom_return_type_cname (ValaCreationMethod* self, const char* value);
 GType vala_creation_method_get_type (void);
 
 
