@@ -40,7 +40,7 @@ enum  {
 static void vala_declaration_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static gpointer vala_declaration_statement_parent_class = NULL;
 static ValaStatementIface* vala_declaration_statement_vala_statement_parent_iface = NULL;
-static void vala_declaration_statement_dispose (GObject * obj);
+static void vala_declaration_statement_finalize (GObject * obj);
 
 
 
@@ -96,6 +96,7 @@ void vala_declaration_statement_set_declaration (ValaDeclarationStatement* self,
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_declaration = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_declaration == NULL ? NULL : (self->priv->_declaration = (g_object_unref (self->priv->_declaration), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "declaration");
 }
 
 
@@ -132,7 +133,7 @@ static void vala_declaration_statement_class_init (ValaDeclarationStatementClass
 	g_type_class_add_private (klass, sizeof (ValaDeclarationStatementPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_declaration_statement_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_declaration_statement_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_declaration_statement_dispose;
+	G_OBJECT_CLASS (klass)->finalize = vala_declaration_statement_finalize;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_declaration_statement_real_accept;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DECLARATION_STATEMENT_DECLARATION, g_param_spec_object ("declaration", "declaration", "declaration", VALA_TYPE_SYMBOL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
 }
@@ -143,23 +144,23 @@ static void vala_declaration_statement_vala_statement_interface_init (ValaStatem
 }
 
 
-static void vala_declaration_statement_init (ValaDeclarationStatement * self) {
+static void vala_declaration_statement_instance_init (ValaDeclarationStatement * self) {
 	self->priv = VALA_DECLARATION_STATEMENT_GET_PRIVATE (self);
 }
 
 
-static void vala_declaration_statement_dispose (GObject * obj) {
+static void vala_declaration_statement_finalize (GObject * obj) {
 	ValaDeclarationStatement * self;
 	self = VALA_DECLARATION_STATEMENT (obj);
 	(self->priv->_declaration == NULL ? NULL : (self->priv->_declaration = (g_object_unref (self->priv->_declaration), NULL)));
-	G_OBJECT_CLASS (vala_declaration_statement_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (vala_declaration_statement_parent_class)->finalize (obj);
 }
 
 
 GType vala_declaration_statement_get_type (void) {
 	static GType vala_declaration_statement_type_id = 0;
-	if (G_UNLIKELY (vala_declaration_statement_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaDeclarationStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_declaration_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaDeclarationStatement), 0, (GInstanceInitFunc) vala_declaration_statement_init };
+	if (vala_declaration_statement_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (ValaDeclarationStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_declaration_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaDeclarationStatement), 0, (GInstanceInitFunc) vala_declaration_statement_instance_init };
 		static const GInterfaceInfo vala_statement_info = { (GInterfaceInitFunc) vala_declaration_statement_vala_statement_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		vala_declaration_statement_type_id = g_type_register_static (VALA_TYPE_CODE_NODE, "ValaDeclarationStatement", &g_define_type_info, 0);
 		g_type_add_interface_static (vala_declaration_statement_type_id, VALA_TYPE_STATEMENT, &vala_statement_info);
