@@ -77,7 +77,7 @@ static char* vala_delegate_get_return_type_string (ValaDelegate* self);
 static char* vala_delegate_get_parameters_string (ValaDelegate* self);
 static GObject * vala_delegate_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
 static gpointer vala_delegate_parent_class = NULL;
-static void vala_delegate_dispose (GObject * obj);
+static void vala_delegate_finalize (GObject * obj);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
 static int _vala_strcmp0 (const char * str1, const char * str2);
 
@@ -512,6 +512,7 @@ void vala_delegate_set_return_type (ValaDelegate* self, ValaDataType* value) {
 	_tmp1 = NULL;
 	self->priv->_return_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_return_type == NULL ? NULL : (self->priv->_return_type = (g_object_unref (self->priv->_return_type), NULL))), _tmp2);
 	vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_return_type), VALA_CODE_NODE (self));
+	g_object_notify (((GObject *) (self)), "return-type");
 }
 
 
@@ -524,6 +525,7 @@ gboolean vala_delegate_get_has_target (ValaDelegate* self) {
 void vala_delegate_set_has_target (ValaDelegate* self, gboolean value) {
 	g_return_if_fail (VALA_IS_DELEGATE (self));
 	self->priv->_has_target = value;
+	g_object_notify (((GObject *) (self)), "has-target");
 }
 
 
@@ -536,6 +538,7 @@ double vala_delegate_get_cinstance_parameter_position (ValaDelegate* self) {
 void vala_delegate_set_cinstance_parameter_position (ValaDelegate* self, double value) {
 	g_return_if_fail (VALA_IS_DELEGATE (self));
 	self->priv->_cinstance_parameter_position = value;
+	g_object_notify (((GObject *) (self)), "cinstance-parameter-position");
 }
 
 
@@ -548,6 +551,7 @@ double vala_delegate_get_carray_length_parameter_position (ValaDelegate* self) {
 void vala_delegate_set_carray_length_parameter_position (ValaDelegate* self, double value) {
 	g_return_if_fail (VALA_IS_DELEGATE (self));
 	self->priv->_carray_length_parameter_position = value;
+	g_object_notify (((GObject *) (self)), "carray-length-parameter-position");
 }
 
 
@@ -560,6 +564,7 @@ double vala_delegate_get_cdelegate_target_parameter_position (ValaDelegate* self
 void vala_delegate_set_cdelegate_target_parameter_position (ValaDelegate* self, double value) {
 	g_return_if_fail (VALA_IS_DELEGATE (self));
 	self->priv->_cdelegate_target_parameter_position = value;
+	g_object_notify (((GObject *) (self)), "cdelegate-target-parameter-position");
 }
 
 
@@ -585,6 +590,7 @@ void vala_delegate_set_no_array_length (ValaDelegate* self, gboolean value) {
 			}
 		}
 	}
+	g_object_notify (((GObject *) (self)), "no-array-length");
 }
 
 
@@ -670,7 +676,7 @@ static void vala_delegate_class_init (ValaDelegateClass * klass) {
 	G_OBJECT_CLASS (klass)->get_property = vala_delegate_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_delegate_set_property;
 	G_OBJECT_CLASS (klass)->constructor = vala_delegate_constructor;
-	G_OBJECT_CLASS (klass)->dispose = vala_delegate_dispose;
+	G_OBJECT_CLASS (klass)->finalize = vala_delegate_finalize;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_delegate_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_delegate_real_accept_children;
 	VALA_TYPESYMBOL_CLASS (klass)->get_cname = vala_delegate_real_get_cname;
@@ -696,20 +702,20 @@ static void vala_delegate_instance_init (ValaDelegate * self) {
 }
 
 
-static void vala_delegate_dispose (GObject * obj) {
+static void vala_delegate_finalize (GObject * obj) {
 	ValaDelegate * self;
 	self = VALA_DELEGATE (obj);
 	(self->priv->type_parameters == NULL ? NULL : (self->priv->type_parameters = (g_object_unref (self->priv->type_parameters), NULL)));
 	(self->priv->parameters == NULL ? NULL : (self->priv->parameters = (g_object_unref (self->priv->parameters), NULL)));
 	self->priv->cname = (g_free (self->priv->cname), NULL);
 	(self->priv->_return_type == NULL ? NULL : (self->priv->_return_type = (g_object_unref (self->priv->_return_type), NULL)));
-	G_OBJECT_CLASS (vala_delegate_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (vala_delegate_parent_class)->finalize (obj);
 }
 
 
 GType vala_delegate_get_type (void) {
 	static GType vala_delegate_type_id = 0;
-	if (G_UNLIKELY (vala_delegate_type_id == 0)) {
+	if (vala_delegate_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaDelegateClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_delegate_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaDelegate), 0, (GInstanceInitFunc) vala_delegate_instance_init };
 		vala_delegate_type_id = g_type_register_static (VALA_TYPE_TYPESYMBOL, "ValaDelegate", &g_define_type_info, 0);
 	}
