@@ -1,6 +1,6 @@
 /* valadestructor.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -22,6 +22,7 @@
 
 #include <vala/valadestructor.h>
 #include <vala/valablock.h>
+#include <vala/valaformalparameter.h>
 #include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
 
@@ -30,18 +31,21 @@
 
 struct _ValaDestructorPrivate {
 	ValaBlock* _body;
-	gboolean _instance;
+	ValaFormalParameter* _this_parameter;
+	MemberBinding _binding;
 };
+
 #define VALA_DESTRUCTOR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_DESTRUCTOR, ValaDestructorPrivate))
 enum  {
 	VALA_DESTRUCTOR_DUMMY_PROPERTY,
 	VALA_DESTRUCTOR_BODY,
-	VALA_DESTRUCTOR_INSTANCE
+	VALA_DESTRUCTOR_THIS_PARAMETER,
+	VALA_DESTRUCTOR_BINDING
 };
 static void vala_destructor_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_destructor_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static gpointer vala_destructor_parent_class = NULL;
-static void vala_destructor_dispose (GObject * obj);
+static void vala_destructor_finalize (GObject * obj);
 
 
 
@@ -63,7 +67,7 @@ ValaDestructor* vala_destructor_new (ValaSourceReference* source_reference) {
 static void vala_destructor_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaDestructor * self;
 	self = VALA_DESTRUCTOR (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_destructor (visitor, self);
 }
 
@@ -71,7 +75,7 @@ static void vala_destructor_real_accept (ValaCodeNode* base, ValaCodeVisitor* vi
 static void vala_destructor_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaDestructor * self;
 	self = VALA_DESTRUCTOR (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	if (self->priv->_body != NULL) {
 		vala_code_node_accept (VALA_CODE_NODE (self->priv->_body), visitor);
 	}
@@ -91,18 +95,37 @@ void vala_destructor_set_body (ValaDestructor* self, ValaBlock* value) {
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_body = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "body");
 }
 
 
-gboolean vala_destructor_get_instance (ValaDestructor* self) {
-	g_return_val_if_fail (VALA_IS_DESTRUCTOR (self), FALSE);
-	return self->priv->_instance;
+ValaFormalParameter* vala_destructor_get_this_parameter (ValaDestructor* self) {
+	g_return_val_if_fail (VALA_IS_DESTRUCTOR (self), NULL);
+	return self->priv->_this_parameter;
 }
 
 
-void vala_destructor_set_instance (ValaDestructor* self, gboolean value) {
+void vala_destructor_set_this_parameter (ValaDestructor* self, ValaFormalParameter* value) {
+	ValaFormalParameter* _tmp2;
+	ValaFormalParameter* _tmp1;
 	g_return_if_fail (VALA_IS_DESTRUCTOR (self));
-	self->priv->_instance = value;
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_this_parameter = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_this_parameter == NULL ? NULL : (self->priv->_this_parameter = (g_object_unref (self->priv->_this_parameter), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "this-parameter");
+}
+
+
+MemberBinding vala_destructor_get_binding (ValaDestructor* self) {
+	g_return_val_if_fail (VALA_IS_DESTRUCTOR (self), 0);
+	return self->priv->_binding;
+}
+
+
+void vala_destructor_set_binding (ValaDestructor* self, MemberBinding value) {
+	g_return_if_fail (VALA_IS_DESTRUCTOR (self));
+	self->priv->_binding = value;
+	g_object_notify (((GObject *) (self)), "binding");
 }
 
 
@@ -113,8 +136,11 @@ static void vala_destructor_get_property (GObject * object, guint property_id, G
 		case VALA_DESTRUCTOR_BODY:
 		g_value_set_object (value, vala_destructor_get_body (self));
 		break;
-		case VALA_DESTRUCTOR_INSTANCE:
-		g_value_set_boolean (value, vala_destructor_get_instance (self));
+		case VALA_DESTRUCTOR_THIS_PARAMETER:
+		g_value_set_object (value, vala_destructor_get_this_parameter (self));
+		break;
+		case VALA_DESTRUCTOR_BINDING:
+		g_value_set_enum (value, vala_destructor_get_binding (self));
 		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -130,8 +156,11 @@ static void vala_destructor_set_property (GObject * object, guint property_id, c
 		case VALA_DESTRUCTOR_BODY:
 		vala_destructor_set_body (self, g_value_get_object (value));
 		break;
-		case VALA_DESTRUCTOR_INSTANCE:
-		vala_destructor_set_instance (self, g_value_get_boolean (value));
+		case VALA_DESTRUCTOR_THIS_PARAMETER:
+		vala_destructor_set_this_parameter (self, g_value_get_object (value));
+		break;
+		case VALA_DESTRUCTOR_BINDING:
+		vala_destructor_set_binding (self, g_value_get_enum (value));
 		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -145,32 +174,34 @@ static void vala_destructor_class_init (ValaDestructorClass * klass) {
 	g_type_class_add_private (klass, sizeof (ValaDestructorPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_destructor_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_destructor_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_destructor_dispose;
+	G_OBJECT_CLASS (klass)->finalize = vala_destructor_finalize;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_destructor_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_destructor_real_accept_children;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DESTRUCTOR_BODY, g_param_spec_object ("body", "body", "body", VALA_TYPE_BLOCK, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DESTRUCTOR_INSTANCE, g_param_spec_boolean ("instance", "instance", "instance", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DESTRUCTOR_THIS_PARAMETER, g_param_spec_object ("this-parameter", "this-parameter", "this-parameter", VALA_TYPE_FORMAL_PARAMETER, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DESTRUCTOR_BINDING, g_param_spec_enum ("binding", "binding", "binding", TYPE_MEMBER_BINDING, MEMBER_BINDING_INSTANCE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
-static void vala_destructor_init (ValaDestructor * self) {
+static void vala_destructor_instance_init (ValaDestructor * self) {
 	self->priv = VALA_DESTRUCTOR_GET_PRIVATE (self);
-	self->priv->_instance = TRUE;
+	self->priv->_binding = MEMBER_BINDING_INSTANCE;
 }
 
 
-static void vala_destructor_dispose (GObject * obj) {
+static void vala_destructor_finalize (GObject * obj) {
 	ValaDestructor * self;
 	self = VALA_DESTRUCTOR (obj);
 	(self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL)));
-	G_OBJECT_CLASS (vala_destructor_parent_class)->dispose (obj);
+	(self->priv->_this_parameter == NULL ? NULL : (self->priv->_this_parameter = (g_object_unref (self->priv->_this_parameter), NULL)));
+	G_OBJECT_CLASS (vala_destructor_parent_class)->finalize (obj);
 }
 
 
 GType vala_destructor_get_type (void) {
 	static GType vala_destructor_type_id = 0;
-	if (G_UNLIKELY (vala_destructor_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaDestructorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_destructor_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaDestructor), 0, (GInstanceInitFunc) vala_destructor_init };
+	if (vala_destructor_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (ValaDestructorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_destructor_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaDestructor), 0, (GInstanceInitFunc) vala_destructor_instance_init };
 		vala_destructor_type_id = g_type_register_static (VALA_TYPE_SYMBOL, "ValaDestructor", &g_define_type_info, 0);
 	}
 	return vala_destructor_type_id;
