@@ -45,7 +45,7 @@ static void vala_do_statement_real_accept_children (ValaCodeNode* base, ValaCode
 static void vala_do_statement_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node);
 static gpointer vala_do_statement_parent_class = NULL;
 static ValaStatementIface* vala_do_statement_vala_statement_parent_iface = NULL;
-static void vala_do_statement_dispose (GObject * obj);
+static void vala_do_statement_finalize (GObject * obj);
 
 
 
@@ -125,6 +125,7 @@ void vala_do_statement_set_body (ValaDoStatement* self, ValaBlock* value) {
 	_tmp1 = NULL;
 	self->priv->_body = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL))), _tmp2);
 	vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_body), VALA_CODE_NODE (self));
+	g_object_notify (((GObject *) (self)), "body");
 }
 
 
@@ -142,6 +143,7 @@ void vala_do_statement_set_condition (ValaDoStatement* self, ValaExpression* val
 	_tmp1 = NULL;
 	self->priv->_condition = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_condition == NULL ? NULL : (self->priv->_condition = (g_object_unref (self->priv->_condition), NULL))), _tmp2);
 	vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_condition), VALA_CODE_NODE (self));
+	g_object_notify (((GObject *) (self)), "condition");
 }
 
 
@@ -184,7 +186,7 @@ static void vala_do_statement_class_init (ValaDoStatementClass * klass) {
 	g_type_class_add_private (klass, sizeof (ValaDoStatementPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_do_statement_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_do_statement_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_do_statement_dispose;
+	G_OBJECT_CLASS (klass)->finalize = vala_do_statement_finalize;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_do_statement_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_do_statement_real_accept_children;
 	VALA_CODE_NODE_CLASS (klass)->replace_expression = vala_do_statement_real_replace_expression;
@@ -203,18 +205,18 @@ static void vala_do_statement_instance_init (ValaDoStatement * self) {
 }
 
 
-static void vala_do_statement_dispose (GObject * obj) {
+static void vala_do_statement_finalize (GObject * obj) {
 	ValaDoStatement * self;
 	self = VALA_DO_STATEMENT (obj);
 	(self->priv->_condition == NULL ? NULL : (self->priv->_condition = (g_object_unref (self->priv->_condition), NULL)));
 	(self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL)));
-	G_OBJECT_CLASS (vala_do_statement_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (vala_do_statement_parent_class)->finalize (obj);
 }
 
 
 GType vala_do_statement_get_type (void) {
 	static GType vala_do_statement_type_id = 0;
-	if (G_UNLIKELY (vala_do_statement_type_id == 0)) {
+	if (vala_do_statement_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaDoStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_do_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaDoStatement), 0, (GInstanceInitFunc) vala_do_statement_instance_init };
 		static const GInterfaceInfo vala_statement_info = { (GInterfaceInitFunc) vala_do_statement_vala_statement_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		vala_do_statement_type_id = g_type_register_static (VALA_TYPE_CODE_NODE, "ValaDoStatement", &g_define_type_info, 0);
