@@ -48,7 +48,7 @@ static GeeList* vala_dynamic_method_real_get_cheader_filenames (ValaSymbol* base
 static char* vala_dynamic_method_real_get_default_cname (ValaMethod* base);
 static ValaCodeBinding* vala_dynamic_method_real_create_code_binding (ValaCodeNode* base, ValaCodeGenerator* codegen);
 static gpointer vala_dynamic_method_parent_class = NULL;
-static void vala_dynamic_method_dispose (GObject * obj);
+static void vala_dynamic_method_finalize (GObject * obj);
 
 
 
@@ -110,6 +110,7 @@ void vala_dynamic_method_set_dynamic_type (ValaDynamicMethod* self, ValaDataType
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_dynamic_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_dynamic_type == NULL ? NULL : (self->priv->_dynamic_type = (g_object_unref (self->priv->_dynamic_type), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "dynamic-type");
 }
 
 
@@ -126,6 +127,7 @@ void vala_dynamic_method_set_invocation (ValaDynamicMethod* self, ValaInvocation
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_invocation = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_invocation == NULL ? NULL : (self->priv->_invocation = (g_object_unref (self->priv->_invocation), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "invocation");
 }
 
 
@@ -168,7 +170,7 @@ static void vala_dynamic_method_class_init (ValaDynamicMethodClass * klass) {
 	g_type_class_add_private (klass, sizeof (ValaDynamicMethodPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_dynamic_method_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_dynamic_method_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_dynamic_method_dispose;
+	G_OBJECT_CLASS (klass)->finalize = vala_dynamic_method_finalize;
 	VALA_SYMBOL_CLASS (klass)->get_cheader_filenames = vala_dynamic_method_real_get_cheader_filenames;
 	VALA_METHOD_CLASS (klass)->get_default_cname = vala_dynamic_method_real_get_default_cname;
 	VALA_CODE_NODE_CLASS (klass)->create_code_binding = vala_dynamic_method_real_create_code_binding;
@@ -182,19 +184,19 @@ static void vala_dynamic_method_instance_init (ValaDynamicMethod * self) {
 }
 
 
-static void vala_dynamic_method_dispose (GObject * obj) {
+static void vala_dynamic_method_finalize (GObject * obj) {
 	ValaDynamicMethod * self;
 	self = VALA_DYNAMIC_METHOD (obj);
 	(self->priv->_dynamic_type == NULL ? NULL : (self->priv->_dynamic_type = (g_object_unref (self->priv->_dynamic_type), NULL)));
 	(self->priv->_invocation == NULL ? NULL : (self->priv->_invocation = (g_object_unref (self->priv->_invocation), NULL)));
 	self->priv->cname = (g_free (self->priv->cname), NULL);
-	G_OBJECT_CLASS (vala_dynamic_method_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (vala_dynamic_method_parent_class)->finalize (obj);
 }
 
 
 GType vala_dynamic_method_get_type (void) {
 	static GType vala_dynamic_method_type_id = 0;
-	if (G_UNLIKELY (vala_dynamic_method_type_id == 0)) {
+	if (vala_dynamic_method_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaDynamicMethodClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_dynamic_method_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaDynamicMethod), 0, (GInstanceInitFunc) vala_dynamic_method_instance_init };
 		vala_dynamic_method_type_id = g_type_register_static (VALA_TYPE_METHOD, "ValaDynamicMethod", &g_define_type_info, 0);
 	}
