@@ -22,8 +22,8 @@
 
 #include <vala/valaenum.h>
 #include <gee/arraylist.h>
-#include <gee/list.h>
-#include <gee/readonlycollection.h>
+#include <gee/collection.h>
+#include <gee/readonlylist.h>
 #include <vala/valaenumvalue.h>
 #include <vala/valamethod.h>
 #include <vala/valasourcereference.h>
@@ -61,21 +61,21 @@ enum  {
 };
 static void vala_enum_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_enum_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
-static char* vala_enum_real_get_cname (ValaTypesymbol* base, gboolean const_type);
+static char* vala_enum_real_get_cname (ValaTypeSymbol* base, gboolean const_type);
 static char* vala_enum_real_get_lower_case_cprefix (ValaSymbol* base);
 static char* vala_enum_get_lower_case_csuffix (ValaEnum* self);
 static char* vala_enum_real_get_lower_case_cname (ValaSymbol* base, const char* infix);
-static char* vala_enum_real_get_upper_case_cname (ValaTypesymbol* base, const char* infix);
-static gboolean vala_enum_real_is_reference_type (ValaTypesymbol* base);
+static char* vala_enum_real_get_upper_case_cname (ValaTypeSymbol* base, const char* infix);
+static gboolean vala_enum_real_is_reference_type (ValaTypeSymbol* base);
 static void vala_enum_set_cname (ValaEnum* self, const char* cname);
 static void vala_enum_process_ccode_attribute (ValaEnum* self, ValaAttribute* a);
-static char* vala_enum_real_get_type_id (ValaTypesymbol* base);
-static char* vala_enum_real_get_marshaller_type_name (ValaTypesymbol* base);
-static char* vala_enum_real_get_get_value_function (ValaTypesymbol* base);
-static char* vala_enum_real_get_set_value_function (ValaTypesymbol* base);
-static char* vala_enum_real_get_default_value (ValaTypesymbol* base);
+static char* vala_enum_real_get_type_id (ValaTypeSymbol* base);
+static char* vala_enum_real_get_marshaller_type_name (ValaTypeSymbol* base);
+static char* vala_enum_real_get_get_value_function (ValaTypeSymbol* base);
+static char* vala_enum_real_get_set_value_function (ValaTypeSymbol* base);
+static char* vala_enum_real_get_default_value (ValaTypeSymbol* base);
 static gpointer vala_enum_parent_class = NULL;
-static void vala_enum_dispose (GObject * obj);
+static void vala_enum_finalize (GObject * obj);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
 static int _vala_strcmp0 (const char * str1, const char * str2);
 
@@ -145,9 +145,9 @@ void vala_enum_add_method (ValaEnum* self, ValaMethod* m) {
  *
  * @return list of enum values
  */
-GeeCollection* vala_enum_get_values (ValaEnum* self) {
+GeeList* vala_enum_get_values (ValaEnum* self) {
 	g_return_val_if_fail (VALA_IS_ENUM (self), NULL);
-	return GEE_COLLECTION (gee_read_only_collection_new (VALA_TYPE_ENUM_VALUE, ((GBoxedCopyFunc) g_object_ref), g_object_unref, GEE_COLLECTION (self->priv->values)));
+	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_ENUM_VALUE, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, self->priv->values));
 }
 
 
@@ -156,9 +156,9 @@ GeeCollection* vala_enum_get_values (ValaEnum* self) {
  *
  * @return list of methods
  */
-GeeCollection* vala_enum_get_methods (ValaEnum* self) {
+GeeList* vala_enum_get_methods (ValaEnum* self) {
 	g_return_val_if_fail (VALA_IS_ENUM (self), NULL);
-	return GEE_COLLECTION (gee_read_only_collection_new (VALA_TYPE_METHOD, ((GBoxedCopyFunc) g_object_ref), g_object_unref, GEE_COLLECTION (self->priv->methods)));
+	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_METHOD, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, self->priv->methods));
 }
 
 
@@ -176,38 +176,34 @@ static void vala_enum_real_accept_children (ValaCodeNode* base, ValaCodeVisitor*
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	{
 		GeeList* value_collection;
-		GeeIterator* value_it;
+		int value_it;
 		value_collection = self->priv->values;
-		value_it = gee_iterable_iterator (GEE_ITERABLE (value_collection));
-		while (gee_iterator_next (value_it)) {
+		for (value_it = 0; value_it < gee_collection_get_size (GEE_COLLECTION (value_collection)); value_it = value_it + 1) {
 			ValaEnumValue* value;
-			value = ((ValaEnumValue*) gee_iterator_get (value_it));
+			value = ((ValaEnumValue*) (gee_list_get (GEE_LIST (value_collection), value_it)));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (value), visitor);
 				(value == NULL ? NULL : (value = (g_object_unref (value), NULL)));
 			}
 		}
-		(value_it == NULL ? NULL : (value_it = (g_object_unref (value_it), NULL)));
 	}
 	{
 		GeeList* m_collection;
-		GeeIterator* m_it;
+		int m_it;
 		m_collection = self->priv->methods;
-		m_it = gee_iterable_iterator (GEE_ITERABLE (m_collection));
-		while (gee_iterator_next (m_it)) {
+		for (m_it = 0; m_it < gee_collection_get_size (GEE_COLLECTION (m_collection)); m_it = m_it + 1) {
 			ValaMethod* m;
-			m = ((ValaMethod*) gee_iterator_get (m_it));
+			m = ((ValaMethod*) (gee_list_get (GEE_LIST (m_collection), m_it)));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (m), visitor);
 				(m == NULL ? NULL : (m = (g_object_unref (m), NULL)));
 			}
 		}
-		(m_it == NULL ? NULL : (m_it = (g_object_unref (m_it), NULL)));
 	}
 }
 
 
-static char* vala_enum_real_get_cname (ValaTypesymbol* base, gboolean const_type) {
+static char* vala_enum_real_get_cname (ValaTypeSymbol* base, gboolean const_type) {
 	ValaEnum * self;
 	const char* _tmp2;
 	self = VALA_ENUM (base);
@@ -270,7 +266,7 @@ static char* vala_enum_real_get_lower_case_cname (ValaSymbol* base, const char*
 }
 
 
-static char* vala_enum_real_get_upper_case_cname (ValaTypesymbol* base, const char* infix) {
+static char* vala_enum_real_get_upper_case_cname (ValaTypeSymbol* base, const char* infix) {
 	ValaEnum * self;
 	char* _tmp0;
 	char* _tmp1;
@@ -281,7 +277,7 @@ static char* vala_enum_real_get_upper_case_cname (ValaTypesymbol* base, const ch
 }
 
 
-static gboolean vala_enum_real_is_reference_type (ValaTypesymbol* base) {
+static gboolean vala_enum_real_is_reference_type (ValaTypeSymbol* base) {
 	ValaEnum * self;
 	self = VALA_ENUM (base);
 	return FALSE;
@@ -362,8 +358,8 @@ static void vala_enum_process_ccode_attribute (ValaEnum* self, ValaAttribute* a)
 		val = vala_attribute_get_string (a, "cheader_filename");
 		{
 			char** filename_collection;
-			char** filename_it;
 			int filename_collection_length1;
+			char** filename_it;
 			filename_collection = g_strsplit (val, ",", 0);
 			filename_collection_length1 = -1;
 			for (filename_it = filename_collection; *filename_it != NULL; filename_it = filename_it + 1) {
@@ -376,7 +372,7 @@ static void vala_enum_process_ccode_attribute (ValaEnum* self, ValaAttribute* a)
 					filename = (g_free (filename), NULL);
 				}
 			}
-			filename_collection = (_vala_array_free (filename_collection, filename_collection_length1, ((GDestroyNotify) g_free)), NULL);
+			filename_collection = (_vala_array_free (filename_collection, filename_collection_length1, ((GDestroyNotify) (g_free))), NULL);
 		}
 		val = (g_free (val), NULL);
 	}
@@ -404,7 +400,7 @@ void vala_enum_process_attributes (ValaEnum* self) {
 			ValaAttribute* _tmp0;
 			ValaAttribute* a;
 			_tmp0 = NULL;
-			a = (_tmp0 = ((ValaAttribute*) a_it->data), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
+			a = (_tmp0 = ((ValaAttribute*) (a_it->data)), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
 			{
 				if (_vala_strcmp0 (vala_attribute_get_name (a), "CCode") == 0) {
 					vala_enum_process_ccode_attribute (self, a);
@@ -430,7 +426,7 @@ void vala_enum_set_type_id (ValaEnum* self, const char* type_id) {
 }
 
 
-static char* vala_enum_real_get_type_id (ValaTypesymbol* base) {
+static char* vala_enum_real_get_type_id (ValaTypeSymbol* base) {
 	ValaEnum * self;
 	const char* _tmp3;
 	self = VALA_ENUM (base);
@@ -452,7 +448,7 @@ static char* vala_enum_real_get_type_id (ValaTypesymbol* base) {
 }
 
 
-static char* vala_enum_real_get_marshaller_type_name (ValaTypesymbol* base) {
+static char* vala_enum_real_get_marshaller_type_name (ValaTypeSymbol* base) {
 	ValaEnum * self;
 	self = VALA_ENUM (base);
 	if (self->priv->_has_type_id) {
@@ -471,7 +467,7 @@ static char* vala_enum_real_get_marshaller_type_name (ValaTypesymbol* base) {
 }
 
 
-static char* vala_enum_real_get_get_value_function (ValaTypesymbol* base) {
+static char* vala_enum_real_get_get_value_function (ValaTypeSymbol* base) {
 	ValaEnum * self;
 	self = VALA_ENUM (base);
 	if (self->priv->_has_type_id) {
@@ -490,7 +486,7 @@ static char* vala_enum_real_get_get_value_function (ValaTypesymbol* base) {
 }
 
 
-static char* vala_enum_real_get_set_value_function (ValaTypesymbol* base) {
+static char* vala_enum_real_get_set_value_function (ValaTypeSymbol* base) {
 	ValaEnum * self;
 	self = VALA_ENUM (base);
 	if (self->priv->_has_type_id) {
@@ -509,7 +505,7 @@ static char* vala_enum_real_get_set_value_function (ValaTypesymbol* base) {
 }
 
 
-static char* vala_enum_real_get_default_value (ValaTypesymbol* base) {
+static char* vala_enum_real_get_default_value (ValaTypeSymbol* base) {
 	ValaEnum * self;
 	self = VALA_ENUM (base);
 	return g_strdup ("0");
@@ -525,6 +521,7 @@ gboolean vala_enum_get_is_flags (ValaEnum* self) {
 void vala_enum_set_is_flags (ValaEnum* self, gboolean value) {
 	g_return_if_fail (VALA_IS_ENUM (self));
 	self->priv->_is_flags = value;
+	g_object_notify (((GObject *) (self)), "is-flags");
 }
 
 
@@ -537,6 +534,7 @@ gboolean vala_enum_get_has_type_id (ValaEnum* self) {
 void vala_enum_set_has_type_id (ValaEnum* self, gboolean value) {
 	g_return_if_fail (VALA_IS_ENUM (self));
 	self->priv->_has_type_id = value;
+	g_object_notify (((GObject *) (self)), "has-type-id");
 }
 
 
@@ -579,7 +577,7 @@ static void vala_enum_class_init (ValaEnumClass * klass) {
 	g_type_class_add_private (klass, sizeof (ValaEnumPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_enum_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_enum_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_enum_dispose;
+	G_OBJECT_CLASS (klass)->finalize = vala_enum_finalize;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_enum_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_enum_real_accept_children;
 	VALA_TYPESYMBOL_CLASS (klass)->get_cname = vala_enum_real_get_cname;
@@ -597,15 +595,15 @@ static void vala_enum_class_init (ValaEnumClass * klass) {
 }
 
 
-static void vala_enum_init (ValaEnum * self) {
+static void vala_enum_instance_init (ValaEnum * self) {
 	self->priv = VALA_ENUM_GET_PRIVATE (self);
 	self->priv->_has_type_id = TRUE;
-	self->priv->values = GEE_LIST (gee_array_list_new (VALA_TYPE_ENUM_VALUE, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
-	self->priv->methods = GEE_LIST (gee_array_list_new (VALA_TYPE_METHOD, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
+	self->priv->values = GEE_LIST (gee_array_list_new (VALA_TYPE_ENUM_VALUE, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
+	self->priv->methods = GEE_LIST (gee_array_list_new (VALA_TYPE_METHOD, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
 }
 
 
-static void vala_enum_dispose (GObject * obj) {
+static void vala_enum_finalize (GObject * obj) {
 	ValaEnum * self;
 	self = VALA_ENUM (obj);
 	(self->priv->values == NULL ? NULL : (self->priv->values = (g_object_unref (self->priv->values), NULL)));
@@ -615,14 +613,14 @@ static void vala_enum_dispose (GObject * obj) {
 	self->priv->lower_case_cprefix = (g_free (self->priv->lower_case_cprefix), NULL);
 	self->priv->lower_case_csuffix = (g_free (self->priv->lower_case_csuffix), NULL);
 	self->priv->type_id = (g_free (self->priv->type_id), NULL);
-	G_OBJECT_CLASS (vala_enum_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (vala_enum_parent_class)->finalize (obj);
 }
 
 
 GType vala_enum_get_type (void) {
 	static GType vala_enum_type_id = 0;
-	if (G_UNLIKELY (vala_enum_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaEnumClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_enum_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaEnum), 0, (GInstanceInitFunc) vala_enum_init };
+	if (vala_enum_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (ValaEnumClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_enum_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaEnum), 0, (GInstanceInitFunc) vala_enum_instance_init };
 		vala_enum_type_id = g_type_register_static (VALA_TYPE_TYPESYMBOL, "ValaEnum", &g_define_type_info, 0);
 	}
 	return vala_enum_type_id;
@@ -634,12 +632,12 @@ static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify
 		int i;
 		if (array_length >= 0)
 		for (i = 0; i < array_length; i = i + 1) {
-			if (((gpointer*) array)[i] != NULL)
-			destroy_func (((gpointer*) array)[i]);
+			if (((gpointer*) (array))[i] != NULL)
+			destroy_func (((gpointer*) (array))[i]);
 		}
 		else
-		for (i = 0; ((gpointer*) array)[i] != NULL; i = i + 1) {
-			destroy_func (((gpointer*) array)[i]);
+		for (i = 0; ((gpointer*) (array))[i] != NULL; i = i + 1) {
+			destroy_func (((gpointer*) (array))[i]);
 		}
 	}
 	g_free (array);
