@@ -26,7 +26,6 @@
 #include <vala/valasourcefile.h>
 #include <vala/valacodecontext.h>
 #include <vala/valanamespace.h>
-#include <vala/valascope.h>
 
 
 
@@ -41,15 +40,16 @@ enum  {
 	VALA_ERROR_TYPE_ERROR_DOMAIN
 };
 static gboolean vala_error_type_real_compatible (ValaDataType* base, ValaDataType* target_type);
-static char* vala_error_type_real_to_string (ValaCodeNode* base);
+static char* vala_error_type_real_to_qualified_string (ValaDataType* base, ValaScope* scope);
 static ValaDataType* vala_error_type_real_copy (ValaDataType* base);
 static char* vala_error_type_real_get_cname (ValaDataType* base);
 static char* vala_error_type_real_get_lower_case_cname (ValaDataType* base, const char* infix);
 static gboolean vala_error_type_real_equals (ValaDataType* base, ValaDataType* type2);
 static ValaSymbol* vala_error_type_real_get_member (ValaDataType* base, const char* member_name);
 static char* vala_error_type_real_get_type_id (ValaDataType* base);
+static gboolean vala_error_type_real_is_reference_type_or_type_parameter (ValaDataType* base);
 static gpointer vala_error_type_parent_class = NULL;
-static void vala_error_type_dispose (GObject * obj);
+static void vala_error_type_finalize (GObject * obj);
 
 
 
@@ -79,7 +79,7 @@ static gboolean vala_error_type_real_compatible (ValaDataType* base, ValaDataTyp
 	}
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	et = (_tmp2 = (_tmp1 = target_type, (VALA_IS_ERROR_TYPE (_tmp1) ? ((ValaErrorType*) _tmp1) : NULL)), (_tmp2 == NULL ? NULL : g_object_ref (_tmp2)));
+	et = (_tmp2 = (_tmp1 = target_type, (VALA_IS_ERROR_TYPE (_tmp1) ? ((ValaErrorType*) (_tmp1)) : NULL)), (_tmp2 == NULL ? NULL : g_object_ref (_tmp2)));
 	/* error types are only compatible to error types */
 	if (et == NULL) {
 		gboolean _tmp3;
@@ -95,9 +95,10 @@ static gboolean vala_error_type_real_compatible (ValaDataType* base, ValaDataTyp
 }
 
 
-static char* vala_error_type_real_to_string (ValaCodeNode* base) {
+static char* vala_error_type_real_to_qualified_string (ValaDataType* base, ValaScope* scope) {
 	ValaErrorType * self;
 	self = VALA_ERROR_TYPE (base);
+	g_return_val_if_fail (scope == NULL || VALA_IS_SCOPE (scope), NULL);
 	if (self->priv->_error_domain == NULL) {
 		return g_strdup ("GLib.Error");
 	} else {
@@ -108,8 +109,13 @@ static char* vala_error_type_real_to_string (ValaCodeNode* base) {
 
 static ValaDataType* vala_error_type_real_copy (ValaDataType* base) {
 	ValaErrorType * self;
+	ValaErrorType* result;
 	self = VALA_ERROR_TYPE (base);
-	return VALA_DATA_TYPE (vala_error_type_new (self->priv->_error_domain, vala_code_node_get_source_reference (VALA_CODE_NODE (self))));
+	result = vala_error_type_new (self->priv->_error_domain, vala_code_node_get_source_reference (VALA_CODE_NODE (self)));
+	vala_code_node_set_source_reference (VALA_CODE_NODE (result), vala_code_node_get_source_reference (VALA_CODE_NODE (self)));
+	vala_data_type_set_value_owned (VALA_DATA_TYPE (result), vala_data_type_get_value_owned (VALA_DATA_TYPE (self)));
+	vala_data_type_set_nullable (VALA_DATA_TYPE (result), vala_data_type_get_nullable (VALA_DATA_TYPE (self)));
+	return VALA_DATA_TYPE (result);
 }
 
 
@@ -145,7 +151,7 @@ static gboolean vala_error_type_real_equals (ValaDataType* base, ValaDataType* t
 	g_return_val_if_fail (VALA_IS_DATA_TYPE (type2), FALSE);
 	_tmp1 = NULL;
 	_tmp0 = NULL;
-	et = (_tmp1 = (_tmp0 = type2, (VALA_IS_ERROR_TYPE (_tmp0) ? ((ValaErrorType*) _tmp0) : NULL)), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
+	et = (_tmp1 = (_tmp0 = type2, (VALA_IS_ERROR_TYPE (_tmp0) ? ((ValaErrorType*) (_tmp0)) : NULL)), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
 	if (et == NULL) {
 		gboolean _tmp2;
 		return (_tmp2 = FALSE, (et == NULL ? NULL : (et = (g_object_unref (et), NULL))), _tmp2);
@@ -181,6 +187,13 @@ static char* vala_error_type_real_get_type_id (ValaDataType* base) {
 }
 
 
+static gboolean vala_error_type_real_is_reference_type_or_type_parameter (ValaDataType* base) {
+	ValaErrorType * self;
+	self = VALA_ERROR_TYPE (base);
+	return TRUE;
+}
+
+
 ValaErrorDomain* vala_error_type_get_error_domain (ValaErrorType* self) {
 	g_return_val_if_fail (VALA_IS_ERROR_TYPE (self), NULL);
 	return self->priv->_error_domain;
@@ -190,6 +203,7 @@ ValaErrorDomain* vala_error_type_get_error_domain (ValaErrorType* self) {
 void vala_error_type_set_error_domain (ValaErrorType* self, ValaErrorDomain* value) {
 	g_return_if_fail (VALA_IS_ERROR_TYPE (self));
 	self->priv->_error_domain = value;
+	g_object_notify (((GObject *) (self)), "error-domain");
 }
 
 
@@ -226,35 +240,36 @@ static void vala_error_type_class_init (ValaErrorTypeClass * klass) {
 	g_type_class_add_private (klass, sizeof (ValaErrorTypePrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_error_type_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_error_type_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_error_type_dispose;
+	G_OBJECT_CLASS (klass)->finalize = vala_error_type_finalize;
 	VALA_DATA_TYPE_CLASS (klass)->compatible = vala_error_type_real_compatible;
-	VALA_CODE_NODE_CLASS (klass)->to_string = vala_error_type_real_to_string;
+	VALA_DATA_TYPE_CLASS (klass)->to_qualified_string = vala_error_type_real_to_qualified_string;
 	VALA_DATA_TYPE_CLASS (klass)->copy = vala_error_type_real_copy;
 	VALA_DATA_TYPE_CLASS (klass)->get_cname = vala_error_type_real_get_cname;
 	VALA_DATA_TYPE_CLASS (klass)->get_lower_case_cname = vala_error_type_real_get_lower_case_cname;
 	VALA_DATA_TYPE_CLASS (klass)->equals = vala_error_type_real_equals;
 	VALA_DATA_TYPE_CLASS (klass)->get_member = vala_error_type_real_get_member;
 	VALA_DATA_TYPE_CLASS (klass)->get_type_id = vala_error_type_real_get_type_id;
+	VALA_DATA_TYPE_CLASS (klass)->is_reference_type_or_type_parameter = vala_error_type_real_is_reference_type_or_type_parameter;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_ERROR_TYPE_ERROR_DOMAIN, g_param_spec_object ("error-domain", "error-domain", "error-domain", VALA_TYPE_ERROR_DOMAIN, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
-static void vala_error_type_init (ValaErrorType * self) {
+static void vala_error_type_instance_init (ValaErrorType * self) {
 	self->priv = VALA_ERROR_TYPE_GET_PRIVATE (self);
 }
 
 
-static void vala_error_type_dispose (GObject * obj) {
+static void vala_error_type_finalize (GObject * obj) {
 	ValaErrorType * self;
 	self = VALA_ERROR_TYPE (obj);
-	G_OBJECT_CLASS (vala_error_type_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (vala_error_type_parent_class)->finalize (obj);
 }
 
 
 GType vala_error_type_get_type (void) {
 	static GType vala_error_type_type_id = 0;
-	if (G_UNLIKELY (vala_error_type_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaErrorTypeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_error_type_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaErrorType), 0, (GInstanceInitFunc) vala_error_type_init };
+	if (vala_error_type_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (ValaErrorTypeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_error_type_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaErrorType), 0, (GInstanceInitFunc) vala_error_type_instance_init };
 		vala_error_type_type_id = g_type_register_static (VALA_TYPE_REFERENCE_TYPE, "ValaErrorType", &g_define_type_info, 0);
 	}
 	return vala_error_type_type_id;
