@@ -60,7 +60,7 @@ static void vala_field_real_set_lock_used (ValaLockable* base, gboolean used);
 static void vala_field_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type);
 static gpointer vala_field_parent_class = NULL;
 static ValaLockableIface* vala_field_vala_lockable_parent_iface = NULL;
-static void vala_field_dispose (GObject * obj);
+static void vala_field_finalize (GObject * obj);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
 static int _vala_strcmp0 (const char * str1, const char * str2);
 
@@ -310,6 +310,7 @@ void vala_field_set_field_type (ValaField* self, ValaDataType* value) {
 	_tmp1 = NULL;
 	self->priv->_data_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_data_type == NULL ? NULL : (self->priv->_data_type = (g_object_unref (self->priv->_data_type), NULL))), _tmp2);
 	vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_data_type), VALA_CODE_NODE (self));
+	g_object_notify (((GObject *) (self)), "field-type");
 }
 
 
@@ -329,6 +330,7 @@ void vala_field_set_initializer (ValaField* self, ValaExpression* value) {
 	if (self->priv->_initializer != NULL) {
 		vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_initializer), VALA_CODE_NODE (self));
 	}
+	g_object_notify (((GObject *) (self)), "initializer");
 }
 
 
@@ -341,6 +343,7 @@ MemberBinding vala_field_get_binding (ValaField* self) {
 void vala_field_set_binding (ValaField* self, MemberBinding value) {
 	g_return_if_fail (VALA_IS_FIELD (self));
 	self->priv->_binding = value;
+	g_object_notify (((GObject *) (self)), "binding");
 }
 
 
@@ -353,6 +356,7 @@ gboolean vala_field_get_is_volatile (ValaField* self) {
 void vala_field_set_is_volatile (ValaField* self, gboolean value) {
 	g_return_if_fail (VALA_IS_FIELD (self));
 	self->priv->_is_volatile = value;
+	g_object_notify (((GObject *) (self)), "is-volatile");
 }
 
 
@@ -365,6 +369,7 @@ gboolean vala_field_get_no_array_length (ValaField* self) {
 void vala_field_set_no_array_length (ValaField* self, gboolean value) {
 	g_return_if_fail (VALA_IS_FIELD (self));
 	self->priv->_no_array_length = value;
+	g_object_notify (((GObject *) (self)), "no-array-length");
 }
 
 
@@ -425,7 +430,7 @@ static void vala_field_class_init (ValaFieldClass * klass) {
 	g_type_class_add_private (klass, sizeof (ValaFieldPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_field_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_field_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_field_dispose;
+	G_OBJECT_CLASS (klass)->finalize = vala_field_finalize;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_field_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_field_real_accept_children;
 	VALA_CODE_NODE_CLASS (klass)->replace_type = vala_field_real_replace_type;
@@ -451,19 +456,19 @@ static void vala_field_instance_init (ValaField * self) {
 }
 
 
-static void vala_field_dispose (GObject * obj) {
+static void vala_field_finalize (GObject * obj) {
 	ValaField * self;
 	self = VALA_FIELD (obj);
 	self->priv->cname = (g_free (self->priv->cname), NULL);
 	(self->priv->_initializer == NULL ? NULL : (self->priv->_initializer = (g_object_unref (self->priv->_initializer), NULL)));
 	(self->priv->_data_type == NULL ? NULL : (self->priv->_data_type = (g_object_unref (self->priv->_data_type), NULL)));
-	G_OBJECT_CLASS (vala_field_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (vala_field_parent_class)->finalize (obj);
 }
 
 
 GType vala_field_get_type (void) {
 	static GType vala_field_type_id = 0;
-	if (G_UNLIKELY (vala_field_type_id == 0)) {
+	if (vala_field_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaFieldClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_field_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaField), 0, (GInstanceInitFunc) vala_field_instance_init };
 		static const GInterfaceInfo vala_lockable_info = { (GInterfaceInitFunc) vala_field_vala_lockable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		vala_field_type_id = g_type_register_static (VALA_TYPE_MEMBER, "ValaField", &g_define_type_info, 0);
