@@ -40,6 +40,7 @@ struct _ValaFormalParameterPrivate {
 	double _cparameter_position;
 	double _carray_length_parameter_position;
 	double _cdelegate_target_parameter_position;
+	char* _ctype;
 	ValaDataType* _data_type;
 };
 
@@ -54,7 +55,8 @@ enum  {
 	VALA_FORMAL_PARAMETER_CONSTRUCT_PARAMETER,
 	VALA_FORMAL_PARAMETER_CPARAMETER_POSITION,
 	VALA_FORMAL_PARAMETER_CARRAY_LENGTH_PARAMETER_POSITION,
-	VALA_FORMAL_PARAMETER_CDELEGATE_TARGET_PARAMETER_POSITION
+	VALA_FORMAL_PARAMETER_CDELEGATE_TARGET_PARAMETER_POSITION,
+	VALA_FORMAL_PARAMETER_CTYPE
 };
 static void vala_formal_parameter_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_formal_parameter_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
@@ -62,7 +64,7 @@ static void vala_formal_parameter_real_replace_type (ValaCodeNode* base, ValaDat
 static void vala_formal_parameter_process_ccode_attribute (ValaFormalParameter* self, ValaAttribute* a);
 static GObject * vala_formal_parameter_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
 static gpointer vala_formal_parameter_parent_class = NULL;
-static void vala_formal_parameter_dispose (GObject * obj);
+static void vala_formal_parameter_finalize (GObject * obj);
 static int _vala_strcmp0 (const char * str1, const char * str2);
 
 
@@ -137,6 +139,12 @@ static void vala_formal_parameter_real_replace_type (ValaCodeNode* base, ValaDat
 static void vala_formal_parameter_process_ccode_attribute (ValaFormalParameter* self, ValaAttribute* a) {
 	g_return_if_fail (VALA_IS_FORMAL_PARAMETER (self));
 	g_return_if_fail (VALA_IS_ATTRIBUTE (a));
+	if (vala_attribute_has_argument (a, "type")) {
+		char* _tmp0;
+		_tmp0 = NULL;
+		vala_formal_parameter_set_ctype (self, (_tmp0 = vala_attribute_get_string (a, "type")));
+		_tmp0 = (g_free (_tmp0), NULL);
+	}
 	if (vala_attribute_has_argument (a, "array_length_pos")) {
 		vala_formal_parameter_set_carray_length_parameter_position (self, vala_attribute_get_double (a, "array_length_pos"));
 	}
@@ -197,6 +205,7 @@ void vala_formal_parameter_set_parameter_type (ValaFormalParameter* self, ValaDa
 	_tmp1 = NULL;
 	self->priv->_data_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_data_type == NULL ? NULL : (self->priv->_data_type = (g_object_unref (self->priv->_data_type), NULL))), _tmp2);
 	vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_data_type), VALA_CODE_NODE (self));
+	g_object_notify (((GObject *) (self)), "parameter-type");
 }
 
 
@@ -209,6 +218,7 @@ ValaParameterDirection vala_formal_parameter_get_direction (ValaFormalParameter*
 void vala_formal_parameter_set_direction (ValaFormalParameter* self, ValaParameterDirection value) {
 	g_return_if_fail (VALA_IS_FORMAL_PARAMETER (self));
 	self->priv->_direction = value;
+	g_object_notify (((GObject *) (self)), "direction");
 }
 
 
@@ -221,6 +231,7 @@ gboolean vala_formal_parameter_get_ellipsis (ValaFormalParameter* self) {
 void vala_formal_parameter_set_ellipsis (ValaFormalParameter* self, gboolean value) {
 	g_return_if_fail (VALA_IS_FORMAL_PARAMETER (self));
 	self->priv->_ellipsis = value;
+	g_object_notify (((GObject *) (self)), "ellipsis");
 }
 
 
@@ -237,6 +248,7 @@ void vala_formal_parameter_set_default_expression (ValaFormalParameter* self, Va
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_default_expression = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_default_expression == NULL ? NULL : (self->priv->_default_expression = (g_object_unref (self->priv->_default_expression), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "default-expression");
 }
 
 
@@ -249,6 +261,7 @@ gboolean vala_formal_parameter_get_no_array_length (ValaFormalParameter* self) {
 void vala_formal_parameter_set_no_array_length (ValaFormalParameter* self, gboolean value) {
 	g_return_if_fail (VALA_IS_FORMAL_PARAMETER (self));
 	self->priv->_no_array_length = value;
+	g_object_notify (((GObject *) (self)), "no-array-length");
 }
 
 
@@ -261,6 +274,7 @@ gboolean vala_formal_parameter_get_construct_parameter (ValaFormalParameter* sel
 void vala_formal_parameter_set_construct_parameter (ValaFormalParameter* self, gboolean value) {
 	g_return_if_fail (VALA_IS_FORMAL_PARAMETER (self));
 	self->priv->_construct_parameter = value;
+	g_object_notify (((GObject *) (self)), "construct-parameter");
 }
 
 
@@ -273,6 +287,7 @@ double vala_formal_parameter_get_cparameter_position (ValaFormalParameter* self)
 void vala_formal_parameter_set_cparameter_position (ValaFormalParameter* self, double value) {
 	g_return_if_fail (VALA_IS_FORMAL_PARAMETER (self));
 	self->priv->_cparameter_position = value;
+	g_object_notify (((GObject *) (self)), "cparameter-position");
 }
 
 
@@ -285,6 +300,7 @@ double vala_formal_parameter_get_carray_length_parameter_position (ValaFormalPar
 void vala_formal_parameter_set_carray_length_parameter_position (ValaFormalParameter* self, double value) {
 	g_return_if_fail (VALA_IS_FORMAL_PARAMETER (self));
 	self->priv->_carray_length_parameter_position = value;
+	g_object_notify (((GObject *) (self)), "carray-length-parameter-position");
 }
 
 
@@ -297,6 +313,24 @@ double vala_formal_parameter_get_cdelegate_target_parameter_position (ValaFormal
 void vala_formal_parameter_set_cdelegate_target_parameter_position (ValaFormalParameter* self, double value) {
 	g_return_if_fail (VALA_IS_FORMAL_PARAMETER (self));
 	self->priv->_cdelegate_target_parameter_position = value;
+	g_object_notify (((GObject *) (self)), "cdelegate-target-parameter-position");
+}
+
+
+const char* vala_formal_parameter_get_ctype (ValaFormalParameter* self) {
+	g_return_val_if_fail (VALA_IS_FORMAL_PARAMETER (self), NULL);
+	return self->priv->_ctype;
+}
+
+
+void vala_formal_parameter_set_ctype (ValaFormalParameter* self, const char* value) {
+	char* _tmp2;
+	const char* _tmp1;
+	g_return_if_fail (VALA_IS_FORMAL_PARAMETER (self));
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_ctype = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_ctype = (g_free (self->priv->_ctype), NULL)), _tmp2);
+	g_object_notify (((GObject *) (self)), "ctype");
 }
 
 
@@ -347,6 +381,9 @@ static void vala_formal_parameter_get_property (GObject * object, guint property
 		case VALA_FORMAL_PARAMETER_CDELEGATE_TARGET_PARAMETER_POSITION:
 		g_value_set_double (value, vala_formal_parameter_get_cdelegate_target_parameter_position (self));
 		break;
+		case VALA_FORMAL_PARAMETER_CTYPE:
+		g_value_set_string (value, vala_formal_parameter_get_ctype (self));
+		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
 		break;
@@ -385,6 +422,9 @@ static void vala_formal_parameter_set_property (GObject * object, guint property
 		case VALA_FORMAL_PARAMETER_CDELEGATE_TARGET_PARAMETER_POSITION:
 		vala_formal_parameter_set_cdelegate_target_parameter_position (self, g_value_get_double (value));
 		break;
+		case VALA_FORMAL_PARAMETER_CTYPE:
+		vala_formal_parameter_set_ctype (self, g_value_get_string (value));
+		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
 		break;
@@ -398,7 +438,7 @@ static void vala_formal_parameter_class_init (ValaFormalParameterClass * klass)
 	G_OBJECT_CLASS (klass)->get_property = vala_formal_parameter_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_formal_parameter_set_property;
 	G_OBJECT_CLASS (klass)->constructor = vala_formal_parameter_constructor;
-	G_OBJECT_CLASS (klass)->dispose = vala_formal_parameter_dispose;
+	G_OBJECT_CLASS (klass)->finalize = vala_formal_parameter_finalize;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_formal_parameter_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_formal_parameter_real_accept_children;
 	VALA_CODE_NODE_CLASS (klass)->replace_type = vala_formal_parameter_real_replace_type;
@@ -411,6 +451,7 @@ static void vala_formal_parameter_class_init (ValaFormalParameterClass * klass)
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FORMAL_PARAMETER_CPARAMETER_POSITION, g_param_spec_double ("cparameter-position", "cparameter-position", "cparameter-position", -G_MAXDOUBLE, G_MAXDOUBLE, 0.0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FORMAL_PARAMETER_CARRAY_LENGTH_PARAMETER_POSITION, g_param_spec_double ("carray-length-parameter-position", "carray-length-parameter-position", "carray-length-parameter-position", -G_MAXDOUBLE, G_MAXDOUBLE, 0.0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FORMAL_PARAMETER_CDELEGATE_TARGET_PARAMETER_POSITION, g_param_spec_double ("cdelegate-target-parameter-position", "cdelegate-target-parameter-position", "cdelegate-target-parameter-position", -G_MAXDOUBLE, G_MAXDOUBLE, 0.0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FORMAL_PARAMETER_CTYPE, g_param_spec_string ("ctype", "ctype", "ctype", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
@@ -420,18 +461,19 @@ static void vala_formal_parameter_instance_init (ValaFormalParameter * self) {
 }
 
 
-static void vala_formal_parameter_dispose (GObject * obj) {
+static void vala_formal_parameter_finalize (GObject * obj) {
 	ValaFormalParameter * self;
 	self = VALA_FORMAL_PARAMETER (obj);
 	(self->priv->_default_expression == NULL ? NULL : (self->priv->_default_expression = (g_object_unref (self->priv->_default_expression), NULL)));
+	self->priv->_ctype = (g_free (self->priv->_ctype), NULL);
 	(self->priv->_data_type == NULL ? NULL : (self->priv->_data_type = (g_object_unref (self->priv->_data_type), NULL)));
-	G_OBJECT_CLASS (vala_formal_parameter_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (vala_formal_parameter_parent_class)->finalize (obj);
 }
 
 
 GType vala_formal_parameter_get_type (void) {
 	static GType vala_formal_parameter_type_id = 0;
-	if (G_UNLIKELY (vala_formal_parameter_type_id == 0)) {
+	if (vala_formal_parameter_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaFormalParameterClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_formal_parameter_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaFormalParameter), 0, (GInstanceInitFunc) vala_formal_parameter_instance_init };
 		vala_formal_parameter_type_id = g_type_register_static (VALA_TYPE_SYMBOL, "ValaFormalParameter", &g_define_type_info, 0);
 	}
