@@ -50,7 +50,7 @@ static void vala_for_statement_real_accept_children (ValaCodeNode* base, ValaCod
 static void vala_for_statement_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node);
 static gpointer vala_for_statement_parent_class = NULL;
 static ValaStatementIface* vala_for_statement_vala_statement_parent_iface = NULL;
-static void vala_for_statement_dispose (GObject * obj);
+static void vala_for_statement_finalize (GObject * obj);
 
 
 
@@ -237,6 +237,7 @@ void vala_for_statement_set_condition (ValaForStatement* self, ValaExpression* v
 	if (self->priv->_condition != NULL) {
 		vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_condition), VALA_CODE_NODE (self));
 	}
+	g_object_notify (((GObject *) (self)), "condition");
 }
 
 
@@ -254,6 +255,7 @@ void vala_for_statement_set_body (ValaForStatement* self, ValaBlock* value) {
 	_tmp1 = NULL;
 	self->priv->_body = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL))), _tmp2);
 	vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_body), VALA_CODE_NODE (self));
+	g_object_notify (((GObject *) (self)), "body");
 }
 
 
@@ -296,7 +298,7 @@ static void vala_for_statement_class_init (ValaForStatementClass * klass) {
 	g_type_class_add_private (klass, sizeof (ValaForStatementPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_for_statement_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_for_statement_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_for_statement_dispose;
+	G_OBJECT_CLASS (klass)->finalize = vala_for_statement_finalize;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_for_statement_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_for_statement_real_accept_children;
 	VALA_CODE_NODE_CLASS (klass)->replace_expression = vala_for_statement_real_replace_expression;
@@ -317,20 +319,20 @@ static void vala_for_statement_instance_init (ValaForStatement * self) {
 }
 
 
-static void vala_for_statement_dispose (GObject * obj) {
+static void vala_for_statement_finalize (GObject * obj) {
 	ValaForStatement * self;
 	self = VALA_FOR_STATEMENT (obj);
 	(self->priv->initializer == NULL ? NULL : (self->priv->initializer = (g_object_unref (self->priv->initializer), NULL)));
 	(self->priv->iterator == NULL ? NULL : (self->priv->iterator = (g_object_unref (self->priv->iterator), NULL)));
 	(self->priv->_condition == NULL ? NULL : (self->priv->_condition = (g_object_unref (self->priv->_condition), NULL)));
 	(self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL)));
-	G_OBJECT_CLASS (vala_for_statement_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (vala_for_statement_parent_class)->finalize (obj);
 }
 
 
 GType vala_for_statement_get_type (void) {
 	static GType vala_for_statement_type_id = 0;
-	if (G_UNLIKELY (vala_for_statement_type_id == 0)) {
+	if (vala_for_statement_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaForStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_for_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaForStatement), 0, (GInstanceInitFunc) vala_for_statement_instance_init };
 		static const GInterfaceInfo vala_statement_info = { (GInterfaceInitFunc) vala_for_statement_vala_statement_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		vala_for_statement_type_id = g_type_register_static (VALA_TYPE_CODE_NODE, "ValaForStatement", &g_define_type_info, 0);
