@@ -65,7 +65,7 @@ static void vala_genie_scanner_push_comment (ValaGenieScanner* self, const char*
 static void vala_genie_scanner_set_source_file (ValaGenieScanner* self, ValaSourceFile* value);
 static GObject * vala_genie_scanner_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
 static gpointer vala_genie_scanner_parent_class = NULL;
-static void vala_genie_scanner_dispose (GObject * obj);
+static void vala_genie_scanner_finalize (GObject * obj);
 
 
 
@@ -1482,6 +1482,7 @@ static void vala_genie_scanner_set_source_file (ValaGenieScanner* self, ValaSour
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_source_file = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_source_file == NULL ? NULL : (self->priv->_source_file = (g_object_unref (self->priv->_source_file), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "source-file");
 }
 
 
@@ -1494,6 +1495,7 @@ gint vala_genie_scanner_get_indent_spaces (ValaGenieScanner* self) {
 void vala_genie_scanner_set_indent_spaces (ValaGenieScanner* self, gint value) {
 	g_return_if_fail (VALA_GENIE_IS_SCANNER (self));
 	self->priv->_indent_spaces = value;
+	g_object_notify (((GObject *) (self)), "indent-spaces");
 }
 
 
@@ -1563,7 +1565,7 @@ static void vala_genie_scanner_class_init (ValaGenieScannerClass * klass) {
 	G_OBJECT_CLASS (klass)->get_property = vala_genie_scanner_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_genie_scanner_set_property;
 	G_OBJECT_CLASS (klass)->constructor = vala_genie_scanner_constructor;
-	G_OBJECT_CLASS (klass)->dispose = vala_genie_scanner_dispose;
+	G_OBJECT_CLASS (klass)->finalize = vala_genie_scanner_finalize;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_GENIE_SCANNER_SOURCE_FILE, g_param_spec_object ("source-file", "source-file", "source-file", VALA_TYPE_SOURCE_FILE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_GENIE_SCANNER_INDENT_SPACES, g_param_spec_int ("indent-spaces", "indent-spaces", "indent-spaces", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
@@ -1574,18 +1576,18 @@ static void vala_genie_scanner_instance_init (ValaGenieScanner * self) {
 }
 
 
-static void vala_genie_scanner_dispose (GObject * obj) {
+static void vala_genie_scanner_finalize (GObject * obj) {
 	ValaGenieScanner * self;
 	self = VALA_GENIE_SCANNER (obj);
 	(self->priv->_source_file == NULL ? NULL : (self->priv->_source_file = (g_object_unref (self->priv->_source_file), NULL)));
 	self->priv->_comment = (g_free (self->priv->_comment), NULL);
-	G_OBJECT_CLASS (vala_genie_scanner_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (vala_genie_scanner_parent_class)->finalize (obj);
 }
 
 
 GType vala_genie_scanner_get_type (void) {
 	static GType vala_genie_scanner_type_id = 0;
-	if (G_UNLIKELY (vala_genie_scanner_type_id == 0)) {
+	if (vala_genie_scanner_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaGenieScannerClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_genie_scanner_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaGenieScanner), 0, (GInstanceInitFunc) vala_genie_scanner_instance_init };
 		vala_genie_scanner_type_id = g_type_register_static (G_TYPE_OBJECT, "ValaGenieScanner", &g_define_type_info, 0);
 	}
