@@ -23,8 +23,8 @@
 
 #include <vala/valainitializerlist.h>
 #include <gee/arraylist.h>
-#include <gee/list.h>
-#include <gee/readonlycollection.h>
+#include <gee/collection.h>
+#include <gee/readonlylist.h>
 #include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
 
@@ -45,7 +45,7 @@ static void vala_initializer_list_real_accept (ValaCodeNode* base, ValaCodeVisit
 static gboolean vala_initializer_list_real_is_pure (ValaExpression* base);
 static void vala_initializer_list_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node);
 static gpointer vala_initializer_list_parent_class = NULL;
-static void vala_initializer_list_dispose (GObject * obj);
+static void vala_initializer_list_finalize (GObject * obj);
 
 
 
@@ -67,9 +67,9 @@ void vala_initializer_list_append (ValaInitializerList* self, ValaExpression* ex
  *
  * @return expression list
  */
-GeeCollection* vala_initializer_list_get_initializers (ValaInitializerList* self) {
+GeeList* vala_initializer_list_get_initializers (ValaInitializerList* self) {
 	g_return_val_if_fail (VALA_IS_INITIALIZER_LIST (self), NULL);
-	return GEE_COLLECTION (gee_read_only_collection_new (VALA_TYPE_EXPRESSION, ((GBoxedCopyFunc) g_object_ref), g_object_unref, GEE_COLLECTION (self->priv->initializers)));
+	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_EXPRESSION, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, self->priv->initializers));
 }
 
 
@@ -94,18 +94,16 @@ static void vala_initializer_list_real_accept_children (ValaCodeNode* base, Vala
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	{
 		GeeList* expr_collection;
-		GeeIterator* expr_it;
+		int expr_it;
 		expr_collection = self->priv->initializers;
-		expr_it = gee_iterable_iterator (GEE_ITERABLE (expr_collection));
-		while (gee_iterator_next (expr_it)) {
+		for (expr_it = 0; expr_it < gee_collection_get_size (GEE_COLLECTION (expr_collection)); expr_it = expr_it + 1) {
 			ValaExpression* expr;
-			expr = ((ValaExpression*) gee_iterator_get (expr_it));
+			expr = ((ValaExpression*) (gee_list_get (GEE_LIST (expr_collection), expr_it)));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (expr), visitor);
 				(expr == NULL ? NULL : (expr = (g_object_unref (expr), NULL)));
 			}
 		}
-		(expr_it == NULL ? NULL : (expr_it = (g_object_unref (expr_it), NULL)));
 	}
 }
 
@@ -123,21 +121,19 @@ static gboolean vala_initializer_list_real_is_pure (ValaExpression* base) {
 	self = VALA_INITIALIZER_LIST (base);
 	{
 		GeeList* initializer_collection;
-		GeeIterator* initializer_it;
+		int initializer_it;
 		initializer_collection = self->priv->initializers;
-		initializer_it = gee_iterable_iterator (GEE_ITERABLE (initializer_collection));
-		while (gee_iterator_next (initializer_it)) {
+		for (initializer_it = 0; initializer_it < gee_collection_get_size (GEE_COLLECTION (initializer_collection)); initializer_it = initializer_it + 1) {
 			ValaExpression* initializer;
-			initializer = ((ValaExpression*) gee_iterator_get (initializer_it));
+			initializer = ((ValaExpression*) (gee_list_get (GEE_LIST (initializer_collection), initializer_it)));
 			{
 				if (!vala_expression_is_pure (initializer)) {
 					gboolean _tmp0;
-					return (_tmp0 = FALSE, (initializer == NULL ? NULL : (initializer = (g_object_unref (initializer), NULL))), (initializer_it == NULL ? NULL : (initializer_it = (g_object_unref (initializer_it), NULL))), _tmp0);
+					return (_tmp0 = FALSE, (initializer == NULL ? NULL : (initializer = (g_object_unref (initializer), NULL))), _tmp0);
 				}
 				(initializer == NULL ? NULL : (initializer = (g_object_unref (initializer), NULL)));
 			}
 		}
-		(initializer_it == NULL ? NULL : (initializer_it = (g_object_unref (initializer_it), NULL)));
 	}
 	return TRUE;
 }
@@ -155,8 +151,8 @@ static void vala_initializer_list_real_replace_expression (ValaCodeNode* base, V
 			ValaExpression* _tmp0;
 			gboolean _tmp1;
 			_tmp0 = NULL;
-			if ((_tmp1 = (_tmp0 = ((ValaExpression*) gee_list_get (((GeeList*) self->priv->initializers), i))) == old_node, (_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL))), _tmp1)) {
-				gee_list_set (((GeeList*) self->priv->initializers), i, new_node);
+			if ((_tmp1 = (_tmp0 = ((ValaExpression*) (gee_list_get (((GeeList*) (self->priv->initializers)), i)))) == old_node, (_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL))), _tmp1)) {
+				gee_list_set (((GeeList*) (self->priv->initializers)), i, new_node);
 			}
 		}
 	}
@@ -187,7 +183,7 @@ static void vala_initializer_list_class_init (ValaInitializerListClass * klass)
 	vala_initializer_list_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaInitializerListPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_initializer_list_get_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_initializer_list_dispose;
+	G_OBJECT_CLASS (klass)->finalize = vala_initializer_list_finalize;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_initializer_list_real_accept_children;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_initializer_list_real_accept;
 	VALA_EXPRESSION_CLASS (klass)->is_pure = vala_initializer_list_real_is_pure;
@@ -196,24 +192,24 @@ static void vala_initializer_list_class_init (ValaInitializerListClass * klass)
 }
 
 
-static void vala_initializer_list_init (ValaInitializerList * self) {
+static void vala_initializer_list_instance_init (ValaInitializerList * self) {
 	self->priv = VALA_INITIALIZER_LIST_GET_PRIVATE (self);
-	self->priv->initializers = GEE_LIST (gee_array_list_new (VALA_TYPE_EXPRESSION, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
+	self->priv->initializers = GEE_LIST (gee_array_list_new (VALA_TYPE_EXPRESSION, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
 }
 
 
-static void vala_initializer_list_dispose (GObject * obj) {
+static void vala_initializer_list_finalize (GObject * obj) {
 	ValaInitializerList * self;
 	self = VALA_INITIALIZER_LIST (obj);
 	(self->priv->initializers == NULL ? NULL : (self->priv->initializers = (g_object_unref (self->priv->initializers), NULL)));
-	G_OBJECT_CLASS (vala_initializer_list_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (vala_initializer_list_parent_class)->finalize (obj);
 }
 
 
 GType vala_initializer_list_get_type (void) {
 	static GType vala_initializer_list_type_id = 0;
-	if (G_UNLIKELY (vala_initializer_list_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaInitializerListClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_initializer_list_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaInitializerList), 0, (GInstanceInitFunc) vala_initializer_list_init };
+	if (vala_initializer_list_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (ValaInitializerListClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_initializer_list_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaInitializerList), 0, (GInstanceInitFunc) vala_initializer_list_instance_init };
 		vala_initializer_list_type_id = g_type_register_static (VALA_TYPE_EXPRESSION, "ValaInitializerList", &g_define_type_info, 0);
 	}
 	return vala_initializer_list_type_id;
