@@ -41,7 +41,7 @@ static void vala_integer_literal_real_accept (ValaCodeNode* base, ValaCodeVisito
 static char* vala_integer_literal_real_to_string (ValaCodeNode* base);
 static gboolean vala_integer_literal_real_is_pure (ValaExpression* base);
 static gpointer vala_integer_literal_parent_class = NULL;
-static void vala_integer_literal_dispose (GObject * obj);
+static void vala_integer_literal_finalize (GObject * obj);
 
 
 
@@ -176,6 +176,7 @@ void vala_integer_literal_set_value (ValaIntegerLiteral* self, const char* value
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_value = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_value = (g_free (self->priv->_value), NULL)), _tmp2);
+	g_object_notify (((GObject *) (self)), "value");
 }
 
 
@@ -212,7 +213,7 @@ static void vala_integer_literal_class_init (ValaIntegerLiteralClass * klass) {
 	g_type_class_add_private (klass, sizeof (ValaIntegerLiteralPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_integer_literal_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_integer_literal_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_integer_literal_dispose;
+	G_OBJECT_CLASS (klass)->finalize = vala_integer_literal_finalize;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_integer_literal_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->to_string = vala_integer_literal_real_to_string;
 	VALA_EXPRESSION_CLASS (klass)->is_pure = vala_integer_literal_real_is_pure;
@@ -225,17 +226,17 @@ static void vala_integer_literal_instance_init (ValaIntegerLiteral * self) {
 }
 
 
-static void vala_integer_literal_dispose (GObject * obj) {
+static void vala_integer_literal_finalize (GObject * obj) {
 	ValaIntegerLiteral * self;
 	self = VALA_INTEGER_LITERAL (obj);
 	self->priv->_value = (g_free (self->priv->_value), NULL);
-	G_OBJECT_CLASS (vala_integer_literal_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (vala_integer_literal_parent_class)->finalize (obj);
 }
 
 
 GType vala_integer_literal_get_type (void) {
 	static GType vala_integer_literal_type_id = 0;
-	if (G_UNLIKELY (vala_integer_literal_type_id == 0)) {
+	if (vala_integer_literal_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaIntegerLiteralClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_integer_literal_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaIntegerLiteral), 0, (GInstanceInitFunc) vala_integer_literal_instance_init };
 		vala_integer_literal_type_id = g_type_register_static (VALA_TYPE_LITERAL, "ValaIntegerLiteral", &g_define_type_info, 0);
 	}
