@@ -57,7 +57,7 @@ struct _ValaIntegerTypeClass {
 };
 
 
-ValaIntegerType* vala_integer_type_new (ValaTypesymbol* type_symbol);
+ValaIntegerType* vala_integer_type_new (ValaTypeSymbol* type_symbol);
 ValaIntegerLiteral* vala_integer_type_get_literal (ValaIntegerType* self);
 void vala_integer_type_set_literal (ValaIntegerType* self, ValaIntegerLiteral* value);
 GType vala_integer_type_get_type (void);
