@@ -22,10 +22,11 @@
 
 #include <vala/valainvocationexpression.h>
 #include <gee/arraylist.h>
-#include <gee/readonlycollection.h>
+#include <gee/collection.h>
 #include <gee/readonlylist.h>
 #include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
+#include <vala/valacodegenerator.h>
 
 
 
@@ -35,6 +36,7 @@ struct _ValaInvocationExpressionPrivate {
 	GeeList* argument_list;
 	GeeList* array_sizes;
 };
+
 #define VALA_INVOCATION_EXPRESSION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_INVOCATION_EXPRESSION, ValaInvocationExpressionPrivate))
 enum  {
 	VALA_INVOCATION_EXPRESSION_DUMMY_PROPERTY,
@@ -45,8 +47,9 @@ static void vala_invocation_expression_real_accept (ValaCodeNode* base, ValaCode
 static void vala_invocation_expression_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_invocation_expression_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node);
 static gboolean vala_invocation_expression_real_is_pure (ValaExpression* base);
+static ValaCodeBinding* vala_invocation_expression_real_create_code_binding (ValaCodeNode* base, ValaCodeGenerator* codegen);
 static gpointer vala_invocation_expression_parent_class = NULL;
-static void vala_invocation_expression_dispose (GObject * obj);
+static void vala_invocation_expression_finalize (GObject * obj);
 
 
 
@@ -61,7 +64,7 @@ ValaInvocationExpression* vala_invocation_expression_new (ValaExpression* call,
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaInvocationExpression * self;
-	g_return_val_if_fail (call == NULL || VALA_IS_EXPRESSION (call), NULL);
+	g_return_val_if_fail (VALA_IS_EXPRESSION (call), NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
@@ -87,7 +90,7 @@ ValaInvocationExpression* vala_invocation_expression_new (ValaExpression* call,
  */
 void vala_invocation_expression_add_argument (ValaInvocationExpression* self, ValaExpression* arg) {
 	g_return_if_fail (VALA_IS_INVOCATION_EXPRESSION (self));
-	g_return_if_fail (arg == NULL || VALA_IS_EXPRESSION (arg));
+	g_return_if_fail (VALA_IS_EXPRESSION (arg));
 	gee_collection_add (GEE_COLLECTION (self->priv->argument_list), arg);
 	vala_code_node_set_parent_node (VALA_CODE_NODE (arg), VALA_CODE_NODE (self));
 }
@@ -98,9 +101,9 @@ void vala_invocation_expression_add_argument (ValaInvocationExpression* self, Va
  *
  * @return argument list
  */
-GeeCollection* vala_invocation_expression_get_argument_list (ValaInvocationExpression* self) {
+GeeList* vala_invocation_expression_get_argument_list (ValaInvocationExpression* self) {
 	g_return_val_if_fail (VALA_IS_INVOCATION_EXPRESSION (self), NULL);
-	return GEE_COLLECTION (gee_read_only_collection_new (VALA_TYPE_EXPRESSION, ((GBoxedCopyFunc) g_object_ref), g_object_unref, GEE_COLLECTION (self->priv->argument_list)));
+	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_EXPRESSION, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, self->priv->argument_list));
 }
 
 
@@ -109,7 +112,7 @@ GeeCollection* vala_invocation_expression_get_argument_list (ValaInvocationExpre
  */
 void vala_invocation_expression_append_array_size (ValaInvocationExpression* self, ValaCCodeExpression* size) {
 	g_return_if_fail (VALA_IS_INVOCATION_EXPRESSION (self));
-	g_return_if_fail (size == NULL || VALA_IS_CCODE_EXPRESSION (size));
+	g_return_if_fail (VALA_IS_CCODE_EXPRESSION (size));
 	gee_collection_add (GEE_COLLECTION (self->priv->array_sizes), size);
 }
 
@@ -120,37 +123,36 @@ void vala_invocation_expression_append_array_size (ValaInvocationExpression* sel
  */
 GeeList* vala_invocation_expression_get_array_sizes (ValaInvocationExpression* self) {
 	g_return_val_if_fail (VALA_IS_INVOCATION_EXPRESSION (self), NULL);
-	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_CCODE_EXPRESSION, ((GBoxedCopyFunc) g_object_ref), g_object_unref, self->priv->array_sizes));
+	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_CCODE_EXPRESSION, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, self->priv->array_sizes));
 }
 
 
 static void vala_invocation_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaInvocationExpression * self;
 	self = VALA_INVOCATION_EXPRESSION (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_invocation_expression (visitor, self);
+	vala_code_visitor_visit_expression (visitor, VALA_EXPRESSION (self));
 }
 
 
 static void vala_invocation_expression_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaInvocationExpression * self;
 	self = VALA_INVOCATION_EXPRESSION (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_node_accept (VALA_CODE_NODE (vala_invocation_expression_get_call (self)), visitor);
 	{
 		GeeList* expr_collection;
-		GeeIterator* expr_it;
+		int expr_it;
 		expr_collection = self->priv->argument_list;
-		expr_it = gee_iterable_iterator (GEE_ITERABLE (expr_collection));
-		while (gee_iterator_next (expr_it)) {
+		for (expr_it = 0; expr_it < gee_collection_get_size (GEE_COLLECTION (expr_collection)); expr_it = expr_it + 1) {
 			ValaExpression* expr;
-			expr = ((ValaExpression*) gee_iterator_get (expr_it));
+			expr = ((ValaExpression*) (gee_list_get (GEE_LIST (expr_collection), expr_it)));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (expr), visitor);
 				(expr == NULL ? NULL : (expr = (g_object_unref (expr), NULL)));
 			}
 		}
-		(expr_it == NULL ? NULL : (expr_it = (g_object_unref (expr_it), NULL)));
 	}
 }
 
@@ -159,14 +161,14 @@ static void vala_invocation_expression_real_replace_expression (ValaCodeNode* ba
 	ValaInvocationExpression * self;
 	gint index;
 	self = VALA_INVOCATION_EXPRESSION (base);
-	g_return_if_fail (old_node == NULL || VALA_IS_EXPRESSION (old_node));
-	g_return_if_fail (new_node == NULL || VALA_IS_EXPRESSION (new_node));
+	g_return_if_fail (VALA_IS_EXPRESSION (old_node));
+	g_return_if_fail (VALA_IS_EXPRESSION (new_node));
 	if (vala_invocation_expression_get_call (self) == old_node) {
 		vala_invocation_expression_set_call (self, new_node);
 	}
 	index = gee_list_index_of (self->priv->argument_list, old_node);
 	if (index >= 0 && vala_code_node_get_parent_node (VALA_CODE_NODE (new_node)) == NULL) {
-		gee_list_set (((GeeList*) self->priv->argument_list), index, new_node);
+		gee_list_set (((GeeList*) (self->priv->argument_list)), index, new_node);
 		vala_code_node_set_parent_node (VALA_CODE_NODE (new_node), VALA_CODE_NODE (self));
 	}
 }
@@ -179,6 +181,14 @@ static gboolean vala_invocation_expression_real_is_pure (ValaExpression* base) {
 }
 
 
+static ValaCodeBinding* vala_invocation_expression_real_create_code_binding (ValaCodeNode* base, ValaCodeGenerator* codegen) {
+	ValaInvocationExpression * self;
+	self = VALA_INVOCATION_EXPRESSION (base);
+	g_return_val_if_fail (VALA_IS_CODE_GENERATOR (codegen), NULL);
+	return vala_code_generator_create_invocation_expression_binding (codegen, self);
+}
+
+
 ValaExpression* vala_invocation_expression_get_call (ValaInvocationExpression* self) {
 	g_return_val_if_fail (VALA_IS_INVOCATION_EXPRESSION (self), NULL);
 	return self->_call;
@@ -193,6 +203,7 @@ void vala_invocation_expression_set_call (ValaInvocationExpression* self, ValaEx
 	_tmp1 = NULL;
 	self->_call = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->_call == NULL ? NULL : (self->_call = (g_object_unref (self->_call), NULL))), _tmp2);
 	vala_code_node_set_parent_node (VALA_CODE_NODE (self->_call), VALA_CODE_NODE (self));
+	g_object_notify (((GObject *) (self)), "call");
 }
 
 
@@ -209,6 +220,7 @@ void vala_invocation_expression_set_delegate_target (ValaInvocationExpression* s
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_delegate_target = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_delegate_target == NULL ? NULL : (self->priv->_delegate_target = (g_object_unref (self->priv->_delegate_target), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "delegate-target");
 }
 
 
@@ -251,38 +263,39 @@ static void vala_invocation_expression_class_init (ValaInvocationExpressionClass
 	g_type_class_add_private (klass, sizeof (ValaInvocationExpressionPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_invocation_expression_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_invocation_expression_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_invocation_expression_dispose;
+	G_OBJECT_CLASS (klass)->finalize = vala_invocation_expression_finalize;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_invocation_expression_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_invocation_expression_real_accept_children;
 	VALA_CODE_NODE_CLASS (klass)->replace_expression = vala_invocation_expression_real_replace_expression;
 	VALA_EXPRESSION_CLASS (klass)->is_pure = vala_invocation_expression_real_is_pure;
+	VALA_CODE_NODE_CLASS (klass)->create_code_binding = vala_invocation_expression_real_create_code_binding;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_INVOCATION_EXPRESSION_CALL, g_param_spec_object ("call", "call", "call", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_INVOCATION_EXPRESSION_DELEGATE_TARGET, g_param_spec_object ("delegate-target", "delegate-target", "delegate-target", VALA_TYPE_CCODE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
-static void vala_invocation_expression_init (ValaInvocationExpression * self) {
+static void vala_invocation_expression_instance_init (ValaInvocationExpression * self) {
 	self->priv = VALA_INVOCATION_EXPRESSION_GET_PRIVATE (self);
-	self->priv->argument_list = GEE_LIST (gee_array_list_new (VALA_TYPE_EXPRESSION, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
-	self->priv->array_sizes = GEE_LIST (gee_array_list_new (VALA_TYPE_CCODE_EXPRESSION, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
+	self->priv->argument_list = GEE_LIST (gee_array_list_new (VALA_TYPE_EXPRESSION, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
+	self->priv->array_sizes = GEE_LIST (gee_array_list_new (VALA_TYPE_CCODE_EXPRESSION, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
 }
 
 
-static void vala_invocation_expression_dispose (GObject * obj) {
+static void vala_invocation_expression_finalize (GObject * obj) {
 	ValaInvocationExpression * self;
 	self = VALA_INVOCATION_EXPRESSION (obj);
 	(self->priv->_delegate_target == NULL ? NULL : (self->priv->_delegate_target = (g_object_unref (self->priv->_delegate_target), NULL)));
 	(self->_call == NULL ? NULL : (self->_call = (g_object_unref (self->_call), NULL)));
 	(self->priv->argument_list == NULL ? NULL : (self->priv->argument_list = (g_object_unref (self->priv->argument_list), NULL)));
 	(self->priv->array_sizes == NULL ? NULL : (self->priv->array_sizes = (g_object_unref (self->priv->array_sizes), NULL)));
-	G_OBJECT_CLASS (vala_invocation_expression_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (vala_invocation_expression_parent_class)->finalize (obj);
 }
 
 
 GType vala_invocation_expression_get_type (void) {
 	static GType vala_invocation_expression_type_id = 0;
-	if (G_UNLIKELY (vala_invocation_expression_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaInvocationExpressionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_invocation_expression_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaInvocationExpression), 0, (GInstanceInitFunc) vala_invocation_expression_init };
+	if (vala_invocation_expression_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (ValaInvocationExpressionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_invocation_expression_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaInvocationExpression), 0, (GInstanceInitFunc) vala_invocation_expression_instance_init };
 		vala_invocation_expression_type_id = g_type_register_static (VALA_TYPE_EXPRESSION, "ValaInvocationExpression", &g_define_type_info, 0);
 	}
 	return vala_invocation_expression_type_id;
