@@ -50,7 +50,7 @@ static void vala_lambda_expression_real_accept (ValaCodeNode* base, ValaCodeVisi
 static void vala_lambda_expression_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static gboolean vala_lambda_expression_real_is_pure (ValaExpression* base);
 static gpointer vala_lambda_expression_parent_class = NULL;
-static void vala_lambda_expression_dispose (GObject * obj);
+static void vala_lambda_expression_finalize (GObject * obj);
 
 
 
@@ -161,6 +161,7 @@ void vala_lambda_expression_set_expression_body (ValaLambdaExpression* self, Val
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_expression_body = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_expression_body == NULL ? NULL : (self->priv->_expression_body = (g_object_unref (self->priv->_expression_body), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "expression-body");
 }
 
 
@@ -177,6 +178,7 @@ void vala_lambda_expression_set_statement_body (ValaLambdaExpression* self, Vala
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_statement_body = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_statement_body == NULL ? NULL : (self->priv->_statement_body = (g_object_unref (self->priv->_statement_body), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "statement-body");
 }
 
 
@@ -193,6 +195,7 @@ void vala_lambda_expression_set_method (ValaLambdaExpression* self, ValaMethod*
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_method = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_method == NULL ? NULL : (self->priv->_method = (g_object_unref (self->priv->_method), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "method");
 }
 
 
@@ -241,7 +244,7 @@ static void vala_lambda_expression_class_init (ValaLambdaExpressionClass * klass
 	g_type_class_add_private (klass, sizeof (ValaLambdaExpressionPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_lambda_expression_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_lambda_expression_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_lambda_expression_dispose;
+	G_OBJECT_CLASS (klass)->finalize = vala_lambda_expression_finalize;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_lambda_expression_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_lambda_expression_real_accept_children;
 	VALA_EXPRESSION_CLASS (klass)->is_pure = vala_lambda_expression_real_is_pure;
@@ -257,20 +260,20 @@ static void vala_lambda_expression_instance_init (ValaLambdaExpression * self) {
 }
 
 
-static void vala_lambda_expression_dispose (GObject * obj) {
+static void vala_lambda_expression_finalize (GObject * obj) {
 	ValaLambdaExpression * self;
 	self = VALA_LAMBDA_EXPRESSION (obj);
 	(self->priv->_expression_body == NULL ? NULL : (self->priv->_expression_body = (g_object_unref (self->priv->_expression_body), NULL)));
 	(self->priv->_statement_body == NULL ? NULL : (self->priv->_statement_body = (g_object_unref (self->priv->_statement_body), NULL)));
 	(self->priv->_method == NULL ? NULL : (self->priv->_method = (g_object_unref (self->priv->_method), NULL)));
 	(self->priv->parameters == NULL ? NULL : (self->priv->parameters = (g_object_unref (self->priv->parameters), NULL)));
-	G_OBJECT_CLASS (vala_lambda_expression_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (vala_lambda_expression_parent_class)->finalize (obj);
 }
 
 
 GType vala_lambda_expression_get_type (void) {
 	static GType vala_lambda_expression_type_id = 0;
-	if (G_UNLIKELY (vala_lambda_expression_type_id == 0)) {
+	if (vala_lambda_expression_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaLambdaExpressionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_lambda_expression_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaLambdaExpression), 0, (GInstanceInitFunc) vala_lambda_expression_instance_init };
 		vala_lambda_expression_type_id = g_type_register_static (VALA_TYPE_EXPRESSION, "ValaLambdaExpression", &g_define_type_info, 0);
 	}
