@@ -44,7 +44,7 @@ enum  {
 };
 static void vala_member_initializer_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static gpointer vala_member_initializer_parent_class = NULL;
-static void vala_member_initializer_dispose (GObject * obj);
+static void vala_member_initializer_finalize (GObject * obj);
 
 
 
@@ -90,6 +90,7 @@ void vala_member_initializer_set_name (ValaMemberInitializer* self, const char*
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_name = (g_free (self->priv->_name), NULL)), _tmp2);
+	g_object_notify (((GObject *) (self)), "name");
 }
 
 
@@ -106,6 +107,7 @@ void vala_member_initializer_set_initializer (ValaMemberInitializer* self, ValaE
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_initializer = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_initializer == NULL ? NULL : (self->priv->_initializer = (g_object_unref (self->priv->_initializer), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "initializer");
 }
 
 
@@ -118,6 +120,7 @@ ValaSymbol* vala_member_initializer_get_symbol_reference (ValaMemberInitializer*
 void vala_member_initializer_set_symbol_reference (ValaMemberInitializer* self, ValaSymbol* value) {
 	g_return_if_fail (VALA_IS_MEMBER_INITIALIZER (self));
 	self->priv->_symbol_reference = value;
+	g_object_notify (((GObject *) (self)), "symbol-reference");
 }
 
 
@@ -166,7 +169,7 @@ static void vala_member_initializer_class_init (ValaMemberInitializerClass * kla
 	g_type_class_add_private (klass, sizeof (ValaMemberInitializerPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_member_initializer_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_member_initializer_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_member_initializer_dispose;
+	G_OBJECT_CLASS (klass)->finalize = vala_member_initializer_finalize;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_member_initializer_real_accept;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_MEMBER_INITIALIZER_NAME, g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_MEMBER_INITIALIZER_INITIALIZER, g_param_spec_object ("initializer", "initializer", "initializer", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
@@ -179,18 +182,18 @@ static void vala_member_initializer_instance_init (ValaMemberInitializer * self)
 }
 
 
-static void vala_member_initializer_dispose (GObject * obj) {
+static void vala_member_initializer_finalize (GObject * obj) {
 	ValaMemberInitializer * self;
 	self = VALA_MEMBER_INITIALIZER (obj);
 	self->priv->_name = (g_free (self->priv->_name), NULL);
 	(self->priv->_initializer == NULL ? NULL : (self->priv->_initializer = (g_object_unref (self->priv->_initializer), NULL)));
-	G_OBJECT_CLASS (vala_member_initializer_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (vala_member_initializer_parent_class)->finalize (obj);
 }
 
 
 GType vala_member_initializer_get_type (void) {
 	static GType vala_member_initializer_type_id = 0;
-	if (G_UNLIKELY (vala_member_initializer_type_id == 0)) {
+	if (vala_member_initializer_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaMemberInitializerClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_member_initializer_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaMemberInitializer), 0, (GInstanceInitFunc) vala_member_initializer_instance_init };
 		vala_member_initializer_type_id = g_type_register_static (VALA_TYPE_CODE_NODE, "ValaMemberInitializer", &g_define_type_info, 0);
 	}
