@@ -113,7 +113,7 @@ static void vala_method_find_base_class_method (ValaMethod* self, ValaClass* cl)
 static void vala_method_find_base_interface_method (ValaMethod* self, ValaClass* cl);
 static GObject * vala_method_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
 static gpointer vala_method_parent_class = NULL;
-static void vala_method_dispose (GObject * obj);
+static void vala_method_finalize (GObject * obj);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
 static int _vala_strcmp0 (const char * str1, const char * str2);
 
@@ -659,7 +659,7 @@ static void vala_method_find_base_methods (ValaMethod* self) {
 		if (!vala_symbol_get_external_package (vala_symbol_get_parent_symbol (VALA_SYMBOL (self)))) {
 			if (!(VALA_IS_CREATION_METHOD (self))) {
 				vala_method_find_base_interface_method (self, VALA_CLASS (vala_symbol_get_parent_symbol (VALA_SYMBOL (self))));
-				if (self->priv->_is_virtual || self->priv->_overrides) {
+				if (self->priv->_is_virtual || self->priv->_is_abstract || self->priv->_overrides) {
 					vala_method_find_base_class_method (self, VALA_CLASS (vala_symbol_get_parent_symbol (VALA_SYMBOL (self))));
 				}
 			}
@@ -861,6 +861,7 @@ void vala_method_set_return_type (ValaMethod* self, ValaDataType* value) {
 	_tmp1 = NULL;
 	self->priv->_return_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_return_type == NULL ? NULL : (self->priv->_return_type = (g_object_unref (self->priv->_return_type), NULL))), _tmp2);
 	vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_return_type), VALA_CODE_NODE (self));
+	g_object_notify (((GObject *) (self)), "return-type");
 }
 
 
@@ -880,6 +881,7 @@ void vala_method_set_body (ValaMethod* self, ValaBlock* value) {
 	if (self->priv->_body != NULL) {
 		vala_symbol_set_owner (VALA_SYMBOL (self->priv->_body), vala_symbol_get_scope (VALA_SYMBOL (self)));
 	}
+	g_object_notify (((GObject *) (self)), "body");
 }
 
 
@@ -896,6 +898,7 @@ void vala_method_set_entry_block (ValaMethod* self, ValaBasicBlock* value) {
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_entry_block = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_entry_block == NULL ? NULL : (self->priv->_entry_block = (g_object_unref (self->priv->_entry_block), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "entry-block");
 }
 
 
@@ -912,6 +915,7 @@ void vala_method_set_exit_block (ValaMethod* self, ValaBasicBlock* value) {
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_exit_block = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_exit_block == NULL ? NULL : (self->priv->_exit_block = (g_object_unref (self->priv->_exit_block), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "exit-block");
 }
 
 
@@ -924,6 +928,7 @@ MemberBinding vala_method_get_binding (ValaMethod* self) {
 void vala_method_set_binding (ValaMethod* self, MemberBinding value) {
 	g_return_if_fail (VALA_IS_METHOD (self));
 	self->priv->_binding = value;
+	g_object_notify (((GObject *) (self)), "binding");
 }
 
 
@@ -947,6 +952,7 @@ void vala_method_set_vfunc_name (ValaMethod* self, const char* value) {
 	_tmp4 = NULL;
 	_tmp3 = NULL;
 	self->priv->_vfunc_name = (_tmp4 = (_tmp3 = value, (_tmp3 == NULL ? NULL : g_strdup (_tmp3))), (self->priv->_vfunc_name = (g_free (self->priv->_vfunc_name), NULL)), _tmp4);
+	g_object_notify (((GObject *) (self)), "vfunc-name");
 }
 
 
@@ -966,6 +972,7 @@ void vala_method_set_sentinel (ValaMethod* self, const char* value) {
 	_tmp3 = NULL;
 	_tmp2 = NULL;
 	self->priv->_sentinel = (_tmp3 = (_tmp2 = value, (_tmp2 == NULL ? NULL : g_strdup (_tmp2))), (self->priv->_sentinel = (g_free (self->priv->_sentinel), NULL)), _tmp3);
+	g_object_notify (((GObject *) (self)), "sentinel");
 }
 
 
@@ -978,6 +985,7 @@ gboolean vala_method_get_is_abstract (ValaMethod* self) {
 void vala_method_set_is_abstract (ValaMethod* self, gboolean value) {
 	g_return_if_fail (VALA_IS_METHOD (self));
 	self->priv->_is_abstract = value;
+	g_object_notify (((GObject *) (self)), "is-abstract");
 }
 
 
@@ -990,6 +998,7 @@ gboolean vala_method_get_is_virtual (ValaMethod* self) {
 void vala_method_set_is_virtual (ValaMethod* self, gboolean value) {
 	g_return_if_fail (VALA_IS_METHOD (self));
 	self->priv->_is_virtual = value;
+	g_object_notify (((GObject *) (self)), "is-virtual");
 }
 
 
@@ -1002,6 +1011,7 @@ gboolean vala_method_get_overrides (ValaMethod* self) {
 void vala_method_set_overrides (ValaMethod* self, gboolean value) {
 	g_return_if_fail (VALA_IS_METHOD (self));
 	self->priv->_overrides = value;
+	g_object_notify (((GObject *) (self)), "overrides");
 }
 
 
@@ -1014,6 +1024,7 @@ gboolean vala_method_get_is_inline (ValaMethod* self) {
 void vala_method_set_is_inline (ValaMethod* self, gboolean value) {
 	g_return_if_fail (VALA_IS_METHOD (self));
 	self->priv->_is_inline = value;
+	g_object_notify (((GObject *) (self)), "is-inline");
 }
 
 
@@ -1026,6 +1037,7 @@ gboolean vala_method_get_returns_modified_pointer (ValaMethod* self) {
 void vala_method_set_returns_modified_pointer (ValaMethod* self, gboolean value) {
 	g_return_if_fail (VALA_IS_METHOD (self));
 	self->priv->_returns_modified_pointer = value;
+	g_object_notify (((GObject *) (self)), "returns-modified-pointer");
 }
 
 
@@ -1056,6 +1068,7 @@ void vala_method_set_this_parameter (ValaMethod* self, ValaFormalParameter* valu
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_this_parameter = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_this_parameter == NULL ? NULL : (self->priv->_this_parameter = (g_object_unref (self->priv->_this_parameter), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "this-parameter");
 }
 
 
@@ -1072,6 +1085,7 @@ void vala_method_set_result_var (ValaMethod* self, ValaLocalVariable* value) {
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_result_var = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_result_var == NULL ? NULL : (self->priv->_result_var = (g_object_unref (self->priv->_result_var), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "result-var");
 }
 
 
@@ -1084,6 +1098,7 @@ double vala_method_get_cinstance_parameter_position (ValaMethod* self) {
 void vala_method_set_cinstance_parameter_position (ValaMethod* self, double value) {
 	g_return_if_fail (VALA_IS_METHOD (self));
 	self->priv->_cinstance_parameter_position = value;
+	g_object_notify (((GObject *) (self)), "cinstance-parameter-position");
 }
 
 
@@ -1096,6 +1111,7 @@ double vala_method_get_carray_length_parameter_position (ValaMethod* self) {
 void vala_method_set_carray_length_parameter_position (ValaMethod* self, double value) {
 	g_return_if_fail (VALA_IS_METHOD (self));
 	self->priv->_carray_length_parameter_position = value;
+	g_object_notify (((GObject *) (self)), "carray-length-parameter-position");
 }
 
 
@@ -1108,6 +1124,7 @@ double vala_method_get_cdelegate_target_parameter_position (ValaMethod* self) {
 void vala_method_set_cdelegate_target_parameter_position (ValaMethod* self, double value) {
 	g_return_if_fail (VALA_IS_METHOD (self));
 	self->priv->_cdelegate_target_parameter_position = value;
+	g_object_notify (((GObject *) (self)), "cdelegate-target-parameter-position");
 }
 
 
@@ -1133,6 +1150,7 @@ void vala_method_set_no_array_length (ValaMethod* self, gboolean value) {
 			}
 		}
 	}
+	g_object_notify (((GObject *) (self)), "no-array-length");
 }
 
 
@@ -1145,6 +1163,7 @@ gboolean vala_method_get_printf_format (ValaMethod* self) {
 void vala_method_set_printf_format (ValaMethod* self, gboolean value) {
 	g_return_if_fail (VALA_IS_METHOD (self));
 	self->priv->_printf_format = value;
+	g_object_notify (((GObject *) (self)), "printf-format");
 }
 
 
@@ -1313,7 +1332,7 @@ static void vala_method_class_init (ValaMethodClass * klass) {
 	G_OBJECT_CLASS (klass)->get_property = vala_method_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_method_set_property;
 	G_OBJECT_CLASS (klass)->constructor = vala_method_constructor;
-	G_OBJECT_CLASS (klass)->dispose = vala_method_dispose;
+	G_OBJECT_CLASS (klass)->finalize = vala_method_finalize;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_method_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_method_real_accept_children;
 	VALA_METHOD_CLASS (klass)->get_default_cname = vala_method_real_get_default_cname;
@@ -1352,7 +1371,7 @@ static void vala_method_instance_init (ValaMethod * self) {
 }
 
 
-static void vala_method_dispose (GObject * obj) {
+static void vala_method_finalize (GObject * obj) {
 	ValaMethod * self;
 	self = VALA_METHOD (obj);
 	(self->priv->_entry_block == NULL ? NULL : (self->priv->_entry_block = (g_object_unref (self->priv->_entry_block), NULL)));
@@ -1368,13 +1387,13 @@ static void vala_method_dispose (GObject * obj) {
 	(self->priv->_return_type == NULL ? NULL : (self->priv->_return_type = (g_object_unref (self->priv->_return_type), NULL)));
 	(self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL)));
 	(self->priv->_base_interface_method == NULL ? NULL : (self->priv->_base_interface_method = (g_object_unref (self->priv->_base_interface_method), NULL)));
-	G_OBJECT_CLASS (vala_method_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (vala_method_parent_class)->finalize (obj);
 }
 
 
 GType vala_method_get_type (void) {
 	static GType vala_method_type_id = 0;
-	if (G_UNLIKELY (vala_method_type_id == 0)) {
+	if (vala_method_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaMethodClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_method_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaMethod), 0, (GInstanceInitFunc) vala_method_instance_init };
 		vala_method_type_id = g_type_register_static (VALA_TYPE_MEMBER, "ValaMethod", &g_define_type_info, 0);
 	}
