@@ -45,7 +45,7 @@ static gboolean vala_method_type_real_compatible (ValaDataType* base, ValaDataTy
 static char* vala_method_type_real_to_qualified_string (ValaDataType* base, ValaScope* scope);
 static char* vala_method_type_real_get_cname (ValaDataType* base);
 static gpointer vala_method_type_parent_class = NULL;
-static void vala_method_type_dispose (GObject * obj);
+static void vala_method_type_finalize (GObject * obj);
 
 
 
@@ -136,6 +136,7 @@ void vala_method_type_set_method_symbol (ValaMethodType* self, ValaMethod* value
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_method_symbol = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_method_symbol == NULL ? NULL : (self->priv->_method_symbol = (g_object_unref (self->priv->_method_symbol), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "method-symbol");
 }
 
 
@@ -172,7 +173,7 @@ static void vala_method_type_class_init (ValaMethodTypeClass * klass) {
 	g_type_class_add_private (klass, sizeof (ValaMethodTypePrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_method_type_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_method_type_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_method_type_dispose;
+	G_OBJECT_CLASS (klass)->finalize = vala_method_type_finalize;
 	VALA_DATA_TYPE_CLASS (klass)->is_invokable = vala_method_type_real_is_invokable;
 	VALA_DATA_TYPE_CLASS (klass)->get_return_type = vala_method_type_real_get_return_type;
 	VALA_DATA_TYPE_CLASS (klass)->get_parameters = vala_method_type_real_get_parameters;
@@ -189,17 +190,17 @@ static void vala_method_type_instance_init (ValaMethodType * self) {
 }
 
 
-static void vala_method_type_dispose (GObject * obj) {
+static void vala_method_type_finalize (GObject * obj) {
 	ValaMethodType * self;
 	self = VALA_METHOD_TYPE (obj);
 	(self->priv->_method_symbol == NULL ? NULL : (self->priv->_method_symbol = (g_object_unref (self->priv->_method_symbol), NULL)));
-	G_OBJECT_CLASS (vala_method_type_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (vala_method_type_parent_class)->finalize (obj);
 }
 
 
 GType vala_method_type_get_type (void) {
 	static GType vala_method_type_type_id = 0;
-	if (G_UNLIKELY (vala_method_type_type_id == 0)) {
+	if (vala_method_type_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaMethodTypeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_method_type_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaMethodType), 0, (GInstanceInitFunc) vala_method_type_instance_init };
 		vala_method_type_type_id = g_type_register_static (VALA_TYPE_DATA_TYPE, "ValaMethodType", &g_define_type_info, 0);
 	}
