@@ -73,7 +73,7 @@ static char* vala_namespace_real_get_lower_case_cprefix (ValaSymbol* base);
 static GeeList* vala_namespace_real_get_cheader_filenames (ValaSymbol* base);
 static void vala_namespace_process_ccode_attribute (ValaNamespace* self, ValaAttribute* a);
 static gpointer vala_namespace_parent_class = NULL;
-static void vala_namespace_dispose (GObject * obj);
+static void vala_namespace_finalize (GObject * obj);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
 static int _vala_strcmp0 (const char * str1, const char * str2);
 
@@ -983,7 +983,7 @@ void vala_namespace_process_attributes (ValaNamespace* self) {
 static void vala_namespace_class_init (ValaNamespaceClass * klass) {
 	vala_namespace_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaNamespacePrivate));
-	G_OBJECT_CLASS (klass)->dispose = vala_namespace_dispose;
+	G_OBJECT_CLASS (klass)->finalize = vala_namespace_finalize;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_namespace_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_namespace_real_accept_children;
 	VALA_SYMBOL_CLASS (klass)->get_cprefix = vala_namespace_real_get_cprefix;
@@ -1009,7 +1009,7 @@ static void vala_namespace_instance_init (ValaNamespace * self) {
 }
 
 
-static void vala_namespace_dispose (GObject * obj) {
+static void vala_namespace_finalize (GObject * obj) {
 	ValaNamespace * self;
 	self = VALA_NAMESPACE (obj);
 	(self->priv->classes == NULL ? NULL : (self->priv->classes = (g_object_unref (self->priv->classes), NULL)));
@@ -1025,13 +1025,13 @@ static void vala_namespace_dispose (GObject * obj) {
 	self->priv->lower_case_cprefix = (g_free (self->priv->lower_case_cprefix), NULL);
 	(self->priv->cheader_filenames == NULL ? NULL : (self->priv->cheader_filenames = (g_object_unref (self->priv->cheader_filenames), NULL)));
 	(self->priv->namespaces == NULL ? NULL : (self->priv->namespaces = (g_object_unref (self->priv->namespaces), NULL)));
-	G_OBJECT_CLASS (vala_namespace_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (vala_namespace_parent_class)->finalize (obj);
 }
 
 
 GType vala_namespace_get_type (void) {
 	static GType vala_namespace_type_id = 0;
-	if (G_UNLIKELY (vala_namespace_type_id == 0)) {
+	if (vala_namespace_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaNamespaceClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_namespace_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaNamespace), 0, (GInstanceInitFunc) vala_namespace_instance_init };
 		vala_namespace_type_id = g_type_register_static (VALA_TYPE_SYMBOL, "ValaNamespace", &g_define_type_info, 0);
 	}
