@@ -83,7 +83,7 @@ static void vala_null_checker_real_visit_conditional_expression (ValaCodeVisitor
 static void vala_null_checker_real_visit_lambda_expression (ValaCodeVisitor* base, ValaLambdaExpression* l);
 static void vala_null_checker_real_visit_assignment (ValaCodeVisitor* base, ValaAssignment* a);
 static gpointer vala_null_checker_parent_class = NULL;
-static void vala_null_checker_dispose (GObject * obj);
+static void vala_null_checker_finalize (GObject * obj);
 
 
 
@@ -425,6 +425,7 @@ static void vala_null_checker_real_visit_element_access (ValaCodeVisitor* base,
 	ValaNullChecker * self;
 	self = VALA_NULL_CHECKER (base);
 	g_return_if_fail (VALA_IS_ELEMENT_ACCESS (expr));
+	vala_code_node_accept_children (VALA_CODE_NODE (expr), VALA_CODE_VISITOR (self));
 	vala_null_checker_check_non_null (self, vala_element_access_get_container (expr));
 }
 
@@ -487,7 +488,7 @@ static void vala_null_checker_real_visit_assignment (ValaCodeVisitor* base, Vala
 static void vala_null_checker_class_init (ValaNullCheckerClass * klass) {
 	vala_null_checker_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaNullCheckerPrivate));
-	G_OBJECT_CLASS (klass)->dispose = vala_null_checker_dispose;
+	G_OBJECT_CLASS (klass)->finalize = vala_null_checker_finalize;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_source_file = vala_null_checker_real_visit_source_file;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_class = vala_null_checker_real_visit_class;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_struct = vala_null_checker_real_visit_struct;
@@ -531,18 +532,18 @@ static void vala_null_checker_instance_init (ValaNullChecker * self) {
 }
 
 
-static void vala_null_checker_dispose (GObject * obj) {
+static void vala_null_checker_finalize (GObject * obj) {
 	ValaNullChecker * self;
 	self = VALA_NULL_CHECKER (obj);
 	(self->priv->context == NULL ? NULL : (self->priv->context = (g_object_unref (self->priv->context), NULL)));
 	(self->priv->current_return_type == NULL ? NULL : (self->priv->current_return_type = (g_object_unref (self->priv->current_return_type), NULL)));
-	G_OBJECT_CLASS (vala_null_checker_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (vala_null_checker_parent_class)->finalize (obj);
 }
 
 
 GType vala_null_checker_get_type (void) {
 	static GType vala_null_checker_type_id = 0;
-	if (G_UNLIKELY (vala_null_checker_type_id == 0)) {
+	if (vala_null_checker_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaNullCheckerClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_null_checker_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaNullChecker), 0, (GInstanceInitFunc) vala_null_checker_instance_init };
 		vala_null_checker_type_id = g_type_register_static (VALA_TYPE_CODE_VISITOR, "ValaNullChecker", &g_define_type_info, 0);
 	}
