@@ -108,7 +108,7 @@ static void vala_null_type_instance_init (ValaNullType * self) {
 
 GType vala_null_type_get_type (void) {
 	static GType vala_null_type_type_id = 0;
-	if (G_UNLIKELY (vala_null_type_type_id == 0)) {
+	if (vala_null_type_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaNullTypeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_null_type_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaNullType), 0, (GInstanceInitFunc) vala_null_type_instance_init };
 		vala_null_type_type_id = g_type_register_static (VALA_TYPE_REFERENCE_TYPE, "ValaNullType", &g_define_type_info, 0);
 	}
