@@ -57,7 +57,7 @@ static void vala_object_creation_expression_real_replace_expression (ValaCodeNod
 static gboolean vala_object_creation_expression_real_is_pure (ValaExpression* base);
 static void vala_object_creation_expression_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type);
 static gpointer vala_object_creation_expression_parent_class = NULL;
-static void vala_object_creation_expression_dispose (GObject * obj);
+static void vala_object_creation_expression_finalize (GObject * obj);
 
 
 
@@ -221,6 +221,7 @@ void vala_object_creation_expression_set_type_reference (ValaObjectCreationExpre
 	_tmp1 = NULL;
 	self->priv->_data_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_data_type == NULL ? NULL : (self->priv->_data_type = (g_object_unref (self->priv->_data_type), NULL))), _tmp2);
 	vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_data_type), VALA_CODE_NODE (self));
+	g_object_notify (((GObject *) (self)), "type-reference");
 }
 
 
@@ -237,6 +238,7 @@ void vala_object_creation_expression_set_constructor (ValaObjectCreationExpressi
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_constructor = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_constructor == NULL ? NULL : (self->priv->_constructor = (g_object_unref (self->priv->_constructor), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "constructor");
 }
 
 
@@ -253,6 +255,7 @@ void vala_object_creation_expression_set_member_name (ValaObjectCreationExpressi
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_member_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_member_name == NULL ? NULL : (self->priv->_member_name = (g_object_unref (self->priv->_member_name), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "member-name");
 }
 
 
@@ -265,6 +268,7 @@ gboolean vala_object_creation_expression_get_struct_creation (ValaObjectCreation
 void vala_object_creation_expression_set_struct_creation (ValaObjectCreationExpression* self, gboolean value) {
 	g_return_if_fail (VALA_IS_OBJECT_CREATION_EXPRESSION (self));
 	self->priv->_struct_creation = value;
+	g_object_notify (((GObject *) (self)), "struct-creation");
 }
 
 
@@ -319,7 +323,7 @@ static void vala_object_creation_expression_class_init (ValaObjectCreationExpres
 	g_type_class_add_private (klass, sizeof (ValaObjectCreationExpressionPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_object_creation_expression_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_object_creation_expression_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_object_creation_expression_dispose;
+	G_OBJECT_CLASS (klass)->finalize = vala_object_creation_expression_finalize;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_object_creation_expression_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_object_creation_expression_real_accept_children;
 	VALA_CODE_NODE_CLASS (klass)->replace_expression = vala_object_creation_expression_real_replace_expression;
@@ -339,7 +343,7 @@ static void vala_object_creation_expression_instance_init (ValaObjectCreationExp
 }
 
 
-static void vala_object_creation_expression_dispose (GObject * obj) {
+static void vala_object_creation_expression_finalize (GObject * obj) {
 	ValaObjectCreationExpression * self;
 	self = VALA_OBJECT_CREATION_EXPRESSION (obj);
 	(self->priv->_constructor == NULL ? NULL : (self->priv->_constructor = (g_object_unref (self->priv->_constructor), NULL)));
@@ -347,13 +351,13 @@ static void vala_object_creation_expression_dispose (GObject * obj) {
 	(self->priv->argument_list == NULL ? NULL : (self->priv->argument_list = (g_object_unref (self->priv->argument_list), NULL)));
 	(self->priv->object_initializer == NULL ? NULL : (self->priv->object_initializer = (g_object_unref (self->priv->object_initializer), NULL)));
 	(self->priv->_data_type == NULL ? NULL : (self->priv->_data_type = (g_object_unref (self->priv->_data_type), NULL)));
-	G_OBJECT_CLASS (vala_object_creation_expression_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (vala_object_creation_expression_parent_class)->finalize (obj);
 }
 
 
 GType vala_object_creation_expression_get_type (void) {
 	static GType vala_object_creation_expression_type_id = 0;
-	if (G_UNLIKELY (vala_object_creation_expression_type_id == 0)) {
+	if (vala_object_creation_expression_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaObjectCreationExpressionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_object_creation_expression_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaObjectCreationExpression), 0, (GInstanceInitFunc) vala_object_creation_expression_instance_init };
 		vala_object_creation_expression_type_id = g_type_register_static (VALA_TYPE_EXPRESSION, "ValaObjectCreationExpression", &g_define_type_info, 0);
 	}
