@@ -40,7 +40,7 @@ static void vala_pointer_indirection_real_accept (ValaCodeNode* base, ValaCodeVi
 static void vala_pointer_indirection_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node);
 static gboolean vala_pointer_indirection_real_is_pure (ValaExpression* base);
 static gpointer vala_pointer_indirection_parent_class = NULL;
-static void vala_pointer_indirection_dispose (GObject * obj);
+static void vala_pointer_indirection_finalize (GObject * obj);
 
 
 
@@ -115,6 +115,7 @@ void vala_pointer_indirection_set_inner (ValaPointerIndirection* self, ValaExpre
 	_tmp1 = NULL;
 	self->priv->_inner = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL))), _tmp2);
 	vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_inner), VALA_CODE_NODE (self));
+	g_object_notify (((GObject *) (self)), "inner");
 }
 
 
@@ -151,7 +152,7 @@ static void vala_pointer_indirection_class_init (ValaPointerIndirectionClass * k
 	g_type_class_add_private (klass, sizeof (ValaPointerIndirectionPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_pointer_indirection_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_pointer_indirection_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_pointer_indirection_dispose;
+	G_OBJECT_CLASS (klass)->finalize = vala_pointer_indirection_finalize;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_pointer_indirection_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->replace_expression = vala_pointer_indirection_real_replace_expression;
 	VALA_EXPRESSION_CLASS (klass)->is_pure = vala_pointer_indirection_real_is_pure;
@@ -164,17 +165,17 @@ static void vala_pointer_indirection_instance_init (ValaPointerIndirection * sel
 }
 
 
-static void vala_pointer_indirection_dispose (GObject * obj) {
+static void vala_pointer_indirection_finalize (GObject * obj) {
 	ValaPointerIndirection * self;
 	self = VALA_POINTER_INDIRECTION (obj);
 	(self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL)));
-	G_OBJECT_CLASS (vala_pointer_indirection_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (vala_pointer_indirection_parent_class)->finalize (obj);
 }
 
 
 GType vala_pointer_indirection_get_type (void) {
 	static GType vala_pointer_indirection_type_id = 0;
-	if (G_UNLIKELY (vala_pointer_indirection_type_id == 0)) {
+	if (vala_pointer_indirection_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaPointerIndirectionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_pointer_indirection_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaPointerIndirection), 0, (GInstanceInitFunc) vala_pointer_indirection_instance_init };
 		vala_pointer_indirection_type_id = g_type_register_static (VALA_TYPE_EXPRESSION, "ValaPointerIndirection", &g_define_type_info, 0);
 	}
