@@ -25,8 +25,10 @@
 #include <vala/valablock.h>
 #include <vala/valabasicblock.h>
 #include <vala/valaformalparameter.h>
+#include <vala/valatypesymbol.h>
 #include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
+#include <vala/valaattribute.h>
 
 
 
@@ -42,6 +44,7 @@ struct _ValaPropertyAccessorPrivate {
 	ValaBasicBlock* _exit_block;
 	gboolean _automatic_body;
 	ValaFormalParameter* _value_parameter;
+	char* _cname;
 };
 
 #define VALA_PROPERTY_ACCESSOR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_PROPERTY_ACCESSOR, ValaPropertyAccessorPrivate))
@@ -61,10 +64,47 @@ enum  {
 static void vala_property_accessor_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_property_accessor_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static gpointer vala_property_accessor_parent_class = NULL;
-static void vala_property_accessor_dispose (GObject * obj);
+static void vala_property_accessor_finalize (GObject * obj);
+static int _vala_strcmp0 (const char * str1, const char * str2);
 
 
 
+/**
+ * The publicly accessible name of the function that performs the
+ * access in C code.
+ */
+char* vala_property_accessor_get_cname (ValaPropertyAccessor* self) {
+	ValaTypeSymbol* _tmp2;
+	ValaTypeSymbol* t;
+	g_return_val_if_fail (VALA_IS_PROPERTY_ACCESSOR (self), NULL);
+	if (self->priv->_cname != NULL) {
+		const char* _tmp0;
+		_tmp0 = NULL;
+		return (_tmp0 = self->priv->_cname, (_tmp0 == NULL ? NULL : g_strdup (_tmp0)));
+	}
+	_tmp2 = NULL;
+	t = (_tmp2 = VALA_TYPESYMBOL (vala_symbol_get_parent_symbol (VALA_SYMBOL (self->priv->_prop))), (_tmp2 == NULL ? NULL : g_object_ref (_tmp2)));
+	if (self->priv->_readable) {
+		char* _tmp3;
+		char* _tmp4;
+		char* _tmp5;
+		_tmp3 = NULL;
+		_tmp4 = NULL;
+		_tmp5 = NULL;
+		return (_tmp5 = (_tmp4 = g_strdup_printf ("%s_get_%s", (_tmp3 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (t), NULL)), vala_symbol_get_name (VALA_SYMBOL (self->priv->_prop))), (_tmp3 = (g_free (_tmp3), NULL)), _tmp4), (t == NULL ? NULL : (t = (g_object_unref (t), NULL))), _tmp5);
+	} else {
+		char* _tmp6;
+		char* _tmp7;
+		char* _tmp8;
+		_tmp6 = NULL;
+		_tmp7 = NULL;
+		_tmp8 = NULL;
+		return (_tmp8 = (_tmp7 = g_strdup_printf ("%s_set_%s", (_tmp6 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (t), NULL)), vala_symbol_get_name (VALA_SYMBOL (self->priv->_prop))), (_tmp6 = (g_free (_tmp6), NULL)), _tmp7), (t == NULL ? NULL : (t = (g_object_unref (t), NULL))), _tmp8);
+	}
+	(t == NULL ? NULL : (t = (g_object_unref (t), NULL)));
+}
+
+
 /**
  * Creates a new property accessor.
  *
@@ -107,6 +147,35 @@ static void vala_property_accessor_real_accept_children (ValaCodeNode* base, Val
 }
 
 
+/**
+ * Process all associated attributes.
+ */
+void vala_property_accessor_process_attributes (ValaPropertyAccessor* self) {
+	g_return_if_fail (VALA_IS_PROPERTY_ACCESSOR (self));
+	{
+		GList* a_collection;
+		GList* a_it;
+		a_collection = VALA_CODE_NODE (self)->attributes;
+		for (a_it = a_collection; a_it != NULL; a_it = a_it->next) {
+			ValaAttribute* _tmp1;
+			ValaAttribute* a;
+			_tmp1 = NULL;
+			a = (_tmp1 = ((ValaAttribute*) (a_it->data)), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
+			{
+				if (_vala_strcmp0 (vala_attribute_get_name (a), "CCode") == 0) {
+					if (vala_attribute_has_argument (a, "cname")) {
+						char* _tmp0;
+						_tmp0 = NULL;
+						self->priv->_cname = (_tmp0 = vala_attribute_get_string (a, "cname"), (self->priv->_cname = (g_free (self->priv->_cname), NULL)), _tmp0);
+					}
+				}
+				(a == NULL ? NULL : (a = (g_object_unref (a), NULL)));
+			}
+		}
+	}
+}
+
+
 ValaProperty* vala_property_accessor_get_prop (ValaPropertyAccessor* self) {
 	g_return_val_if_fail (VALA_IS_PROPERTY_ACCESSOR (self), NULL);
 	return self->priv->_prop;
@@ -116,6 +185,7 @@ ValaProperty* vala_property_accessor_get_prop (ValaPropertyAccessor* self) {
 void vala_property_accessor_set_prop (ValaPropertyAccessor* self, ValaProperty* value) {
 	g_return_if_fail (VALA_IS_PROPERTY_ACCESSOR (self));
 	self->priv->_prop = value;
+	g_object_notify (((GObject *) (self)), "prop");
 }
 
 
@@ -128,6 +198,7 @@ gboolean vala_property_accessor_get_readable (ValaPropertyAccessor* self) {
 void vala_property_accessor_set_readable (ValaPropertyAccessor* self, gboolean value) {
 	g_return_if_fail (VALA_IS_PROPERTY_ACCESSOR (self));
 	self->priv->_readable = value;
+	g_object_notify (((GObject *) (self)), "readable");
 }
 
 
@@ -140,6 +211,7 @@ gboolean vala_property_accessor_get_writable (ValaPropertyAccessor* self) {
 void vala_property_accessor_set_writable (ValaPropertyAccessor* self, gboolean value) {
 	g_return_if_fail (VALA_IS_PROPERTY_ACCESSOR (self));
 	self->priv->_writable = value;
+	g_object_notify (((GObject *) (self)), "writable");
 }
 
 
@@ -152,6 +224,7 @@ gboolean vala_property_accessor_get_construction (ValaPropertyAccessor* self) {
 void vala_property_accessor_set_construction (ValaPropertyAccessor* self, gboolean value) {
 	g_return_if_fail (VALA_IS_PROPERTY_ACCESSOR (self));
 	self->priv->_construction = value;
+	g_object_notify (((GObject *) (self)), "construction");
 }
 
 
@@ -164,6 +237,7 @@ ValaSymbolAccessibility vala_property_accessor_get_access (ValaPropertyAccessor*
 void vala_property_accessor_set_access (ValaPropertyAccessor* self, ValaSymbolAccessibility value) {
 	g_return_if_fail (VALA_IS_PROPERTY_ACCESSOR (self));
 	self->priv->_access = value;
+	g_object_notify (((GObject *) (self)), "access");
 }
 
 
@@ -180,6 +254,7 @@ void vala_property_accessor_set_body (ValaPropertyAccessor* self, ValaBlock* val
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_body = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "body");
 }
 
 
@@ -196,6 +271,7 @@ void vala_property_accessor_set_entry_block (ValaPropertyAccessor* self, ValaBas
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_entry_block = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_entry_block == NULL ? NULL : (self->priv->_entry_block = (g_object_unref (self->priv->_entry_block), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "entry-block");
 }
 
 
@@ -212,6 +288,7 @@ void vala_property_accessor_set_exit_block (ValaPropertyAccessor* self, ValaBasi
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_exit_block = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_exit_block == NULL ? NULL : (self->priv->_exit_block = (g_object_unref (self->priv->_exit_block), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "exit-block");
 }
 
 
@@ -224,6 +301,7 @@ gboolean vala_property_accessor_get_automatic_body (ValaPropertyAccessor* self)
 void vala_property_accessor_set_automatic_body (ValaPropertyAccessor* self, gboolean value) {
 	g_return_if_fail (VALA_IS_PROPERTY_ACCESSOR (self));
 	self->priv->_automatic_body = value;
+	g_object_notify (((GObject *) (self)), "automatic-body");
 }
 
 
@@ -240,6 +318,7 @@ void vala_property_accessor_set_value_parameter (ValaPropertyAccessor* self, Val
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_value_parameter = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_value_parameter == NULL ? NULL : (self->priv->_value_parameter = (g_object_unref (self->priv->_value_parameter), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "value-parameter");
 }
 
 
@@ -330,7 +409,7 @@ static void vala_property_accessor_class_init (ValaPropertyAccessorClass * klass
 	g_type_class_add_private (klass, sizeof (ValaPropertyAccessorPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_property_accessor_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_property_accessor_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_property_accessor_dispose;
+	G_OBJECT_CLASS (klass)->finalize = vala_property_accessor_finalize;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_property_accessor_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_property_accessor_real_accept_children;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_ACCESSOR_PROP, g_param_spec_object ("prop", "prop", "prop", VALA_TYPE_PROPERTY, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
@@ -351,20 +430,21 @@ static void vala_property_accessor_instance_init (ValaPropertyAccessor * self) {
 }
 
 
-static void vala_property_accessor_dispose (GObject * obj) {
+static void vala_property_accessor_finalize (GObject * obj) {
 	ValaPropertyAccessor * self;
 	self = VALA_PROPERTY_ACCESSOR (obj);
 	(self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL)));
 	(self->priv->_entry_block == NULL ? NULL : (self->priv->_entry_block = (g_object_unref (self->priv->_entry_block), NULL)));
 	(self->priv->_exit_block == NULL ? NULL : (self->priv->_exit_block = (g_object_unref (self->priv->_exit_block), NULL)));
 	(self->priv->_value_parameter == NULL ? NULL : (self->priv->_value_parameter = (g_object_unref (self->priv->_value_parameter), NULL)));
-	G_OBJECT_CLASS (vala_property_accessor_parent_class)->dispose (obj);
+	self->priv->_cname = (g_free (self->priv->_cname), NULL);
+	G_OBJECT_CLASS (vala_property_accessor_parent_class)->finalize (obj);
 }
 
 
 GType vala_property_accessor_get_type (void) {
 	static GType vala_property_accessor_type_id = 0;
-	if (G_UNLIKELY (vala_property_accessor_type_id == 0)) {
+	if (vala_property_accessor_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaPropertyAccessorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_property_accessor_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaPropertyAccessor), 0, (GInstanceInitFunc) vala_property_accessor_instance_init };
 		vala_property_accessor_type_id = g_type_register_static (VALA_TYPE_CODE_NODE, "ValaPropertyAccessor", &g_define_type_info, 0);
 	}
@@ -372,5 +452,16 @@ GType vala_property_accessor_get_type (void) {
 }
 
 
+static int _vala_strcmp0 (const char * str1, const char * str2) {
+	if (str1 == NULL) {
+		return -(str1 != str2);
+	}
+	if (str2 == NULL) {
+		return (str1 != str2);
+	}
+	return strcmp (str1, str2);
+}
+
+
 
 
