@@ -25,6 +25,8 @@
 
 #include <glib.h>
 #include <glib-object.h>
+#include <stdlib.h>
+#include <string.h>
 #include <vala/valacodenode.h>
 #include <vala/valasymbol.h>
 
@@ -53,7 +55,9 @@ struct _ValaPropertyAccessorClass {
 };
 
 
+char* vala_property_accessor_get_cname (ValaPropertyAccessor* self);
 ValaPropertyAccessor* vala_property_accessor_new (gboolean readable, gboolean writable, gboolean construction, ValaBlock* body, ValaSourceReference* source_reference);
+void vala_property_accessor_process_attributes (ValaPropertyAccessor* self);
 ValaProperty* vala_property_accessor_get_prop (ValaPropertyAccessor* self);
 void vala_property_accessor_set_prop (ValaPropertyAccessor* self, ValaProperty* value);
 gboolean vala_property_accessor_get_readable (ValaPropertyAccessor* self);
