@@ -23,6 +23,7 @@
 #include <vala/valarealliteral.h>
 #include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
+#include <vala/valaexpression.h>
 
 
 
@@ -30,6 +31,7 @@
 struct _ValaRealLiteralPrivate {
 	char* _value;
 };
+
 #define VALA_REAL_LITERAL_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_REAL_LITERAL, ValaRealLiteralPrivate))
 enum  {
 	VALA_REAL_LITERAL_DUMMY_PROPERTY,
@@ -38,7 +40,7 @@ enum  {
 static void vala_real_literal_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static gboolean vala_real_literal_real_is_pure (ValaExpression* base);
 static gpointer vala_real_literal_parent_class = NULL;
-static void vala_real_literal_dispose (GObject * obj);
+static void vala_real_literal_finalize (GObject * obj);
 
 
 
@@ -65,6 +67,7 @@ static void vala_real_literal_real_accept (ValaCodeNode* base, ValaCodeVisitor*
 	self = VALA_REAL_LITERAL (base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_real_literal (visitor, self);
+	vala_code_visitor_visit_expression (visitor, VALA_EXPRESSION (self));
 }
 
 
@@ -89,7 +92,7 @@ static gboolean vala_real_literal_real_is_pure (ValaExpression* base) {
 }
 
 
-char* vala_real_literal_get_value (ValaRealLiteral* self) {
+const char* vala_real_literal_get_value (ValaRealLiteral* self) {
 	g_return_val_if_fail (VALA_IS_REAL_LITERAL (self), NULL);
 	return self->priv->_value;
 }
@@ -102,6 +105,7 @@ void vala_real_literal_set_value (ValaRealLiteral* self, const char* value) {
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_value = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_value = (g_free (self->priv->_value), NULL)), _tmp2);
+	g_object_notify (((GObject *) (self)), "value");
 }
 
 
@@ -138,30 +142,30 @@ static void vala_real_literal_class_init (ValaRealLiteralClass * klass) {
 	g_type_class_add_private (klass, sizeof (ValaRealLiteralPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_real_literal_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_real_literal_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_real_literal_dispose;
+	G_OBJECT_CLASS (klass)->finalize = vala_real_literal_finalize;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_real_literal_real_accept;
 	VALA_EXPRESSION_CLASS (klass)->is_pure = vala_real_literal_real_is_pure;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_REAL_LITERAL_VALUE, g_param_spec_string ("value", "value", "value", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
-static void vala_real_literal_init (ValaRealLiteral * self) {
+static void vala_real_literal_instance_init (ValaRealLiteral * self) {
 	self->priv = VALA_REAL_LITERAL_GET_PRIVATE (self);
 }
 
 
-static void vala_real_literal_dispose (GObject * obj) {
+static void vala_real_literal_finalize (GObject * obj) {
 	ValaRealLiteral * self;
 	self = VALA_REAL_LITERAL (obj);
 	self->priv->_value = (g_free (self->priv->_value), NULL);
-	G_OBJECT_CLASS (vala_real_literal_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (vala_real_literal_parent_class)->finalize (obj);
 }
 
 
 GType vala_real_literal_get_type (void) {
 	static GType vala_real_literal_type_id = 0;
-	if (G_UNLIKELY (vala_real_literal_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaRealLiteralClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_real_literal_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaRealLiteral), 0, (GInstanceInitFunc) vala_real_literal_init };
+	if (vala_real_literal_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (ValaRealLiteralClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_real_literal_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaRealLiteral), 0, (GInstanceInitFunc) vala_real_literal_instance_init };
 		vala_real_literal_type_id = g_type_register_static (VALA_TYPE_LITERAL, "ValaRealLiteral", &g_define_type_info, 0);
 	}
 	return vala_real_literal_type_id;
