@@ -41,7 +41,7 @@ static void vala_reference_transfer_expression_real_accept_children (ValaCodeNod
 static void vala_reference_transfer_expression_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node);
 static gboolean vala_reference_transfer_expression_real_is_pure (ValaExpression* base);
 static gpointer vala_reference_transfer_expression_parent_class = NULL;
-static void vala_reference_transfer_expression_dispose (GObject * obj);
+static void vala_reference_transfer_expression_finalize (GObject * obj);
 
 
 
@@ -123,6 +123,7 @@ void vala_reference_transfer_expression_set_inner (ValaReferenceTransferExpressi
 	_tmp1 = NULL;
 	self->priv->_inner = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL))), _tmp2);
 	vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_inner), VALA_CODE_NODE (self));
+	g_object_notify (((GObject *) (self)), "inner");
 }
 
 
@@ -159,7 +160,7 @@ static void vala_reference_transfer_expression_class_init (ValaReferenceTransfer
 	g_type_class_add_private (klass, sizeof (ValaReferenceTransferExpressionPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_reference_transfer_expression_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_reference_transfer_expression_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_reference_transfer_expression_dispose;
+	G_OBJECT_CLASS (klass)->finalize = vala_reference_transfer_expression_finalize;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_reference_transfer_expression_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_reference_transfer_expression_real_accept_children;
 	VALA_CODE_NODE_CLASS (klass)->replace_expression = vala_reference_transfer_expression_real_replace_expression;
@@ -173,17 +174,17 @@ static void vala_reference_transfer_expression_instance_init (ValaReferenceTrans
 }
 
 
-static void vala_reference_transfer_expression_dispose (GObject * obj) {
+static void vala_reference_transfer_expression_finalize (GObject * obj) {
 	ValaReferenceTransferExpression * self;
 	self = VALA_REFERENCE_TRANSFER_EXPRESSION (obj);
 	(self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL)));
-	G_OBJECT_CLASS (vala_reference_transfer_expression_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (vala_reference_transfer_expression_parent_class)->finalize (obj);
 }
 
 
 GType vala_reference_transfer_expression_get_type (void) {
 	static GType vala_reference_transfer_expression_type_id = 0;
-	if (G_UNLIKELY (vala_reference_transfer_expression_type_id == 0)) {
+	if (vala_reference_transfer_expression_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaReferenceTransferExpressionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_reference_transfer_expression_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaReferenceTransferExpression), 0, (GInstanceInitFunc) vala_reference_transfer_expression_instance_init };
 		vala_reference_transfer_expression_type_id = g_type_register_static (VALA_TYPE_EXPRESSION, "ValaReferenceTransferExpression", &g_define_type_info, 0);
 	}
