@@ -43,7 +43,7 @@ static void vala_reference_type_instance_init (ValaReferenceType * self) {
 
 GType vala_reference_type_get_type (void) {
 	static GType vala_reference_type_type_id = 0;
-	if (G_UNLIKELY (vala_reference_type_type_id == 0)) {
+	if (vala_reference_type_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaReferenceTypeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_reference_type_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaReferenceType), 0, (GInstanceInitFunc) vala_reference_type_instance_init };
 		vala_reference_type_type_id = g_type_register_static (VALA_TYPE_DATA_TYPE, "ValaReferenceType", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
 	}
