@@ -1,6 +1,6 @@
 /* valareport.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -27,10 +27,9 @@
 
 
 
-static gint vala_report_warnings;
-static gint vala_report_errors;
-static gboolean vala_report_verbose_errors;
-static void vala_report_report_source (ValaSourceReference* source);
+gint vala_report_warnings = 0;
+gint vala_report_errors = 0;
+gboolean vala_report_verbose_errors = FALSE;
 
 
 
@@ -61,22 +60,22 @@ gint vala_report_get_errors (void) {
 /**
  * Pretty-print the actual line of offending code if possible.
  */
-static void vala_report_report_source (ValaSourceReference* source) {
+void vala_report_report_source (ValaSourceReference* source) {
 	char* offending_line;
-	g_return_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source));
+	g_return_if_fail (VALA_IS_SOURCE_REFERENCE (source));
 	if (vala_source_reference_get_first_line (source) != vala_source_reference_get_last_line (source)) {
+		/* FIXME Cannot report multi-line issues currently*/
 		return;
 	}
-	/* FIXME Cannot report multi-line issues currently*/
 	offending_line = vala_source_file_get_source_line (vala_source_reference_get_file (source), vala_source_reference_get_first_line (source));
 	if (offending_line != NULL) {
 		gint idx;
 		fprintf (stderr, "%s\n", offending_line);
 		idx = 0;
+		/* We loop in this manner so that we don't fall over on differing
+		 * tab widths. This means we get the ^s in the right places.
+		 */
 		for (idx = 1; idx < vala_source_reference_get_first_column (source); (idx = idx + 1)) {
-			/* We loop in this manner so that we don't fall over on differing
-			 * tab widths. This means we get the ^s in the right places.
-			 */
 			if (g_utf8_get_char (g_utf8_offset_to_pointer (offending_line, idx - 1)) == '\t') {
 				fprintf (stderr, "\t");
 			} else {
@@ -104,6 +103,7 @@ static void vala_report_report_source (ValaSourceReference* source) {
  */
 void vala_report_warning (ValaSourceReference* source, const char* message) {
 	g_return_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source));
+	g_return_if_fail (message != NULL);
 	vala_report_warnings++;
 	if (source == NULL) {
 		fprintf (stderr, "warning: %s\n", message);
@@ -127,6 +127,7 @@ void vala_report_warning (ValaSourceReference* source, const char* message) {
  */
 void vala_report_error (ValaSourceReference* source, const char* message) {
 	g_return_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source));
+	g_return_if_fail (message != NULL);
 	vala_report_errors++;
 	if (source == NULL) {
 		fprintf (stderr, "error: %s\n", message);
