@@ -42,7 +42,7 @@ static void vala_return_statement_real_accept_children (ValaCodeNode* base, Vala
 static void vala_return_statement_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node);
 static gpointer vala_return_statement_parent_class = NULL;
 static ValaStatementIface* vala_return_statement_vala_statement_parent_iface = NULL;
-static void vala_return_statement_dispose (GObject * obj);
+static void vala_return_statement_finalize (GObject * obj);
 
 
 
@@ -110,6 +110,7 @@ void vala_return_statement_set_return_expression (ValaReturnStatement* self, Val
 	if (self->priv->_return_expression != NULL) {
 		vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_return_expression), VALA_CODE_NODE (self));
 	}
+	g_object_notify (((GObject *) (self)), "return-expression");
 }
 
 
@@ -146,7 +147,7 @@ static void vala_return_statement_class_init (ValaReturnStatementClass * klass)
 	g_type_class_add_private (klass, sizeof (ValaReturnStatementPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_return_statement_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_return_statement_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_return_statement_dispose;
+	G_OBJECT_CLASS (klass)->finalize = vala_return_statement_finalize;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_return_statement_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_return_statement_real_accept_children;
 	VALA_CODE_NODE_CLASS (klass)->replace_expression = vala_return_statement_real_replace_expression;
@@ -164,17 +165,17 @@ static void vala_return_statement_instance_init (ValaReturnStatement * self) {
 }
 
 
-static void vala_return_statement_dispose (GObject * obj) {
+static void vala_return_statement_finalize (GObject * obj) {
 	ValaReturnStatement * self;
 	self = VALA_RETURN_STATEMENT (obj);
 	(self->priv->_return_expression == NULL ? NULL : (self->priv->_return_expression = (g_object_unref (self->priv->_return_expression), NULL)));
-	G_OBJECT_CLASS (vala_return_statement_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (vala_return_statement_parent_class)->finalize (obj);
 }
 
 
 GType vala_return_statement_get_type (void) {
 	static GType vala_return_statement_type_id = 0;
-	if (G_UNLIKELY (vala_return_statement_type_id == 0)) {
+	if (vala_return_statement_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaReturnStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_return_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaReturnStatement), 0, (GInstanceInitFunc) vala_return_statement_instance_init };
 		static const GInterfaceInfo vala_statement_info = { (GInterfaceInitFunc) vala_return_statement_vala_statement_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		vala_return_statement_type_id = g_type_register_static (VALA_TYPE_CODE_NODE, "ValaReturnStatement", &g_define_type_info, 0);
