@@ -22,7 +22,10 @@
 
 #include <vala/valascope.h>
 #include <gee/map.h>
+#include <gee/list.h>
 #include <gee/hashmap.h>
+#include <gee/arraylist.h>
+#include <gee/collection.h>
 #include <vala/valasymbol.h>
 #include <vala/valareport.h>
 #include <vala/valasourcereference.h>
@@ -34,7 +37,9 @@ struct _ValaScopePrivate {
 	ValaSymbol* _owner;
 	ValaScope* _parent_scope;
 	GeeMap* symbol_table;
+	GeeList* anonymous_members;
 };
+
 #define VALA_SCOPE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_SCOPE, ValaScopePrivate))
 enum  {
 	VALA_SCOPE_DUMMY_PROPERTY,
@@ -42,7 +47,7 @@ enum  {
 	VALA_SCOPE_PARENT_SCOPE
 };
 static gpointer vala_scope_parent_class = NULL;
-static void vala_scope_dispose (GObject * obj);
+static void vala_scope_finalize (GObject * obj);
 
 
 
@@ -69,12 +74,12 @@ ValaScope* vala_scope_new (ValaSymbol* owner) {
  */
 void vala_scope_add (ValaScope* self, const char* name, ValaSymbol* sym) {
 	g_return_if_fail (VALA_IS_SCOPE (self));
-	g_return_if_fail (sym == NULL || VALA_IS_SYMBOL (sym));
+	g_return_if_fail (VALA_IS_SYMBOL (sym));
 	if (name != NULL) {
 		if (self->priv->symbol_table == NULL) {
 			GeeMap* _tmp0;
 			_tmp0 = NULL;
-			self->priv->symbol_table = (_tmp0 = GEE_MAP (gee_hash_map_new (G_TYPE_STRING, ((GBoxedCopyFunc) g_strdup), g_free, VALA_TYPE_SYMBOL, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_str_hash, g_str_equal, g_direct_equal)), (self->priv->symbol_table == NULL ? NULL : (self->priv->symbol_table = (g_object_unref (self->priv->symbol_table), NULL))), _tmp0);
+			self->priv->symbol_table = (_tmp0 = GEE_MAP (gee_hash_map_new (G_TYPE_STRING, ((GBoxedCopyFunc) (g_strdup)), g_free, VALA_TYPE_SYMBOL, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_str_hash, g_str_equal, g_direct_equal)), (self->priv->symbol_table == NULL ? NULL : (self->priv->symbol_table = (g_object_unref (self->priv->symbol_table), NULL))), _tmp0);
 		} else {
 			ValaSymbol* _tmp1;
 			gboolean _tmp2;
@@ -85,18 +90,32 @@ void vala_scope_add (ValaScope* self, const char* name, ValaSymbol* sym) {
 				vala_code_node_set_error (VALA_CODE_NODE (self->priv->_owner), TRUE);
 				_tmp4 = NULL;
 				_tmp3 = NULL;
-				vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (self->priv->_owner)), (_tmp4 = g_strdup_printf ("`%s' already contains a definition for `%s'", (_tmp3 = vala_symbol_get_full_name (self->priv->_owner)), name)));
+				vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (sym)), (_tmp4 = g_strdup_printf ("`%s' already contains a definition for `%s'", (_tmp3 = vala_symbol_get_full_name (self->priv->_owner)), name)));
 				_tmp4 = (g_free (_tmp4), NULL);
 				_tmp3 = (g_free (_tmp3), NULL);
 				return;
 			}
 		}
-		gee_map_set (((GeeMap*) self->priv->symbol_table), name, sym);
+		gee_map_set (((GeeMap*) (self->priv->symbol_table)), ((const char*) (name)), sym);
+	} else {
+		if (self->priv->anonymous_members == NULL) {
+			GeeList* _tmp5;
+			_tmp5 = NULL;
+			self->priv->anonymous_members = (_tmp5 = GEE_LIST (gee_array_list_new (VALA_TYPE_SYMBOL, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal)), (self->priv->anonymous_members == NULL ? NULL : (self->priv->anonymous_members = (g_object_unref (self->priv->anonymous_members), NULL))), _tmp5);
+		}
+		gee_collection_add (GEE_COLLECTION (self->priv->anonymous_members), sym);
 	}
 	vala_symbol_set_owner (sym, self);
 }
 
 
+void vala_scope_remove (ValaScope* self, const char* name) {
+	g_return_if_fail (VALA_IS_SCOPE (self));
+	g_return_if_fail (name != NULL);
+	gee_map_remove (self->priv->symbol_table, name);
+}
+
+
 /**
  * Returns the symbol stored in the symbol table with the specified
  * name.
@@ -107,10 +126,11 @@ void vala_scope_add (ValaScope* self, const char* name, ValaSymbol* sym) {
 ValaSymbol* vala_scope_lookup (ValaScope* self, const char* name) {
 	ValaSymbol* sym;
 	g_return_val_if_fail (VALA_IS_SCOPE (self), NULL);
+	g_return_val_if_fail (name != NULL, NULL);
 	if (self->priv->symbol_table == NULL) {
 		return NULL;
 	}
-	sym = ((ValaSymbol*) gee_map_get (((GeeMap*) self->priv->symbol_table), name));
+	sym = ((ValaSymbol*) (gee_map_get (((GeeMap*) (self->priv->symbol_table)), name)));
 	if (sym != NULL && !vala_symbol_get_active (sym)) {
 		ValaSymbol* _tmp1;
 		_tmp1 = NULL;
@@ -153,6 +173,7 @@ ValaSymbol* vala_scope_get_owner (ValaScope* self) {
 void vala_scope_set_owner (ValaScope* self, ValaSymbol* value) {
 	g_return_if_fail (VALA_IS_SCOPE (self));
 	self->priv->_owner = value;
+	g_object_notify (((GObject *) (self)), "owner");
 }
 
 
@@ -165,6 +186,7 @@ ValaScope* vala_scope_get_parent_scope (ValaScope* self) {
 void vala_scope_set_parent_scope (ValaScope* self, ValaScope* value) {
 	g_return_if_fail (VALA_IS_SCOPE (self));
 	self->priv->_parent_scope = value;
+	g_object_notify (((GObject *) (self)), "parent-scope");
 }
 
 
@@ -207,29 +229,30 @@ static void vala_scope_class_init (ValaScopeClass * klass) {
 	g_type_class_add_private (klass, sizeof (ValaScopePrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_scope_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_scope_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_scope_dispose;
+	G_OBJECT_CLASS (klass)->finalize = vala_scope_finalize;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SCOPE_OWNER, g_param_spec_object ("owner", "owner", "owner", VALA_TYPE_SYMBOL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SCOPE_PARENT_SCOPE, g_param_spec_object ("parent-scope", "parent-scope", "parent-scope", VALA_TYPE_SCOPE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
-static void vala_scope_init (ValaScope * self) {
+static void vala_scope_instance_init (ValaScope * self) {
 	self->priv = VALA_SCOPE_GET_PRIVATE (self);
 }
 
 
-static void vala_scope_dispose (GObject * obj) {
+static void vala_scope_finalize (GObject * obj) {
 	ValaScope * self;
 	self = VALA_SCOPE (obj);
 	(self->priv->symbol_table == NULL ? NULL : (self->priv->symbol_table = (g_object_unref (self->priv->symbol_table), NULL)));
-	G_OBJECT_CLASS (vala_scope_parent_class)->dispose (obj);
+	(self->priv->anonymous_members == NULL ? NULL : (self->priv->anonymous_members = (g_object_unref (self->priv->anonymous_members), NULL)));
+	G_OBJECT_CLASS (vala_scope_parent_class)->finalize (obj);
 }
 
 
 GType vala_scope_get_type (void) {
 	static GType vala_scope_type_id = 0;
-	if (G_UNLIKELY (vala_scope_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaScopeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_scope_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaScope), 0, (GInstanceInitFunc) vala_scope_init };
+	if (vala_scope_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (ValaScopeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_scope_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaScope), 0, (GInstanceInitFunc) vala_scope_instance_init };
 		vala_scope_type_id = g_type_register_static (G_TYPE_OBJECT, "ValaScope", &g_define_type_info, 0);
 	}
 	return vala_scope_type_id;
