@@ -61,7 +61,7 @@ static void vala_signal_real_set_lock_used (ValaLockable* base, gboolean used);
 static void vala_signal_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type);
 static gpointer vala_signal_parent_class = NULL;
 static ValaLockableIface* vala_signal_vala_lockable_parent_iface = NULL;
-static void vala_signal_dispose (GObject * obj);
+static void vala_signal_finalize (GObject * obj);
 static int _vala_strcmp0 (const char * str1, const char * str2);
 
 
@@ -119,7 +119,7 @@ ValaDelegate* vala_signal_get_delegate (ValaSignal* self, ValaDataType* sender_t
 	ValaDelegate* generated_delegate;
 	ValaDataType* sender_param_type;
 	ValaFormalParameter* sender_param;
-	ValaDelegate* _tmp0;
+	ValaDelegate* _tmp1;
 	g_return_val_if_fail (VALA_IS_SIGNAL (self), NULL);
 	g_return_val_if_fail (VALA_IS_DATA_TYPE (sender_type), NULL);
 	generated_delegate = vala_delegate_new (NULL, vala_signal_get_return_type (self), NULL);
@@ -138,14 +138,17 @@ ValaDelegate* vala_signal_get_delegate (ValaSignal* self, ValaDataType* sender_t
 			ValaFormalParameter* param;
 			param = ((ValaFormalParameter*) (gee_list_get (GEE_LIST (param_collection), param_it)));
 			{
-				vala_delegate_add_parameter (generated_delegate, param);
+				ValaFormalParameter* _tmp0;
+				_tmp0 = NULL;
+				vala_delegate_add_parameter (generated_delegate, (_tmp0 = vala_formal_parameter_copy (param)));
+				(_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL)));
 				(param == NULL ? NULL : (param = (g_object_unref (param), NULL)));
 			}
 		}
 	}
 	vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (self)), NULL, VALA_SYMBOL (generated_delegate));
-	_tmp0 = NULL;
-	return (_tmp0 = generated_delegate, (sender_param_type == NULL ? NULL : (sender_param_type = (g_object_unref (sender_param_type), NULL))), (sender_param == NULL ? NULL : (sender_param = (g_object_unref (sender_param), NULL))), _tmp0);
+	_tmp1 = NULL;
+	return (_tmp1 = generated_delegate, (sender_param_type == NULL ? NULL : (sender_param_type = (g_object_unref (sender_param_type), NULL))), (sender_param == NULL ? NULL : (sender_param = (g_object_unref (sender_param), NULL))), _tmp1);
 }
 
 
@@ -342,6 +345,7 @@ void vala_signal_set_return_type (ValaSignal* self, ValaDataType* value) {
 	_tmp1 = NULL;
 	self->priv->_return_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_return_type == NULL ? NULL : (self->priv->_return_type = (g_object_unref (self->priv->_return_type), NULL))), _tmp2);
 	vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_return_type), VALA_CODE_NODE (self));
+	g_object_notify (((GObject *) (self)), "return-type");
 }
 
 
@@ -354,6 +358,7 @@ gboolean vala_signal_get_has_emitter (ValaSignal* self) {
 void vala_signal_set_has_emitter (ValaSignal* self, gboolean value) {
 	g_return_if_fail (VALA_IS_SIGNAL (self));
 	self->priv->_has_emitter = value;
+	g_object_notify (((GObject *) (self)), "has-emitter");
 }
 
 
@@ -366,6 +371,7 @@ gboolean vala_signal_get_is_virtual (ValaSignal* self) {
 void vala_signal_set_is_virtual (ValaSignal* self, gboolean value) {
 	g_return_if_fail (VALA_IS_SIGNAL (self));
 	self->priv->_is_virtual = value;
+	g_object_notify (((GObject *) (self)), "is-virtual");
 }
 
 
@@ -414,7 +420,7 @@ static void vala_signal_class_init (ValaSignalClass * klass) {
 	g_type_class_add_private (klass, sizeof (ValaSignalPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_signal_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_signal_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_signal_dispose;
+	G_OBJECT_CLASS (klass)->finalize = vala_signal_finalize;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_signal_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_signal_real_accept_children;
 	VALA_CODE_NODE_CLASS (klass)->replace_type = vala_signal_real_replace_type;
@@ -438,20 +444,20 @@ static void vala_signal_instance_init (ValaSignal * self) {
 }
 
 
-static void vala_signal_dispose (GObject * obj) {
+static void vala_signal_finalize (GObject * obj) {
 	ValaSignal * self;
 	self = VALA_SIGNAL (obj);
 	(self->priv->parameters == NULL ? NULL : (self->priv->parameters = (g_object_unref (self->priv->parameters), NULL)));
 	(self->priv->generated_method == NULL ? NULL : (self->priv->generated_method = (g_object_unref (self->priv->generated_method), NULL)));
 	self->priv->cname = (g_free (self->priv->cname), NULL);
 	(self->priv->_return_type == NULL ? NULL : (self->priv->_return_type = (g_object_unref (self->priv->_return_type), NULL)));
-	G_OBJECT_CLASS (vala_signal_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (vala_signal_parent_class)->finalize (obj);
 }
 
 
 GType vala_signal_get_type (void) {
 	static GType vala_signal_type_id = 0;
-	if (G_UNLIKELY (vala_signal_type_id == 0)) {
+	if (vala_signal_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaSignalClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_signal_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaSignal), 0, (GInstanceInitFunc) vala_signal_instance_init };
 		static const GInterfaceInfo vala_lockable_info = { (GInterfaceInitFunc) vala_signal_vala_lockable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		vala_signal_type_id = g_type_register_static (VALA_TYPE_MEMBER, "ValaSignal", &g_define_type_info, 0);
