@@ -39,7 +39,7 @@ static ValaDataType* vala_signal_type_real_get_return_type (ValaDataType* base);
 static GeeList* vala_signal_type_real_get_parameters (ValaDataType* base);
 static ValaDataType* vala_signal_type_real_copy (ValaDataType* base);
 static gpointer vala_signal_type_parent_class = NULL;
-static void vala_signal_type_dispose (GObject * obj);
+static void vala_signal_type_finalize (GObject * obj);
 
 
 
@@ -95,6 +95,7 @@ void vala_signal_type_set_signal_symbol (ValaSignalType* self, ValaSignal* value
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_signal_symbol = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_signal_symbol == NULL ? NULL : (self->priv->_signal_symbol = (g_object_unref (self->priv->_signal_symbol), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "signal-symbol");
 }
 
 
@@ -131,7 +132,7 @@ static void vala_signal_type_class_init (ValaSignalTypeClass * klass) {
 	g_type_class_add_private (klass, sizeof (ValaSignalTypePrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_signal_type_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_signal_type_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_signal_type_dispose;
+	G_OBJECT_CLASS (klass)->finalize = vala_signal_type_finalize;
 	VALA_DATA_TYPE_CLASS (klass)->is_invokable = vala_signal_type_real_is_invokable;
 	VALA_DATA_TYPE_CLASS (klass)->get_return_type = vala_signal_type_real_get_return_type;
 	VALA_DATA_TYPE_CLASS (klass)->get_parameters = vala_signal_type_real_get_parameters;
@@ -145,17 +146,17 @@ static void vala_signal_type_instance_init (ValaSignalType * self) {
 }
 
 
-static void vala_signal_type_dispose (GObject * obj) {
+static void vala_signal_type_finalize (GObject * obj) {
 	ValaSignalType * self;
 	self = VALA_SIGNAL_TYPE (obj);
 	(self->priv->_signal_symbol == NULL ? NULL : (self->priv->_signal_symbol = (g_object_unref (self->priv->_signal_symbol), NULL)));
-	G_OBJECT_CLASS (vala_signal_type_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (vala_signal_type_parent_class)->finalize (obj);
 }
 
 
 GType vala_signal_type_get_type (void) {
 	static GType vala_signal_type_type_id = 0;
-	if (G_UNLIKELY (vala_signal_type_type_id == 0)) {
+	if (vala_signal_type_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaSignalTypeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_signal_type_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaSignalType), 0, (GInstanceInitFunc) vala_signal_type_instance_init };
 		vala_signal_type_type_id = g_type_register_static (VALA_TYPE_DATA_TYPE, "ValaSignalType", &g_define_type_info, 0);
 	}
