@@ -22,14 +22,16 @@
 
 #include <vala/valasourcefile.h>
 #include <gee/arraylist.h>
+#include <gee/hashset.h>
 #include <gee/collection.h>
 #include <gee/readonlylist.h>
+#include <gee/readonlyset.h>
 #include <glib/gstdio.h>
 #include <vala/valasourcefilecycle.h>
 #include <vala/valacodecontext.h>
 #include <vala/valanamespacereference.h>
-#include <vala/valacodevisitor.h>
 #include <vala/valasymbol.h>
+#include <vala/valacodevisitor.h>
 #include <vala/valatypesymbol.h>
 #include <vala/valamethod.h>
 #include <vala/valafield.h>
@@ -62,6 +64,7 @@ struct _ValaSourceFilePrivate {
 	GeeList* source_internal_includes;
 	GeeList* header_internal_full_dependencies;
 	GeeList* header_internal_dependencies;
+	GeeSet* source_symbol_dependencies;
 	GeeArrayList* source_array;
 	GMappedFile* mapped_file;
 };
@@ -82,7 +85,7 @@ static char* vala_source_file_get_destination_directory (ValaSourceFile* self);
 static char* vala_source_file_get_basename (ValaSourceFile* self);
 static void vala_source_file_read_source_file (ValaSourceFile* self);
 static gpointer vala_source_file_parent_class = NULL;
-static void vala_source_file_dispose (GObject * obj);
+static void vala_source_file_finalize (GObject * obj);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
 static int _vala_strcmp0 (const char * str1, const char * str2);
 
@@ -401,6 +404,7 @@ void vala_source_file_add_symbol_dependency (ValaSourceFile* self, ValaSymbol* s
 		}
 	}
 	if (dep_type == VALA_SOURCE_FILE_DEPENDENCY_TYPE_SOURCE) {
+		gee_collection_add (GEE_COLLECTION (self->priv->source_symbol_dependencies), s);
 		if (vala_symbol_get_external_package (s)) {
 			{
 				GeeList* fn_collection;
@@ -594,6 +598,12 @@ GeeList* vala_source_file_get_header_internal_dependencies (ValaSourceFile* self
 }
 
 
+GeeSet* vala_source_file_get_source_symbol_dependencies (ValaSourceFile* self) {
+	g_return_val_if_fail (VALA_IS_SOURCE_FILE (self), NULL);
+	return GEE_SET (gee_read_only_set_new (VALA_TYPE_SYMBOL, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, self->priv->source_symbol_dependencies));
+}
+
+
 /**
  * Returns the requested line from this file, loading it if needed.
  *
@@ -728,6 +738,7 @@ void vala_source_file_set_filename (ValaSourceFile* self, const char* value) {
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_filename = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_filename = (g_free (self->priv->_filename), NULL)), _tmp2);
+	g_object_notify (((GObject *) (self)), "filename");
 }
 
 
@@ -744,6 +755,7 @@ void vala_source_file_set_comment (ValaSourceFile* self, const char* value) {
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_comment = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_comment = (g_free (self->priv->_comment), NULL)), _tmp2);
+	g_object_notify (((GObject *) (self)), "comment");
 }
 
 
@@ -756,6 +768,7 @@ gboolean vala_source_file_get_external_package (ValaSourceFile* self) {
 void vala_source_file_set_external_package (ValaSourceFile* self, gboolean value) {
 	g_return_if_fail (VALA_IS_SOURCE_FILE (self));
 	self->priv->_external_package = value;
+	g_object_notify (((GObject *) (self)), "external-package");
 }
 
 
@@ -772,6 +785,7 @@ void vala_source_file_set_cycle (ValaSourceFile* self, ValaSourceFileCycle* valu
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_cycle = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_cycle == NULL ? NULL : (self->priv->_cycle = (g_object_unref (self->priv->_cycle), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "cycle");
 }
 
 
@@ -784,6 +798,7 @@ gboolean vala_source_file_get_is_cycle_head (ValaSourceFile* self) {
 void vala_source_file_set_is_cycle_head (ValaSourceFile* self, gboolean value) {
 	g_return_if_fail (VALA_IS_SOURCE_FILE (self));
 	self->priv->_is_cycle_head = value;
+	g_object_notify (((GObject *) (self)), "is-cycle-head");
 }
 
 
@@ -796,6 +811,7 @@ gint vala_source_file_get_mark (ValaSourceFile* self) {
 void vala_source_file_set_mark (ValaSourceFile* self, gint value) {
 	g_return_if_fail (VALA_IS_SOURCE_FILE (self));
 	self->priv->_mark = value;
+	g_object_notify (((GObject *) (self)), "mark");
 }
 
 
@@ -808,6 +824,7 @@ ValaCodeContext* vala_source_file_get_context (ValaSourceFile* self) {
 void vala_source_file_set_context (ValaSourceFile* self, ValaCodeContext* value) {
 	g_return_if_fail (VALA_IS_SOURCE_FILE (self));
 	self->priv->_context = value;
+	g_object_notify (((GObject *) (self)), "context");
 }
 
 
@@ -880,7 +897,7 @@ static void vala_source_file_class_init (ValaSourceFileClass * klass) {
 	g_type_class_add_private (klass, sizeof (ValaSourceFilePrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_source_file_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_source_file_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_source_file_dispose;
+	G_OBJECT_CLASS (klass)->finalize = vala_source_file_finalize;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SOURCE_FILE_FILENAME, g_param_spec_string ("filename", "filename", "filename", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SOURCE_FILE_COMMENT, g_param_spec_string ("comment", "comment", "comment", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SOURCE_FILE_EXTERNAL_PACKAGE, g_param_spec_boolean ("external-package", "external-package", "external-package", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
@@ -904,12 +921,13 @@ static void vala_source_file_instance_init (ValaSourceFile * self) {
 	self->priv->source_internal_includes = GEE_LIST (gee_array_list_new (G_TYPE_STRING, ((GBoxedCopyFunc) (g_strdup)), g_free, g_direct_equal));
 	self->priv->header_internal_full_dependencies = GEE_LIST (gee_array_list_new (VALA_TYPE_SOURCE_FILE, NULL, NULL, g_direct_equal));
 	self->priv->header_internal_dependencies = GEE_LIST (gee_array_list_new (VALA_TYPE_SOURCE_FILE, NULL, NULL, g_direct_equal));
+	self->priv->source_symbol_dependencies = GEE_SET (gee_hash_set_new (VALA_TYPE_SYMBOL, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_hash, g_direct_equal));
 	self->priv->source_array = NULL;
 	self->priv->mapped_file = NULL;
 }
 
 
-static void vala_source_file_dispose (GObject * obj) {
+static void vala_source_file_finalize (GObject * obj) {
 	ValaSourceFile * self;
 	self = VALA_SOURCE_FILE (obj);
 	self->priv->_filename = (g_free (self->priv->_filename), NULL);
@@ -926,15 +944,16 @@ static void vala_source_file_dispose (GObject * obj) {
 	(self->priv->source_internal_includes == NULL ? NULL : (self->priv->source_internal_includes = (g_object_unref (self->priv->source_internal_includes), NULL)));
 	(self->priv->header_internal_full_dependencies == NULL ? NULL : (self->priv->header_internal_full_dependencies = (g_object_unref (self->priv->header_internal_full_dependencies), NULL)));
 	(self->priv->header_internal_dependencies == NULL ? NULL : (self->priv->header_internal_dependencies = (g_object_unref (self->priv->header_internal_dependencies), NULL)));
+	(self->priv->source_symbol_dependencies == NULL ? NULL : (self->priv->source_symbol_dependencies = (g_object_unref (self->priv->source_symbol_dependencies), NULL)));
 	(self->priv->source_array == NULL ? NULL : (self->priv->source_array = (g_object_unref (self->priv->source_array), NULL)));
 	(self->priv->mapped_file == NULL ? NULL : (self->priv->mapped_file = (g_mapped_file_free (self->priv->mapped_file), NULL)));
-	G_OBJECT_CLASS (vala_source_file_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (vala_source_file_parent_class)->finalize (obj);
 }
 
 
 GType vala_source_file_get_type (void) {
 	static GType vala_source_file_type_id = 0;
-	if (G_UNLIKELY (vala_source_file_type_id == 0)) {
+	if (vala_source_file_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaSourceFileClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_source_file_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaSourceFile), 0, (GInstanceInitFunc) vala_source_file_instance_init };
 		vala_source_file_type_id = g_type_register_static (G_TYPE_OBJECT, "ValaSourceFile", &g_define_type_info, 0);
 	}
