@@ -38,7 +38,7 @@ static void vala_statement_base_init (ValaStatementIface * iface) {
 
 GType vala_statement_get_type (void) {
 	static GType vala_statement_type_id = 0;
-	if (G_UNLIKELY (vala_statement_type_id == 0)) {
+	if (vala_statement_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaStatementIface), (GBaseInitFunc) vala_statement_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL };
 		vala_statement_type_id = g_type_register_static (G_TYPE_INTERFACE, "ValaStatement", &g_define_type_info, 0);
 		g_type_interface_add_prerequisite (vala_statement_type_id, VALA_TYPE_CODE_NODE);
