@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,8 +20,8 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#ifndef __VALASTATEMENT_H__
-#define __VALASTATEMENT_H__
+#ifndef __VALA_VALASTATEMENT_H__
+#define __VALA_VALASTATEMENT_H__
 
 #include <glib.h>
 #include <glib-object.h>
@@ -40,11 +40,13 @@ G_BEGIN_DECLS
  * Interface for all statement types.
  */
 struct _ValaStatementIface {
-	GTypeInterface parent;
+	GTypeInterface parent_iface;
 };
 
+
 GType vala_statement_get_type (void);
 
+
 G_END_DECLS
 
 #endif
