@@ -100,8 +100,9 @@ static char* vala_struct_real_get_default_value (ValaTypeSymbol* base);
 static void vala_struct_set_default_value (ValaStruct* self, const char* value);
 static gint vala_struct_real_get_type_parameter_index (ValaTypeSymbol* base, const char* name);
 static void vala_struct_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type);
+static gboolean vala_struct_real_is_subtype_of (ValaTypeSymbol* base, ValaTypeSymbol* t);
 static gpointer vala_struct_parent_class = NULL;
-static void vala_struct_dispose (GObject * obj);
+static void vala_struct_finalize (GObject * obj);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
 static int _vala_strcmp0 (const char * str1, const char * str2);
 
@@ -1102,6 +1103,33 @@ static void vala_struct_real_replace_type (ValaCodeNode* base, ValaDataType* old
 }
 
 
+static gboolean vala_struct_real_is_subtype_of (ValaTypeSymbol* base, ValaTypeSymbol* t) {
+	ValaStruct * self;
+	self = VALA_STRUCT (base);
+	g_return_val_if_fail (VALA_IS_TYPESYMBOL (t), FALSE);
+	if (VALA_TYPESYMBOL (self) == t) {
+		return TRUE;
+	}
+	{
+		GeeList* base_type_collection;
+		int base_type_it;
+		base_type_collection = self->priv->base_types;
+		for (base_type_it = 0; base_type_it < gee_collection_get_size (GEE_COLLECTION (base_type_collection)); base_type_it = base_type_it + 1) {
+			ValaDataType* base_type;
+			base_type = ((ValaDataType*) (gee_list_get (GEE_LIST (base_type_collection), base_type_it)));
+			{
+				if (vala_data_type_get_data_type (base_type) != NULL && vala_typesymbol_is_subtype_of (vala_data_type_get_data_type (base_type), t)) {
+					gboolean _tmp1;
+					return (_tmp1 = TRUE, (base_type == NULL ? NULL : (base_type = (g_object_unref (base_type), NULL))), _tmp1);
+				}
+				(base_type == NULL ? NULL : (base_type = (g_object_unref (base_type), NULL)));
+			}
+		}
+	}
+	return FALSE;
+}
+
+
 ValaMethod* vala_struct_get_default_construction_method (ValaStruct* self) {
 	g_return_val_if_fail (VALA_IS_STRUCT (self), NULL);
 	return self->priv->_default_construction_method;
@@ -1115,6 +1143,7 @@ void vala_struct_set_default_construction_method (ValaStruct* self, ValaMethod*
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_default_construction_method = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_default_construction_method == NULL ? NULL : (self->priv->_default_construction_method = (g_object_unref (self->priv->_default_construction_method), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "default-construction-method");
 }
 
 
@@ -1151,7 +1180,7 @@ static void vala_struct_class_init (ValaStructClass * klass) {
 	g_type_class_add_private (klass, sizeof (ValaStructPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_struct_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_struct_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_struct_dispose;
+	G_OBJECT_CLASS (klass)->finalize = vala_struct_finalize;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_struct_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_struct_real_accept_children;
 	VALA_TYPESYMBOL_CLASS (klass)->get_cname = vala_struct_real_get_cname;
@@ -1166,6 +1195,7 @@ static void vala_struct_class_init (ValaStructClass * klass) {
 	VALA_TYPESYMBOL_CLASS (klass)->get_default_value = vala_struct_real_get_default_value;
 	VALA_TYPESYMBOL_CLASS (klass)->get_type_parameter_index = vala_struct_real_get_type_parameter_index;
 	VALA_CODE_NODE_CLASS (klass)->replace_type = vala_struct_real_replace_type;
+	VALA_TYPESYMBOL_CLASS (klass)->is_subtype_of = vala_struct_real_is_subtype_of;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_STRUCT_DEFAULT_CONSTRUCTION_METHOD, g_param_spec_object ("default-construction-method", "default-construction-method", "default-construction-method", VALA_TYPE_METHOD, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
@@ -1181,7 +1211,7 @@ static void vala_struct_instance_init (ValaStruct * self) {
 }
 
 
-static void vala_struct_dispose (GObject * obj) {
+static void vala_struct_finalize (GObject * obj) {
 	ValaStruct * self;
 	self = VALA_STRUCT (obj);
 	(self->priv->type_parameters == NULL ? NULL : (self->priv->type_parameters = (g_object_unref (self->priv->type_parameters), NULL)));
@@ -1202,13 +1232,13 @@ static void vala_struct_dispose (GObject * obj) {
 	self->priv->default_value = (g_free (self->priv->default_value), NULL);
 	self->priv->type_signature = (g_free (self->priv->type_signature), NULL);
 	(self->priv->_default_construction_method == NULL ? NULL : (self->priv->_default_construction_method = (g_object_unref (self->priv->_default_construction_method), NULL)));
-	G_OBJECT_CLASS (vala_struct_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (vala_struct_parent_class)->finalize (obj);
 }
 
 
 GType vala_struct_get_type (void) {
 	static GType vala_struct_type_id = 0;
-	if (G_UNLIKELY (vala_struct_type_id == 0)) {
+	if (vala_struct_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaStructClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_struct_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaStruct), 0, (GInstanceInitFunc) vala_struct_instance_init };
 		vala_struct_type_id = g_type_register_static (VALA_TYPE_TYPESYMBOL, "ValaStruct", &g_define_type_info, 0);
 	}
