@@ -43,7 +43,7 @@ enum  {
 static void vala_switch_section_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_switch_section_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static gpointer vala_switch_section_parent_class = NULL;
-static void vala_switch_section_dispose (GObject * obj);
+static void vala_switch_section_finalize (GObject * obj);
 
 
 
@@ -152,7 +152,7 @@ static void vala_switch_section_real_accept_children (ValaCodeNode* base, ValaCo
 static void vala_switch_section_class_init (ValaSwitchSectionClass * klass) {
 	vala_switch_section_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaSwitchSectionPrivate));
-	G_OBJECT_CLASS (klass)->dispose = vala_switch_section_dispose;
+	G_OBJECT_CLASS (klass)->finalize = vala_switch_section_finalize;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_switch_section_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_switch_section_real_accept_children;
 }
@@ -164,17 +164,17 @@ static void vala_switch_section_instance_init (ValaSwitchSection * self) {
 }
 
 
-static void vala_switch_section_dispose (GObject * obj) {
+static void vala_switch_section_finalize (GObject * obj) {
 	ValaSwitchSection * self;
 	self = VALA_SWITCH_SECTION (obj);
 	(self->priv->labels == NULL ? NULL : (self->priv->labels = (g_object_unref (self->priv->labels), NULL)));
-	G_OBJECT_CLASS (vala_switch_section_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (vala_switch_section_parent_class)->finalize (obj);
 }
 
 
 GType vala_switch_section_get_type (void) {
 	static GType vala_switch_section_type_id = 0;
-	if (G_UNLIKELY (vala_switch_section_type_id == 0)) {
+	if (vala_switch_section_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaSwitchSectionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_switch_section_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaSwitchSection), 0, (GInstanceInitFunc) vala_switch_section_instance_init };
 		vala_switch_section_type_id = g_type_register_static (VALA_TYPE_BLOCK, "ValaSwitchSection", &g_define_type_info, 0);
 	}
