@@ -34,9 +34,9 @@ struct _ValaSymbolPrivate {
 	char* _name;
 	gboolean _active;
 	ValaSymbolAccessibility _access;
+	gboolean _external;
 	ValaScope* _owner;
 	ValaScope* _scope;
-	gboolean _external;
 };
 
 #define VALA_SYMBOL_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_SYMBOL, ValaSymbolPrivate))
@@ -57,7 +57,7 @@ static char* vala_symbol_real_get_lower_case_cprefix (ValaSymbol* self);
 static GeeList* vala_symbol_real_get_cheader_filenames (ValaSymbol* self);
 static GObject * vala_symbol_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
 static gpointer vala_symbol_parent_class = NULL;
-static void vala_symbol_dispose (GObject * obj);
+static void vala_symbol_finalize (GObject * obj);
 
 
 
@@ -68,19 +68,23 @@ static void vala_symbol_dispose (GObject * obj);
  */
 gboolean vala_symbol_is_internal_symbol (ValaSymbol* self) {
 	g_return_val_if_fail (VALA_IS_SYMBOL (self), FALSE);
+	if (!self->priv->_external && vala_symbol_get_external_package (self)) {
+		/* non-external symbols in VAPI files are internal symbols*/
+		return TRUE;
+	}
 	{
-		ValaSymbol* _tmp0;
-		ValaSymbol* sym;
-		ValaSymbol* _tmp2;
 		ValaSymbol* _tmp1;
-		_tmp0 = NULL;
-		sym = (_tmp0 = self, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
-		_tmp2 = NULL;
+		ValaSymbol* sym;
+		ValaSymbol* _tmp3;
+		ValaSymbol* _tmp2;
 		_tmp1 = NULL;
-		for (; NULL != sym; sym = (_tmp2 = (_tmp1 = vala_symbol_get_parent_symbol (sym), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (sym == NULL ? NULL : (sym = (g_object_unref (sym), NULL))), _tmp2)) {
+		sym = (_tmp1 = self, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
+		_tmp3 = NULL;
+		_tmp2 = NULL;
+		for (; NULL != sym; sym = (_tmp3 = (_tmp2 = vala_symbol_get_parent_symbol (sym), (_tmp2 == NULL ? NULL : g_object_ref (_tmp2))), (sym == NULL ? NULL : (sym = (g_object_unref (sym), NULL))), _tmp3)) {
 			if (VALA_SYMBOL_ACCESSIBILITY_PRIVATE == sym->priv->_access) {
-				gboolean _tmp3;
-				return (_tmp3 = TRUE, (sym == NULL ? NULL : (sym = (g_object_unref (sym), NULL))), _tmp3);
+				gboolean _tmp4;
+				return (_tmp4 = TRUE, (sym == NULL ? NULL : (sym = (g_object_unref (sym), NULL))), _tmp4);
 			}
 		}
 		(sym == NULL ? NULL : (sym = (g_object_unref (sym), NULL)));
@@ -258,8 +262,8 @@ char* vala_symbol_lower_case_to_camel_case (const char* lower_case) {
 	GString* result;
 	const char* i;
 	gboolean last_underscore;
-	const char* _tmp0;
-	char* _tmp1;
+	const char* _tmp2;
+	char* _tmp3;
 	g_return_val_if_fail (lower_case != NULL, NULL);
 	result = g_string_new ("");
 	i = lower_case;
@@ -270,18 +274,27 @@ char* vala_symbol_lower_case_to_camel_case (const char* lower_case) {
 		if (c == '_') {
 			last_underscore = TRUE;
 		} else {
-			if (last_underscore) {
-				g_string_append_unichar (result, g_unichar_toupper (c));
-				last_underscore = FALSE;
+			if (g_unichar_isupper (c)) {
+				const char* _tmp0;
+				char* _tmp1;
+				/* original string is not lower_case, don't apply transformation*/
+				_tmp0 = NULL;
+				_tmp1 = NULL;
+				return (_tmp1 = (_tmp0 = lower_case, (_tmp0 == NULL ? NULL : g_strdup (_tmp0))), (result == NULL ? NULL : (result = (g_string_free (result, TRUE), NULL))), _tmp1);
 			} else {
-				g_string_append_unichar (result, c);
+				if (last_underscore) {
+					g_string_append_unichar (result, g_unichar_toupper (c));
+					last_underscore = FALSE;
+				} else {
+					g_string_append_unichar (result, c);
+				}
 			}
 		}
 		i = g_utf8_next_char (i);
 	}
-	_tmp0 = NULL;
-	_tmp1 = NULL;
-	return (_tmp1 = (_tmp0 = result->str, (_tmp0 == NULL ? NULL : g_strdup (_tmp0))), (result == NULL ? NULL : (result = (g_string_free (result, TRUE), NULL))), _tmp1);
+	_tmp2 = NULL;
+	_tmp3 = NULL;
+	return (_tmp3 = (_tmp2 = result->str, (_tmp2 == NULL ? NULL : g_strdup (_tmp2))), (result == NULL ? NULL : (result = (g_string_free (result, TRUE), NULL))), _tmp3);
 }
 
 
@@ -331,6 +344,7 @@ void vala_symbol_set_owner (ValaSymbol* self, ValaScope* value) {
 	g_return_if_fail (VALA_IS_SYMBOL (self));
 	self->priv->_owner = value;
 	vala_scope_set_parent_scope (self->priv->_scope, value);
+	g_object_notify (((GObject *) (self)), "owner");
 }
 
 
@@ -347,6 +361,7 @@ void vala_symbol_set_name (ValaSymbol* self, const char* value) {
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_name = (g_free (self->priv->_name), NULL)), _tmp2);
+	g_object_notify (((GObject *) (self)), "name");
 }
 
 
@@ -359,6 +374,7 @@ gboolean vala_symbol_get_active (ValaSymbol* self) {
 void vala_symbol_set_active (ValaSymbol* self, gboolean value) {
 	g_return_if_fail (VALA_IS_SYMBOL (self));
 	self->priv->_active = value;
+	g_object_notify (((GObject *) (self)), "active");
 }
 
 
@@ -371,6 +387,7 @@ ValaSymbolAccessibility vala_symbol_get_access (ValaSymbol* self) {
 void vala_symbol_set_access (ValaSymbol* self, ValaSymbolAccessibility value) {
 	g_return_if_fail (VALA_IS_SYMBOL (self));
 	self->priv->_access = value;
+	g_object_notify (((GObject *) (self)), "access");
 }
 
 
@@ -382,13 +399,14 @@ ValaScope* vala_symbol_get_scope (ValaSymbol* self) {
 
 gboolean vala_symbol_get_external (ValaSymbol* self) {
 	g_return_val_if_fail (VALA_IS_SYMBOL (self), FALSE);
-	return self->priv->_external || (vala_symbol_get_parent_symbol (self) != NULL && vala_symbol_get_external (vala_symbol_get_parent_symbol (self))) || vala_symbol_get_external_package (self);
+	return self->priv->_external;
 }
 
 
 void vala_symbol_set_external (ValaSymbol* self, gboolean value) {
 	g_return_if_fail (VALA_IS_SYMBOL (self));
 	self->priv->_external = value;
+	g_object_notify (((GObject *) (self)), "external");
 }
 
 
@@ -484,7 +502,7 @@ static void vala_symbol_class_init (ValaSymbolClass * klass) {
 	G_OBJECT_CLASS (klass)->get_property = vala_symbol_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_symbol_set_property;
 	G_OBJECT_CLASS (klass)->constructor = vala_symbol_constructor;
-	G_OBJECT_CLASS (klass)->dispose = vala_symbol_dispose;
+	G_OBJECT_CLASS (klass)->finalize = vala_symbol_finalize;
 	VALA_SYMBOL_CLASS (klass)->get_cprefix = vala_symbol_real_get_cprefix;
 	VALA_SYMBOL_CLASS (klass)->get_lower_case_cname = vala_symbol_real_get_lower_case_cname;
 	VALA_SYMBOL_CLASS (klass)->get_lower_case_cprefix = vala_symbol_real_get_lower_case_cprefix;
@@ -505,18 +523,18 @@ static void vala_symbol_instance_init (ValaSymbol * self) {
 }
 
 
-static void vala_symbol_dispose (GObject * obj) {
+static void vala_symbol_finalize (GObject * obj) {
 	ValaSymbol * self;
 	self = VALA_SYMBOL (obj);
 	self->priv->_name = (g_free (self->priv->_name), NULL);
 	(self->priv->_scope == NULL ? NULL : (self->priv->_scope = (g_object_unref (self->priv->_scope), NULL)));
-	G_OBJECT_CLASS (vala_symbol_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (vala_symbol_parent_class)->finalize (obj);
 }
 
 
 GType vala_symbol_get_type (void) {
 	static GType vala_symbol_type_id = 0;
-	if (G_UNLIKELY (vala_symbol_type_id == 0)) {
+	if (vala_symbol_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaSymbolClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_symbol_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaSymbol), 0, (GInstanceInitFunc) vala_symbol_instance_init };
 		vala_symbol_type_id = g_type_register_static (VALA_TYPE_CODE_NODE, "ValaSymbol", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
 	}
