@@ -101,7 +101,7 @@ static void vala_symbol_resolver_real_visit_reference_transfer_expression (ValaC
 static void vala_symbol_resolver_real_visit_lambda_expression (ValaCodeVisitor* base, ValaLambdaExpression* l);
 static void vala_symbol_resolver_real_visit_assignment (ValaCodeVisitor* base, ValaAssignment* a);
 static gpointer vala_symbol_resolver_parent_class = NULL;
-static void vala_symbol_resolver_dispose (GObject * obj);
+static void vala_symbol_resolver_finalize (GObject * obj);
 static int _vala_strcmp0 (const char * str1, const char * str2);
 
 
@@ -891,7 +891,7 @@ ValaSymbolResolver* vala_symbol_resolver_new (void) {
 static void vala_symbol_resolver_class_init (ValaSymbolResolverClass * klass) {
 	vala_symbol_resolver_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaSymbolResolverPrivate));
-	G_OBJECT_CLASS (klass)->dispose = vala_symbol_resolver_dispose;
+	G_OBJECT_CLASS (klass)->finalize = vala_symbol_resolver_finalize;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_source_file = vala_symbol_resolver_real_visit_source_file;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_class = vala_symbol_resolver_real_visit_class;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_struct = vala_symbol_resolver_real_visit_struct;
@@ -941,19 +941,19 @@ static void vala_symbol_resolver_instance_init (ValaSymbolResolver * self) {
 }
 
 
-static void vala_symbol_resolver_dispose (GObject * obj) {
+static void vala_symbol_resolver_finalize (GObject * obj) {
 	ValaSymbolResolver * self;
 	self = VALA_SYMBOL_RESOLVER (obj);
 	(self->priv->root_symbol == NULL ? NULL : (self->priv->root_symbol = (g_object_unref (self->priv->root_symbol), NULL)));
 	(self->priv->current_scope == NULL ? NULL : (self->priv->current_scope = (g_object_unref (self->priv->current_scope), NULL)));
 	(self->priv->current_using_directives == NULL ? NULL : (self->priv->current_using_directives = (g_object_unref (self->priv->current_using_directives), NULL)));
-	G_OBJECT_CLASS (vala_symbol_resolver_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (vala_symbol_resolver_parent_class)->finalize (obj);
 }
 
 
 GType vala_symbol_resolver_get_type (void) {
 	static GType vala_symbol_resolver_type_id = 0;
-	if (G_UNLIKELY (vala_symbol_resolver_type_id == 0)) {
+	if (vala_symbol_resolver_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaSymbolResolverClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_symbol_resolver_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaSymbolResolver), 0, (GInstanceInitFunc) vala_symbol_resolver_instance_init };
 		vala_symbol_resolver_type_id = g_type_register_static (VALA_TYPE_CODE_VISITOR, "ValaSymbolResolver", &g_define_type_info, 0);
 	}
