@@ -42,7 +42,7 @@ static void vala_throw_statement_real_accept_children (ValaCodeNode* base, ValaC
 static void vala_throw_statement_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node);
 static gpointer vala_throw_statement_parent_class = NULL;
 static ValaStatementIface* vala_throw_statement_vala_statement_parent_iface = NULL;
-static void vala_throw_statement_dispose (GObject * obj);
+static void vala_throw_statement_finalize (GObject * obj);
 
 
 
@@ -110,6 +110,7 @@ void vala_throw_statement_set_error_expression (ValaThrowStatement* self, ValaEx
 	if (self->priv->_error_expression != NULL) {
 		vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_error_expression), VALA_CODE_NODE (self));
 	}
+	g_object_notify (((GObject *) (self)), "error-expression");
 }
 
 
@@ -146,7 +147,7 @@ static void vala_throw_statement_class_init (ValaThrowStatementClass * klass) {
 	g_type_class_add_private (klass, sizeof (ValaThrowStatementPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_throw_statement_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_throw_statement_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_throw_statement_dispose;
+	G_OBJECT_CLASS (klass)->finalize = vala_throw_statement_finalize;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_throw_statement_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_throw_statement_real_accept_children;
 	VALA_CODE_NODE_CLASS (klass)->replace_expression = vala_throw_statement_real_replace_expression;
@@ -164,17 +165,17 @@ static void vala_throw_statement_instance_init (ValaThrowStatement * self) {
 }
 
 
-static void vala_throw_statement_dispose (GObject * obj) {
+static void vala_throw_statement_finalize (GObject * obj) {
 	ValaThrowStatement * self;
 	self = VALA_THROW_STATEMENT (obj);
 	(self->priv->_error_expression == NULL ? NULL : (self->priv->_error_expression = (g_object_unref (self->priv->_error_expression), NULL)));
-	G_OBJECT_CLASS (vala_throw_statement_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (vala_throw_statement_parent_class)->finalize (obj);
 }
 
 
 GType vala_throw_statement_get_type (void) {
 	static GType vala_throw_statement_type_id = 0;
-	if (G_UNLIKELY (vala_throw_statement_type_id == 0)) {
+	if (vala_throw_statement_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaThrowStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_throw_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaThrowStatement), 0, (GInstanceInitFunc) vala_throw_statement_instance_init };
 		static const GInterfaceInfo vala_statement_info = { (GInterfaceInitFunc) vala_throw_statement_vala_statement_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		vala_throw_statement_type_id = g_type_register_static (VALA_TYPE_CODE_NODE, "ValaThrowStatement", &g_define_type_info, 0);
