@@ -37,7 +37,7 @@ enum  {
 };
 static gboolean vala_tuple_real_is_pure (ValaExpression* base);
 static gpointer vala_tuple_parent_class = NULL;
-static void vala_tuple_dispose (GObject * obj);
+static void vala_tuple_finalize (GObject * obj);
 
 
 
@@ -73,7 +73,7 @@ static gboolean vala_tuple_real_is_pure (ValaExpression* base) {
 static void vala_tuple_class_init (ValaTupleClass * klass) {
 	vala_tuple_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaTuplePrivate));
-	G_OBJECT_CLASS (klass)->dispose = vala_tuple_dispose;
+	G_OBJECT_CLASS (klass)->finalize = vala_tuple_finalize;
 	VALA_EXPRESSION_CLASS (klass)->is_pure = vala_tuple_real_is_pure;
 }
 
@@ -84,17 +84,17 @@ static void vala_tuple_instance_init (ValaTuple * self) {
 }
 
 
-static void vala_tuple_dispose (GObject * obj) {
+static void vala_tuple_finalize (GObject * obj) {
 	ValaTuple * self;
 	self = VALA_TUPLE (obj);
 	(self->priv->expression_list == NULL ? NULL : (self->priv->expression_list = (g_object_unref (self->priv->expression_list), NULL)));
-	G_OBJECT_CLASS (vala_tuple_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (vala_tuple_parent_class)->finalize (obj);
 }
 
 
 GType vala_tuple_get_type (void) {
 	static GType vala_tuple_type_id = 0;
-	if (G_UNLIKELY (vala_tuple_type_id == 0)) {
+	if (vala_tuple_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaTupleClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_tuple_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaTuple), 0, (GInstanceInitFunc) vala_tuple_instance_init };
 		vala_tuple_type_id = g_type_register_static (VALA_TYPE_EXPRESSION, "ValaTuple", &g_define_type_info, 0);
 	}
