@@ -38,7 +38,7 @@ enum  {
 };
 static void vala_typeparameter_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static gpointer vala_typeparameter_parent_class = NULL;
-static void vala_typeparameter_dispose (GObject * obj);
+static void vala_typeparameter_finalize (GObject * obj);
 
 
 
@@ -89,7 +89,7 @@ gboolean vala_typeparameter_equals (ValaTypeParameter* self, ValaTypeParameter*
 static void vala_typeparameter_class_init (ValaTypeParameterClass * klass) {
 	vala_typeparameter_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaTypeParameterPrivate));
-	G_OBJECT_CLASS (klass)->dispose = vala_typeparameter_dispose;
+	G_OBJECT_CLASS (klass)->finalize = vala_typeparameter_finalize;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_typeparameter_real_accept;
 }
 
@@ -99,17 +99,17 @@ static void vala_typeparameter_instance_init (ValaTypeParameter * self) {
 }
 
 
-static void vala_typeparameter_dispose (GObject * obj) {
+static void vala_typeparameter_finalize (GObject * obj) {
 	ValaTypeParameter * self;
 	self = VALA_TYPEPARAMETER (obj);
 	(self->priv->array_types == NULL ? NULL : (self->priv->array_types = (g_object_unref (self->priv->array_types), NULL)));
-	G_OBJECT_CLASS (vala_typeparameter_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (vala_typeparameter_parent_class)->finalize (obj);
 }
 
 
 GType vala_typeparameter_get_type (void) {
 	static GType vala_typeparameter_type_id = 0;
-	if (G_UNLIKELY (vala_typeparameter_type_id == 0)) {
+	if (vala_typeparameter_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaTypeParameterClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_typeparameter_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaTypeParameter), 0, (GInstanceInitFunc) vala_typeparameter_instance_init };
 		vala_typeparameter_type_id = g_type_register_static (VALA_TYPE_SYMBOL, "ValaTypeParameter", &g_define_type_info, 0);
 	}
