@@ -31,6 +31,7 @@ struct _ValaUnaryExpressionPrivate {
 	ValaUnaryOperator _operator;
 	ValaExpression* _inner;
 };
+
 #define VALA_UNARY_EXPRESSION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_UNARY_EXPRESSION, ValaUnaryExpressionPrivate))
 enum  {
 	VALA_UNARY_EXPRESSION_DUMMY_PROPERTY,
@@ -38,12 +39,13 @@ enum  {
 	VALA_UNARY_EXPRESSION_INNER
 };
 static void vala_unary_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
+static void vala_unary_expression_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_unary_expression_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node);
 static char* vala_unary_expression_get_operator_string (ValaUnaryExpression* self);
 static char* vala_unary_expression_real_to_string (ValaCodeNode* base);
 static gboolean vala_unary_expression_real_is_pure (ValaExpression* base);
 static gpointer vala_unary_expression_parent_class = NULL;
-static void vala_unary_expression_dispose (GObject * obj);
+static void vala_unary_expression_finalize (GObject * obj);
 
 
 
@@ -59,8 +61,8 @@ ValaUnaryExpression* vala_unary_expression_new (ValaUnaryOperator op, ValaExpres
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaUnaryExpression * self;
-	g_return_val_if_fail (_inner == NULL || VALA_IS_EXPRESSION (_inner), NULL);
-	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
+	g_return_val_if_fail (VALA_IS_EXPRESSION (_inner), NULL);
+	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (source), NULL);
 	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
 	__params_it->name = "inner";
@@ -82,17 +84,25 @@ ValaUnaryExpression* vala_unary_expression_new (ValaUnaryOperator op, ValaExpres
 static void vala_unary_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaUnaryExpression * self;
 	self = VALA_UNARY_EXPRESSION (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
-	vala_code_node_accept (VALA_CODE_NODE (vala_unary_expression_get_inner (self)), visitor);
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_unary_expression (visitor, self);
+	vala_code_visitor_visit_expression (visitor, VALA_EXPRESSION (self));
+}
+
+
+static void vala_unary_expression_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
+	ValaUnaryExpression * self;
+	self = VALA_UNARY_EXPRESSION (base);
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	vala_code_node_accept (VALA_CODE_NODE (vala_unary_expression_get_inner (self)), visitor);
 }
 
 
 static void vala_unary_expression_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node) {
 	ValaUnaryExpression * self;
 	self = VALA_UNARY_EXPRESSION (base);
-	g_return_if_fail (old_node == NULL || VALA_IS_EXPRESSION (old_node));
-	g_return_if_fail (new_node == NULL || VALA_IS_EXPRESSION (new_node));
+	g_return_if_fail (VALA_IS_EXPRESSION (old_node));
+	g_return_if_fail (VALA_IS_EXPRESSION (new_node));
 	if (vala_unary_expression_get_inner (self) == old_node) {
 		vala_unary_expression_set_inner (self, new_node);
 	}
@@ -164,6 +174,7 @@ ValaUnaryOperator vala_unary_expression_get_operator (ValaUnaryExpression* self)
 void vala_unary_expression_set_operator (ValaUnaryExpression* self, ValaUnaryOperator value) {
 	g_return_if_fail (VALA_IS_UNARY_EXPRESSION (self));
 	self->priv->_operator = value;
+	g_object_notify (((GObject *) (self)), "operator");
 }
 
 
@@ -181,6 +192,7 @@ void vala_unary_expression_set_inner (ValaUnaryExpression* self, ValaExpression*
 	_tmp1 = NULL;
 	self->priv->_inner = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL))), _tmp2);
 	vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_inner), VALA_CODE_NODE (self));
+	g_object_notify (((GObject *) (self)), "inner");
 }
 
 
@@ -223,8 +235,9 @@ static void vala_unary_expression_class_init (ValaUnaryExpressionClass * klass)
 	g_type_class_add_private (klass, sizeof (ValaUnaryExpressionPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_unary_expression_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_unary_expression_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_unary_expression_dispose;
+	G_OBJECT_CLASS (klass)->finalize = vala_unary_expression_finalize;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_unary_expression_real_accept;
+	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_unary_expression_real_accept_children;
 	VALA_CODE_NODE_CLASS (klass)->replace_expression = vala_unary_expression_real_replace_expression;
 	VALA_CODE_NODE_CLASS (klass)->to_string = vala_unary_expression_real_to_string;
 	VALA_EXPRESSION_CLASS (klass)->is_pure = vala_unary_expression_real_is_pure;
@@ -233,23 +246,23 @@ static void vala_unary_expression_class_init (ValaUnaryExpressionClass * klass)
 }
 
 
-static void vala_unary_expression_init (ValaUnaryExpression * self) {
+static void vala_unary_expression_instance_init (ValaUnaryExpression * self) {
 	self->priv = VALA_UNARY_EXPRESSION_GET_PRIVATE (self);
 }
 
 
-static void vala_unary_expression_dispose (GObject * obj) {
+static void vala_unary_expression_finalize (GObject * obj) {
 	ValaUnaryExpression * self;
 	self = VALA_UNARY_EXPRESSION (obj);
 	(self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL)));
-	G_OBJECT_CLASS (vala_unary_expression_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (vala_unary_expression_parent_class)->finalize (obj);
 }
 
 
 GType vala_unary_expression_get_type (void) {
 	static GType vala_unary_expression_type_id = 0;
-	if (G_UNLIKELY (vala_unary_expression_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaUnaryExpressionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_unary_expression_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaUnaryExpression), 0, (GInstanceInitFunc) vala_unary_expression_init };
+	if (vala_unary_expression_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (ValaUnaryExpressionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_unary_expression_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaUnaryExpression), 0, (GInstanceInitFunc) vala_unary_expression_instance_init };
 		vala_unary_expression_type_id = g_type_register_static (VALA_TYPE_EXPRESSION, "ValaUnaryExpression", &g_define_type_info, 0);
 	}
 	return vala_unary_expression_type_id;
@@ -260,7 +273,7 @@ GType vala_unary_expression_get_type (void) {
 GType vala_unary_operator_get_type (void) {
 	static GType vala_unary_operator_type_id = 0;
 	if (G_UNLIKELY (vala_unary_operator_type_id == 0)) {
-		static const GEnumValue values[] = {{VALA_UNARY_OPERATOR_PLUS, "VALA_UNARY_OPERATOR_PLUS", "plus"}, {VALA_UNARY_OPERATOR_MINUS, "VALA_UNARY_OPERATOR_MINUS", "minus"}, {VALA_UNARY_OPERATOR_LOGICAL_NEGATION, "VALA_UNARY_OPERATOR_LOGICAL_NEGATION", "logical-negation"}, {VALA_UNARY_OPERATOR_BITWISE_COMPLEMENT, "VALA_UNARY_OPERATOR_BITWISE_COMPLEMENT", "bitwise-complement"}, {VALA_UNARY_OPERATOR_INCREMENT, "VALA_UNARY_OPERATOR_INCREMENT", "increment"}, {VALA_UNARY_OPERATOR_DECREMENT, "VALA_UNARY_OPERATOR_DECREMENT", "decrement"}, {VALA_UNARY_OPERATOR_REF, "VALA_UNARY_OPERATOR_REF", "ref"}, {VALA_UNARY_OPERATOR_OUT, "VALA_UNARY_OPERATOR_OUT", "out"}, {0, NULL, NULL}};
+		static const GEnumValue values[] = {{VALA_UNARY_OPERATOR_NONE, "VALA_UNARY_OPERATOR_NONE", "none"}, {VALA_UNARY_OPERATOR_PLUS, "VALA_UNARY_OPERATOR_PLUS", "plus"}, {VALA_UNARY_OPERATOR_MINUS, "VALA_UNARY_OPERATOR_MINUS", "minus"}, {VALA_UNARY_OPERATOR_LOGICAL_NEGATION, "VALA_UNARY_OPERATOR_LOGICAL_NEGATION", "logical-negation"}, {VALA_UNARY_OPERATOR_BITWISE_COMPLEMENT, "VALA_UNARY_OPERATOR_BITWISE_COMPLEMENT", "bitwise-complement"}, {VALA_UNARY_OPERATOR_INCREMENT, "VALA_UNARY_OPERATOR_INCREMENT", "increment"}, {VALA_UNARY_OPERATOR_DECREMENT, "VALA_UNARY_OPERATOR_DECREMENT", "decrement"}, {VALA_UNARY_OPERATOR_REF, "VALA_UNARY_OPERATOR_REF", "ref"}, {VALA_UNARY_OPERATOR_OUT, "VALA_UNARY_OPERATOR_OUT", "out"}, {0, NULL, NULL}};
 		vala_unary_operator_type_id = g_enum_register_static ("ValaUnaryOperator", values);
 	}
 	return vala_unary_operator_type_id;
