@@ -42,7 +42,7 @@ enum  {
 static ValaDataType* vala_unresolved_type_real_copy (ValaDataType* base);
 static char* vala_unresolved_type_real_to_qualified_string (ValaDataType* base, ValaScope* scope);
 static gpointer vala_unresolved_type_parent_class = NULL;
-static void vala_unresolved_type_dispose (GObject * obj);
+static void vala_unresolved_type_finalize (GObject * obj);
 
 
 
@@ -202,6 +202,7 @@ void vala_unresolved_type_set_unresolved_symbol (ValaUnresolvedType* self, ValaU
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_unresolved_symbol = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_unresolved_symbol == NULL ? NULL : (self->priv->_unresolved_symbol = (g_object_unref (self->priv->_unresolved_symbol), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "unresolved-symbol");
 }
 
 
@@ -238,7 +239,7 @@ static void vala_unresolved_type_class_init (ValaUnresolvedTypeClass * klass) {
 	g_type_class_add_private (klass, sizeof (ValaUnresolvedTypePrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_unresolved_type_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_unresolved_type_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_unresolved_type_dispose;
+	G_OBJECT_CLASS (klass)->finalize = vala_unresolved_type_finalize;
 	VALA_DATA_TYPE_CLASS (klass)->copy = vala_unresolved_type_real_copy;
 	VALA_DATA_TYPE_CLASS (klass)->to_qualified_string = vala_unresolved_type_real_to_qualified_string;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_UNRESOLVED_TYPE_UNRESOLVED_SYMBOL, g_param_spec_object ("unresolved-symbol", "unresolved-symbol", "unresolved-symbol", VALA_TYPE_UNRESOLVED_SYMBOL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
@@ -250,17 +251,17 @@ static void vala_unresolved_type_instance_init (ValaUnresolvedType * self) {
 }
 
 
-static void vala_unresolved_type_dispose (GObject * obj) {
+static void vala_unresolved_type_finalize (GObject * obj) {
 	ValaUnresolvedType * self;
 	self = VALA_UNRESOLVED_TYPE (obj);
 	(self->priv->_unresolved_symbol == NULL ? NULL : (self->priv->_unresolved_symbol = (g_object_unref (self->priv->_unresolved_symbol), NULL)));
-	G_OBJECT_CLASS (vala_unresolved_type_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (vala_unresolved_type_parent_class)->finalize (obj);
 }
 
 
 GType vala_unresolved_type_get_type (void) {
 	static GType vala_unresolved_type_type_id = 0;
-	if (G_UNLIKELY (vala_unresolved_type_type_id == 0)) {
+	if (vala_unresolved_type_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaUnresolvedTypeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_unresolved_type_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaUnresolvedType), 0, (GInstanceInitFunc) vala_unresolved_type_instance_init };
 		vala_unresolved_type_type_id = g_type_register_static (VALA_TYPE_DATA_TYPE, "ValaUnresolvedType", &g_define_type_info, 0);
 	}
